(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    900120,      28150]*)
(*NotebookOutlinePosition[   1118353,      33309]*)
(*  CellTagsIndexPosition[   1116536,      33260]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{"Disclaimer", "LoanFunctions"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->{"Disclaimer", "LoanFunctions"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"Disclaimer", "LoanFunctions"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"Disclaimer", "LoanFunctions"}],

Cell[CellGroupData[{

Cell["Disclaimer", "Section",
  CellTags->{"Disclaimer", "LoanFunctions"}],

Cell["\<\
LoanFunctions.m is a package containing functions that help in \
calculations of certain loan costs: for estimating home purchase costs and \
performing other loan calculations. Its original intent was to provide \
functions that perform cost calculations for the purchase of a single family \
home; however, the functions are somewhat more general than that and can \
therefore be used in a variety of other situations.

WARNING: The author is not liable for any errors or omissions. For your \
decisions you should contact a finance professional for professional advice \
and to obtain the actual information that you use in your decision making \
process. The intent of this package is to provide some simple tools for \
making initial estimates, for creatively exploring options, and as a starting \
point for the creation of functions tailored to an individual's specific \
needs. 

THE AUTHOR, DAVID REISS SHALL NOT BE RESPONSIBLE UNDER ANY CIRCUMSTANCES FOR \
PROVIDING INFORMATION ON OR CORRECTIONS TO ERRORS AND OMISSIONS DISCOVERED AT \
ANY TIME IN LOANFUNCTIONS.M OR ITS ASSOCIATED DOCUMENTATION, WHETHER OR NOT \
HE IS AWARE OF THE ERRORS OR OMISSIONS. THE AUTHOR DOES NOT RECOMMEND THE USE \
OF LOANFUNCTIONS.M OR ITS ASSOCIATED DOCUMENTATION FOR APPLICATIONS IN WHICH \
ERRORS OR OMISSIONS COULD THREATEN LIFE, INJURY OR SIGNIFICANT LOSS.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"LoanFunctions", "Disclaimer"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[CellGroupData[{

Cell["LoanFunctions.m Introduction", "Section",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[CellGroupData[{

Cell["Installing the Package", "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "To install the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package place the folder ",
  StyleBox["LoanFunctions", "MR"],
  " within the ",
  StyleBox["AddOns\[RightTriangle]Applications", "SR"],
  " subdirectory of your main ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory. After you have done this, start ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (if it has already been started, quit it first and restart) and then \
choose the ",
  StyleBox["Help\[RightTriangle]Rebuild Help Index", "SR"],
  " menu item.  In the Help Browser you will now have access to the \
documentation for the ",
  StyleBox["LoanFunctions.m", "MR"],
  "  package under the ",
  StyleBox["AddOns", "SR"],
  " category. To be able to use the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package you will need a password."
}], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Referralware", "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "This package is \"referralware\": if the package is of use to you then you \
are requested to suggest the services of ",
  ButtonBox["Scientific Arts",
    ButtonData:>{
      URL[ "http://www.scientificarts.com"], None},
    ButtonStyle->"Hyperlink"],
  " to friends and colleagues and to pass on potential contacts to ",
  StyleBox["Scientific Arts",
    FontSlant->"Italic"],
  ". In this case ",
  StyleBox["Scientific Arts",
    FontSlant->"Italic"],
  " provides you with a single user license for this software in return for \
the help that you can give in helping our business to succeed."
}], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Password", "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "To use the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package you need a password. When you first try to load the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package you will be prompted for a password. A password can be obtained \
by sending email to ",
  StyleBox["loanpassword@scientificarts.com",
    FontColor->RGBColor[0.6, 0, 0]],
  ". The password will allow you to use the package with a single license of \
Mathematica. Your email address will not be used for any other purpose than \
to send you the password and an associated message. You will not be contacted \
further unless you request it. Your email should contain your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  License ID. You can find out what your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " License ID is by executing ",
  StyleBox["$LicenseID", "MR"],
  " from within a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. (Note that your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " License ID is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the same as your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " password and we do not request your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " password. Your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " License ID stays the same even if you upgrade ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to a new version. Your ",
  StyleBox["LoanFunctions.m", "MR"],
  " password therefore will still be valid should you upgrade to a newer \
version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".)  Once you have obtained your password it should be pasted into the \
dialogue box that prompts you for a password when the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package is first loaded. The password only needs to be entered once and \
will automatically be placed in a file named ",
  StyleBox["LFPassword.m", "MR"],
  " located in the ",
  StyleBox["AddOns\[RightTriangle]Applications\[RightTriangle]LoanFunctions", 
    "SR"],
  " subdirectory of your main ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory (assuming that you have installed the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package as per the instructions in the preceding section). (Alternatively \
you can create a file named ",
  StyleBox["LFPassword.m", "MR"],
  " from within a text editor place the password in it and place it in the ",
  StyleBox["AddOns\[RightTriangle]Applications\[RightTriangle]LoanFunctions", 
    "SR"],
  " subdirectory of your main ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory). Once you have entered the password the ",
  StyleBox["LoanFunctions.m", "MR"],
  "  package will be operational."
}], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading the Package", "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "If you have installed the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package and obtained a password according to the instructions in the \
previous two sections you can now load the package."
}], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "This gives the ",
  StyleBox["$LoanFunctionsPackageVersion", "MR"],
  " of the current package."
}], "MathCaption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[CellGroupData[{

Cell[BoxData["$LoanFunctionsPackageVersion"], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[BoxData["\<\"1.1\"\>"], "Output",
  CellLabel->"Out[2]=",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[TextData[{
  "Here is a listing of all of the exported functions, options, and \
parameters from the ",
  StyleBox["LoanFunctions", "MR"],
  StyleBox[".m", "MR"],
  " package:"
}], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            StyleBox["\<\"ActualPayment\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"AmortizationReport\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"CalculationBasis\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"Current\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"DownPayment\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"EffectivePayment\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"Equity\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"EquityCalculator\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"EquityTargetPayment\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"HomeCost\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"HomeValue\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"HomeValueCalculator\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"LoanAmount\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"LoanFunctions\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"Original\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"Payment\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"PaymentCalculator\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"PaymentNumberToYears\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"PaymentsRemaining\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"PaymentsRemainingCalculator\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"PaymentToInterest\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"PaymentToPrincipal\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"PercentageDownPayment\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"Principal\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"PrincipalCalculator\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"ResetLoanFunctionsDefaults\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"SetErrorChecking\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"TemporarySetPaymentsPerYear\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"TotalInterestPaid\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"TotalPayments\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"TotalPaymentsCalculator\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"TotalPrincipalPaid\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"YearsToPaymentNumber\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"$CalculatorBackgroundColor\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"$EquityFindRootStart\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"$ErrorChecking\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"$LoanFunctionsPackageVersion\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\"$PaymentsPerYear\"\>",
              FontFamily->"Times",
              FontSize->10]},
          {
            StyleBox["\<\"$StrongErrorChecking\"\>",
              FontFamily->"Times",
              FontSize->10], 
            StyleBox["\<\" \"\>",
              FontFamily->"Times",
              FontSize->10]}
          },
        ColumnAlignments->{Left},
        GridFrame->True],
      DisplayForm]], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "Listing of all of the exported functions, options, and parameters from ",
  StyleBox["LoanFunctions.m", "MR"]
}], "Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "By clicking on the following button you will generate a notebook \
containing all of the usage messages for the functions in the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package (",
  StyleBox["note:",
    FontWeight->"Bold"],
  " for this to work you need to have loaded the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package first -- if you haven't done this and you accidentally click on \
the button you will have to restart the kernel in order for the functions to \
be available). When you have done this you can print out the resulting \
notebook to use as a quick reference."
}], "MathCaption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[BoxData[
    ButtonBox["\<\"Generate Usage Notebook\"\>",
      ButtonFunction:>(
        Module[ {SciArtsUtilities`SciArtsUtilities`Private`nb$}, 
          CompoundExpression[ 
            Off[ 
              MessageName[ Message, "name"]], 
            Set[ SciArtsUtilities`SciArtsUtilities`Private`nb$, 
              NotebookPut[ 
                Notebook[ 
                  Flatten[ 
                    Map[ 
                      Function[ 
                      SciArtsUtilities`SciArtsUtilities`Private`z$, {
                        Cell[ 
                        SciArtsUtilities`SciArtsUtilities`Private`z$, 
                          "Subsection", CellTags -> ToString[ 
                            Unevaluated[ 
                            SciArtsUtilities`SciArtsUtilities`Private`z$]]], 
                        Cell[ 
                          Function[ 
                          SciArtsUtilities`SciArtsUtilities`Private`w, 
                            ReleaseHold[ 
                              MessageName[ 
                              SciArtsUtilities`SciArtsUtilities`Private`w, 
                                "usage"]]][ 
                            ToHeldExpression[ 
                            SciArtsUtilities`SciArtsUtilities`Private`z$]], 
                          "DefinitionBox", CellTags -> ToString[ 
                            Unevaluated[ 
                            SciArtsUtilities`SciArtsUtilities`Private`z$]]], 
                        Cell[ 
                          TextData[ {"Usage message for ", 
                            StyleBox[ 
                              ToString[ 
                                Unevaluated[ 
                                SciArtsUtilities`SciArtsUtilities`Private`z$]]\
, "MR"]}], "Caption", CellTags -> ToString[ 
                            Unevaluated[ 
                            SciArtsUtilities`SciArtsUtilities`Private`z$]]]}],
                       
                      Names[ 
                        StringJoin[ "LoanFunctions`LoanFunctions`", "*"]]]], 
                  StyleDefinitions -> "HelpBrowser.nb", WindowTitle -> 
                  "LoanFunctions.m Usage Messages"]]], 
            On[ 
              MessageName[ Message, "name"]], 
            SciArtsUtilities`SciArtsUtilities`Private`nb$]]&),
      ButtonEvaluator->Automatic,
      Active->True]], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contents of this Package", "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["\<\
LoanFunctions.m is a package containing functions that help in \
calculations of certain loan costs: for estimating home purchase costs and \
performing other loan calculations. Its original intent was to provide \
functions that perform cost calculations for the purchase of a single family \
home; however, the functions are somewhat more general than that and can \
therefore be used in a variety of other situations. \
\>", "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "The assumptions used in this package are that the payment periods are \
equal in length and that interest is compounded once per payment period at \
the end of that period. If you are making payments on a loan that, for \
example,  is compounded once per month based on the ",
  StyleBox["number of days in that month",
    FontSlant->"Italic"],
  " then the functions in this package will give results that are slightly \
different than those that correspond to such a circumstance."
}], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["\<\
LoanFunctions.m is a package containing functions that help in \
calculations of certain loan costs: for estimating home purchase costs and \
performing other loan calculations. Its original intent was to provide \
functions that perform cost calculations for the purchase of a single family \
home; however, the functions are somewhat more general than that and can \
therefore be used in a variety of other situations.

WARNING: The author is not liable for any errors or omissions. For your \
decisions you should contact a finance professional for professional advice \
and to obtain the actual information that you use in your decision making \
process. The intent of this package is to provide some simple tools for \
making initial estimates, for creatively exploring options, and as a starting \
point for the creation of functions tailored to an individual's specific \
needs. 

THE AUTHOR, DAVID REISS SHALL NOT BE RESPONSIBLE UNDER ANY CIRCUMSTANCES FOR \
PROVIDING INFORMATION ON OR CORRECTIONS TO ERRORS AND OMISSIONS DISCOVERED AT \
ANY TIME IN LOANFUNCTIONS.M OR ITS ASSOCIATED DOCUMENTATION, WHETHER OR NOT \
HE IS AWARE OF THE ERRORS OR OMISSIONS. THE AUTHOR DOES NOT RECOMMEND THE USE \
OF LOANFUNCTIONS.M OR ITS ASSOCIATED DOCUMENTATION FOR APPLICATIONS IN WHICH \
ERRORS OR OMISSIONS COULD THREATEN LIFE, INJURY OR SIGNIFICANT LOSS.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["\<\
This documentation lists all of the functions in this package and \
gives some examples of the use of each.\
\>", "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "The graphics in this documentation are generated with the following \
settings for the ",
  StyleBox["Plot", "MR"],
  " and ",
  StyleBox["ListPlot", "MR"],
  "."
}], "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[BoxData[{
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Plot", ",", " ", 
          RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
          RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"RGBColor", "[", 
                  RowBox[{".6", ",", " ", "0", ",", " ", "0"}], "]"}], ",", 
                RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}]}], 
        " ", "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"ListPlot", ",", " ", 
          RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
          RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", 
          RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"RGBColor", "[", 
                  RowBox[{".6", ",", " ", "0", ",", " ", "0"}], "]"}], ",", 
                RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}]}], 
        "]"}], ";"}]}], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell["$PaymentsPerYear", "Section",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "The parameter ",
  StyleBox["$PaymentsPerYear", "MR"],
  " fixes the number of loan payments per year. Interest is compounded once \
per payment period a the end of the period."
}], "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell["\<\
$PaymentsPerYear is a variable that gives the number of mortgage \
payments in a year. Its default value is 12.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["$PaymentsPerYear", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["$PaymentsPerYear", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData[
    RowBox[{"{", "ReadProtected", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["$PaymentsPerYear", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "If you change the value for ",
  StyleBox["$PaymentsPerYear", "MR"],
  " its effect is global: all calculations the package will make use of the \
new value. "
}], "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "This is the default value for ",
  StyleBox["$PaymentsPerYear", "MR"],
  "."
}], "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData["$PaymentsPerYear"], "Input",
  CellLabel->"In[2]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData["12"], "Output",
  CellLabel->"Out[2]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],

Cell["\<\
This is the monthly payment on a 15 year fixed rate mortgage on a \
mythical $100000 home with 15% down at 7.2% interest per year.\
\>", \
"MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", "7.2", ",", 
        " ", "15"}], "]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData["773.5397284256978`"], "Output",
  CellLabel->"Out[3]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],

Cell["\<\
Now increase the number payments so that there are twice as many.\
\
\>", "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"$PaymentsPerYear", "=", "24"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData["24"], "Output",
  CellLabel->"Out[4]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],

Cell["\<\
Now there are twice as many payments each at slightly less than \
half the previous value.\
\>", "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", "7.2", ",", 
        " ", "15"}], "]"}]], "Input",
  CellLabel->"In[5]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData["386.4485476913902927606442529523`12.9972"], "Output",
  CellLabel->"Out[5]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],

Cell["\<\
ResetLoanFunctionsDefaults[] resets the default values of the \
package parameters to what they were when the package was first loaded.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["ResetLoanFunctionsDefaults", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["ResetLoanFunctionsDefaults", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["ResetLoanFunctionsDefaults", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],

Cell["Reset the defaults.", "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData[
    RowBox[{"ResetLoanFunctionsDefaults", "[", "]"}]], "Input",
  CellLabel->"In[7]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData["$PaymentsPerYear"], "Input",
  CellLabel->"In[8]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData["12"], "Output",
  CellLabel->"Out[8]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],

Cell[TextData[{
  "You can use the ",
  StyleBox["Block", "MR"],
  " construct to temporarily set the value of ",
  StyleBox["$PaymentsPerYear", "MR"],
  " to something else."
}], "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell["\<\
This compares twice the payment for 24 payments in a year to the \
monthly payment when there are exactly 12 payments in a year. The fraction of \
a dollar that is saved can be used as a down payment on a cup of \
coffee.\
\>", "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"2", 
          RowBox[{"Block", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"$PaymentsPerYear", "=", "24"}], "}"}], ",", 
              RowBox[{"Payment", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", 
                  "7.2", ",", " ", "15"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"Payment", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", "7.2", ",",
             " ", "15"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[9]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "772.8970953827805855212885059047`12.9972", ",", "773.5397284256978`"}],
       "}"}]], "Output",
  CellLabel->"Out[9]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],

Cell[TextData[{
  "There is a function that does this automatically  called ",
  StyleBox["TemporarySetPaymentsPerYear", "MR"]
}], "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell["\<\
TemporarySetPaymentsPerYear[n, function] evaluates function with \
$PaymentsPerYear temporarily set to the integer n. The global value of \
$PaymentsPerYear is not changed.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["TemporarySetPaymentsPerYear", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["TemporarySetPaymentsPerYear", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "HoldAll", ",", "Locked", ",", "NHoldAll", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["TemporarySetPaymentsPerYear", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[{
  "This computes the payment for 24 payments per year (without changing the \
global value of ",
  StyleBox["$PaymentsPerYear", "MR"],
  ")."
}], "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TemporarySetPaymentsPerYear", "[", 
      RowBox[{"24", ",", " ", 
        RowBox[{"Payment", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", "7.2", ",",
             " ", "15"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[11]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData["386.4485476913902927606442529523`12.9972"], "Output",
  CellLabel->"Out[11]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],

Cell[TextData[{
  StyleBox["$PaymentsPerYear", "MR"],
  " still has its default value."
}], "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{

Cell[BoxData["$PaymentsPerYear"], "Input",
  CellLabel->"In[12]:=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[BoxData["12"], "Output",
  CellLabel->"Out[12]=",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"HomeCost"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"HomeCost"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"HomeCost"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"HomeCost"],

Cell[CellGroupData[{

Cell["HomeCost", "Section",
  CellTags->"HomeCost"],

Cell[TextData[{
  StyleBox["HomeCost", "MR"],
  " is a very simple function."
}], "Text",
  CellTags->"HomeCost"],

Cell["\<\
HomeCost[LoanAmount, PercentageDownPayment] gives the cost of a \
home when a loan is taken out in the amount of LoanAmount and a down payment \
is put down corresponding to a percentage of the house cost corresponding to \
PercentageDownPayment.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeCost"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["HomeCost", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeCost"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeCost"],

Cell[TextData[{
  "Default options for ",
  StyleBox["HomeCost", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeCost"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeCost"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["HomeCost", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeCost"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"HomeCost"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"HomeCost"],

Cell[TextData[{
  StyleBox["HomeCost", "MR"],
  " corresponds to a very simple analytic expression."
}], "MathCaption",
  CellTags->"HomeCost"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HomeCost", "[", 
      RowBox[{"\[Lambda]", ",", " ", "p"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"HomeCost"],

Cell[BoxData[
    FractionBox["\[Lambda]", 
      RowBox[{"1", "-", 
        FractionBox["p", "100"]}]]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"HomeCost"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"LoanAmount"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"LoanAmount"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"LoanAmount"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"LoanAmount"],

Cell[CellGroupData[{

Cell["LoanAmount", "Section",
  CellTags->"LoanAmount"],

Cell[TextData[{
  StyleBox["LoanAmount", "MR"],
  " is a very simple function."
}], "Text",
  CellTags->"LoanAmount"],

Cell["\<\
LoanAmount[HomeCost, PercentageDownPayment] gives the amount of a \
Loan needed for a home of cost HomeCost where the percentage down payment is \
given by PercentageDownPayment.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LoanAmount"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["LoanAmount", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LoanAmount"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LoanAmount"],

Cell[TextData[{
  "Default options for ",
  StyleBox["LoanAmount", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LoanAmount"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LoanAmount"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["LoanAmount", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LoanAmount"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"LoanAmount"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"LoanAmount"],

Cell[TextData[{
  StyleBox["LoanAmount", "MR"],
  " corresponds to a very simple analytic expression."
}], "MathCaption",
  CellTags->"LoanAmount"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LoanAmount", "[", 
      RowBox[{"h", ",", " ", "p"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"LoanAmount"],

Cell[BoxData[
    RowBox[{"h", " ", 
      RowBox[{"(", 
        RowBox[{"1", "-", 
          FractionBox["p", "100"]}], ")"}]}]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"LoanAmount"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"DownPayment"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"DownPayment"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"DownPayment"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"DownPayment"],

Cell[CellGroupData[{

Cell["DownPayment", "Section",
  CellTags->"DownPayment"],

Cell[TextData[{
  StyleBox["DownPayment", "MR"],
  " is a simple function."
}], "Text",
  CellTags->"DownPayment"],

Cell["\<\
DownPayment[HomeCost, PercentageDownPayment] gives the amount of a \
down payment for a home of cost HomeCost where the percentage down payment is \
given by PercentageDownPayment.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DownPayment"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["DownPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DownPayment"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DownPayment"],

Cell[TextData[{
  "Default options for ",
  StyleBox["DownPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DownPayment"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DownPayment"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["DownPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DownPayment"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"DownPayment"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"DownPayment"],

Cell[TextData[{
  "The analytic expression for ",
  StyleBox["DownPayment", "MR"],
  " is very simple."
}], "MathCaption",
  CellTags->"DownPayment"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DownPayment", "[", 
      RowBox[{"h", ",", " ", "p"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"DownPayment"],

Cell[BoxData[
    FractionBox[
      RowBox[{"h", " ", "p"}], "100"]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"DownPayment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"PercentageDownPayment"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"PercentageDownPayment"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PercentageDownPayment"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PercentageDownPayment"],

Cell[CellGroupData[{

Cell["PercentageDownPayment", "Section",
  CellTags->"PercentageDownPayment"],

Cell[TextData[{
  StyleBox["PercentageDownPayment", "MR"],
  " is a simple function."
}], "Text",
  CellTags->"PercentageDownPayment"],

Cell["\<\
PercentageDownPayment[HomeCost, LoanAmount] gives the percentage of \
the house cost needed to for a down payment on a house of cost HomeCost when \
taking a loan of size LoanAmount.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PercentageDownPayment"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PercentageDownPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PercentageDownPayment"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PercentageDownPayment"],

Cell[TextData[{
  "Default options for ",
  StyleBox["PercentageDownPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PercentageDownPayment"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PercentageDownPayment"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PercentageDownPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PercentageDownPayment"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"PercentageDownPayment"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"PercentageDownPayment"],

Cell[TextData[{
  "The analytic expression for ",
  StyleBox["PercentageDownPayment", "MR"],
  " is very simple."
}], "MathCaption",
  CellTags->"PercentageDownPayment"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PercentageDownPayment", "[", 
      RowBox[{"h", ",", " ", "\[Lambda]"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"PercentageDownPayment"],

Cell[BoxData[
    FractionBox[
      RowBox[{"100", " ", 
        RowBox[{"(", 
          RowBox[{"h", "-", "\[Lambda]"}], ")"}]}], "h"]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"PercentageDownPayment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"Payment"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"Payment"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Payment"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Payment"],

Cell[CellGroupData[{

Cell["Payment", "Section",
  CellTags->"Payment"],

Cell[TextData[{
  StyleBox["Payment", "MR"],
  " computes the payment due at each payment interval (for ",
  StyleBox["$PaymentsPerYear", "MR"],
  " payments per year) for both fixed and variable rate mortgages."
}], "Text",
  CellTags->"Payment"],

Cell["\<\
Payment[{HomeCost, PercentageDownPayment}, InterestRate, Years] \
uses the home cost and the percentage down payment as inputs (and calculates \
the loan amount from HomeCost(1-PercentageDownPayment). 

Payment[LoanAmount, InterestRate, Years] gives the payments (for principal \
and interest) on a loan of size LoanAmount at an interest rate of \
InterestRate (expressed as a percentage) amortized over a number of years \
given by Years. The number of payments per year is given by $PaymentsPerYear. \


Payment[{HomeCost, PercentageDownPayment}, {{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber] calculates the payment for a variable rate loan with interest \
rate InterestRate1 for a number of payments given by Payments1 followed by \
InterestRate2 for a number of payments given by Payments2, and so on. Note \
that PaymentNumber must be given. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. 

Payment[LoanAmount, {{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, Years, PaymentNumber] is also a \
valid input. If PaymentNumber is not numerical then an analytical result will \
be returned (if $StrongErrorChecking is not True) that assumes that \
PaymentNumber is greater than Payments1+Payments2+...+Payments(M-1).\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Payment"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["Payment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Payment"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Payment"],

Cell[TextData[{
  "Default options for ",
  StyleBox["Payment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Payment"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Payment"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["Payment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Payment"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"Payment"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Payment"],

Cell["\<\
Here is the monthly payment  on a $100000 loan at 7% for 30 \
years.\
\>", "MathCaption",
  CellTags->"Payment"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{"100000", ",", " ", "7.0", ",", " ", "30"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Payment"],

Cell[BoxData["665.302495179182302681527521`13.0672"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"Payment"]
}, Open  ]],

Cell["\<\
This is an interest rate table that corresponds to an initial \
interest rate of 6% which increases by 0.25% increments every 3 years for 21 \
years and then remains constant.\
\>", "MathCaption",
  CellTags->"Payment"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"interestRateTable", "=", 
      RowBox[{"Table", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"6", " ", "+", 
                RowBox[{"0.25", " ", "i"}]}], ",", "36"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Payment"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"6", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.25`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.5`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.75`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.25`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.5`", ",", "36"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"Payment"]
}, Open  ]],

Cell["\<\
Here a plot of the payment versus the payment number over the \
course of the full 30 years.\
\>", "MathCaption",
  CellTags->"Payment"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ListPlot", "[", 
        RowBox[{"Table", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"i", ",", 
                RowBox[{"Payment", "[", 
                  RowBox[{
                  "100000", ",", "interestRateTable", ",", " ", "30", ",", 
                    "i"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "360"}], "}"}]}], "]"}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Payment"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 -4.85227 0.00811772 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01836 -18 -4.5 ]
[-0.0125 .01836 0 4.5 ]
[-0.0125 .09954 -18 -4.5 ]
[-0.0125 .09954 0 4.5 ]
[-0.0125 .18072 -18 -4.5 ]
[-0.0125 .18072 0 4.5 ]
[-0.0125 .2619 -18 -4.5 ]
[-0.0125 .2619 0 4.5 ]
[-0.0125 .34307 -18 -4.5 ]
[-0.0125 .34307 0 4.5 ]
[-0.0125 .42425 -18 -4.5 ]
[-0.0125 .42425 0 4.5 ]
[-0.0125 .50543 -18 -4.5 ]
[-0.0125 .50543 0 4.5 ]
[-0.0125 .5866 -18 -4.5 ]
[-0.0125 .5866 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01836 m
.00625 .01836 L
s
[(600)] -0.0125 .01836 1 0 Mshowa
0 .09954 m
.00625 .09954 L
s
[(610)] -0.0125 .09954 1 0 Mshowa
0 .18072 m
.00625 .18072 L
s
[(620)] -0.0125 .18072 1 0 Mshowa
0 .2619 m
.00625 .2619 L
s
[(630)] -0.0125 .2619 1 0 Mshowa
0 .34307 m
.00625 .34307 L
s
[(640)] -0.0125 .34307 1 0 Mshowa
0 .42425 m
.00625 .42425 L
s
[(650)] -0.0125 .42425 1 0 Mshowa
0 .50543 m
.00625 .50543 L
s
[(660)] -0.0125 .50543 1 0 Mshowa
0 .5866 m
.00625 .5866 L
s
[(670)] -0.0125 .5866 1 0 Mshowa
.125 Mabswid
0 .0346 m
.00375 .0346 L
s
0 .05083 m
.00375 .05083 L
s
0 .06707 m
.00375 .06707 L
s
0 .08331 m
.00375 .08331 L
s
0 .11578 m
.00375 .11578 L
s
0 .13201 m
.00375 .13201 L
s
0 .14825 m
.00375 .14825 L
s
0 .16448 m
.00375 .16448 L
s
0 .19695 m
.00375 .19695 L
s
0 .21319 m
.00375 .21319 L
s
0 .22942 m
.00375 .22942 L
s
0 .24566 m
.00375 .24566 L
s
0 .27813 m
.00375 .27813 L
s
0 .29437 m
.00375 .29437 L
s
0 .3106 m
.00375 .3106 L
s
0 .32684 m
.00375 .32684 L
s
0 .35931 m
.00375 .35931 L
s
0 .37554 m
.00375 .37554 L
s
0 .39178 m
.00375 .39178 L
s
0 .40801 m
.00375 .40801 L
s
0 .44049 m
.00375 .44049 L
s
0 .45672 m
.00375 .45672 L
s
0 .47296 m
.00375 .47296 L
s
0 .48919 m
.00375 .48919 L
s
0 .52166 m
.00375 .52166 L
s
0 .5379 m
.00375 .5379 L
s
0 .55413 m
.00375 .55413 L
s
0 .57037 m
.00375 .57037 L
s
0 .00213 m
.00375 .00213 L
s
0 .60284 m
.00375 .60284 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01836 m
1 .01836 L
s
.99375 .09954 m
1 .09954 L
s
.99375 .18072 m
1 .18072 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .34307 m
1 .34307 L
s
.99375 .42425 m
1 .42425 L
s
.99375 .50543 m
1 .50543 L
s
.99375 .5866 m
1 .5866 L
s
.125 Mabswid
.99625 .0346 m
1 .0346 L
s
.99625 .05083 m
1 .05083 L
s
.99625 .06707 m
1 .06707 L
s
.99625 .08331 m
1 .08331 L
s
.99625 .11578 m
1 .11578 L
s
.99625 .13201 m
1 .13201 L
s
.99625 .14825 m
1 .14825 L
s
.99625 .16448 m
1 .16448 L
s
.99625 .19695 m
1 .19695 L
s
.99625 .21319 m
1 .21319 L
s
.99625 .22942 m
1 .22942 L
s
.99625 .24566 m
1 .24566 L
s
.99625 .27813 m
1 .27813 L
s
.99625 .29437 m
1 .29437 L
s
.99625 .3106 m
1 .3106 L
s
.99625 .32684 m
1 .32684 L
s
.99625 .35931 m
1 .35931 L
s
.99625 .37554 m
1 .37554 L
s
.99625 .39178 m
1 .39178 L
s
.99625 .40801 m
1 .40801 L
s
.99625 .44049 m
1 .44049 L
s
.99625 .45672 m
1 .45672 L
s
.99625 .47296 m
1 .47296 L
s
.99625 .48919 m
1 .48919 L
s
.99625 .52166 m
1 .52166 L
s
.99625 .5379 m
1 .5379 L
s
.99625 .55413 m
1 .55413 L
s
.99625 .57037 m
1 .57037 L
s
.99625 .00213 m
1 .00213 L
s
.99625 .60284 m
1 .60284 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02646 .01472 m
.0291 .01472 L
.03175 .01472 L
.03439 .01472 L
.03704 .01472 L
.03968 .01472 L
.04233 .01472 L
.04497 .01472 L
.04762 .01472 L
.05026 .01472 L
.05291 .01472 L
.05556 .01472 L
.0582 .01472 L
.06085 .01472 L
.06349 .01472 L
.06614 .01472 L
.06878 .01472 L
.07143 .01472 L
.07407 .01472 L
.07672 .01472 L
.07937 .01472 L
.08201 .01472 L
.08466 .01472 L
.0873 .01472 L
.08995 .01472 L
.09259 .01472 L
.09524 .01472 L
.09788 .01472 L
.10053 .01472 L
.10317 .01472 L
.10582 .01472 L
.10847 .01472 L
.11111 .01472 L
.11376 .01472 L
.1164 .01472 L
.11905 .01472 L
.12169 .13715 L
.12434 .13715 L
.12698 .13715 L
.12963 .13715 L
.13228 .13715 L
.13492 .13715 L
.13757 .13715 L
.14021 .13715 L
.14286 .13715 L
.1455 .13715 L
.14815 .13715 L
.15079 .13715 L
.15344 .13715 L
.15608 .13715 L
Mistroke
.15873 .13715 L
.16138 .13715 L
.16402 .13715 L
.16667 .13715 L
.16931 .13715 L
.17196 .13715 L
.1746 .13715 L
.17725 .13715 L
.17989 .13715 L
.18254 .13715 L
.18519 .13715 L
.18783 .13715 L
.19048 .13715 L
.19312 .13715 L
.19577 .13715 L
.19841 .13715 L
.20106 .13715 L
.2037 .13715 L
.20635 .13715 L
.20899 .13715 L
.21164 .13715 L
.21429 .13715 L
.21693 .25137 L
.21958 .25137 L
.22222 .25137 L
.22487 .25137 L
.22751 .25137 L
.23016 .25137 L
.2328 .25137 L
.23545 .25137 L
.2381 .25137 L
.24074 .25137 L
.24339 .25137 L
.24603 .25137 L
.24868 .25137 L
.25132 .25137 L
.25397 .25137 L
.25661 .25137 L
.25926 .25137 L
.2619 .25137 L
.26455 .25137 L
.2672 .25137 L
.26984 .25137 L
.27249 .25137 L
.27513 .25137 L
.27778 .25137 L
.28042 .25137 L
.28307 .25137 L
.28571 .25137 L
.28836 .25137 L
Mistroke
.29101 .25137 L
.29365 .25137 L
.2963 .25137 L
.29894 .25137 L
.30159 .25137 L
.30423 .25137 L
.30688 .25137 L
.30952 .25137 L
.31217 .35633 L
.31481 .35633 L
.31746 .35633 L
.32011 .35633 L
.32275 .35633 L
.3254 .35633 L
.32804 .35633 L
.33069 .35633 L
.33333 .35633 L
.33598 .35633 L
.33862 .35633 L
.34127 .35633 L
.34392 .35633 L
.34656 .35633 L
.34921 .35633 L
.35185 .35633 L
.3545 .35633 L
.35714 .35633 L
.35979 .35633 L
.36243 .35633 L
.36508 .35633 L
.36772 .35633 L
.37037 .35633 L
.37302 .35633 L
.37566 .35633 L
.37831 .35633 L
.38095 .35633 L
.3836 .35633 L
.38624 .35633 L
.38889 .35633 L
.39153 .35633 L
.39418 .35633 L
.39683 .35633 L
.39947 .35633 L
.40212 .35633 L
.40476 .35633 L
.40741 .45087 L
.41005 .45087 L
.4127 .45087 L
.41534 .45087 L
.41799 .45087 L
.42063 .45087 L
Mistroke
.42328 .45087 L
.42593 .45087 L
.42857 .45087 L
.43122 .45087 L
.43386 .45087 L
.43651 .45087 L
.43915 .45087 L
.4418 .45087 L
.44444 .45087 L
.44709 .45087 L
.44974 .45087 L
.45238 .45087 L
.45503 .45087 L
.45767 .45087 L
.46032 .45087 L
.46296 .45087 L
.46561 .45087 L
.46825 .45087 L
.4709 .45087 L
.47354 .45087 L
.47619 .45087 L
.47884 .45087 L
.48148 .45087 L
.48413 .45087 L
.48677 .45087 L
.48942 .45087 L
.49206 .45087 L
.49471 .45087 L
.49735 .45087 L
.5 .45087 L
.50265 .53368 L
.50529 .53368 L
.50794 .53368 L
.51058 .53368 L
.51323 .53368 L
.51587 .53368 L
.51852 .53368 L
.52116 .53368 L
.52381 .53368 L
.52646 .53368 L
.5291 .53368 L
.53175 .53368 L
.53439 .53368 L
.53704 .53368 L
.53968 .53368 L
.54233 .53368 L
.54497 .53368 L
.54762 .53368 L
.55026 .53368 L
.55291 .53368 L
Mistroke
.55556 .53368 L
.5582 .53368 L
.56085 .53368 L
.56349 .53368 L
.56614 .53368 L
.56878 .53368 L
.57143 .53368 L
.57407 .53368 L
.57672 .53368 L
.57937 .53368 L
.58201 .53368 L
.58466 .53368 L
.5873 .53368 L
.58995 .53368 L
.59259 .53368 L
.59524 .53368 L
.59788 .60332 L
.60053 .60332 L
.60317 .60332 L
.60582 .60332 L
.60847 .60332 L
.61111 .60332 L
.61376 .60332 L
.6164 .60332 L
.61905 .60332 L
.62169 .60332 L
.62434 .60332 L
.62698 .60332 L
.62963 .60332 L
.63228 .60332 L
.63492 .60332 L
.63757 .60332 L
.64021 .60332 L
.64286 .60332 L
.6455 .60332 L
.64815 .60332 L
.65079 .60332 L
.65344 .60332 L
.65608 .60332 L
.65873 .60332 L
.66138 .60332 L
.66402 .60332 L
.66667 .60332 L
.66931 .60332 L
.67196 .60332 L
.6746 .60332 L
.67725 .60332 L
.67989 .60332 L
.68254 .60332 L
.68519 .60332 L
Mistroke
.68783 .60332 L
.69048 .60332 L
.69312 .60332 L
.69577 .60332 L
.69841 .60332 L
.70106 .60332 L
.7037 .60332 L
.70635 .60332 L
.70899 .60332 L
.71164 .60332 L
.71429 .60332 L
.71693 .60332 L
.71958 .60332 L
.72222 .60332 L
.72487 .60332 L
.72751 .60332 L
.73016 .60332 L
.7328 .60332 L
.73545 .60332 L
.7381 .60332 L
.74074 .60332 L
.74339 .60332 L
.74603 .60332 L
.74868 .60332 L
.75132 .60332 L
.75397 .60332 L
.75661 .60332 L
.75926 .60332 L
.7619 .60332 L
.76455 .60332 L
.7672 .60332 L
.76984 .60332 L
.77249 .60332 L
.77513 .60332 L
.77778 .60332 L
.78042 .60332 L
.78307 .60332 L
.78571 .60332 L
.78836 .60332 L
.79101 .60332 L
.79365 .60332 L
.7963 .60332 L
.79894 .60332 L
.80159 .60332 L
.80423 .60332 L
.80688 .60332 L
.80952 .60332 L
.81217 .60332 L
.81481 .60332 L
.81746 .60332 L
Mistroke
.82011 .60332 L
.82275 .60332 L
.8254 .60332 L
.82804 .60332 L
.83069 .60332 L
.83333 .60332 L
.83598 .60332 L
.83862 .60332 L
.84127 .60332 L
.84392 .60332 L
.84656 .60332 L
.84921 .60332 L
.85185 .60332 L
.8545 .60332 L
.85714 .60332 L
.85979 .60332 L
.86243 .60332 L
.86508 .60332 L
.86772 .60332 L
.87037 .60332 L
.87302 .60332 L
.87566 .60332 L
.87831 .60332 L
.88095 .60332 L
.8836 .60332 L
.88624 .60332 L
.88889 .60332 L
.89153 .60332 L
.89418 .60332 L
.89683 .60332 L
.89947 .60332 L
.90212 .60332 L
.90476 .60332 L
.90741 .60332 L
.91005 .60332 L
.9127 .60332 L
.91534 .60332 L
.91799 .60332 L
.92063 .60332 L
.92328 .60332 L
.92593 .60332 L
.92857 .60332 L
.93122 .60332 L
.93386 .60332 L
.93651 .60332 L
.93915 .60332 L
.9418 .60332 L
.94444 .60332 L
.94709 .60332 L
.94974 .60332 L
Mistroke
.95238 .60332 L
.95503 .60332 L
.95767 .60332 L
.96032 .60332 L
.96296 .60332 L
.96561 .60332 L
.96825 .60332 L
.9709 .60332 L
.97354 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool2000001d0oooo0`0000040?ooo`8000005`3oool3000000@0oooo0P0000040?oo
o`8000005@3oool3000000<0oooo0`0000040?ooo`8000004`3oool5000000<0oooo0P0000040?oo
o`8000004`3oool500000080oooo0`0000040?ooo`800000503oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`800000203oool001T0oooo00@000000?ooo`3o
ool000006`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000C0?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000I0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`006@3o
ool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000005@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001@0oooo0P0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01@3oool001T0oooo00@000000?ooo`3oool000006`3oool4000000<0oooo
00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`3oool4000000<0oooo00@0
00000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000B0?ooo`060000003oool0oooo0?ooo`000000oooo
100000030?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000003
0?ooo`040000003oool0oooo000000L0oooo000I0?ooo`040000003oool0oooo000001/0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`800000103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001@0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000070?ooo`006P3o
ool2000001`0oooo1@0000030?ooo`800000603oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000001H0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000203oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo
000E0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000000@3oool001D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo0@000001
0?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo1`3oool100000040oooo00001@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
6P2I003Y0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P0000040?oooaX0V@00j03oool20000
0040oooo0004000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01/0oooo0P2I003Y0?ooo`4000000@3oool000030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01/0oooo0P2I003Y0?ooo`4000000@3oool000030?ooo`000000oooo00@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo
0P2I003Y0?ooo`4000000@3oool00080oooo0P0000040?ooo`800000103oool2000000D0oooo0P00
000L0?ooo`80V@00j03oool200000040oooo000E0?ooo`030000003oool0oooo01/0oooo0P2I003Y
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool06`3oool209T00>T0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`0K0?ooo`80V@00j@3oool100000040oooo000E0?ooo`030000
003oool0oooo01/0oooo0P2I003Y0?ooo`4000000@3oool001D0oooo0P00000L0?ooo`80V@00j03o
ool200000040oooo000E0?ooo`030000003oool0oooo01/0oooo0P2I003Y0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool06`3oool209T00>T0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`0K0?ooo`80V@00j@3oool100000040oooo000E0?ooo`800000703oool209T00>P0oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`0K0?ooo`80V@00j@3oool100000040oooo000E
0?ooo`030000003oool0oooo01/0oooo0P2I003Y0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool06`3oool309T00>P0oooo0@0000010?ooo`005@3oool2000001d0oooo0P2I003W0?ooo`80
00000@3oool001D0oooo00<000000?ooo`3oool0703oool209T00>P0oooo0@0000010?ooo`0000@0
oooo00000000000000000`3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo01`0oooo
0P2I003X0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool209T00>P0
oooo0@0000010?ooo`0000D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0L0?ooo`80V@00j03oool10000
0040oooo0004000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`8000007@3oool209T00>L0oooo0P0000010?ooo`0000<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool209T0
0>P0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool2000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0L0?ooo`80V@00j03oool100000040oooo00020?ooo`80
0000103oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`0L0?ooo`80
V@00j03oool100000040oooo000E0?ooo`8000007@3oool209T00>L0oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`0L0?ooo`80V@00j03oool100000040oooo000E0?ooo`030000003oool0
oooo01`0oooo0P2I003X0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0703oool209T0
0>P0oooo0@0000010?ooo`005@3oool2000001d0oooo0P2I003W0?ooo`8000000@3oool001D0oooo
00<000000?ooo`3oool0703oool209T00>P0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`0L0?oooa/0V@00c`3oool100000040oooo000E0?ooo`030000003oool0oooo01`0oooo6`2I003?
0?ooo`4000000@3oool001D0oooo0P00000f0?ooo`80V@00cP3oool200000040oooo000E0?ooo`03
0000003oool0oooo03D0oooo0P2I003?0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
=@3oool209T00<l0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0e0?ooo`80V@00c`3o
ool100000040oooo000E0?ooo`030000003oool0oooo03D0oooo0P2I003?0?ooo`4000000@3oool0
01D0oooo0P00000f0?ooo`80V@00cP3oool200000040oooo000E0?ooo`030000003oool0oooo03D0
oooo0P2I003?0?ooo`4000000@3oool000040?ooo`000000000000000080oooo1@0000030?ooo`80
00001@3oool00`000000oooo0?ooo`0e0?ooo`80V@00c`3oool100000040oooo00001@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo03D0oooo0P2I003?0?ooo`4000000@3oool000050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P00
000f0?ooo`80V@00cP3oool200000040oooo0004000000D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool209T00<l0oooo0@00
00010?ooo`0000<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0e0?ooo`80V@00c`3oool100000040oooo
00000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo03D0oooo0P2I003?0?ooo`4000000@3oool00080oooo
0P0000030?ooo`<00000103oool2000000D0oooo0P00000f0?ooo`80V@00cP3oool200000040oooo
000E0?ooo`030000003oool0oooo03D0oooo0P2I003?0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0=@3oool209T00<l0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0e0?oo
o`80V@00c`3oool100000040oooo000E0?ooo`030000003oool0oooo03D0oooo0P2I003?0?ooo`40
00000@3oool001D0oooo0P00000f0?ooo`80V@00cP3oool200000040oooo000E0?ooo`030000003o
ool0oooo03D0oooo0P2I003?0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0=@3oool2
09T00<l0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0e0?ooo`80V@00c`3oool10000
0040oooo000E0?ooo`800000=P3oool209T00<h0oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`0e0?ooo`80V@00c`3oool100000040oooo000E0?ooo`030000003oool0oooo03D0oooo0P2I
003?0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0=@3oool209T00<l0oooo0@000001
0?ooo`005@3oool2000003H0oooo0P2I003>0?ooo`8000000@3oool001D0oooo00<000000?ooo`3o
ool0=@3oool209T00<l0oooo0@0000010?ooo`0000@0oooo00000000000000000`3oool3000000@0
oooo0P0000050?ooo`030000003oool0oooo03D0oooo6`2I002f0?ooo`4000000@3oool000070000
003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?oooa/0V@00]P3oool100000040oooo00001@00
0000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04h0oooo0P2I002f0?ooo`4000000@3oool000@00000103oool2
000000<0oooo00@000000?ooo`3oool00000103oool2000004l0oooo0P2I002e0?ooo`8000000@3o
ool000030000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04h0oooo0P2I002f0?ooo`4000000@3oool000030?ooo`000000
oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0CP3oool209T00;H0oooo0@0000010?ooo`000P3oool2000000<0oooo0`00
00040?ooo`8000001@3oool00`000000oooo0?ooo`1>0?ooo`80V@00]P3oool100000040oooo000E
0?ooo`800000C`3oool209T00;D0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1>0?oo
o`80V@00]P3oool100000040oooo000E0?ooo`030000003oool0oooo04h0oooo0P2I002f0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0CP3oool209T00;H0oooo0@0000010?ooo`005@3o
ool2000004l0oooo0P2I002e0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0CP3oool2
09T00;H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`80V@00]P3oool10000
0040oooo000E0?ooo`030000003oool0oooo04h0oooo0P2I002f0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0CP3oool309T00;D0oooo0@0000010?ooo`005@3oool200000500oooo0P2I
002d0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0C`3oool209T00;D0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`80V@00]@3oool100000040oooo000E0?ooo`03
0000003oool0oooo04l0oooo0P2I002e0?ooo`4000000@3oool001D0oooo0P00001@0?ooo`80V@00
]03oool200000040oooo000E0?ooo`030000003oool0oooo04l0oooo0P2I002e0?ooo`4000000@3o
ool000040?ooo`0000000000000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?oo
o`1?0?ooo`80V@00]@3oool100000040oooo00001@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
C`3oool209T00;D0oooo0@0000010?ooo`0000H000000?ooo`3oool0oooo0000003oool500000080
oooo00@000000?ooo`3oool00000103oool200000500oooo0P2I002d0?ooo`8000000@3oool000@0
00000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0C`3oool209T00;D0oooo0@0000010?ooo`0000<000000?ooo`3oool0103oool00`00
0000oooo000000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0C`3oool2
09T00;D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool2000000<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1?0?ooo`80V@00]@3oool100000040oooo00020?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`1?0?oo
oaX0V@00W@3oool100000040oooo000E0?ooo`800000D03ooolJ09T009`0oooo0P0000010?ooo`00
5@3oool00`000000oooo0?ooo`1W0?ooo`80V@00W@3oool100000040oooo000E0?ooo`030000003o
ool0oooo06L0oooo0P2I002M0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0I`3oool2
09T009d0oooo0@0000010?ooo`005@3oool2000006P0oooo0P2I002L0?ooo`8000000@3oool001D0
oooo00<000000?ooo`3oool0I`3oool209T009d0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1W0?ooo`80V@00W@3oool100000040oooo000E0?ooo`030000003oool0oooo06L0oooo0P2I
002M0?ooo`4000000@3oool001D0oooo0P00001X0?ooo`80V@00W03oool200000040oooo000E0?oo
o`030000003oool0oooo06L0oooo0P2I002M0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0I`3oool209T009d0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1W0?ooo`80V@00
W@3oool100000040oooo000E0?ooo`800000J03oool309T009/0oooo0P0000010?ooo`005@3oool0
0`000000oooo0?ooo`1X0?ooo`80V@00W03oool100000040oooo0000103oool00000000000000003
0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0J03oool209T009`0oooo0@000001
0?ooo`0000L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06P0oooo0P2I002L0?ooo`400000
0@3oool000050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0J03oool209T009`0oooo0@0000010?ooo`00
100000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2000006T0
oooo0P2I002K0?ooo`8000000@3oool000030000003oool0oooo00<0oooo100000030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0J03oool209T009`0oooo0@0000010?ooo`00
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0J03oool209T009`0oooo0@0000010?ooo`000P3oool200000080oooo
1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`1X0?ooo`80V@00W03oool100000040oooo
000E0?ooo`800000J@3oool209T009/0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1X
0?ooo`80V@00W03oool100000040oooo000E0?ooo`030000003oool0oooo06P0oooo0P2I002L0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0J03ooolK09T008<0oooo0@0000010?ooo`00
5@3oool2000006T0oooo6`2I00220?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0P@3o
ool209T008<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`210?ooo`80V@00P`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0840oooo0P2I00230?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0P@3oool209T008<0oooo0@0000010?ooo`005@3oool200000880oooo
0P2I00220?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0P@3oool209T008<0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`210?ooo`80V@00P`3oool100000040oooo000E0?oo
o`030000003oool0oooo0840oooo0P2I00230?ooo`4000000@3oool001D0oooo0P0000220?ooo`80
V@00PP3oool200000040oooo000E0?ooo`030000003oool0oooo0840oooo0P2I00230?ooo`400000
0@3oool000040?ooo`0000000000000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo
0?ooo`210?ooo`80V@00P`3oool100000040oooo00001`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0P@3oool209T008<0oooo0@0000010?ooo`0000L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000PP3o
ool209T00880oooo0P0000010?ooo`00100000020?ooo`@000000`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0840oooo0P2I00230?ooo`4000000@3oool000030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0840oooo0P2I00230?ooo`4000000@3oool000030?ooo`000000oooo00@0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0840oooo0P2I
00230?ooo`4000000@3oool00080oooo0P0000040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0P@3oool209T008<0oooo0@0000010?ooo`005@3oool200000880oooo0P2I00220?oo
o`8000000@3oool001D0oooo00<000000?ooo`3oool0P@3oool209T008<0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`210?ooo`80V@00P`3oool100000040oooo000E0?ooo`030000003o
ool0oooo0840oooo6`2I001Z0?ooo`4000000@3oool001D0oooo0P0000220?oooa/0V@00J@3oool2
00000040oooo000E0?ooo`030000003oool0oooo09X0oooo0P2I001Z0?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0VP3oool209T006X0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`2J0?ooo`80V@00JP3oool100000040oooo000E0?ooo`800000V`3oool209T006T0oooo0P00
00010?ooo`005@3oool00`000000oooo0?ooo`2J0?ooo`80V@00JP3oool100000040oooo000E0?oo
o`030000003oool0oooo09X0oooo0P2I001Z0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0VP3oool209T006X0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2J0?ooo`80V@00
JP3oool100000040oooo000E0?ooo`800000V`3oool309T006P0oooo0P0000010?ooo`0000@0oooo
0000000000000000103oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?oo
o`2K0?ooo`80V@00J@3oool100000040oooo00001@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo09/0oooo
0P2I001Y0?ooo`4000000@3oool000050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2K0?ooo`80
V@00J@3oool100000040oooo0004000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo0P00002L0?ooo`80V@00J03oool200000040oooo00000`000000oooo
0?ooo`070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2K0?ooo`80V@00J@3oool100000040oooo00000`3oool000000?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
09/0oooo0P2I001Y0?ooo`4000000@3oool00080oooo0P0000020?ooo`D000000`3oool2000000D0
oooo00<000000?ooo`3oool0V`3oool209T006T0oooo0@0000010?ooo`005@3oool2000009`0oooo
I@2I00050?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0V`3ooomU09T000H0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`005@3ooooo000000/0
00000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-39.349, 591.908, 1.42345, \
0.46389}},
  CellTags->"Payment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"PaymentToInterest"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"PaymentToInterest"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentToInterest"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentToInterest"],

Cell[CellGroupData[{

Cell["PaymentToInterest", "Section",
  CellTags->"PaymentToInterest"],

Cell[TextData[{
  StyleBox["PaymentToInterest", "MR"],
  " computes the portion of a payment paid to interest."
}], "Text",
  CellTags->"PaymentToInterest"],

Cell["\<\
PaymentToInterest[{HomeCost, PercentageDownPayment}, InterestRate, \
Years, PaymentNumber] gives the portion of the payment given by PaymentNumber \
that is paid into interest for a loan on a house of initial value given by \
HomeCost with a down payment given by PercentageDownPayment for a loan \
amortized over the number of years given by Years with the fixed interest \
rate given by InterestRate. 

PaymentToInterest[LoanAmount, InterestRate, Years, PaymentNumber] assumes a \
loan amount given by LoanAmount. 

PaymentToInterest[{HomeCost, PercentageDownPayment}, {{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber] calculates for a variable rate loan with interest rate \
InterestRate1 for a number of payments given by Payments1 followed by \
InterestRate2 for a number of payments given by Payments2, and so on. Note \
that PaymentNumber must be given. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. If PaymentNumber is not numerical then an \
analytical result will be returned (if $StrongErrorChecking is not True) that \
assumes that PaymentNumber is greater than \
Payments1+Payments2+...+Payments(M-1).

PaymentToInterest[LoanAmount, {{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, Years, PaymentNumber] is also a \
valid input.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToInterest"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PaymentToInterest", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToInterest"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToInterest"],

Cell[TextData[{
  "Default options for ",
  StyleBox["PaymentToInterest", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToInterest"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToInterest"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PaymentToInterest", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToInterest"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"PaymentToInterest"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"PaymentToInterest"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"fixedPlot", "=", 
        RowBox[{"Plot", "[", 
          RowBox[{
            RowBox[{"PaymentToInterest", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"100000", ",", " ", "20"}], "}"}], ",", " ", "7.0", 
                ",", " ", "30", ",", " ", "\[Mu]"}], "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"\[Mu]", ",", "1", ",", "360"}], "}"}]}], "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"PaymentToInterest"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 0.0147151 0.00126129 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14084 -18 -4.5 ]
[-0.0125 .14084 0 4.5 ]
[-0.0125 .26697 -18 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .3931 -18 -4.5 ]
[-0.0125 .3931 0 4.5 ]
[-0.0125 .51923 -18 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14084 m
.00625 .14084 L
s
[(100)] -0.0125 .14084 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(200)] -0.0125 .26697 1 0 Mshowa
0 .3931 m
.00625 .3931 L
s
[(300)] -0.0125 .3931 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(400)] -0.0125 .51923 1 0 Mshowa
.125 Mabswid
0 .03994 m
.00375 .03994 L
s
0 .06517 m
.00375 .06517 L
s
0 .09039 m
.00375 .09039 L
s
0 .11562 m
.00375 .11562 L
s
0 .16607 m
.00375 .16607 L
s
0 .1913 m
.00375 .1913 L
s
0 .21652 m
.00375 .21652 L
s
0 .24175 m
.00375 .24175 L
s
0 .2922 m
.00375 .2922 L
s
0 .31743 m
.00375 .31743 L
s
0 .34265 m
.00375 .34265 L
s
0 .36788 m
.00375 .36788 L
s
0 .41833 m
.00375 .41833 L
s
0 .44356 m
.00375 .44356 L
s
0 .46878 m
.00375 .46878 L
s
0 .49401 m
.00375 .49401 L
s
0 .54446 m
.00375 .54446 L
s
0 .56968 m
.00375 .56968 L
s
0 .59491 m
.00375 .59491 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14084 m
1 .14084 L
s
.99375 .26697 m
1 .26697 L
s
.99375 .3931 m
1 .3931 L
s
.99375 .51923 m
1 .51923 L
s
.125 Mabswid
.99625 .03994 m
1 .03994 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .09039 m
1 .09039 L
s
.99625 .11562 m
1 .11562 L
s
.99625 .16607 m
1 .16607 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .24175 m
1 .24175 L
s
.99625 .2922 m
1 .2922 L
s
.99625 .31743 m
1 .31743 L
s
.99625 .34265 m
1 .34265 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .41833 m
1 .41833 L
s
.99625 .44356 m
1 .44356 L
s
.99625 .46878 m
1 .46878 L
s
.99625 .49401 m
1 .49401 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56968 m
1 .56968 L
s
.99625 .59491 m
1 .59491 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02646 .60332 m
.06498 .59601 L
.107 .5873 L
.14646 .57835 L
.18441 .56898 L
.22481 .5581 L
.26369 .54669 L
.30502 .53343 L
.34484 .51947 L
.38315 .50483 L
.4239 .48785 L
.46315 .46999 L
.50088 .45131 L
.54105 .42963 L
.57972 .40688 L
.62083 .38048 L
.66042 .35268 L
.69851 .32357 L
.73904 .28979 L
.77806 .25429 L
.81953 .21308 L
.85949 .16965 L
.89793 .12411 L
.93882 .07125 L
.97619 .01861 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[2]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool2000001d0oooo0`0000040?ooo`8000005`3oool3000000@0oooo0P0000040?oo
o`8000005@3oool3000000<0oooo0`0000040?ooo`8000004`3oool5000000<0oooo0P0000040?oo
o`8000004`3oool500000080oooo0`0000040?ooo`800000503oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`800000203oool001T0oooo00@000000?ooo`3o
ool000006`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000C0?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000I0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`006@3o
ool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000005@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001@0oooo0P0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01@3oool001T0oooo00@000000?ooo`3oool000006`3oool4000000<0oooo
00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`3oool4000000<0oooo00@0
00000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000B0?ooo`060000003oool0oooo0?ooo`000000oooo
100000030?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000003
0?ooo`040000003oool0oooo000000L0oooo000I0?ooo`040000003oool0oooo000001/0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`800000103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001@0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000070?ooo`006P3o
ool2000001`0oooo1@0000030?ooo`800000603oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000001H0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000203oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo
000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool100000040oooo000>
0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool02P3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000103oool2
00000?l0oooo1`3oool200000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool209T000D0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo0P2I00050?ooo`4000000@3oool000d0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3n0?ooo`<0V@001@3oool100000040oooo000>0?oo
o`8000001@3oool00`000000oooo0?ooo`3m0?ooo`<0V@001P3oool100000040oooo000E0?ooo`03
0000003oool0oooo0?`0oooo0`2I00070?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
o03oool209T000P0oooo0@0000010?ooo`005@3oool200000?`0oooo0`2I00070?ooo`8000000@3o
ool001D0oooo00<000000?ooo`3oool0nP3oool309T000T0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3j0?ooo`80V@002P3oool100000040oooo000E0?ooo`030000003oool0oooo0?T0
oooo0`2I000:0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0n03oool309T000/0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`3g0?ooo`<0V@00303oool100000040oooo000E
0?ooo`800000n03oool209T000`0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3f0?oo
o`<0V@003@3oool100000040oooo000E0?ooo`030000003oool0oooo0?D0oooo0`2I000>0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0m@3oool209T000l0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3d0?ooo`<0V@003`3oool100000040oooo000E0?ooo`030000003oool0
oooo0?<0oooo0`2I000@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0lP3oool309T0
0140oooo0@0000010?ooo`005@3oool200000?80oooo0`2I000A0?ooo`8000000@3oool001D0oooo
00<000000?ooo`3oool0l@3oool209T001<0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`3`0?ooo`<0V@004`3oool100000040oooo000E0?ooo`030000003oool0oooo0>l0oooo0`2I000D
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0kP3oool309T001D0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3^0?ooo`80V@005P3oool100000040oooo000E0?ooo`030000
003oool0oooo0>d0oooo0`2I000F0?ooo`4000000@3oool001D0oooo0P00003]0?ooo`<0V@005P3o
ool200000040oooo000E0?ooo`030000003oool0oooo0>/0oooo0`2I000H0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0jP3oool309T001T0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3Z0?ooo`80V@006P3oool100000040oooo0000103oool000000000000000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0j@3oool309T001X0oooo0@0000010?ooo`00
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3X0?ooo`<0V@006`3oool100000040oooo00020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0>L0oooo0`2I000L0?ooo`4000000@3oool00080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P00
003W0?ooo`<0V@00703oool200000040oooo00020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>D0oooo
0`2I000N0?ooo`4000000@3oool000030?ooo`000000000000@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>D0oooo0P2I000O0?ooo`40
00000@3oool00080oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo0>@0oooo0`2I000O0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0h`3o
ool309T00200oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3R0?ooo`<0V@008@3oool1
00000040oooo000E0?ooo`800000hP3oool309T00240oooo0P0000010?ooo`005@3oool00`000000
oooo0?ooo`3P0?ooo`<0V@008`3oool100000040oooo000E0?ooo`030000003oool0oooo0>00oooo
0P2I000T0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0g`3oool309T002@0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`3N0?ooo`<0V@009@3oool100000040oooo000E0?oo
o`030000003oool0oooo0=d0oooo0`2I000V0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0g03oool309T002L0oooo0@0000010?ooo`005@3oool200000=`0oooo0`2I000W0?ooo`800000
0@3oool001D0oooo00<000000?ooo`3oool0fP3oool309T002T0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`3I0?ooo`<0V@00:P3oool100000040oooo000E0?ooo`030000003oool0oooo
0=P0oooo0`2I000[0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0e`3oool309T002`0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3F0?ooo`<0V@00;@3oool100000040oooo
000E0?ooo`030000003oool0oooo0=D0oooo0`2I000^0?ooo`4000000@3oool001D0oooo0P00003E
0?ooo`<0V@00;P3oool200000040oooo000E0?ooo`030000003oool0oooo0=<0oooo0`2I000`0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0dP3oool309T00340oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`3A0?ooo`<0V@00<P3oool100000040oooo000E0?ooo`030000003o
ool0oooo0=00oooo0`2I000c0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0c`3oool3
09T003@0oooo0@0000010?ooo`005@3oool200000<l0oooo0`2I000d0?ooo`8000000@3oool001D0
oooo00<000000?ooo`3oool0c@3oool309T003H0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`3<0?ooo`<0V@00=`3oool100000040oooo000E0?ooo`030000003oool0oooo0</0oooo0`2I
000h0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0b@3oool409T003T0oooo0@000001
0?ooo`001@0000030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0b03oool409T0
03X0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`370?ooo`<0V@00?03o
ool100000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`800000a`3oool309T003`0oooo0P0000010?ooo`000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0<D0oooo0`2I000n0?ooo`4000000@3oool000050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0a03oool309T003l0oooo0@0000010?ooo`0000D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`330?ooo`<0V@00@03oool100000040oooo0000103oool000000000
000000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0`P3oool309T00440oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`310?ooo`<0V@00@P3oool100000040oooo000E
0?ooo`030000003oool0oooo0;l0oooo102I00130?ooo`4000000@3oool001D0oooo0P00002o0?oo
o`@0V@00@`3oool200000040oooo000E0?ooo`030000003oool0oooo0;d0oooo0`2I00160?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0_03oool309T004L0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`2j0?ooo`@0V@00B03oool100000040oooo000E0?ooo`030000003oool0
oooo0;T0oooo102I00190?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0^03oool309T0
04/0oooo0@0000010?ooo`005@3oool200000;P0oooo0`2I001;0?ooo`8000000@3oool001D0oooo
00<000000?ooo`3oool0]P3oool309T004d0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`2d0?ooo`@0V@00CP3oool100000040oooo000E0?ooo`030000003oool0oooo0;<0oooo102I001?
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0/P3oool309T00540oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`2a0?ooo`<0V@00DP3oool100000040oooo000E0?ooo`030000
003oool0oooo0:l0oooo102I001C0?ooo`4000000@3oool001D0oooo0P00002_0?ooo`@0V@00D`3o
ool200000040oooo000E0?ooo`030000003oool0oooo0:d0oooo0`2I001F0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0[03oool309T005L0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`2Z0?ooo`@0V@00F03oool100000040oooo000E0?ooo`030000003oool0oooo0:T0oooo
102I001I0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0Y`3oool409T005/0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`2V0?ooo`@0V@00G03oool100000040oooo000E0?oo
o`800000YP3oool309T005d0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2S0?ooo`@0
V@00G`3oool100000040oooo000E0?ooo`030000003oool0oooo0:80oooo102I001P0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0X03oool409T00680oooo0@0000010?ooo`0000@0oooo
0000000000000000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo09l0oooo102I
001S0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0W@3oool409T006D0
oooo0@0000010?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2K0?ooo`D0V@00IP3oool10000
0040oooo00020?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo0P00002K0?ooo`@0V@00I`3oool200000040oooo00040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo09P0oooo102I001Z0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0U`3oool409T006/0oooo0@0000010?ooo`0000@0oooo0000000000000000103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo09D0oooo102I001]0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0T`3oool509T006h0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`2B0?ooo`@0V@00L03oool100000040oooo000E0?ooo`800000T@3oool409T00740oooo0P000001
0?ooo`005@3oool00`000000oooo0?ooo`2>0?ooo`D0V@00L`3oool100000040oooo000E0?ooo`03
0000003oool0oooo08d0oooo102I001e0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
R`3oool409T007L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`290?ooo`D0V@00N03o
ool100000040oooo000E0?ooo`030000003oool0oooo08L0oooo1@2I001j0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0QP3oool409T007`0oooo0@0000010?ooo`005@3oool2000008D0
oooo102I001m0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0PP3oool509T007l0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`200?ooo`D0V@00P@3oool100000040oooo000E
0?ooo`030000003oool0oooo07h0oooo1@2I00230?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0O03oool509T008D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1j0?ooo`D0
V@00Q`3oool100000040oooo000E0?ooo`030000003oool0oooo07P0oooo1@2I00290?ooo`400000
0@3oool001D0oooo0P00001g0?ooo`D0V@00RP3oool200000040oooo000E0?ooo`030000003oool0
oooo07@0oooo1@2I002=0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0L@3oool609T0
08l0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1_0?ooo`H0V@00T@3oool100000040
oooo000E0?ooo`030000003oool0oooo06d0oooo1@2I002D0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0J`3oool509T009H0oooo0@0000010?ooo`005@3oool2000006T0oooo1P2I002G
0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0IP3oool609T009X0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`1S0?ooo`H0V@00W@3oool100000040oooo000E0?ooo`030000
003oool0oooo0640oooo1P2I002O0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0GP3o
ool609T00:80oooo0@0000010?ooo`000P3oool3000000<0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`1K0?ooo`L0V@00Y03oool100000040oooo00030?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0F03oool709T00:L0oooo0@0000010?ooo`001@0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool2000005L0oooo1P2I002Y0?ooo`800000
0@3oool000040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05<0oooo1P2I002]0?ooo`4000000@3oool00004
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0540oooo1P2I002_0?ooo`4000000@3oool00080oooo0P000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1>0?ooo`H0V@00/P3oool100000040oooo00030?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`1;0?ooo`L0V@00]03oool100000040oooo000E
0?ooo`030000003oool0oooo04L0oooo202I002g0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0A03oool809T00;X0oooo0@0000010?ooo`005@3oool200000440oooo202I002m0?ooo`80
00000@3oool001D0oooo00<000000?ooo`3oool0?@3oool809T00<40oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`0j0?ooo`L0V@00a@3oool100000040oooo000E0?ooo`030000003oool0
oooo03H0oooo202I00380?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0<P3oool909T0
0</0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`P0V@00c`3oool100000040
oooo000E0?ooo`800000;03oool809T00=80oooo0P0000010?ooo`005@3oool00`000000oooo0?oo
o`0X0?ooo`P0V@00eP3oool100000040oooo000E0?ooo`030000003oool0oooo02D0oooo1`2I003J
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0803oool909T00=d0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`0K0?ooo`/0V@00h03oool100000040oooo000E0?ooo`030000
003oool0oooo01D0oooo302I003U0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0403o
ool<09T00>X0oooo0@0000010?ooo`005@3oool2000000`0oooo2`2I003_0?ooo`8000000@3oool0
01D0oooo00<000000?ooo`3oool01P3oool;09T00?D0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`030?ooo`T0V@00nP3oool100000040oooo000E0?ooo`030000003oool0oooo00<0oooo
102I003o0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`4000000@3oool0
01D0ooooo`00000;00000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-39.349, -49.1918, 1.42345, \
2.98562}},
  CellTags->"PaymentToInterest"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"interestRateTable", "=", 
      RowBox[{"Table", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"6", " ", "+", 
                RowBox[{"0.25", " ", "i"}]}], ",", "36"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"PaymentToInterest"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"6", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.25`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.5`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.75`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.25`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.5`", ",", "36"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"PaymentToInterest"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"variablePlot", "=", 
        RowBox[{"Plot", "[", 
          RowBox[{
            RowBox[{"PaymentToInterest", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"100000", ",", " ", "20"}], "}"}], ",", " ", 
                "interestRateTable", ",", " ", "30", ",", " ", "\[Mu]"}], 
              "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"\[Mu]", ",", "1", ",", "360"}], "}"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
            RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", " ", "0", ",", " ", ".6"}], "]"}], ",", 
                  
                  RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}]}], 
          "]"}]}], ";"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"PaymentToInterest"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0211566 0.00265287 0.00976268 0.00148304 [
[.02116 -0.0125 -3 -9 ]
[.02116 -0.0125 3 0 ]
[.1538 -0.0125 -6 -9 ]
[.1538 -0.0125 6 0 ]
[.28644 -0.0125 -9 -9 ]
[.28644 -0.0125 9 0 ]
[.41909 -0.0125 -9 -9 ]
[.41909 -0.0125 9 0 ]
[.55173 -0.0125 -9 -9 ]
[.55173 -0.0125 9 0 ]
[.68437 -0.0125 -9 -9 ]
[.68437 -0.0125 9 0 ]
[.81702 -0.0125 -9 -9 ]
[.81702 -0.0125 9 0 ]
[.94966 -0.0125 -9 -9 ]
[.94966 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00976 -6 -4.5 ]
[-0.0125 .00976 0 4.5 ]
[-0.0125 .15807 -18 -4.5 ]
[-0.0125 .15807 0 4.5 ]
[-0.0125 .30637 -18 -4.5 ]
[-0.0125 .30637 0 4.5 ]
[-0.0125 .45467 -18 -4.5 ]
[-0.0125 .45467 0 4.5 ]
[-0.0125 .60298 -18 -4.5 ]
[-0.0125 .60298 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02116 0 m
.02116 .00625 L
s
[(0)] .02116 -0.0125 0 1 Mshowa
.1538 0 m
.1538 .00625 L
s
[(50)] .1538 -0.0125 0 1 Mshowa
.28644 0 m
.28644 .00625 L
s
[(100)] .28644 -0.0125 0 1 Mshowa
.41909 0 m
.41909 .00625 L
s
[(150)] .41909 -0.0125 0 1 Mshowa
.55173 0 m
.55173 .00625 L
s
[(200)] .55173 -0.0125 0 1 Mshowa
.68437 0 m
.68437 .00625 L
s
[(250)] .68437 -0.0125 0 1 Mshowa
.81702 0 m
.81702 .00625 L
s
[(300)] .81702 -0.0125 0 1 Mshowa
.94966 0 m
.94966 .00625 L
s
[(350)] .94966 -0.0125 0 1 Mshowa
.125 Mabswid
.04769 0 m
.04769 .00375 L
s
.07421 0 m
.07421 .00375 L
s
.10074 0 m
.10074 .00375 L
s
.12727 0 m
.12727 .00375 L
s
.18033 0 m
.18033 .00375 L
s
.20686 0 m
.20686 .00375 L
s
.23339 0 m
.23339 .00375 L
s
.25992 0 m
.25992 .00375 L
s
.31297 0 m
.31297 .00375 L
s
.3395 0 m
.3395 .00375 L
s
.36603 0 m
.36603 .00375 L
s
.39256 0 m
.39256 .00375 L
s
.44562 0 m
.44562 .00375 L
s
.47214 0 m
.47214 .00375 L
s
.49867 0 m
.49867 .00375 L
s
.5252 0 m
.5252 .00375 L
s
.57826 0 m
.57826 .00375 L
s
.60479 0 m
.60479 .00375 L
s
.63132 0 m
.63132 .00375 L
s
.65785 0 m
.65785 .00375 L
s
.7109 0 m
.7109 .00375 L
s
.73743 0 m
.73743 .00375 L
s
.76396 0 m
.76396 .00375 L
s
.79049 0 m
.79049 .00375 L
s
.84355 0 m
.84355 .00375 L
s
.87008 0 m
.87008 .00375 L
s
.8966 0 m
.8966 .00375 L
s
.92313 0 m
.92313 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00976 m
.00625 .00976 L
s
[(0)] -0.0125 .00976 1 0 Mshowa
0 .15807 m
.00625 .15807 L
s
[(100)] -0.0125 .15807 1 0 Mshowa
0 .30637 m
.00625 .30637 L
s
[(200)] -0.0125 .30637 1 0 Mshowa
0 .45467 m
.00625 .45467 L
s
[(300)] -0.0125 .45467 1 0 Mshowa
0 .60298 m
.00625 .60298 L
s
[(400)] -0.0125 .60298 1 0 Mshowa
.125 Mabswid
0 .03942 m
.00375 .03942 L
s
0 .06908 m
.00375 .06908 L
s
0 .09875 m
.00375 .09875 L
s
0 .12841 m
.00375 .12841 L
s
0 .18773 m
.00375 .18773 L
s
0 .21739 m
.00375 .21739 L
s
0 .24705 m
.00375 .24705 L
s
0 .27671 m
.00375 .27671 L
s
0 .33603 m
.00375 .33603 L
s
0 .36569 m
.00375 .36569 L
s
0 .39535 m
.00375 .39535 L
s
0 .42501 m
.00375 .42501 L
s
0 .48434 m
.00375 .48434 L
s
0 .514 m
.00375 .514 L
s
0 .54366 m
.00375 .54366 L
s
0 .57332 m
.00375 .57332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02116 .61178 m
.02116 .61803 L
s
.1538 .61178 m
.1538 .61803 L
s
.28644 .61178 m
.28644 .61803 L
s
.41909 .61178 m
.41909 .61803 L
s
.55173 .61178 m
.55173 .61803 L
s
.68437 .61178 m
.68437 .61803 L
s
.81702 .61178 m
.81702 .61803 L
s
.94966 .61178 m
.94966 .61803 L
s
.125 Mabswid
.04769 .61428 m
.04769 .61803 L
s
.07421 .61428 m
.07421 .61803 L
s
.10074 .61428 m
.10074 .61803 L
s
.12727 .61428 m
.12727 .61803 L
s
.18033 .61428 m
.18033 .61803 L
s
.20686 .61428 m
.20686 .61803 L
s
.23339 .61428 m
.23339 .61803 L
s
.25992 .61428 m
.25992 .61803 L
s
.31297 .61428 m
.31297 .61803 L
s
.3395 .61428 m
.3395 .61803 L
s
.36603 .61428 m
.36603 .61803 L
s
.39256 .61428 m
.39256 .61803 L
s
.44562 .61428 m
.44562 .61803 L
s
.47214 .61428 m
.47214 .61803 L
s
.49867 .61428 m
.49867 .61803 L
s
.5252 .61428 m
.5252 .61803 L
s
.57826 .61428 m
.57826 .61803 L
s
.60479 .61428 m
.60479 .61803 L
s
.63132 .61428 m
.63132 .61803 L
s
.65785 .61428 m
.65785 .61803 L
s
.7109 .61428 m
.7109 .61803 L
s
.73743 .61428 m
.73743 .61803 L
s
.76396 .61428 m
.76396 .61803 L
s
.79049 .61428 m
.79049 .61803 L
s
.84355 .61428 m
.84355 .61803 L
s
.87008 .61428 m
.87008 .61803 L
s
.8966 .61428 m
.8966 .61803 L
s
.92313 .61428 m
.92313 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00976 m
1 .00976 L
s
.99375 .15807 m
1 .15807 L
s
.99375 .30637 m
1 .30637 L
s
.99375 .45467 m
1 .45467 L
s
.99375 .60298 m
1 .60298 L
s
.125 Mabswid
.99625 .03942 m
1 .03942 L
s
.99625 .06908 m
1 .06908 L
s
.99625 .09875 m
1 .09875 L
s
.99625 .12841 m
1 .12841 L
s
.99625 .18773 m
1 .18773 L
s
.99625 .21739 m
1 .21739 L
s
.99625 .24705 m
1 .24705 L
s
.99625 .27671 m
1 .27671 L
s
.99625 .33603 m
1 .33603 L
s
.99625 .36569 m
1 .36569 L
s
.99625 .39535 m
1 .39535 L
s
.99625 .42501 m
1 .42501 L
s
.99625 .48434 m
1 .48434 L
s
.99625 .514 m
1 .514 L
s
.99625 .54366 m
1 .54366 L
s
.99625 .57332 m
1 .57332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 .6 r
2 Mabswid
.02381 .60298 m
.06244 .59408 L
.08255 .58919 L
.0932 .58652 L
.10458 .58361 L
.11009 .58218 L
.1128 .58147 L
.114 .58115 L
.11531 .58081 L
.11648 .5805 L
.11758 .60013 L
.11874 .60238 L
.11999 .60332 L
.12064 .60315 L
.12135 .60296 L
.12264 .60261 L
.12507 .60196 L
.14415 .59675 L
.16547 .59068 L
.1848 .58496 L
.19448 .58201 L
.19957 .58044 L
.20495 .57876 L
.20722 .57805 L
.20966 .57728 L
.21038 .57705 L
.21106 .57683 L
.21233 .5935 L
.21353 .5958 L
.21483 .59827 L
.21592 .59792 L
.21712 .59753 L
.21956 .59674 L
.22393 .59532 L
.26413 .58164 L
.28261 .57497 L
.29308 .57108 L
.29818 .56915 L
.30282 .56738 L
.30521 .56646 L
.30586 .56621 L
.30656 .56594 L
.3078 .5811 L
.30896 .58327 L
.31004 .5853 L
.31123 .58546 L
.31251 .58496 L
.32286 .58084 L
.34396 .57216 L
.36371 .56369 L
Mistroke
.37413 .55906 L
.38523 .55403 L
.39081 .55146 L
.39606 .549 L
.39835 .54793 L
.40077 .54678 L
.40204 .54618 L
.40276 .54584 L
.40343 .55992 L
.40461 .56201 L
.40587 .56415 L
.40715 .56353 L
.40833 .56296 L
.41101 .56165 L
.41588 .55926 L
.42499 .5547 L
.44529 .54423 L
.46431 .53398 L
.48252 .52377 L
.4875 .5209 L
.49275 .51785 L
.49491 .51658 L
.49723 .51521 L
.49791 .51481 L
.49855 .51443 L
.49976 .52822 L
.50089 .53004 L
.50212 .53027 L
.50335 .52952 L
.50448 .52883 L
.50702 .52728 L
.51161 .52446 L
.52203 .51793 L
.54309 .50427 L
.56376 .4902 L
.57285 .4838 L
.5829 .47658 L
.5875 .47321 L
.58992 .47143 L
.59124 .47045 L
.59247 .46954 L
.59355 .46874 L
.59471 .47917 L
.59599 .4809 L
.59716 .48177 L
.59822 .48096 L
.59937 .48008 L
.60146 .47847 L
.6212 .46288 L
.66208 .42818 L
Mistroke
.70145 .39147 L
.73931 .35283 L
.77962 .30772 L
.81841 .26009 L
.85965 .20445 L
.89938 .14551 L
.93759 .08338 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006@3oool2000001h0oooo0`0000040?ooo`8000005`3oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`8000004`3oool5000000<0oooo0P0000040?oo
o`800000503oool500000080oooo0`0000040?ooo`800000503oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`800000203oool001P0oooo00@000000?ooo`3o
ool00000703oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000503oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000D0?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000H0?ooo`040000003oool0oooo00000200oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`00603o
ool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000503oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001@0oooo0P0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01@3oool001P0oooo00@000000?ooo`3oool00000703oool4000000<0oooo
00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`3oool4000000<0oooo00@0
00000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000C0?ooo`060000003oool0oooo0?ooo`000000oooo
100000030?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000003
0?ooo`040000003oool0oooo000000L0oooo000H0?ooo`040000003oool0oooo000001`0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`800000103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001<0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000C0?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000070?ooo`006@3o
ool2000001d0oooo1@0000030?ooo`800000603oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000001D0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`8000005@3oool300000080oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000203oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000h0oooo0P0000050?ooool00000
2`0000010?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo
0P0000030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool200000040oooo
000=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`400000
0@3oool000d0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`80002I
1@3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
o`3oool20000V@D0oooo0@0000010?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool0oP3o
ool30000V@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3n0?ooo`80002I1P3oool1
00000040oooo000E0?ooo`030000003oool0oooo0?d0oooo0`0009T60?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0o03oool30000V@L0oooo0@0000010?ooo`005@3oool200000?d0oooo
0P0009T70?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0n`3oool30000V@P0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`3k0?ooo`80002I2@3oool100000040oooo000E0?oo
o`030000003oool0oooo0?X0oooo0`0009T90?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0nP3oool20000V@X0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3i0?ooo`<0002I
2P3oool100000040oooo000E0?ooo`030000003oool0oooo0?T0oooo0P0009T;0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0n03oool30000V@/0oooo0@0000010?ooo`005@3oool20000
0?P0oooo0`0009T;0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0m`3oool20000V@d0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3f0?ooo`<0002I3@3oool100000040oooo
000E0?ooo`030000003oool0oooo0?H0oooo0P0009T>0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0m@3oool30000V@h0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3e0?oo
o`80002I3`3oool100000040oooo000E0?ooo`030000003oool0oooo0?@0oooo0`0009T?0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0m03oool20000VA00oooo0@0000010?ooo`005@3o
ool200000?@0oooo0`0009T?0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0lP3oool3
0000VA40oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3b0?ooo`80002I4P3oool10000
0040oooo000E0?ooo`030000003oool0oooo0?40oooo0`0009TB0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0l@3oool20000VA<0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`3`0?ooo`<0002I4`3oool100000040oooo000E0?ooo`030000003oool0oooo0>l0oooo0`0009TD
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0k`3oool20000VAD0oooo0@0000010?oo
o`005@3oool200000>l0oooo0`0009TD0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0
kP3oool20000VAH0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3]0?ooo`<0002I5P3o
ool100000040oooo000E0?ooo`030000003oool0oooo0>`0oooo0`0009TG0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0k03oool20000VAP0oooo0@0000010?ooo`0000@0oooo00000000
00000000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0>/0oooo0`0009TH0?oo
o`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0j`3oool20000VAT0oooo0@000001
0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`3Z0?ooo`<0002I6@3oool100000040oooo0002
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`800000jP3oool30000VAT0oooo0P0000010?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`3X0?ooo`<0002I6`3oool100000040oooo00000`3oool00000000000040?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3X0?oo
o`80002I703oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`3W0?ooo`<0002I703oool100000040oooo000E0?ooo`030000
003oool0oooo0>H0oooo0`0009TM0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0i@3o
ool30000VAh0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3U0?ooo`80002I7`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0>@0oooo0`0009TO0?ooo`4000000@3oool001D0
oooo0P00003T0?ooo`<0002I7`3oool200000040oooo000E0?ooo`030000003oool0oooo0><0oooo
0P0009TQ0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0hP3oool30000VB40oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`3Q0?ooo`<0002I8P3oool100000040oooo000E0?oo
o`030000003oool0oooo0>00oooo0`0009TS0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0h03oool20000VB@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3O0?ooo`<0002I
903oool100000040oooo000E0?ooo`030000003oool0oooo0=h0oooo0`0009TU0?ooo`4000000@3o
ool001D0oooo0P00003N0?ooo`<0002I9@3oool200000040oooo000E0?ooo`030000003oool0oooo
0=d0oooo0P0009TW0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0g03oool30000VBL0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3K0?ooo`<0002I:03oool100000040oooo
000E0?ooo`030000003oool0oooo0=X0oooo0`0009TY0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0fP3oool20000VBX0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3I0?oo
o`<0002I:P3oool100000040oooo000E0?ooo`800000f@3oool30000VBX0oooo0P0000010?ooo`00
5@3oool00`000000oooo0?ooo`3H0?ooo`80002I;03oool100000040oooo000E0?ooo`030000003o
ool0oooo0=L0oooo0`0009T/0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0eP3oool3
0000VBd0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3E0?ooo`<0002I;P3oool10000
0040oooo000E0?ooo`030000003oool0oooo0=D0oooo0P0009T_0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0e03oool30000VBl0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`3C0?ooo`<0002I<03oool100000040oooo000E0?ooo`800000d`3oool30000VC00oooo0P000001
0?ooo`005@3oool00`000000oooo0?ooo`3B0?ooo`80002I<P3oool100000040oooo000E0?ooo`03
0000003oool0oooo0=40oooo0`0009Tb0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
d03oool30000VC<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3?0?ooo`<0002I=03o
ool100000040oooo000E0?ooo`030000003oool0oooo0<h0oooo0`0009Te0?ooo`4000000@3oool0
00D000000`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0<h0oooo0P0009Tf0?oo
o`4000000@3oool000050?ooo`000000oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0c@3oool30000VCH0oooo0@00
00010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool200000<d0oooo0`0009Tf0?ooo`8000000@3oool000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3;0?ooo`<0002I>03oool100000040oooo00001@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0</0oooo0P0009Ti0?ooo`4000000@3oool000050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0bP3oool30000VCT0oooo0@0000010?ooo`0000@0oooo0000000000000000
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0<T0oooo0`0009Tj0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0b03oool30000VC/0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`370?ooo`<0002I?03oool100000040oooo000E0?ooo`030000003oool0oooo
0<H0oooo0`0009Tm0?ooo`4000000@3oool001D0oooo0P0000360?ooo`<0002I?@3oool200000040
oooo000E0?ooo`030000003oool0oooo0<@0oooo0`0009To0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0``3oool30000VD00oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`32
0?ooo`<0002I@@3oool100000040oooo000E0?ooo`030000003oool0oooo0<40oooo0`0009U20?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0`03oool30000VD<0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`2o0?ooo`<0002IA03oool100000040oooo000E0?ooo`030000003o
ool0oooo0;h0oooo0`0009U50?ooo`4000000@3oool001D0oooo0P00002n0?ooo`<0002IA@3oool2
00000040oooo000E0?ooo`030000003oool0oooo0;`0oooo0`0009U70?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0^`3oool30000VDP0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`2j0?ooo`<0002IB@3oool100000040oooo000E0?ooo`030000003oool0oooo0;T0oooo0`00
09U:0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0^03oool30000VD/0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`2g0?ooo`<0002IC03oool100000040oooo000E0?ooo`03
0000003oool0oooo0;H0oooo0`0009U=0?ooo`4000000@3oool001D0oooo0P00002f0?ooo`<0002I
C@3oool200000040oooo000E0?ooo`030000003oool0oooo0;@0oooo0`0009U?0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0/`3oool30000VE00oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`2b0?ooo`<0002ID@3oool100000040oooo000E0?ooo`030000003oool0oooo0;40
oooo0`0009UB0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0/03oool30000VE<0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`2_0?ooo`<0002IE03oool100000040oooo000E
0?ooo`030000003oool0oooo0:h0oooo0`0009UE0?ooo`4000000@3oool001D0oooo0P00002^0?oo
o`<0002IE@3oool200000040oooo000E0?ooo`030000003oool0oooo0:/0oooo100009UG0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0ZP3oool40000VEP0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`2Y0?ooo`<0002IFP3oool100000040oooo000E0?ooo`030000003oool0
oooo0:P0oooo0`0009UK0?ooo`4000000@3oool000040?ooo`0000000000000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`2V0?ooo`@0002IG03oool100000040oooo00001@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0:D0oooo100009UM0?ooo`4000000@3oool000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0Y03oool30000VEl0oooo0@0000010?ooo`000P3oool2000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000Y03oool30000
VEl0oooo0P0000010?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2R0?ooo`<0002IH@3oool1
00000040oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0:00oooo100009UR0?ooo`400000
0@3oool000040?ooo`0000000000000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`2I0?ooo`80002I103oool40000VF<0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`2H0?ooo`<0002I0`3oool30000VFD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2F
0?ooo`H0002I00@0oooo0000V@0009T0002IIP3oool100000040oooo000E0?ooo`030000003oool0
oooo09D0oooo2P0009UW0?ooo`4000000@3oool001D0oooo0P00002E0?ooo`<0002I0`3oool40000
VFL0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2C0?ooo`<0002I103oool30000VFT0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2A0?ooo`@0002IL@3oool100000040oooo
000E0?ooo`030000003oool0oooo0900oooo100009Ub0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0SP3oool40000VG@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2=0?oo
o`@0002IM@3oool100000040oooo000E0?ooo`030000003oool0oooo08/0oooo100009Ug0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0R@3oool50000VGP0oooo0@0000010?ooo`005@3o
ool200000840oooo0P0009T50?ooo`D0002IN@3oool200000040oooo000E0?ooo`030000003oool0
oooo07h0oooo100009T40?ooo`@0002IO03oool100000040oooo000E0?ooo`030000003oool0oooo
07d0oooo1@0009T30?ooo`<0002IOP3oool100000040oooo000E0?ooo`030000003oool0oooo07/0
oooo100009T00`3oool0002I0000V@050000VGl0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1i0?ooo`D0002I0`3oool50000VH00oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`1h0?ooo`@0002I1@3oool30000VH80oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1f
0?ooo`@0002I1`3oool20000VH<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1c0?oo
o`H0002IS@3oool100000040oooo000E0?ooo`800000LP3oool60000VHh0oooo0P0000010?ooo`00
5@3oool00`000000oooo0?ooo`1V0?ooo`<0002I1P3oool50000VI80oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`1S0?ooo`H0002I1@3oool40000VI@0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`1Q0?ooo`P0002I0`3oool40000VIH0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`1N0?ooo`H0002I0`3oool20000V@030?ooo`0009T0002I00<0002IU`3oool10000
0040oooo000E0?ooo`030000003oool0oooo05d0oooo1@0009T50?ooo`H0002IV@3oool100000040
oooo000E0?ooo`030000003oool0oooo04d0oooo0P0009T<0?ooo`@0002I203oool40000VI/0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`1;0?ooo`@0002I2@3oool60000V@X0oooo0P00
09VL0?ooo`4000000@3oool001D0oooo0P00001:0?ooo`H0002I1`3oool60000VJT0oooo0P000001
0?ooo`005@3oool00`000000oooo0?ooo`0c0?ooo`<0002I3`3oool70000V@040?ooo`0009T0002I
0000V@<0oooo1P0009V]0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool06@3oool40000
VA40oooo200009T;0?ooo`T0002I103oool20000V@030?ooo`0009T0002I00@0002I[`3oool10000
0040oooo000E0?ooo`030000003oool0oooo01L0oooo1P0009T?0?ooo`X0002I203oool80000V@P0
oooo1P0009Vb0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool04@3oool90000V@030?oo
o`0009T0002I00`0oooo1P0009T50?ooo`80002I1@3oool70000V@`0oooo100009Vd0?ooo`400000
0@3oool00080oooo0`0000030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool03P3o
ool:0000V@<0oooo0P0009T80?ooo`P0002I1`3oool20000V@80oooo1`0009W70?ooo`4000000@3o
ool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`P0002I2@3oool20000V@@0oooo
2@0009T:0?ooo`P0002IbP3oool100000040oooo000500000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo2P0009T<0?ooo`80
002I00<0oooo0000V@0009T01P0009T?0?ooo`@0002Ic@3oool100000040oooo000010000000oooo
0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2
000000<0oooo2@0009T@0?ooo`L0002I4`3oool20000VLh0oooo0P0000010?ooo`0000@0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool40000VAD0oooo100009WW0?ooo`4000000@3oool00080oooo0P00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02P3oool100000040
oooo00030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`005@3ooooo000000/000000@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-38.2484, -37.8673, 1.41955, \
2.5393}},
  CellTags->"PaymentToInterest"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"fixedPlot", ",", "variablePlot"}], "]"}], ";"}]], "Input",
  CellLabel->"In[5]:=",
  CellTags->"PaymentToInterest"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 -0.372074 0.00209013 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04595 -18 -4.5 ]
[-0.0125 .04595 0 4.5 ]
[-0.0125 .15046 -18 -4.5 ]
[-0.0125 .15046 0 4.5 ]
[-0.0125 .25496 -18 -4.5 ]
[-0.0125 .25496 0 4.5 ]
[-0.0125 .35947 -18 -4.5 ]
[-0.0125 .35947 0 4.5 ]
[-0.0125 .46398 -18 -4.5 ]
[-0.0125 .46398 0 4.5 ]
[-0.0125 .56848 -18 -4.5 ]
[-0.0125 .56848 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04595 m
.00625 .04595 L
s
[(200)] -0.0125 .04595 1 0 Mshowa
0 .15046 m
.00625 .15046 L
s
[(250)] -0.0125 .15046 1 0 Mshowa
0 .25496 m
.00625 .25496 L
s
[(300)] -0.0125 .25496 1 0 Mshowa
0 .35947 m
.00625 .35947 L
s
[(350)] -0.0125 .35947 1 0 Mshowa
0 .46398 m
.00625 .46398 L
s
[(400)] -0.0125 .46398 1 0 Mshowa
0 .56848 m
.00625 .56848 L
s
[(450)] -0.0125 .56848 1 0 Mshowa
.125 Mabswid
0 .06685 m
.00375 .06685 L
s
0 .08775 m
.00375 .08775 L
s
0 .10866 m
.00375 .10866 L
s
0 .12956 m
.00375 .12956 L
s
0 .17136 m
.00375 .17136 L
s
0 .19226 m
.00375 .19226 L
s
0 .21316 m
.00375 .21316 L
s
0 .23406 m
.00375 .23406 L
s
0 .27587 m
.00375 .27587 L
s
0 .29677 m
.00375 .29677 L
s
0 .31767 m
.00375 .31767 L
s
0 .33857 m
.00375 .33857 L
s
0 .38037 m
.00375 .38037 L
s
0 .40127 m
.00375 .40127 L
s
0 .42217 m
.00375 .42217 L
s
0 .44308 m
.00375 .44308 L
s
0 .48488 m
.00375 .48488 L
s
0 .50578 m
.00375 .50578 L
s
0 .52668 m
.00375 .52668 L
s
0 .54758 m
.00375 .54758 L
s
0 .02505 m
.00375 .02505 L
s
0 .00415 m
.00375 .00415 L
s
0 .58938 m
.00375 .58938 L
s
0 .61029 m
.00375 .61029 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04595 m
1 .04595 L
s
.99375 .15046 m
1 .15046 L
s
.99375 .25496 m
1 .25496 L
s
.99375 .35947 m
1 .35947 L
s
.99375 .46398 m
1 .46398 L
s
.99375 .56848 m
1 .56848 L
s
.125 Mabswid
.99625 .06685 m
1 .06685 L
s
.99625 .08775 m
1 .08775 L
s
.99625 .10866 m
1 .10866 L
s
.99625 .12956 m
1 .12956 L
s
.99625 .17136 m
1 .17136 L
s
.99625 .19226 m
1 .19226 L
s
.99625 .21316 m
1 .21316 L
s
.99625 .23406 m
1 .23406 L
s
.99625 .27587 m
1 .27587 L
s
.99625 .29677 m
1 .29677 L
s
.99625 .31767 m
1 .31767 L
s
.99625 .33857 m
1 .33857 L
s
.99625 .38037 m
1 .38037 L
s
.99625 .40127 m
1 .40127 L
s
.99625 .42217 m
1 .42217 L
s
.99625 .44308 m
1 .44308 L
s
.99625 .48488 m
1 .48488 L
s
.99625 .50578 m
1 .50578 L
s
.99625 .52668 m
1 .52668 L
s
.99625 .54758 m
1 .54758 L
s
.99625 .02505 m
1 .02505 L
s
.99625 .00415 m
1 .00415 L
s
.99625 .58938 m
1 .58938 L
s
.99625 .61029 m
1 .61029 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02646 .60332 m
.06498 .5912 L
.107 .57677 L
.14646 .56194 L
.18441 .54641 L
.22481 .52839 L
.26369 .50947 L
.30502 .48751 L
.34484 .46437 L
.38315 .44012 L
.4239 .41197 L
.46315 .38238 L
.50088 .35142 L
.54105 .3155 L
.57972 .2778 L
.62083 .23404 L
.66042 .18798 L
.69851 .13974 L
.73904 .08375 L
.77806 .02493 L
s
.77806 .02493 m
.7932 0 L
s
0 0 .6 r
.02646 .46398 m
.06498 .45144 L
.08504 .44454 L
.09565 .44078 L
.107 .43668 L
.1125 .43466 L
.1152 .43366 L
.11639 .43322 L
.1177 .43273 L
.11887 .4323 L
.11996 .45996 L
.12112 .46314 L
.12236 .46446 L
.12301 .46421 L
.12372 .46395 L
.12501 .46346 L
.12743 .46255 L
.14646 .45519 L
.16772 .44665 L
.187 .43859 L
.19665 .43443 L
.20172 .43222 L
.20709 .42985 L
.20936 .42884 L
.21179 .42776 L
.2125 .42744 L
.21318 .42713 L
.21446 .45062 L
.21565 .45386 L
.21695 .45734 L
.21803 .45684 L
.21923 .4563 L
.22166 .45519 L
.22602 .45319 L
.26611 .43391 L
.28453 .42451 L
.29497 .41902 L
.30006 .4163 L
.30469 .41381 L
.30707 .41251 L
.30773 .41215 L
.30842 .41178 L
.30966 .43315 L
.31081 .4362 L
.31189 .43906 L
.31308 .43929 L
.31435 .43858 L
.32467 .43278 L
.34571 .42055 L
.36541 .4086 L
Mistroke
.37581 .40209 L
.38688 .39499 L
.39244 .39136 L
.39767 .38791 L
.39996 .38639 L
.40237 .38478 L
.40363 .38393 L
.40435 .38345 L
.40502 .40329 L
.40619 .40624 L
.40745 .40926 L
.40873 .40839 L
.40991 .40757 L
.41258 .40573 L
.41743 .40236 L
.42653 .39594 L
.44676 .38118 L
.46574 .36674 L
.48389 .35234 L
.48886 .3483 L
.49409 .344 L
.49625 .34221 L
.49856 .34029 L
.49924 .33972 L
.49988 .33918 L
.50108 .35861 L
.50221 .36119 L
.50343 .3615 L
.50467 .36044 L
.50579 .35947 L
.50833 .35729 L
.5129 .35331 L
.52329 .34411 L
.54429 .32486 L
.5649 .30504 L
.57397 .29602 L
.58399 .28583 L
.58858 .28109 L
.59099 .27858 L
.59231 .2772 L
.59354 .27592 L
.59461 .27478 L
.59577 .28949 L
.59705 .29193 L
.59821 .29316 L
.59927 .29201 L
.60042 .29077 L
.6025 .2885 L
.62218 .26653 L
.66296 .21763 L
Mistroke
.70222 .16589 L
.73997 .11143 L
.78016 .04786 L
Mfstroke
.78016 .04786 m
.80774 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool2000001d0oooo0`0000040?ooo`8000005`3oool3000000@0oooo0P0000040?oo
o`8000005@3oool3000000<0oooo0`0000040?ooo`8000004`3oool5000000<0oooo0P0000040?oo
o`8000004`3oool500000080oooo0`0000040?ooo`800000503oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`800000203oool001T0oooo00@000000?ooo`3o
ool000006`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000C0?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000I0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`006@3o
ool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000005@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001@0oooo0P0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01@3oool001T0oooo00@000000?ooo`3oool000006`3oool4000000<0oooo
00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`3oool4000000<0oooo00@0
00000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000B0?ooo`060000003oool0oooo0?ooo`000000oooo
100000030?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000003
0?ooo`040000003oool0oooo000000L0oooo000I0?ooo`040000003oool0oooo000001/0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`800000103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001@0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000070?ooo`006P3o
ool2000001`0oooo1@0000030?ooo`800000603oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000001H0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000203oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooood@00000209T000800000
0P0009Tc00000040oooo000E0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo0P2I00020?ooo`80002I0P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000000@3o
ool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool05`3oool309T000040?ooo`0009T0002I0000V@80oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0c@3oool209T00080oooo0P0009Tc0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0c03oool309T000040?ooo`0009T0002I0000VC<0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3;0?ooo`<0V@000P3oool20000VC@0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3;0?ooo`80V@000P3oool30000VC@0oooo0@0000010?ooo`005@3oool200000</0oooo
0`2I0000103oool0002I0000V@0009Td0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0
bP3oool209T00080oooo0P0009Tf0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0b@3o
ool309T000040?ooo`0009T0002I0000VCH0oooo0@0000010?ooo`001@0000030?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0b03oool309T00080oooo0P0009Tg0?ooo`4000000@3o
ool000050?ooo`000000oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0b03oool209T00080oooo0`0009Tg0?ooo`40
00000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo0P0000380?ooo`<0V@000P3oool20000VCL0oooo0P0000010?oo
o`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0<H0oooo0`2I00020?ooo`<0002I>03oool1
00000040oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<H0oooo0P2I00030?ooo`80002I
>@3oool100000040oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<D0oooo0`2I00020?oo
o`<0002I>@3oool100000040oooo0000103oool000000000000000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0a03oool309T00080oooo0`0009Tj0?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0a03oool209T000<0oooo0P0009Tk0?ooo`4000000@3oool001D0oooo
0P0000340?ooo`<0V@000P3oool30000VCX0oooo0P0000010?ooo`005@3oool00`000000oooo0?oo
o`320?ooo`<0V@000P3oool30000VC`0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`32
0?ooo`80V@000`3oool20000VCd0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`310?oo
o`<0V@000P3oool30000VCd0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`300?ooo`<0
V@000P3oool30000VCh0oooo0@0000010?ooo`005@3oool200000<40oooo0P2I00030?ooo`80002I
?P3oool200000040oooo000E0?ooo`030000003oool0oooo0;l0oooo0`2I00020?ooo`<0002I?`3o
ool100000040oooo000E0?ooo`030000003oool0oooo0;h0oooo0`2I00030?ooo`80002I@03oool1
00000040oooo000E0?ooo`030000003oool0oooo0;d0oooo0`2I00030?ooo`<0002I@03oool10000
0040oooo000E0?ooo`030000003oool0oooo0;d0oooo0P2I00030?ooo`<0002I@@3oool100000040
oooo000E0?ooo`030000003oool0oooo0;`0oooo0`2I00030?ooo`80002I@P3oool100000040oooo
000E0?ooo`800000_03oool309T000<0oooo0`0009U10?ooo`8000000@3oool001D0oooo00<00000
0?ooo`3oool0^P3oool309T000<0oooo0`0009U30?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0^P3oool209T000@0oooo0P0009U40?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0^@3oool309T000<0oooo0`0009U40?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
^03oool309T000<0oooo0`0009U50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0^03o
ool209T000<0oooo0`0009U60?ooo`4000000@3oool001D0oooo0P00002h0?ooo`<0V@000`3oool2
0000VDH0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2f0?ooo`<0V@000`3oool30000
VDL0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2e0?ooo`<0V@000`3oool30000VDP0
oooo0@0000010?ooo`001@0000020?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0
]@3oool209T000@0oooo0P0009U90?ooo`4000000@3oool000070?ooo`000000oooo0?ooo`000000
oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2d0?ooo`<0V@000`3oool30000VDT0oooo0@0000010?ooo`000P3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool20000
0;@0oooo0`2I00030?ooo`<0002IB@3oool200000040oooo00030?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0;80oooo0`2I00030?ooo`<0002IB`3oool100000040oooo00001P000000oooo0?ooo`3oool00000
0?ooo`@000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0;80oooo0P2I
00040?ooo`80002IC03oool100000040oooo00001`000000oooo0?ooo`3oool000000?ooo`000000
1P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0;40oooo0`2I00030?ooo`<0
002IC03oool100000040oooo0000103oool000000000000000020?ooo`D000000`3oool2000000D0
oooo00<000000?ooo`3oool0/03oool309T000<0oooo0`0009U=0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0[`3oool309T000@0oooo0P0009U>0?ooo`4000000@3oool001D0oooo0P00
002_0?ooo`<0V@00103oool30000VDd0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2^
0?ooo`80V@00103oool30000VDl0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2]0?oo
o`<0V@000`3oool30000VE00oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2/0?ooo`<0
V@00103oool20000VE40oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2[0?ooo`<0V@00
103oool30000VE40oooo0@0000010?ooo`005@3oool200000:`0oooo0P2I00040?ooo`<0002ID@3o
ool200000040oooo000E0?ooo`030000003oool0oooo0:X0oooo0`2I00040?ooo`80002ID`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0:T0oooo0`2I00040?ooo`<0002ID`3oool10000
0040oooo000E0?ooo`030000003oool0oooo0:P0oooo0`2I00040?ooo`<0002IE03oool100000040
oooo000E0?ooo`030000003oool0oooo0:L0oooo0`2I00040?ooo`<0002IE@3oool100000040oooo
000E0?ooo`030000003oool0oooo0:H0oooo0`2I00050?ooo`80002IEP3oool100000040oooo000E
0?ooo`800000Y`3oool209T000D0oooo0`0009UE0?ooo`8000000@3oool001D0oooo00<000000?oo
o`3oool0Y@3oool309T000@0oooo0`0009UG0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0Y03oool309T000D0oooo0P0009UH0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
X`3oool309T000D0oooo0`0009UH0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0XP3o
ool309T000D0oooo0`0009UI0?ooo`4000000@3oool001D0oooo0P00002R0?ooo`<0V@001@3oool3
0000VET0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2Q0?ooo`80V@001@3oool30000
VE/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2P0?ooo`<0V@00103oool30000VE`0
oooo0@0000010?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo09l0oooo0`2I00040?ooo`<0002IG@3oool100000040oooo00001@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo09h0oooo0`2I00050?ooo`80002IGP3oool100000040oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo09d0oooo0`2I00050?ooo`<0002IGP3oool100000040oooo0002
0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
0P00002M0?ooo`<0V@001@3oool30000VEh0oooo0P0000010?ooo`00103oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2K0?ooo`<0V@001@3oool30000VF00oooo0@0000010?ooo`0000D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`2J0?ooo`<0V@001@3oool30000VF40oooo0@0000010?ooo`0000@0oooo0000
000000000000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo09T0oooo0`2I0005
0?ooo`<0002IHP3oool100000040oooo000E0?ooo`030000003oool0oooo09P0oooo0`2I00060?oo
o`80002IH`3oool100000040oooo000E0?ooo`800000V03oool209T000<0002I103oool30000VF80
oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`2F0?ooo`<0V@000`0009T30?ooo`<0002I
I03oool100000040oooo000E0?ooo`030000003oool0oooo09D0oooo0`2I00040000V@80oooo0`00
09UU0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0U03oool309T000D0002I00@0oooo
0000V@0009T0002IIP3oool100000040oooo000E0?ooo`030000003oool0oooo09<0oooo0`2I0003
0000V@030?ooo`0009T0002I00<0002II`3oool100000040oooo000E0?ooo`030000003oool0oooo
0980oooo0`2I00030000V@80oooo100009UX0?ooo`4000000@3oool001D0oooo0P00002B0?ooo`<0
V@000`0009T30?ooo`<0002IJ03oool200000040oooo000E0?ooo`030000003oool0oooo0900oooo
0`2I00030000VG00oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2?0?ooo`80V@001000
09Ua0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0SP3oool209T000@0002ILP3oool1
00000040oooo000E0?ooo`030000003oool0oooo08d0oooo0P2I00030000VG@0oooo0@0000010?oo
o`005@3oool2000008`0oooo0`2I00030000VG@0oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`2:0?ooo`<0V@000`0009Uf0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0R@3o
ool309T000<0002IM`3oool100000040oooo000E0?ooo`030000003oool0oooo08P0oooo0`2I0000
0`3oool0002I0000V@1h0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0QP3oool409T0
00040?ooo`0009T0002I0000VGP0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`250?oo
o`@0V@0000@0oooo0000V@0009T0002IN@3oool100000040oooo000E0?ooo`800000P@3oool30000
V@040?ooo`2I0000V@0009T00080oooo0`0009Ui0?ooo`8000000@3oool001D0oooo00<000000?oo
o`3oool0O`3oool40000V@<0V@000P3oool30000VG/0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`1o0?ooo`@0002I0P2I00000`3oool0002I0000V@020000VG`0oooo0@0000010?ooo`00
00@0oooo00000000000000000`3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo07d0
oooo1P0009T00`2I0000oooo0000V@030000VGd0oooo0@0000010?ooo`0000L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07`0oooo100009T0102I0000002I0000V@3oool30000VGl0oooo0@00
00010?ooo`00103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1k0?ooo`<0002I0`2I00050000VH00oooo0@00
00010?ooo`000P3oool2000000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`800000N`3oool30000V@<0V@0000<0oooo0000V@0009T00P0009V00?ooo`8000000@3o
ool000@0oooo00<000000?ooo`0000000`0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0N@3oool30000V@<0V@000P3oool30000VH80oooo0@0000010?ooo`0000L00000
0?ooo`3oool0oooo0000003oool0000000H0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1g0?ooo`@0002I0`2I00280?ooo`4000000@3oool000040?ooo`000000000000000080
oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`1e0?ooo`D0002I0`2I00290?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0L`3oool50000V@040?ooo`2I0000V@0009T008X0
oooo0@0000010?ooo`005@3oool200000780oooo1@0009T20?ooo`<0V@00RP3oool200000040oooo
000E0?ooo`030000003oool0oooo06L0oooo0P0009T70?ooo`@0002I0P3oool409T008`0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`1U0?ooo`@0002I1P3oool30000V@<0oooo102I002=
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0I03oool50000V@D0oooo0`0009T30?oo
o`<0V@00S`3oool100000040oooo000E0?ooo`030000003oool0oooo0680oooo100009T00`3oool0
002I0000V@040?ooo`<0002I0P3oool409T00900oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`1Q0?ooo`@0002I0P3oool20000V@<0oooo0`0009T20?ooo`@0V@00T@3oool100000040oooo
000E0?ooo`800000H03oool40000V@@0oooo0P0009T00`3oool0002I0000V@020000V@030?ooo`2I
0000V@000080V@00TP3oool200000040oooo000E0?ooo`030000003oool0oooo05h0oooo100009T5
0?ooo`H0002I00<0oooo09T0002I00000P2I002D0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0CP3oool20000V@`0oooo100009T80?ooo`<0002I0P3oool309T009H0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`1=0?ooo`<0002I2P3oool50000V@T0oooo0P0009T00`3oool0
V@0009T0000209T009L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`190?ooo`L0002I
2@3oool40000V@d0oooo102I002H0?ooo`4000000@3oool001D0oooo0P0000190?ooo`P0002I1`3o
ool40000V@d0oooo102I002I0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0AP3oool4
0000V@@0oooo0P0009T50?ooo`D0002I3@3oool409T009/0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`0b0?ooo`@0002I3@3oool60000V@D0oooo0P0009T30?ooo`D0002I3P3oool309T0
09d0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0J0?ooo`<0002I4P3oool70000V@/0
oooo1P0009T70?ooo`80002I00<0oooo0000V@0009T00`0009T>0?ooo`@0V@00WP3oool100000040
oooo000E0?ooo`030000003oool0oooo01L0oooo1P0009TA0?ooo`D0002I00<0oooo0000V@0009T0
2@3oool50000V@X0oooo1P0009T?0?ooo`@0V@00W`3oool100000040oooo000E0?ooo`030000003o
ool0oooo01@0oooo2@0009T?0?ooo`@0002I103oool20000V@L0oooo1@0009T<0?ooo`@0002I3`3o
ool409T00:40oooo0@0000010?ooo`005@3oool200000180oooo1`0009T30?ooo`80002I303oool6
0000V@D0oooo0`0009T40?ooo`D0002I3`3oool20000V@h0oooo1@2I002Q0?ooo`8000000@3oool0
01D0oooo00<000000?ooo`3oool03P3oool70000V@H0oooo0`0009T90?ooo`H0002I203oool20000
V@80oooo1@0009TO0?ooo`D0V@00Y03oool100000040oooo000E0?ooo`030000003oool0oooo00/0
oooo1`0009T:0?ooo`80002I1P3oool60000V@/0oooo0P0009T00`3oool0002I0000V@020000VB00
oooo102I002V0?ooo`4000000@3oool00080oooo0`0000030?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0203oool70000V@d0oooo0P0009T40?ooo`H0002I3@3oool50000VB00oooo
102I002X0?ooo`4000000@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`L0
002I403oool20000V@030?ooo`0009T0002I00@0002I403oool40000VAl0oooo1@2I002Y0?ooo`40
00000@3oool000D000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo0P0000040?ooo`H0002I4`3oool70000VA80oooo0P0009TO0?ooo`D0V@00ZP3oool20000
0040oooo000010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`<0002I5P3oool40000VCD0oooo102I
002]0?ooo`4000000@3oool000040?ooo`000000oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05<0oooo102I002_0?ooo`40
00000@3oool00080oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1B0?ooo`@0V@00/03oool100000040oooo00030?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1A0?ooo`<0
V@00/P3oool100000040oooo000E0?ooo`030000003oool0oooo04l0oooo102I002c0?ooo`400000
0@3oool001D0oooo0P00001?0?ooo`@0V@00/`3oool200000040oooo000E0?ooo`030000003oool0
oooo04`0oooo102I002f0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0BP3oool509T0
0;L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`170?ooo`H0V@00^@3oool100000040
oooo000E0?ooo`030000003oool0oooo04D0oooo1P2I002k0?ooo`4000000@3oool001D0oooo0P00
00140?ooo`D0V@00_@3oool200000040oooo000E0?ooo`030000003oool0oooo0440oooo1@2I0030
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0?`3oool509T00<80oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`0m0?ooo`D0V@00a03oool100000040oooo000E0?ooo`030000
003oool0oooo03/0oooo1@2I00360?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0>@3o
ool509T00<P0oooo0@0000010?ooo`005@3oool2000003P0oooo1@2I00390?ooo`8000000@3oool0
01D0oooo00<000000?ooo`3oool0=@3oool509T00<`0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`0b0?ooo`H0V@00cP3oool100000040oooo000E0?ooo`030000003oool0oooo0300oooo
1P2I003@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0;P3oool509T00=<0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`0/0?ooo`D0V@00e@3oool100000040oooo000E0?oo
o`800000:P3oool609T00=H0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`0W0?ooo`H0
V@00f@3oool100000040oooo000E0?ooo`030000003oool0oooo02@0oooo1P2I003L0?ooo`400000
0@3oool00080oooo0`0000020?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool08P3o
ool609T00=h0oooo0@0000010?ooo`000`3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`H0V@00
h@3oool100000040oooo0005000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`8000007@3oool709T00>80oooo0P0000010?ooo`0000@000000?ooo`3oool00000
1P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06@3oool709T00>H0oooo0@0000010?ooo`0000@0oooo0000003oool000000P3oool4000000<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`H0V@00j@3oool10000
0040oooo00020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0503oool609T00>`0oooo0@0000010?ooo`000`3oool00`000000
oooo0?ooo`05000000<0oooo0P0000050?ooo`030000003oool0oooo0140oooo1`2I003^0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool03P3oool709T00?40oooo0@0000010?ooo`005@3o
ool2000000`0oooo1`2I003c0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0203oool7
09T00?L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`050?ooo`L0V@00nP3oool10000
0040oooo000E0?ooo`030000003oool0oooo00<0oooo1P2I003m0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00`3oool309T00?l0oooo0@3oool100000040oooo000E0?ooo`800000o`3o
ool70?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`4000000@3oool001D0ooooo`00000;00000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-39.349, 155.37, 1.42345, \
1.80167}},
  CellTags->"PaymentToInterest"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"PaymentToPrincipal"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"PaymentToPrincipal"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentToPrincipal"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentToPrincipal"],

Cell[CellGroupData[{

Cell["PaymentToPrincipal", "Section",
  CellTags->"PaymentToPrincipal"],

Cell[TextData[{
  StyleBox["PaymentToPrincipal", "MR"],
  " computes the portion of a payment paid to principal."
}], "Text",
  CellTags->"PaymentToPrincipal"],

Cell["\<\
PaymentToPrincipal[{HomeCost, PercentageDownPayment}, InterestRate, \
Years, PaymentNumber] gives the portion of the payment given by PaymentNumber \
that is paid into principal for a loan on a house of initial value given by \
HomeCost with a down payment given by PercentageDownPayment for a loan \
amortized over the number of years given by Years with the fixed interest \
rate given by InterestRate. 

PaymentToPrincipal[LoanAmount, InterestRate, Years, PaymentNumber] assumes a \
loan amount given by LoanAmount. 

PaymentToPrincipal[{HomeCost, PercentageDownPayment}, {{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber] calculates for a variable rate loan with interest rate \
InterestRate1 for a number of payments given by Payments1 followed by \
InterestRate2 for a number of payments given by Payments2, and so on. Note \
that PaymentNumber must be given. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. If PaymentNumber is not numerical then an \
analytical result will be returned (if $StrongErrorChecking is not True) that \
assumes that PaymentNumber is greater than \
Payments1+Payments2+...+Payments(M-1).

PaymentToPrincipal[LoanAmount, {{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, Years, PaymentNumber] is also a \
valid input.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToPrincipal"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PaymentToPrincipal", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToPrincipal"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToPrincipal"],

Cell[TextData[{
  "Default options for ",
  StyleBox["PaymentToPrincipal", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToPrincipal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToPrincipal"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PaymentToPrincipal", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentToPrincipal"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"PaymentToPrincipal"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"PaymentToPrincipal"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"fixedPlot", "=", 
        RowBox[{"Plot", "[", 
          RowBox[{
            RowBox[{"PaymentToPrincipal", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"100000", ",", " ", "20"}], "}"}], ",", " ", "7.0", 
                ",", " ", "30", ",", " ", "\[Mu]"}], "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"\[Mu]", ",", "1", ",", "360"}], "}"}]}], "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"PaymentToPrincipal"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 0.0147151 0.00111235 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12595 -18 -4.5 ]
[-0.0125 .12595 0 4.5 ]
[-0.0125 .23718 -18 -4.5 ]
[-0.0125 .23718 0 4.5 ]
[-0.0125 .34842 -18 -4.5 ]
[-0.0125 .34842 0 4.5 ]
[-0.0125 .45965 -18 -4.5 ]
[-0.0125 .45965 0 4.5 ]
[-0.0125 .57089 -18 -4.5 ]
[-0.0125 .57089 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12595 m
.00625 .12595 L
s
[(100)] -0.0125 .12595 1 0 Mshowa
0 .23718 m
.00625 .23718 L
s
[(200)] -0.0125 .23718 1 0 Mshowa
0 .34842 m
.00625 .34842 L
s
[(300)] -0.0125 .34842 1 0 Mshowa
0 .45965 m
.00625 .45965 L
s
[(400)] -0.0125 .45965 1 0 Mshowa
0 .57089 m
.00625 .57089 L
s
[(500)] -0.0125 .57089 1 0 Mshowa
.125 Mabswid
0 .03696 m
.00375 .03696 L
s
0 .05921 m
.00375 .05921 L
s
0 .08146 m
.00375 .08146 L
s
0 .1037 m
.00375 .1037 L
s
0 .1482 m
.00375 .1482 L
s
0 .17044 m
.00375 .17044 L
s
0 .19269 m
.00375 .19269 L
s
0 .21494 m
.00375 .21494 L
s
0 .25943 m
.00375 .25943 L
s
0 .28168 m
.00375 .28168 L
s
0 .30393 m
.00375 .30393 L
s
0 .32617 m
.00375 .32617 L
s
0 .37067 m
.00375 .37067 L
s
0 .39291 m
.00375 .39291 L
s
0 .41516 m
.00375 .41516 L
s
0 .43741 m
.00375 .43741 L
s
0 .4819 m
.00375 .4819 L
s
0 .50415 m
.00375 .50415 L
s
0 .52639 m
.00375 .52639 L
s
0 .54864 m
.00375 .54864 L
s
0 .59314 m
.00375 .59314 L
s
0 .61538 m
.00375 .61538 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12595 m
1 .12595 L
s
.99375 .23718 m
1 .23718 L
s
.99375 .34842 m
1 .34842 L
s
.99375 .45965 m
1 .45965 L
s
.99375 .57089 m
1 .57089 L
s
.125 Mabswid
.99625 .03696 m
1 .03696 L
s
.99625 .05921 m
1 .05921 L
s
.99625 .08146 m
1 .08146 L
s
.99625 .1037 m
1 .1037 L
s
.99625 .1482 m
1 .1482 L
s
.99625 .17044 m
1 .17044 L
s
.99625 .19269 m
1 .19269 L
s
.99625 .21494 m
1 .21494 L
s
.99625 .25943 m
1 .25943 L
s
.99625 .28168 m
1 .28168 L
s
.99625 .30393 m
1 .30393 L
s
.99625 .32617 m
1 .32617 L
s
.99625 .37067 m
1 .37067 L
s
.99625 .39291 m
1 .39291 L
s
.99625 .41516 m
1 .41516 L
s
.99625 .43741 m
1 .43741 L
s
.99625 .4819 m
1 .4819 L
s
.99625 .50415 m
1 .50415 L
s
.99625 .52639 m
1 .52639 L
s
.99625 .54864 m
1 .54864 L
s
.99625 .59314 m
1 .59314 L
s
.99625 .61538 m
1 .61538 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02646 .08766 m
.06498 .09411 L
.107 .10179 L
.14646 .10968 L
.18441 .11794 L
.22481 .12753 L
.26369 .1376 L
.30502 .14929 L
.34484 .1616 L
.38315 .17451 L
.4239 .18949 L
.46315 .20524 L
.50088 .22172 L
.54105 .24083 L
.57972 .2609 L
.62083 .28418 L
.66042 .30869 L
.69851 .33437 L
.73904 .36417 L
.77806 .39547 L
.81953 .43181 L
.85949 .47011 L
.89793 .51028 L
.93882 .55689 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[2]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool2000001d0oooo0`0000040?ooo`8000005`3oool3000000@0oooo0P0000040?oo
o`8000005@3oool3000000<0oooo0`0000040?ooo`8000004`3oool5000000<0oooo0P0000040?oo
o`8000004`3oool500000080oooo0`0000040?ooo`800000503oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`800000203oool001T0oooo00@000000?ooo`3o
ool000006`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000C0?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000I0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`006@3o
ool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000005@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001@0oooo0P0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01@3oool001T0oooo00@000000?ooo`3oool000006`3oool4000000<0oooo
00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`3oool4000000<0oooo00@0
00000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000B0?ooo`060000003oool0oooo0?ooo`000000oooo
100000030?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000003
0?ooo`040000003oool0oooo000000L0oooo000I0?ooo`040000003oool0oooo000001/0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`800000103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001@0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000070?ooo`006P3o
ool2000001`0oooo1@0000030?ooo`800000603oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000001H0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000203oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo
000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool100000040oooo000>
0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool02P3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000103oool2
00000?l0oooo1`3oool200000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000>0?ooo`8000001@3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo0@0000010?ooo`005@3oool200000?l0oooo1`3oool200000040oooo000E0?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`03
0000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo
1`3oool100000040oooo000E0?ooo`800000o`3oool70?ooo`8000000@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`4000000@3oool001D0oooo0P00003o0?ooo`L0oooo0P0000010?ooo`005@3oool00`00
0000oooo0?ooo`030?ooo`D0V@00oP3oool100000040oooo000E0?ooo`030000003oool0oooo00<0
oooo2P2I003i0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool01`3oool;09T00?@0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`0<0?ooo`/0V@00k`3oool100000040oooo000E
0?ooo`030000003oool0oooo0140oooo302I003Y0?ooo`4000000@3oool001D0oooo0P00000G0?oo
o``0V@00h`3oool200000040oooo000E0?ooo`030000003oool0oooo01`0oooo302I003N0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool08@3oool<09T00=T0oooo0@0000010?ooo`0000@0
oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo
2P2I003E0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0;03oool909T00=40
oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0`0?ooo`P0V@00cP3oool10000
0040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`800000=@3oool809T00<T0oooo0P0000010?ooo`000P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0g0?ooo`P0V@00a`3oool100000040oooo00000`3oool0000000000004
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0k0?ooo`L0V@00a03oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`0n0?ooo`P0V@00`03oool100000040oooo000E
0?ooo`030000003oool0oooo0440oooo2@2I002l0?ooo`4000000@3oool001D0oooo0P0000160?oo
o`P0V@00^03oool200000040oooo000E0?ooo`030000003oool0oooo04T0oooo202I002e0?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0C03oool809T00;80oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`1@0?ooo`L0V@00[`3oool100000040oooo000E0?ooo`030000003oool0
oooo05<0oooo202I002[0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0EP3oool909T0
0:L0oooo0@0000010?ooo`005@3oool2000005/0oooo202I002S0?ooo`8000000@3oool001D0oooo
00<000000?ooo`3oool0GP3oool709T00:40oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`1Q0?ooo`L0V@00WP3oool100000040oooo000E0?ooo`030000003oool0oooo06@0oooo1P2I002L
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0I`3oool609T009T0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`1Y0?ooo`H0V@00U`3oool100000040oooo000E0?ooo`800000
K@3oool509T009@0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1^0?ooo`H0V@00TP3o
ool100000040oooo000E0?ooo`030000003oool0oooo0700oooo1P2I002@0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0L`3oool509T008h0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`1e0?ooo`D0V@00S03oool100000040oooo000E0?ooo`030000003oool0oooo07L0oooo
1P2I00290?ooo`4000000@3oool001D0oooo0P00001j0?ooo`H0V@00QP3oool200000040oooo000E
0?ooo`030000003oool0oooo07`0oooo1P2I00240?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0OP3oool609T00880oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`210?ooo`D0
V@00P03oool100000040oooo0005000000<0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`230?ooo`H0V@00O@3oool100000040oooo00001@3oool000000?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
08D0oooo1P2I001k0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P0000290?ooo`D0V@00N03oool2
00000040oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0RP3oool509T007L0oooo0@00
00010?ooo`0000D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2<0?ooo`D0V@00M@3oool100000040
oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo08h0oooo1@2I001c0?ooo`4000000@3oool0
00040?ooo`0000000000000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`2@
0?ooo`D0V@00L@3oool100000040oooo000E0?ooo`030000003oool0oooo0980oooo1@2I001_0?oo
o`4000000@3oool001D0oooo0P00002E0?ooo`D0V@00K03oool200000040oooo000E0?ooo`030000
003oool0oooo09H0oooo102I001/0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0V03o
ool409T006X0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2I0?ooo`D0V@00J03oool1
00000040oooo000E0?ooo`030000003oool0oooo09/0oooo102I001W0?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0W@3oool409T006D0oooo0@0000010?ooo`005@3oool2000009l0oooo
102I001S0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0X03oool409T00680oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`2Q0?ooo`D0V@00H03oool100000040oooo000E0?oo
o`030000003oool0oooo0:<0oooo102I001O0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0Y@3oool409T005d0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2V0?ooo`D0V@00
F`3oool100000040oooo000E0?ooo`800000Z@3oool409T005T0oooo0P0000010?ooo`005@3oool0
0`000000oooo0?ooo`2Z0?ooo`@0V@00F03oool100000040oooo000E0?ooo`030000003oool0oooo
0:/0oooo102I001G0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0[@3oool409T005D0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2^0?ooo`@0V@00E03oool100000040oooo
000E0?ooo`030000003oool0oooo0;00oooo0`2I001C0?ooo`4000000@3oool001D0oooo0P00002b
0?ooo`@0V@00D03oool200000040oooo000E0?ooo`030000003oool0oooo0;80oooo102I001@0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0]03oool409T004h0oooo0@0000010?ooo`00
00@0oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0;D0
oooo102I001=0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0]`3oool3
09T004`0oooo0@0000010?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2h0?ooo`@0V@00BP3o
ool100000040oooo00020?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo0P00002j0?ooo`@0V@00B03oool200000040oooo00040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0;/0oooo102I00170?ooo`4000000@3oool000050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0_03oool409T004H0oooo0@0000010?ooo`0000@0oooo0000000000000000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo0;h0oooo0`2I00150?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0_`3oool409T004<0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`300?ooo`@0V@00@P3oool100000040oooo000E0?ooo`800000``3oool309T00400oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`330?ooo`<0V@00@03oool100000040oooo000E
0?ooo`030000003oool0oooo0<@0oooo102I000n0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0a@3oool409T003d0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`370?ooo`<0
V@00?03oool100000040oooo000E0?ooo`800000b@3oool309T003X0oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`390?ooo`@0V@00>@3oool100000040oooo000E0?ooo`030000003oool0
oooo0<X0oooo102I000h0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0c03oool309T0
03L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3=0?ooo`<0V@00=P3oool100000040
oooo000E0?ooo`030000003oool0oooo0<h0oooo0`2I000e0?ooo`4000000@3oool001D0oooo0P00
003@0?ooo`<0V@00<`3oool200000040oooo000E0?ooo`030000003oool0oooo0=00oooo0`2I000c
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0d@3oool309T00380oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3B0?ooo`<0V@00<@3oool100000040oooo000E0?ooo`030000
003oool0oooo0=<0oooo0`2I000`0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0e03o
ool409T002h0oooo0@0000010?ooo`005@3oool200000=H0oooo102I000/0?ooo`8000000@3oool0
01D0oooo00<000000?ooo`3oool0e`3oool309T002`0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3H0?ooo`<0V@00:`3oool100000040oooo000E0?ooo`030000003oool0oooo0=T0oooo
0`2I000Z0?ooo`4000000@3oool00080oooo0`0000030?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0fP3oool309T002T0oooo0@0000010?ooo`000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=/0oooo0`2I000X0?ooo`4000000@3oool000D000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo0P00003M0?ooo`<0V@009P3oool200000040
oooo000010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3M0?ooo`<0V@009P3oool100000040oooo0000103o
ool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3N0?ooo`<0V@009@3oool100000040oooo00020?ooo`8000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0g`3oool309T002@0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`020?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0h03oool209T002@0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3P0?ooo`<0V@008`3oool100000040oooo000E0?ooo`800000hP3oool3
09T00240oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3R0?ooo`<0V@008@3oool10000
0040oooo000E0?ooo`030000003oool0oooo0><0oooo0`2I000P0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0i03oool309T001l0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`3U0?ooo`<0V@007P3oool100000040oooo000E0?ooo`030000003oool0oooo0>H0oooo0`2I000M
0?ooo`4000000@3oool001D0oooo0P00003X0?ooo`<0V@006`3oool200000040oooo000E0?ooo`03
0000003oool0oooo0>P0oooo0`2I000K0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
j@3oool309T001X0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3Z0?ooo`80V@006P3o
ool100000040oooo000E0?ooo`030000003oool0oooo0>X0oooo0`2I000I0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0j`3oool309T001P0oooo0@0000010?ooo`005@3oool200000>d0
oooo0`2I000F0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0k@3oool309T001H0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`3^0?ooo`<0V@005@3oool100000040oooo000E
0?ooo`030000003oool0oooo0>l0oooo0`2I000D0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0l03oool309T001<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3a0?ooo`<0
V@004P3oool100000040oooo000E0?ooo`800000l`3oool309T00100oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`3c0?ooo`<0V@00403oool100000040oooo000E0?ooo`030000003oool0
oooo0?@0oooo0`2I000?0?ooo`4000000@3oool000040?ooo`0000000000000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`3e0?ooo`80V@003`3oool100000040oooo00001@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0?D0oooo0`2I000>0?ooo`4000000@3oool000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0mP3oool309T000d0oooo0@0000010?ooo`00103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool20000
0?P0oooo0`2I000;0?ooo`8000000@3oool000@000000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0n03oool309T000/0oooo0@000001
0?ooo`0000<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0n@3oool309T000X0oooo0@0000010?ooo`001@000003
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0nP3oool209T000X0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`3j0?ooo`<0V@002@3oool100000040oooo000E0?ooo`03
0000003oool0oooo0?/0oooo0`2I00080?ooo`4000000@3oool001D0oooo0P00003m0?ooo`<0V@00
1P3oool200000040oooo000E0?ooo`030000003oool0oooo0?d0oooo0`2I00060?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0oP3oool309T000D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`80V@001@3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0
oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool100000040oooo000E0?ooool000002`0000010?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-39.349, -55.7784, 1.42345, \
3.38538}},
  CellTags->"PaymentToPrincipal"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"interestRateTable", "=", 
      RowBox[{"Table", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"6", " ", "+", 
                RowBox[{"0.25", " ", "i"}]}], ",", "36"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"PaymentToPrincipal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"6", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.25`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.5`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.75`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.25`", ",", "36"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.5`", ",", "36"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"PaymentToPrincipal"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"variablePlot", "=", 
        RowBox[{"Plot", "[", 
          RowBox[{
            RowBox[{"PaymentToPrincipal", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"100000", ",", " ", "20"}], "}"}], ",", " ", 
                "interestRateTable", ",", " ", "30", ",", " ", "\[Mu]"}], 
              "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"\[Mu]", ",", "1", ",", "360"}], "}"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
            RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", " ", "0", ",", " ", ".6"}], "]"}], ",", 
                  
                  RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}]}], 
          "]"}]}], ";"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"PaymentToPrincipal"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0211566 0.00265287 -0.0883859 0.00129458 [
[.02116 -0.0125 -3 -9 ]
[.02116 -0.0125 3 0 ]
[.1538 -0.0125 -6 -9 ]
[.1538 -0.0125 6 0 ]
[.28644 -0.0125 -9 -9 ]
[.28644 -0.0125 9 0 ]
[.41909 -0.0125 -9 -9 ]
[.41909 -0.0125 9 0 ]
[.55173 -0.0125 -9 -9 ]
[.55173 -0.0125 9 0 ]
[.68437 -0.0125 -9 -9 ]
[.68437 -0.0125 9 0 ]
[.81702 -0.0125 -9 -9 ]
[.81702 -0.0125 9 0 ]
[.94966 -0.0125 -9 -9 ]
[.94966 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04107 -18 -4.5 ]
[-0.0125 .04107 0 4.5 ]
[-0.0125 .17053 -18 -4.5 ]
[-0.0125 .17053 0 4.5 ]
[-0.0125 .29999 -18 -4.5 ]
[-0.0125 .29999 0 4.5 ]
[-0.0125 .42945 -18 -4.5 ]
[-0.0125 .42945 0 4.5 ]
[-0.0125 .5589 -18 -4.5 ]
[-0.0125 .5589 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02116 0 m
.02116 .00625 L
s
[(0)] .02116 -0.0125 0 1 Mshowa
.1538 0 m
.1538 .00625 L
s
[(50)] .1538 -0.0125 0 1 Mshowa
.28644 0 m
.28644 .00625 L
s
[(100)] .28644 -0.0125 0 1 Mshowa
.41909 0 m
.41909 .00625 L
s
[(150)] .41909 -0.0125 0 1 Mshowa
.55173 0 m
.55173 .00625 L
s
[(200)] .55173 -0.0125 0 1 Mshowa
.68437 0 m
.68437 .00625 L
s
[(250)] .68437 -0.0125 0 1 Mshowa
.81702 0 m
.81702 .00625 L
s
[(300)] .81702 -0.0125 0 1 Mshowa
.94966 0 m
.94966 .00625 L
s
[(350)] .94966 -0.0125 0 1 Mshowa
.125 Mabswid
.04769 0 m
.04769 .00375 L
s
.07421 0 m
.07421 .00375 L
s
.10074 0 m
.10074 .00375 L
s
.12727 0 m
.12727 .00375 L
s
.18033 0 m
.18033 .00375 L
s
.20686 0 m
.20686 .00375 L
s
.23339 0 m
.23339 .00375 L
s
.25992 0 m
.25992 .00375 L
s
.31297 0 m
.31297 .00375 L
s
.3395 0 m
.3395 .00375 L
s
.36603 0 m
.36603 .00375 L
s
.39256 0 m
.39256 .00375 L
s
.44562 0 m
.44562 .00375 L
s
.47214 0 m
.47214 .00375 L
s
.49867 0 m
.49867 .00375 L
s
.5252 0 m
.5252 .00375 L
s
.57826 0 m
.57826 .00375 L
s
.60479 0 m
.60479 .00375 L
s
.63132 0 m
.63132 .00375 L
s
.65785 0 m
.65785 .00375 L
s
.7109 0 m
.7109 .00375 L
s
.73743 0 m
.73743 .00375 L
s
.76396 0 m
.76396 .00375 L
s
.79049 0 m
.79049 .00375 L
s
.84355 0 m
.84355 .00375 L
s
.87008 0 m
.87008 .00375 L
s
.8966 0 m
.8966 .00375 L
s
.92313 0 m
.92313 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04107 m
.00625 .04107 L
s
[(100)] -0.0125 .04107 1 0 Mshowa
0 .17053 m
.00625 .17053 L
s
[(200)] -0.0125 .17053 1 0 Mshowa
0 .29999 m
.00625 .29999 L
s
[(300)] -0.0125 .29999 1 0 Mshowa
0 .42945 m
.00625 .42945 L
s
[(400)] -0.0125 .42945 1 0 Mshowa
0 .5589 m
.00625 .5589 L
s
[(500)] -0.0125 .5589 1 0 Mshowa
.125 Mabswid
0 .06696 m
.00375 .06696 L
s
0 .09286 m
.00375 .09286 L
s
0 .11875 m
.00375 .11875 L
s
0 .14464 m
.00375 .14464 L
s
0 .19642 m
.00375 .19642 L
s
0 .22231 m
.00375 .22231 L
s
0 .24821 m
.00375 .24821 L
s
0 .2741 m
.00375 .2741 L
s
0 .32588 m
.00375 .32588 L
s
0 .35177 m
.00375 .35177 L
s
0 .37766 m
.00375 .37766 L
s
0 .40355 m
.00375 .40355 L
s
0 .45534 m
.00375 .45534 L
s
0 .48123 m
.00375 .48123 L
s
0 .50712 m
.00375 .50712 L
s
0 .53301 m
.00375 .53301 L
s
0 .01518 m
.00375 .01518 L
s
0 .5848 m
.00375 .5848 L
s
0 .61069 m
.00375 .61069 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02116 .61178 m
.02116 .61803 L
s
.1538 .61178 m
.1538 .61803 L
s
.28644 .61178 m
.28644 .61803 L
s
.41909 .61178 m
.41909 .61803 L
s
.55173 .61178 m
.55173 .61803 L
s
.68437 .61178 m
.68437 .61803 L
s
.81702 .61178 m
.81702 .61803 L
s
.94966 .61178 m
.94966 .61803 L
s
.125 Mabswid
.04769 .61428 m
.04769 .61803 L
s
.07421 .61428 m
.07421 .61803 L
s
.10074 .61428 m
.10074 .61803 L
s
.12727 .61428 m
.12727 .61803 L
s
.18033 .61428 m
.18033 .61803 L
s
.20686 .61428 m
.20686 .61803 L
s
.23339 .61428 m
.23339 .61803 L
s
.25992 .61428 m
.25992 .61803 L
s
.31297 .61428 m
.31297 .61803 L
s
.3395 .61428 m
.3395 .61803 L
s
.36603 .61428 m
.36603 .61803 L
s
.39256 .61428 m
.39256 .61803 L
s
.44562 .61428 m
.44562 .61803 L
s
.47214 .61428 m
.47214 .61803 L
s
.49867 .61428 m
.49867 .61803 L
s
.5252 .61428 m
.5252 .61803 L
s
.57826 .61428 m
.57826 .61803 L
s
.60479 .61428 m
.60479 .61803 L
s
.63132 .61428 m
.63132 .61803 L
s
.65785 .61428 m
.65785 .61803 L
s
.7109 .61428 m
.7109 .61803 L
s
.73743 .61428 m
.73743 .61803 L
s
.76396 .61428 m
.76396 .61803 L
s
.79049 .61428 m
.79049 .61803 L
s
.84355 .61428 m
.84355 .61803 L
s
.87008 .61428 m
.87008 .61803 L
s
.8966 .61428 m
.8966 .61803 L
s
.92313 .61428 m
.92313 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04107 m
1 .04107 L
s
.99375 .17053 m
1 .17053 L
s
.99375 .29999 m
1 .29999 L
s
.99375 .42945 m
1 .42945 L
s
.99375 .5589 m
1 .5589 L
s
.125 Mabswid
.99625 .06696 m
1 .06696 L
s
.99625 .09286 m
1 .09286 L
s
.99625 .11875 m
1 .11875 L
s
.99625 .14464 m
1 .14464 L
s
.99625 .19642 m
1 .19642 L
s
.99625 .22231 m
1 .22231 L
s
.99625 .24821 m
1 .24821 L
s
.99625 .2741 m
1 .2741 L
s
.99625 .32588 m
1 .32588 L
s
.99625 .35177 m
1 .35177 L
s
.99625 .37766 m
1 .37766 L
s
.99625 .40355 m
1 .40355 L
s
.99625 .45534 m
1 .45534 L
s
.99625 .48123 m
1 .48123 L
s
.99625 .50712 m
1 .50712 L
s
.99625 .53301 m
1 .53301 L
s
.99625 .01518 m
1 .01518 L
s
.99625 .5848 m
1 .5848 L
s
.99625 .61069 m
1 .61069 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 .6 r
2 Mabswid
.02381 .01472 m
.06244 .02248 L
.08255 .02675 L
.0932 .02908 L
.10458 .03162 L
.11009 .03287 L
.1128 .03349 L
.114 .03377 L
.11531 .03407 L
.11648 .03434 L
.11758 .03282 L
.11881 .03073 L
.11999 .03004 L
.12126 .03033 L
.12243 .03061 L
.12507 .03122 L
.14415 .03578 L
.18234 .04542 L
.19247 .0481 L
.20202 .05067 L
.2073 .05212 L
.20875 .05252 L
.21028 .05294 L
.21158 .0533 L
.21233 .05319 L
.21302 .05203 L
.21431 .04986 L
.21553 .04922 L
.21663 .04953 L
.21783 .04986 L
.22299 .05132 L
.26377 .06342 L
.28402 .06981 L
.29394 .07304 L
.29829 .07447 L
.30304 .07606 L
.30526 .0768 L
.30647 .07721 L
.30762 .0776 L
.3087 .07593 L
.30986 .07403 L
.31091 .07348 L
.31189 .07382 L
.32121 .07704 L
.34079 .08404 L
.38019 .09902 L
.39035 .10309 L
.39535 .10512 L
.39779 .10612 L
.39999 .10703 L
Mistroke
.40103 .10746 L
.40215 .10792 L
.40321 .10829 L
.40418 .10678 L
.40522 .10517 L
.40635 .10446 L
.40754 .10496 L
.40864 .10543 L
.41808 .10948 L
.43753 .1181 L
.45842 .12778 L
.49738 .14705 L
.53879 .16461 L
.57869 .1886 L
.61707 .20921 L
.65791 .23916 L
.69723 .27085 L
.73503 .3042 L
.77528 .34313 L
.81402 .38423 L
.85522 .43224 L
.89489 .48309 L
.93305 .53667 L
.97367 .59923 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006@3oool2000001h0oooo0`0000040?ooo`8000005`3oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`8000004`3oool5000000<0oooo0P0000040?oo
o`800000503oool500000080oooo0`0000040?ooo`800000503oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`800000203oool001P0oooo00@000000?ooo`3o
ool00000703oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000503oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000D0?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000H0?ooo`040000003oool0oooo00000200oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`00603o
ool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000503oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001@0oooo0P0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01@3oool001P0oooo00@000000?ooo`3oool00000703oool4000000<0oooo
00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`3oool4000000<0oooo00@0
00000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000C0?ooo`060000003oool0oooo0?ooo`000000oooo
100000030?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000003
0?ooo`040000003oool0oooo000000L0oooo000H0?ooo`040000003oool0oooo000001`0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`800000103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001<0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000C0?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000070?ooo`006@3o
ool2000001d0oooo1@0000030?ooo`800000603oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000001D0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`8000005@3oool300000080oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000203oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo
000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool100000040oooo000E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0
oooo0P0000030?ooo`D0002IoP3oool200000040oooo000E0?ooo`030000003oool0oooo0080oooo
2P0009Wj0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool01P3oool;0000VOD0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`/0002Il03oool100000040oooo000E0?oo
o`030000003oool0oooo0100oooo2@0009T20?ooo`D0002IiP3oool100000040oooo0000103oool0
00000000000000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool05@3oool>0000
VN<0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0H0?ooo`D0002I0P3oool8
0000VMl0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool2000002<0oooo2P0009WI0?ooo`8000000@3o
ool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool09P3oool:0000VMH0oooo0@0000010?ooo`000P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0[0?ooo`L0002I0`3oool30000VLh0oooo0@0000010?ooo`00
00<0oooo000000000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0;`3oool<0000VL/0oooo0@0000010?ooo`000P3oool00`000000
oooo0?ooo`030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0<@3oool50000V@03
0?ooo`0009T0002I00H0002Ia`3oool100000040oooo000E0?ooo`030000003oool0oooo03X0oooo
200009W40?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0?P3oool70000VL40oooo0@00
00010?ooo`005@3oool200000480oooo1`0009Vm0?ooo`8000000@3oool001D0oooo00<000000?oo
o`3oool0A03oool70000VK/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`170?ooo`/0
002I]03oool100000040oooo000E0?ooo`030000003oool0oooo04X0oooo300009V`0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0C@3oool30000V@030?ooo`0009T0002I00H0002I[@3o
ool100000040oooo000E0?ooo`030000003oool0oooo05D0oooo1`0009VZ0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0F03oool70000VJL0oooo0@0000010?ooo`005@3oool2000005`0
oooo1`0009VS0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0GP3oool50000VJ<0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`1Q0?ooo`<0002IXP3oool100000040oooo000E
0?ooo`030000003oool0oooo0680oooo2P0009VJ0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0H`3oool;0000VIP0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1V0?ooo`<0
002I0P3oool60000VID0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1]0?ooo`H0002I
T`3oool100000040oooo000E0?ooo`800000L@3oool50000VI00oooo0P0000010?ooo`005@3oool0
0`000000oooo0?ooo`1b0?ooo`D0002IS`3oool100000040oooo000E0?ooo`030000003oool0oooo
07@0oooo1@0009V=0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0MP3oool50000VH/0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1h0?ooo`D0002IR@3oool100000040oooo
000E0?ooo`030000003oool0oooo07X0oooo1@0009V70?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0O03oool50000VHD0oooo0@0000010?ooo`005@3oool2000007l0oooo1@0009V20?oo
o`8000000@3oool001D0oooo00<000000?ooo`3oool0P03oool50000VH40oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`220?ooo`H0002IOP3oool100000040oooo000E0?ooo`030000003o
ool0oooo08@0oooo1P0009Ul0?ooo`4000000@3oool000D000000`3oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo08L0oooo1@0009Uj0?ooo`4000000@3oool000050?ooo`000000oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0R@3oool50000VGP0oooo0@0000010?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000008`0
oooo1@0009Ue0?ooo`8000000@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2=0?oo
o`@0002IM@3oool100000040oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo08l0oooo1000
09Uc0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0T03oool50000VG40
oooo0@0000010?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0980oooo100009U`0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
U03oool40000VFh0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`D0002IK03o
ool100000040oooo000E0?ooo`800000V03oool50000VFT0oooo0P0000010?ooo`005@3oool00`00
0000oooo0?ooo`2I0?ooo`@0002IJ@3oool100000040oooo000E0?ooo`030000003oool0oooo09/0
oooo100009UW0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0W03oool50000VFD0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`2N0?ooo`D0002IH`3oool100000040oooo000E
0?ooo`030000003oool0oooo0:00oooo100009UR0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0XP3oool30000VF40oooo0@0000010?ooo`005@3oool200000:@0oooo100009UN0?ooo`80
00000@3oool001D0oooo00<000000?ooo`3oool0Y03oool40000VEh0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`2V0?ooo`@0002IG03oool100000040oooo000E0?ooo`030000003oool0
oooo0:L0oooo100009UK0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0Z@3oool30000
VEX0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`@0002IF03oool100000040
oooo000E0?ooo`030000003oool0oooo0:/0oooo100009UG0?ooo`4000000@3oool001D0oooo0P00
002^0?ooo`<0002IE@3oool200000040oooo000E0?ooo`030000003oool0oooo0:h0oooo0`0009UE
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0[`3oool40000VE<0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`2`0?ooo`@0002IDP3oool100000040oooo000E0?ooo`030000
003oool0oooo0;80oooo0`0009UA0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0/`3o
ool30000VE00oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2d0?ooo`@0002ICP3oool1
00000040oooo000E0?ooo`800000]P3oool40000VD`0oooo0P0000010?ooo`005@3oool00`000000
oooo0?ooo`2g0?ooo`<0002IC03oool100000040oooo000E0?ooo`030000003oool0oooo0;P0oooo
0`0009U;0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0^@3oool30000VDX0oooo0@00
00010?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo0;X0oooo0`0009U90?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0^`3oool30000VDP0oooo0@0000010?ooo`00103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2l0?oo
o`<0002IA`3oool100000040oooo00020?ooo`8000000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo0P00002n0?ooo`<0002IA@3oool200000040oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0;h0oooo100009U40?ooo`4000000@3oool000050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0_`3oool40000VD<0oooo0@0000010?ooo`0000@0oooo000000000000
0000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0<40oooo0`0009U20?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool0`P3oool30000VD40oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`330?ooo`<0002I@03oool100000040oooo000E0?ooo`030000003oool0
oooo0<@0oooo0`0009To0?ooo`4000000@3oool001D0oooo0P0000360?ooo`<0002I?@3oool20000
0040oooo000E0?ooo`030000003oool0oooo0<H0oooo0`0009Tm0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0a`3oool30000VC`0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`380?ooo`<0002I>`3oool100000040oooo000E0?ooo`030000003oool0oooo0<T0oooo0`0009Tj
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0bP3oool20000VCX0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3:0?ooo`<0002I>@3oool100000040oooo000E0?ooo`800000
c03oool30000VCL0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3<0?ooo`<0002I=`3o
ool100000040oooo000E0?ooo`030000003oool0oooo0<d0oooo0`0009Tf0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0cP3oool30000VCD0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3?0?ooo`<0002I=03oool100000040oooo000E0?ooo`030000003oool0oooo0=00oooo
0`0009Tc0?ooo`4000000@3oool001D0oooo0P00003B0?ooo`<0002I<@3oool200000040oooo000E
0?ooo`030000003oool0oooo0=80oooo0`0009Ta0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0d`3oool30000VC00oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3D0?ooo`80
002I<03oool100000040oooo000E0?ooo`030000003oool0oooo0=@0oooo0`0009T_0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0e@3oool30000VBh0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`3F0?ooo`<0002I;@3oool100000040oooo000E0?ooo`800000f03oool30000
VB/0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3H0?ooo`<0002I:`3oool100000040
oooo000E0?ooo`030000003oool0oooo0=T0oooo0`0009TZ0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0fP3oool20000VBX0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3J
0?ooo`<0002I:@3oool100000040oooo00020?ooo`<000000`3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo0=/0oooo0`0009TX0?ooo`4000000@3oool000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3L0?ooo`<0002I9`3oool100000040oooo000500000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000gP3oool30000VBD0oooo0P00
00010?ooo`0000@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0gP3oool30000VBD0oooo0@0000010?ooo`00
00@0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0g`3oool20000VBD0oooo0@0000010?ooo`000P3oool20000
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0=l0oooo0`0009TT0?ooo`4000000@3oool000<0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo0>00oooo0`0009TS0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0h@3oool30000VB80oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3R0?ooo`80002I8P3oool100000040oooo000E0?ooo`800000h`3oool30000VB00oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`3S0?ooo`<0002I803oool100000040oooo000E
0?ooo`030000003oool0oooo0>@0oooo0`0009TO0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0i@3oool30000VAh0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3V0?ooo`80
002I7P3oool100000040oooo000E0?ooo`030000003oool0oooo0>H0oooo0`0009TM0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0i`3oool30000VA`0oooo0@0000010?ooo`005@3oool2
00000>T0oooo0`0009TJ0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0j@3oool20000
VA/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3Y0?ooo`<0002I6P3oool100000040
oooo000E0?ooo`030000003oool0oooo0>X0oooo0`0009TI0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0j`3oool30000VAP0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3/
0?ooo`80002I603oool100000040oooo000E0?ooo`030000003oool0oooo0>`0oooo0`0009TG0?oo
o`4000000@3oool001D0oooo0P00003^0?ooo`<0002I5@3oool200000040oooo000E0?ooo`030000
003oool0oooo0>h0oooo0`0009TE0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0k`3o
ool20000VAD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3_0?ooo`<0002I503oool1
00000040oooo000E0?ooo`030000003oool0oooo0?00oooo0`0009TC0?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0l@3oool20000VA<0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`3a0?ooo`<0002I4P3oool100000040oooo000E0?ooo`800000l`3oool30000VA00oooo0P00
00010?ooo`005@3oool00`000000oooo0?ooo`3c0?ooo`<0002I403oool100000040oooo000E0?oo
o`030000003oool0oooo0?@0oooo0P0009T@0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0m03oool30000V@l0oooo0@0000010?ooo`0000@0oooo0000000000000000103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0?D0oooo0`0009T>0?ooo`4000000@3oool000050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0mP3oool20000V@h0oooo0@0000010?ooo`00103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3f0?ooo`<0002I3@3oool100000040oooo00040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000
n03oool20000V@`0oooo0P0000010?ooo`00100000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3g0?ooo`<0002I303oool100000040
oooo00000`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3h0?ooo`<0002I2`3oool100000040oooo0005000000<0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3i0?ooo`80002I2`3oool100000040
oooo000E0?ooo`030000003oool0oooo0?T0oooo0`0009T:0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0nP3oool30000V@T0oooo0@0000010?ooo`005@3oool200000?`0oooo0P0009T8
0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0n`3oool30000V@P0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3l0?ooo`80002I203oool100000040oooo000E0?ooo`030000
003oool0oooo0?`0oooo0`0009T70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o@3o
ool30000V@H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3n0?ooo`<0002I1@3oool1
00000040oooo000E0?ooo`030000003oool0oooo0?l0oooo0P0009T50?ooo`4000000@3oool001D0
oooo0P00003o0?ooo`L0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo0@0000010?ooo`005@3ooooo000000/000000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-38.2396, 31.7137, 1.41949, \
2.90884}},
  CellTags->"PaymentToPrincipal"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"fixedPlot", ",", "variablePlot"}], "]"}], ";"}]], "Input",
  CellLabel->"In[5]:=",
  CellTags->"PaymentToPrincipal"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 0.0147151 0.00110162 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12488 -18 -4.5 ]
[-0.0125 .12488 0 4.5 ]
[-0.0125 .23504 -18 -4.5 ]
[-0.0125 .23504 0 4.5 ]
[-0.0125 .3452 -18 -4.5 ]
[-0.0125 .3452 0 4.5 ]
[-0.0125 .45536 -18 -4.5 ]
[-0.0125 .45536 0 4.5 ]
[-0.0125 .56552 -18 -4.5 ]
[-0.0125 .56552 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12488 m
.00625 .12488 L
s
[(100)] -0.0125 .12488 1 0 Mshowa
0 .23504 m
.00625 .23504 L
s
[(200)] -0.0125 .23504 1 0 Mshowa
0 .3452 m
.00625 .3452 L
s
[(300)] -0.0125 .3452 1 0 Mshowa
0 .45536 m
.00625 .45536 L
s
[(400)] -0.0125 .45536 1 0 Mshowa
0 .56552 m
.00625 .56552 L
s
[(500)] -0.0125 .56552 1 0 Mshowa
.125 Mabswid
0 .03675 m
.00375 .03675 L
s
0 .05878 m
.00375 .05878 L
s
0 .08081 m
.00375 .08081 L
s
0 .10284 m
.00375 .10284 L
s
0 .14691 m
.00375 .14691 L
s
0 .16894 m
.00375 .16894 L
s
0 .19097 m
.00375 .19097 L
s
0 .21301 m
.00375 .21301 L
s
0 .25707 m
.00375 .25707 L
s
0 .2791 m
.00375 .2791 L
s
0 .30114 m
.00375 .30114 L
s
0 .32317 m
.00375 .32317 L
s
0 .36723 m
.00375 .36723 L
s
0 .38927 m
.00375 .38927 L
s
0 .4113 m
.00375 .4113 L
s
0 .43333 m
.00375 .43333 L
s
0 .4774 m
.00375 .4774 L
s
0 .49943 m
.00375 .49943 L
s
0 .52146 m
.00375 .52146 L
s
0 .54349 m
.00375 .54349 L
s
0 .58756 m
.00375 .58756 L
s
0 .60959 m
.00375 .60959 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12488 m
1 .12488 L
s
.99375 .23504 m
1 .23504 L
s
.99375 .3452 m
1 .3452 L
s
.99375 .45536 m
1 .45536 L
s
.99375 .56552 m
1 .56552 L
s
.125 Mabswid
.99625 .03675 m
1 .03675 L
s
.99625 .05878 m
1 .05878 L
s
.99625 .08081 m
1 .08081 L
s
.99625 .10284 m
1 .10284 L
s
.99625 .14691 m
1 .14691 L
s
.99625 .16894 m
1 .16894 L
s
.99625 .19097 m
1 .19097 L
s
.99625 .21301 m
1 .21301 L
s
.99625 .25707 m
1 .25707 L
s
.99625 .2791 m
1 .2791 L
s
.99625 .30114 m
1 .30114 L
s
.99625 .32317 m
1 .32317 L
s
.99625 .36723 m
1 .36723 L
s
.99625 .38927 m
1 .38927 L
s
.99625 .4113 m
1 .4113 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .4774 m
1 .4774 L
s
.99625 .49943 m
1 .49943 L
s
.99625 .52146 m
1 .52146 L
s
.99625 .54349 m
1 .54349 L
s
.99625 .58756 m
1 .58756 L
s
.99625 .60959 m
1 .60959 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02646 .08695 m
.06498 .09334 L
.107 .10095 L
.14646 .10877 L
.18441 .11695 L
.22481 .12644 L
.26369 .13642 L
.30502 .14799 L
.34484 .16019 L
.38315 .17297 L
.4239 .1878 L
.46315 .2034 L
.50088 .21972 L
.54105 .23865 L
.57972 .25852 L
.62083 .28158 L
.66042 .30586 L
.69851 .33129 L
.73904 .3608 L
.77806 .3918 L
.81953 .42779 L
.85949 .46572 L
.89793 .5055 L
.93882 .55166 L
.97619 .59764 L
s
0 0 .6 r
.02646 .10245 m
.06498 .10906 L
.08504 .11269 L
.09565 .11467 L
.107 .11684 L
.1125 .1179 L
.1152 .11843 L
.11639 .11866 L
.1177 .11892 L
.11887 .11915 L
.11996 .11786 L
.12119 .11608 L
.12236 .11549 L
.12364 .11574 L
.12481 .11597 L
.12743 .11649 L
.14646 .12037 L
.18455 .12858 L
.19465 .13086 L
.20417 .13305 L
.20944 .13428 L
.21088 .13462 L
.21241 .13498 L
.21371 .13528 L
.21445 .13519 L
.21514 .1342 L
.21643 .13236 L
.21765 .13181 L
.21874 .13207 L
.21994 .13236 L
.22508 .1336 L
.26575 .14389 L
.28595 .14933 L
.29584 .15208 L
.30017 .1533 L
.30491 .15465 L
.30712 .15528 L
.30833 .15563 L
.30948 .15596 L
.31055 .15454 L
.31171 .15293 L
.31276 .15246 L
.31373 .15274 L
.32302 .15549 L
.34255 .16144 L
.38185 .17419 L
.39198 .17765 L
.39696 .17938 L
.39939 .18023 L
.40159 .181 L
Mistroke
.40263 .18137 L
.40374 .18177 L
.4048 .18207 L
.40577 .18079 L
.4068 .17942 L
.40794 .17881 L
.40912 .17924 L
.41022 .17964 L
.41963 .18309 L
.43902 .19042 L
.45986 .19866 L
.49871 .21506 L
.54001 .23 L
.5798 .25042 L
.61807 .26795 L
.65879 .29344 L
.698 .32041 L
.7357 .34879 L
.77584 .38191 L
.81447 .41689 L
.85555 .45774 L
.89512 .50101 L
.93317 .54661 L
.97367 .59984 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool2000001d0oooo0`0000040?ooo`8000005`3oool3000000@0oooo0P0000040?oo
o`8000005@3oool3000000<0oooo0`0000040?ooo`8000004`3oool5000000<0oooo0P0000040?oo
o`8000004`3oool500000080oooo0`0000040?ooo`800000503oool3000000@0oooo0P0000040?oo
o`800000503oool3000000<0oooo0`0000040?ooo`800000203oool001T0oooo00@000000?ooo`3o
ool000006`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000C0?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000I0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`006@3o
ool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000005@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001@0oooo0P0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01@3oool001T0oooo00@000000?ooo`3oool000006`3oool4000000<0oooo
00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`3oool4000000<0oooo00@0
00000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000B0?ooo`060000003oool0oooo0?ooo`000000oooo
100000030?ooo`040000003oool0oooo000001H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000003
0?ooo`040000003oool0oooo000000L0oooo000I0?ooo`040000003oool0oooo000001/0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`800000103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001@0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000004P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`0000070?ooo`006P3o
ool2000001`0oooo1@0000030?ooo`800000603oool00`000000oooo0?ooo`030?ooo`800000103o
ool2000001H0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000503oool3000000@0oooo
0P0000040?ooo`800000503oool300000080oooo1@0000030?ooo`800000203oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`00000;00000040oooo
000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool100000040oooo000>
0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool02P3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000103oool2
00000?l0oooo1`3oool200000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000>0?ooo`8000001@3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo0@0000010?ooo`005@3oool200000?l0oooo1`3oool200000040oooo000E0?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`03
0000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo
1`3oool100000040oooo000E0?ooo`800000o`3oool70?ooo`8000000@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`4000000@3oool001D0oooo0P00003o0?ooo`L0oooo0P0000010?ooo`005@3oool00`00
0000oooo0?ooo`030?ooo`D0V@00oP3oool100000040oooo000E0?ooo`030000003oool0oooo00<0
oooo2P2I003i0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool01`3oool;09T00?@0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`0<0?ooo`/0V@00k`3oool100000040oooo000E
0?ooo`800000103oool50000V@T0oooo302I003X0?ooo`8000000@3oool001D0oooo00<000000?oo
o`3oool00`3oool:0000V@T0oooo302I003T0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool01`3oool;0000V@X0oooo302I003N0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
303oool:0000V@/0oooo302I003I0?ooo`4000000@3oool000040?ooo`0000000000000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0A0?oooa80002I103oool:09T00=D0oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?oooa<0002I103oool909T00=40
oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool2000001/0oooo0`0009T50?ooo`/0002I0`3oool809T0
0<d0oooo0P0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0W0?ooo`X0002I0`3oool9
09T00<T0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0/0?ooo`P0002I00<0
oooo0000V@0009T00P0009T909T00<@0oooo0@0000010?ooo`0000<0oooo000000000000103oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
<03oool=0000V@T0V@00`03oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`0c0?ooo`@0002I00<0oooo0000V@0009T02000
09T809T00;`0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0l0?ooo`X0002I1`2I002i
0?ooo`4000000@3oool001D0oooo0P0000120?ooo`P0002I1`2I002e0?ooo`8000000@3oool001D0
oooo00<000000?ooo`3oool0A@3oool60000V@030?ooo`2I0000V@0000D0V@00/`3oool100000040
oooo000E0?ooo`030000003oool0oooo04P0oooo3@0009Va0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool0BP3oool>0000VJh0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1>
0?ooo`80002I103oool70000VJ/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`1G0?oo
o`L0002I00<0V@000?ooo`3oool0Y@3oool100000040oooo000E0?ooo`800000F`3oool70000V@03
09T0003oool0oooo0:40oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1M0?ooo`P0002I
X@3oool100000040oooo000E0?ooo`030000003oool0oooo0600oooo1P0009T209T009h0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`P0002IVP3oool100000040oooo000E0?oo
o`030000003oool0oooo06D0oooo2@0009VH0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0J@3oool209T000H0002IU@3oool100000040oooo000E0?ooo`800000K@3oool00`2I0000002I
0000V@050000VI40oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`1^0?ooo`80V@001`00
09V?0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0L@3oool209T000H0002IS@3oool1
00000040oooo000E0?ooo`030000003oool0oooo07@0oooo0P2I00060000VHX0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`1g0?ooo`0309T0000009T0002I00@0002IR03oool100000040
oooo000E0?ooo`030000003oool0oooo07T0oooo0P2I00060000VHD0oooo0@0000010?ooo`005@3o
ool2000007d0oooo00<0V@000000V@0009T0100009V20?ooo`8000000@3oool001D0oooo00<00000
0?ooo`3oool0OP3oool209T000H0002IP03oool100000040oooo000E0?ooo`030000003oool0oooo
0840oooo00<0V@000000V@0009T01@0009Um0?ooo`4000000@3oool000D000000`3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo08<0oooo0P2I00070000VGX0oooo0@0000010?ooo`00
00D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`250?ooo`<0V@001P0009Uh0?ooo`4000000@3oool0
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0Q`3oool409T000D0002IMP3oool100000040oooo0003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo0P0000290?ooo`D0V@001@0009Uc0?ooo`8000000@3oool000050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0RP3oool509T000@0002IL`3oool100000040oooo00001@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo08`0oooo1@2I00040000VG40oooo0@0000010?ooo`0000@0oooo
0000000000000000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo08h0oooo102I
00050000VFl0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2@0?ooo`@0V@001@0009U]
0?ooo`4000000@3oool001D0oooo0P00002C0?ooo`@0V@001P0009UY0?ooo`8000000@3oool001D0
oooo00<000000?ooo`3oool0U03oool409T000H0002IJ03oool100000040oooo000E0?ooo`030000
003oool0oooo09H0oooo1@2I00060000VFD0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`2H0?ooo`D0V@001P0009US0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0VP3oool4
09T00080oooo100009UR0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0W03oool409T0
0080oooo100009UP0?ooo`4000000@3oool001D0oooo0P00002N0?ooo`D0V@0000<0oooo0000V@00
09T00`0009UM0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0W`3oool509T000030?oo
o`0009T0002I0080002IG@3oool100000040oooo000E0?ooo`030000003oool0oooo0:40oooo1@2I
00000`3oool0002I0000V@020000VE/0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2S
0?ooo`@0V@0000<0oooo0000V@0009T00P0009UJ0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0Y@3oool409T000030?ooo`0009T0002I0080002IF03oool100000040oooo000E0?ooo`03
0000003oool0oooo0:H0oooo1@2I00040000VEL0oooo0@0000010?ooo`005@3oool200000:T0oooo
102I00000`3oool0002I0000V@020000VE@0oooo0P0000010?ooo`005@3oool00`000000oooo0?oo
o`2Z0?ooo`@0V@00100009UD0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0Z`3oool4
09T000040?ooo`0009T0002I0000VE<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`2]
0?ooo`@0V@00100009UA0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0[P3oool409T0
00@0002ID03oool100000040oooo000E0?ooo`030000003oool0oooo0;00oooo0`2I00000`3oool0
002I0000V@020000VDh0oooo0@0000010?ooo`005@3oool200000;80oooo102I00040000VD`0oooo
0P0000010?ooo`005@3oool00`000000oooo0?ooo`2b0?ooo`@0V@0000@0oooo0000V@0009T0002I
C03oool100000040oooo000E0?ooo`030000003oool0oooo0;@0oooo102I00030000VD/0oooo0@00
00010?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo0;D0oooo102I00040000VDT0oooo0@0000010?ooo`0000D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`2g0?ooo`<0V@00100009U80?ooo`4000000@3oool000@0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0^03oool409T000<0002IA`3oool100000040oooo00020?ooo`8000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P00002j0?ooo`@0V@000`0009U5
0?ooo`8000000@3oool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^`3oool309T000@0002IA03o
ool100000040oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0;`0oooo0`2I00040000VD<0
oooo0@0000010?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0;h0oooo0`2I00030000VD80oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`2o0?ooo`<0V@000`0009U10?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0`03o
ool309T000@0002I?`3oool100000040oooo000E0?ooo`800000``3oool209T000@0002I?@3oool2
00000040oooo000E0?ooo`030000003oool0oooo0<<0oooo0`2I00030000VCd0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`340?ooo`<0V@000`0009Tl0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0a@3oool309T000<0002I>`3oool100000040oooo000E0?ooo`030000003o
ool0oooo0<L0oooo0P2I00040000VCT0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`38
0?ooo`80V@00100009Th0?ooo`4000000@3oool001D0oooo0P00003:0?ooo`<0V@000`0009Tf0?oo
o`8000000@3oool001D0oooo00<000000?ooo`3oool0bP3oool309T000<0002I=P3oool100000040
oooo000E0?ooo`030000003oool0oooo0<`0oooo0P2I00030000VCD0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3=0?ooo`80V@000`0009Td0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0cP3oool209T000<0002I<`3oool100000040oooo000E0?ooo`800000d03oool209T0
00<0002I<@3oool200000040oooo000E0?ooo`030000003oool0oooo0=00oooo0P2I00030000VC40
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3A0?ooo`80V@000`0009T`0?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0dP3oool209T000<0002I;`3oool100000040oooo000E
0?ooo`030000003oool0oooo0=<0oooo0P2I00030000VBh0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3D0?ooo`80V@000`0009T]0?ooo`4000000@3oool001D0oooo0P00003F0?ooo`80
V@000`0009T[0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0e`3oool0102I0000002I
0000V@0009T[0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0f03oool0102I0000002I
0000V@0009TZ0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0f@3oool0102I0000002I
0000V@0009TY0?ooo`4000000@3oool00080oooo0`0000030?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0fP3oool0102I0000002I0000V@0009TX0?ooo`4000000@3oool000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3K0?ooo`0409T0000009T0002I0000VBL0oooo0@000001
0?ooo`001@0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool200000=d0oooo00@0V@000000V@0009T0002I9@3oool200000040oooo000010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`3M0?ooo`0409T0000009T0002I0000VBD0oooo0@0000010?ooo`0000@0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0gP3oool0102I0000002I0000V@0009TT0?ooo`4000000@3oool00080oooo
0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`3O0?ooo`0409T0000009T0002I0000VB<0oooo0@0000010?ooo`000`3oool00`00
0000oooo0?ooo`020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0h03oool0102I
0000002I0000V@0009TR0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0h@3oool0102I
0000002I0000V@0009TQ0?ooo`4000000@3oool001D0oooo0P00003S0?ooo`0409T0000009T0002I
0000VAl0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3S0?ooo`0409T0000009T0002I
0000VAl0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3T0?ooo`0409T0000009T0002I
0000VAh0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3U0?ooo`0409T0000009T0002I
0000VAd0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3V0?ooo`0409T0000009T0002I
0000VA`0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3W0?ooo`0409T0000009T0002I
0000VA/0oooo0@0000010?ooo`005@3oool200000>T0oooo00@0V@000000V@0009T0002I6@3oool2
00000040oooo000E0?ooo`030000003oool0oooo0>T0oooo00<0V@000000V@0009T06P3oool10000
0040oooo000E0?ooo`030000003oool0oooo0>X0oooo0`0009TI0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0jP3oool0102I0000002I0000V@0009TH0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0j`3oool0102I0000002I0000V@0009TG0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0k03oool0102I0000002I0000V@0009TF0?ooo`4000000@3oool001D0oooo
0P00003^0?ooo`0409T0000009T0002I0000VA@0oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`3^0?ooo`0309T0000009T0002I01D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`3_0?ooo`<0002I503oool100000040oooo000E0?ooo`030000003oool0oooo0?00oooo0`0009TC
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0l03oool0102I0000002I0000V@0009TB
0?ooo`4000000@3oool001D0oooo0P00003b0?ooo`0409T0000009T0002I0000VA00oooo0P000001
0?ooo`005@3oool00`000000oooo0?ooo`3b0?ooo`0409T0000009T0002I0000VA00oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`3c0?ooo`0309T0000009T0002I0100oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3d0?ooo`<0002I3`3oool100000040oooo0000103oool00000
0000000000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0m@3oool30000V@h0
oooo0@0000010?ooo`0000D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3e0?ooo`0409T0000009T0
002I0000V@d0oooo0@0000010?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool200000?L0oooo00<0V@000000V@0009T0
303oool200000040oooo00040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?L0oooo0`0009T<0?ooo`40
00000@3oool000@000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0n03oool30000V@/0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0n@3oool20000V@0309T0003oool0oooo00P0oooo0@0000010?ooo`001@0000030?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0n@3oool30000V@X0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3j0?ooo`<0002I2@3oool100000040oooo000E0?ooo`800000
o03oool30000V@L0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3l0?ooo`80002I00<0
V@000?ooo`3oool01@3oool100000040oooo000E0?ooo`030000003oool0oooo0?`0oooo0`0009T0
0`2I0000oooo0?ooo`040?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o@3oool30000
V@0309T0003oool0oooo00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3n0?ooo`<0
002I1@3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo0P0009T50?ooo`400000
0@3oool001D0oooo0P00003o0?ooo`L0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`005@3ooooo000000/000000@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-39.349, -56.3217, 1.42345, \
3.41835}},
  CellTags->"PaymentToPrincipal"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"TotalPrincipalPaid"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"TotalPrincipalPaid"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalPrincipalPaid"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{

Cell["TotalPrincipalPaid", "Section",
  CellTags->"TotalPrincipalPaid"],

Cell["\<\
TotalPrincipalPaid[{HomeCost, PercentageDownPayment}, InterestRate, \
Years, PaymentNumber] gives the total amount paid to principal for all \
payments through the payment given by PaymentNumber for a loan on a house of \
initial value given by HomeCost with a down payment given by \
PercentageDownPayment for a loan amortized over the number of years given by \
Years with the fixed interest rate given by InterestRate. 

TotalPrincipalPaid[{HomeCost, PercentageDownPayment}, InterestRate, Years] \
gives the total principal paid over the life of the loan. 

TotalPrincipalPaid[LoanAmount, InterestRate, Years, PaymentNumber] assumes a \
loan amount given by LoanAmount. 

TotalPrincipalPaid[LoanAmount, InterestRate, Years] again gives the total \
principal paid over the life of the loan. 

For each of the forms above, if InterestRate is replaced by {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, then \
the calculation is done for a variable rate loan with interest rate \
InterestRate1 for a number of payments given by Payments1 followed by \
InterestRate2 for a number of payments given by Payments2, and so on. If \
PaymentNumber is greater than Payments1+Payments2+...+PaymentsM then the \
interest rate is assumed to be InterestRateM for that payment. If \
PaymentNumber is not numerical then an analytical result will be returned (if \
$StrongErrorChecking is not True) that assumes that PaymentNumber is greater \
than Payments1+Payments2+...+Payments(M-1). 

For all of the forms given above, if PaymentNumber is replaced by \
{PaymentNumber1, PaymentNumber2} then the returned value will be the total of \
the principal paid between PaymentNumber1 and PaymentNumber2 inclusive.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPrincipalPaid"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["TotalPrincipalPaid", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPrincipalPaid"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPrincipalPaid"],

Cell[TextData[{
  "Default options for ",
  StyleBox["TotalPrincipalPaid", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPrincipalPaid"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPrincipalPaid"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["TotalPrincipalPaid", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPrincipalPaid"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"TotalPrincipalPaid"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"TotalPrincipalPaid"],

Cell["\<\
Of course the total principal paid over the life of the loan is the \
original loan amount.\
\>", "MathCaption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TotalPrincipalPaid", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", "7.0", ",", 
        " ", "30"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"TotalPrincipalPaid"],

Cell[BoxData["89999.99999999975`"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"TotalPrincipalPaid"]
}, Open  ]],

Cell["\<\
Now assume a variable interest rate loan that starts at 6% and \
changes each year by a random amount between \[PlusMinus]0.5%.\
\>", "Text",
  CellTags->"TotalPrincipalPaid"],

Cell["Here is the interest rate table for the loan.", "MathCaption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"interestRateTable", "=", 
      RowBox[{
        RowBox[{"NestList", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"#", " ", "+", 
                RowBox[{"Random", "[", 
                  RowBox[{"Real", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"-", "1"}], "/", "2"}], ",", 
                        RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}], "&"}], 
            ",", "6", ",", "29"}], "]"}], "/.", 
        RowBox[{
          RowBox[{"z_", "?", "NumberQ"}], "\[RuleDelayed]", 
          RowBox[{"{", 
            RowBox[{"z", ",", "12"}], "}"}]}]}]}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"TotalPrincipalPaid"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"6", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.349898716506829`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.555300813327847`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.36067353205333`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.406588791126387`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.451371174530873`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.389713596473316`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.746078814943381`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.48483986682288`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.164975310733045`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5.995567155395771`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5.78714867085582`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5.76742623333238`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5.363481700497856`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5.851474673778125`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.193882622833037`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.379760429155595`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.021897917255777`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.362469301522881`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.120516424597145`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.327837729004385`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.601535063847439`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.969669449290015`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.341566685123395`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.5724582881476445`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.99625690648387`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.658989195105428`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.725513712213325`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.410490056164518`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.289506291096256`", ",", "12"}], "}"}]}], "}"}]], "Output",\

  CellLabel->"Out[3]=",
  CellTags->"TotalPrincipalPaid"]
}, Open  ]],

Cell["\<\
Look at a graph of the cumulative payment of the principal for the \
variable rate loan.\
\>", "MathCaption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"TotalPrincipalPaid", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", 
              "interestRateTable", ",", " ", "30", ",", "\[Mu]"}], "]"}], ",",
           
          RowBox[{"{", 
            RowBox[{"\[Mu]", ",", "1", ",", "360"}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"TotalPrincipalPaid"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 0.0147151 6.54004e-06 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14552 -30 -4.5 ]
[-0.0125 .14552 0 4.5 ]
[-0.0125 .27632 -30 -4.5 ]
[-0.0125 .27632 0 4.5 ]
[-0.0125 .40712 -30 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .53792 -30 -4.5 ]
[-0.0125 .53792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14552 m
.00625 .14552 L
s
[(20000)] -0.0125 .14552 1 0 Mshowa
0 .27632 m
.00625 .27632 L
s
[(40000)] -0.0125 .27632 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(60000)] -0.0125 .40712 1 0 Mshowa
0 .53792 m
.00625 .53792 L
s
[(80000)] -0.0125 .53792 1 0 Mshowa
.125 Mabswid
0 .04742 m
.00375 .04742 L
s
0 .08012 m
.00375 .08012 L
s
0 .11282 m
.00375 .11282 L
s
0 .17822 m
.00375 .17822 L
s
0 .21092 m
.00375 .21092 L
s
0 .24362 m
.00375 .24362 L
s
0 .30902 m
.00375 .30902 L
s
0 .34172 m
.00375 .34172 L
s
0 .37442 m
.00375 .37442 L
s
0 .43982 m
.00375 .43982 L
s
0 .47252 m
.00375 .47252 L
s
0 .50522 m
.00375 .50522 L
s
0 .57062 m
.00375 .57062 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14552 m
1 .14552 L
s
.99375 .27632 m
1 .27632 L
s
.99375 .40712 m
1 .40712 L
s
.99375 .53792 m
1 .53792 L
s
.125 Mabswid
.99625 .04742 m
1 .04742 L
s
.99625 .08012 m
1 .08012 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02646 .0153 m
.06498 .02404 L
.107 .03369 L
.14646 .04358 L
.18441 .05389 L
.22481 .0657 L
.26369 .07783 L
.30502 .09179 L
.34484 .10711 L
.38315 .12347 L
.4239 .14251 L
.46315 .16277 L
.50088 .18305 L
.54105 .20543 L
.57972 .22871 L
.62083 .25547 L
.66042 .28347 L
.69851 .31219 L
.73904 .34477 L
.77806 .37838 L
.81953 .41714 L
.85949 .45798 L
.89793 .50141 L
.93882 .5523 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009P3oool2
000001/0oooo0`0000040?ooo`8000005P3oool3000000@0oooo0P0000040?ooo`8000004P3oool3
000000<0oooo0`0000040?ooo`8000004P3oool5000000<0oooo0P0000040?ooo`8000004P3oool5
00000080oooo0`0000040?ooo`8000004P3oool3000000@0oooo0P0000040?ooo`8000004`3oool3
000000<0oooo0`0000040?ooo`8000001`3oool002D0oooo00@000000?ooo`3oool000006@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000B0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000004@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0
oooo000U0?ooo`040000003oool0oooo000001d0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`009@3oool010000000oooo
0?ooo`00000M0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
4P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0@0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000001<0oooo0P0000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0103oool002D0oooo00@000000?ooo`3oool000006@3oool4000000<0oooo00@000000?ooo`3o
ool000005P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000004P3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool0
00004@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000A0?ooo`060000003oool0oooo0?ooo`000000oooo100000030?ooo`04
0000003oool0oooo000001@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`0000000`0000030?ooo`040000003o
ool0oooo000000H0oooo000U0?ooo`040000003oool0oooo000001T0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`00000E0?ooo`800000103oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000140oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000004@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000A0?ooo`070000003oool0oooo0?ooo`000000oooo0000
00060?ooo`040000003oool0oooo00000100oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000004@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001P3oool010000000oooo0?ooo`0000060?ooo`009P3oool2000001X0oooo
1@0000030?ooo`8000005`3oool00`000000oooo0?ooo`030?ooo`800000103oool2000001<0oooo
00@000000?ooo`3oool0oooo1@0000030?ooo`8000004`3oool3000000@0oooo0P0000040?ooo`80
00004`3oool300000080oooo1@0000030?ooo`8000004P3oool3000000@0oooo0P0000040?ooo`80
00004`3oool300000080oooo1@0000030?ooo`8000001`3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00240oooooP0000010?ooo`006P3oool2000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool001T0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`3j0?ooo`4000000@3oool001T0oooo00@0
00000?ooo`3oool00000103oool200000?X0oooo0P0000010?ooo`006@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo1@2I003c0?ooo`4000000@3oool001T0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`X0V@00kP3oool100000040oooo
000I0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool;09T00>T0oooo
0@0000010?ooo`006P3oool2000000D0oooo00<000000?ooo`3oool02`3oool;09T00>@0oooo0@00
00010?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`/0V@00g`3oool100000040oooo000Q0?oo
o`030000003oool0oooo01D0oooo2@2I003L0?ooo`4000000@3oool00240oooo00<000000?ooo`3o
ool06P3oool709T00=T0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`0M0?ooo`P0V@00
e@3oool100000040oooo000Q0?ooo`8000008@3oool:09T00<l0oooo0P0000010?ooo`008@3oool0
0`000000oooo0?ooo`0T0?ooo`X0V@00c03oool100000040oooo000Q0?ooo`030000003oool0oooo
02T0oooo2@2I00380?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0;@3oool809T00<D0
oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`P0V@00`@3oool100000040oooo
000Q0?ooo`030000003oool0oooo03@0oooo202I002n0?ooo`4000000@3oool00240oooo00<00000
0?ooo`3oool0>03oool709T00;/0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`0k0?oo
o`L0V@00^03oool100000040oooo000Q0?ooo`800000?`3oool709T00;@0oooo0P0000010?ooo`00
8@3oool00`000000oooo0?ooo`110?ooo`H0V@00/`3oool100000040oooo000Q0?ooo`030000003o
ool0oooo04@0oooo1P2I002`0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0AP3oool6
09T00:h0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`190?ooo`H0V@00Z`3oool10000
0040oooo000Q0?ooo`030000003oool0oooo04/0oooo1P2I002Y0?ooo`4000000@3oool00240oooo
00<000000?ooo`3oool0CP3oool609T00:H0oooo0@0000010?ooo`008@3oool00`000000oooo0?oo
o`1@0?ooo`H0V@00Y03oool100000040oooo000Q0?ooo`800000E03oool609T00:00oooo0P000001
0?ooo`008@3oool00`000000oooo0?ooo`1E0?ooo`H0V@00W`3oool100000040oooo000Q0?ooo`03
0000003oool0oooo05P0oooo1P2I002L0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0
FP3oool609T009X0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`1M0?ooo`D0V@00V03o
ool100000040oooo000Q0?ooo`030000003oool0oooo05l0oooo1@2I002F0?ooo`4000000@3oool0
00D000000`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0H@3oool509T009@0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0H`3oool509T00980
oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0I@3oool509T00900oooo0@0000010?ooo`000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool20000
06P0oooo1@2I002=0?ooo`8000000@3oool000050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06T0oooo1@2I002<0?ooo`40
00000@3oool000050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo06/0oooo1@2I002:0?ooo`4000000@3oool000040?ooo`00
00000000000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo06d0oooo1@2I00280?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0K`3o
ool509T008H0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`1a0?ooo`D0V@00Q03oool1
00000040oooo000Q0?ooo`030000003oool0oooo07<0oooo1@2I00220?ooo`4000000@3oool00240
oooo00<000000?ooo`3oool0M@3oool509T00800oooo0@0000010?ooo`008@3oool2000007P0oooo
1@2I001m0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0N@3oool509T007`0oooo0@00
00010?ooo`008@3oool00`000000oooo0?ooo`1k0?ooo`D0V@00NP3oool100000040oooo000Q0?oo
o`030000003oool0oooo07d0oooo102I001i0?ooo`4000000@3oool00240oooo00<000000?ooo`3o
ool0O`3oool409T007L0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`200?ooo`D0V@00
M@3oool100000040oooo000Q0?ooo`030000003oool0oooo0880oooo102I001d0?ooo`4000000@3o
ool00240oooo00<000000?ooo`3oool0Q03oool409T00780oooo0@0000010?ooo`008@3oool20000
08H0oooo1@2I001_0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0Q`3oool409T006l0
oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`290?ooo`@0V@00K@3oool100000040oooo
000Q0?ooo`030000003oool0oooo08X0oooo1@2I001[0?ooo`4000000@3oool00240oooo00<00000
0?ooo`3oool0S03oool409T006X0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2>0?oo
o`@0V@00J03oool100000040oooo000Q0?ooo`030000003oool0oooo08l0oooo102I001W0?ooo`40
00000@3oool00240oooo00<000000?ooo`3oool0T@3oool409T006D0oooo0@0000010?ooo`008@3o
ool00`000000oooo0?ooo`2B0?ooo`@0V@00I03oool100000040oooo000Q0?ooo`800000U@3oool3
09T00680oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`2E0?ooo`@0V@00H@3oool10000
0040oooo000Q0?ooo`030000003oool0oooo09H0oooo102I001P0?ooo`4000000@3oool00240oooo
00<000000?ooo`3oool0V03oool409T005h0oooo0@0000010?ooo`008@3oool00`000000oooo0?oo
o`2I0?ooo`@0V@00G@3oool100000040oooo00020?ooo`<000000`3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0V`3oool409T005/0oooo0@000001
0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`2L0?ooo`@0V@00FP3oool100000040oooo000500000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2N0?ooo`<0V@00F@3o
ool100000040oooo000010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo0P00002P0?ooo`@0V@00EP3oool200000040oooo0000103oool000000?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0X03oool409T0
05H0oooo0@0000010?ooo`000P3oool2000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`2R0?ooo`@0V@00E03oool100000040oooo00030?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo0:<0oooo102I001C0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0Y@3oool4
09T00540oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2V0?ooo`@0V@00D03oool10000
0040oooo000Q0?ooo`030000003oool0oooo0:P0oooo0`2I001?0?ooo`4000000@3oool00240oooo
00<000000?ooo`3oool0Z@3oool409T004d0oooo0@0000010?ooo`008@3oool200000:/0oooo102I
001;0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0[03oool409T004X0oooo0@000001
0?ooo`008@3oool00`000000oooo0?ooo`2]0?ooo`@0V@00B@3oool100000040oooo000Q0?ooo`03
0000003oool0oooo0:l0oooo0`2I00180?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0
/03oool309T004L0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2a0?ooo`@0V@00A@3o
ool100000040oooo000Q0?ooo`030000003oool0oooo0;80oooo102I00140?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool0]03oool309T004<0oooo0@0000010?ooo`008@3oool200000;H0
oooo0`2I00110?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0]P3oool409T00400oooo
0@0000010?ooo`008@3oool00`000000oooo0?ooo`2g0?ooo`@0V@00?`3oool100000040oooo000Q
0?ooo`030000003oool0oooo0;T0oooo0`2I000n0?ooo`4000000@3oool00240oooo00<000000?oo
o`3oool0^P3oool309T003d0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2k0?ooo`<0
V@00?03oool100000040oooo000Q0?ooo`030000003oool0oooo0;`0oooo0`2I000k0?ooo`400000
0@3oool00240oooo00<000000?ooo`3oool0_@3oool309T003X0oooo0@0000010?ooo`008@3oool0
0`000000oooo0?ooo`2n0?ooo`<0V@00>@3oool100000040oooo000Q0?ooo`800000`03oool309T0
03L0oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`300?ooo`@0V@00=P3oool100000040
oooo000Q0?ooo`030000003oool0oooo0<40oooo102I000e0?ooo`4000000@3oool00240oooo00<0
00000?ooo`3oool0``3oool309T003@0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`34
0?ooo`<0V@00<`3oool100000040oooo000Q0?ooo`030000003oool0oooo0<D0oooo0`2I000b0?oo
o`4000000@3oool000040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0<H0oooo0`2I000a0?ooo`4000000@3oool00005
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0<L0oooo0`2I000`0?ooo`4000000@3oool000050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000b@3oool309T002h0oooo
0P0000010?ooo`00100000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0b@3oool309T002h0oooo0@0000010?ooo`0000<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<X0oooo0`2I000]0?ooo`40
00000@3oool000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`3;0?ooo`<0V@00;03oool100000040oooo00020?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0c03oool3
09T002/0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3=0?ooo`<0V@00:P3oool10000
0040oooo000Q0?ooo`030000003oool0oooo0<h0oooo0`2I000Y0?ooo`4000000@3oool00240oooo
00<000000?ooo`3oool0c`3oool309T002P0oooo0@0000010?ooo`008@3oool200000=40oooo0`2I
000V0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0d@3oool309T002H0oooo0@000001
0?ooo`008@3oool00`000000oooo0?ooo`3B0?ooo`<0V@009@3oool100000040oooo000Q0?ooo`03
0000003oool0oooo0=<0oooo0`2I000T0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0
e03oool309T002<0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3E0?ooo`<0V@008P3o
ool100000040oooo000Q0?ooo`030000003oool0oooo0=H0oooo0P2I000R0?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool0eP3oool309T00240oooo0@0000010?ooo`008@3oool00`000000
oooo0?ooo`3G0?ooo`<0V@00803oool100000040oooo000Q0?ooo`800000f@3oool309T001h0oooo
0P0000010?ooo`008@3oool00`000000oooo0?ooo`3I0?ooo`<0V@007P3oool100000040oooo000Q
0?ooo`030000003oool0oooo0=X0oooo0`2I000M0?ooo`4000000@3oool00240oooo00<000000?oo
o`3oool0f`3oool209T001d0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3K0?ooo`<0
V@00703oool100000040oooo000Q0?ooo`030000003oool0oooo0=`0oooo0`2I000K0?ooo`400000
0@3oool00240oooo00<000000?ooo`3oool0g@3oool309T001X0oooo0@0000010?ooo`008@3oool0
0`000000oooo0?ooo`3N0?ooo`<0V@006@3oool100000040oooo000Q0?ooo`800000h03oool209T0
01P0oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`3O0?ooo`<0V@00603oool100000040
oooo000Q0?ooo`030000003oool0oooo0>00oooo0`2I000G0?ooo`4000000@3oool00240oooo00<0
00000?ooo`3oool0h@3oool309T001H0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3R
0?ooo`<0V@005@3oool100000040oooo000Q0?ooo`030000003oool0oooo0><0oooo0`2I000D0?oo
o`4000000@3oool000040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0>@0oooo0`2I000C0?ooo`4000000@3oool00005
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0>D0oooo0P2I000C0?ooo`4000000@3oool000050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000iP3oool309T00140oooo
0P0000010?ooo`0000@0oooo00000000000000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0>H0oooo0`2I000A0?ooo`4000000@3oool000050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0>L0oooo0`2I000@0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>P0oooo0`2I000?0?oo
o`4000000@3oool000040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0>T0oooo0`2I000>0?ooo`4000000@3oool00240
oooo00<000000?ooo`3oool0jP3oool209T000h0oooo0@0000010?ooo`008@3oool00`000000oooo
0?ooo`3Z0?ooo`<0V@003@3oool100000040oooo000Q0?ooo`030000003oool0oooo0>/0oooo0`2I
000<0?ooo`4000000@3oool00240oooo0P00003]0?ooo`80V@002`3oool200000040oooo000Q0?oo
o`030000003oool0oooo0>`0oooo0`2I000;0?ooo`4000000@3oool00240oooo00<000000?ooo`3o
ool0k@3oool309T000X0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3^0?ooo`<0V@00
2@3oool100000040oooo000Q0?ooo`030000003oool0oooo0>l0oooo0P2I00090?ooo`4000000@3o
ool00240oooo00<000000?ooo`3oool0k`3oool309T000P0oooo0@0000010?ooo`008@3oool00`00
0000oooo0?ooo`3`0?ooo`<0V@001`3oool100000040oooo000Q0?ooo`030000003oool0oooo0?40
oooo0P2I00070?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0l@3oool309T000H0oooo
0@0000010?ooo`008@3oool200000?<0oooo0`2I00040?ooo`8000000@3oool00240oooo00<00000
0?ooo`3oool0l`3oool209T000D0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool100000040oooo000Q0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool100000040oooo000Q0?ooooh00000
0@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-58.4252, -11987.7, 1.48994, \
602.694}},
  CellTags->"TotalPrincipalPaid"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"TotalInterestPaid"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"TotalInterestPaid"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalInterestPaid"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{

Cell["TotalInterestPaid", "Section",
  CellTags->"TotalInterestPaid"],

Cell["\<\
TotalInterestPaid[{HomeCost, PercentageDownPayment}, InterestRate, \
Years, PaymentNumber] gives the total amount paid to interest for all \
payments through the payment given by PaymentNumber for a loan on a house of \
initial value given by HomeCost with a down payment given by \
PercentageDownPayment for a loan amortized over the number of years given by \
Years with the fixed interest rate given by InterestRate. 

TotalInterestPaid[{HomeCost, PercentageDownPayment}, InterestRate, Years] \
gives the total interest paid over the life of the loan. 

TotalInterestPaid[LoanAmount, InterestRate, Years, PaymentNumber] assumes a \
loan amount given by LoanAmount. 

TotalInterestPaid[LoanAmount, InterestRate, Years] again gives the total \
interest paid over the life of the loan. 

For each of the forms above, if InterestRate is replaced by {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, then \
the calculation is done for a variable rate loan with interest rate \
InterestRate1 for a number of payments given by Payments1 followed by \
InterestRate2 for a number of payments given by Payments2, and so on. If \
PaymentNumber is greater than Payments1+Payments2+...+PaymentsM then the \
interest rate is assumed to be InterestRateM for that payment. If \
PaymentNumber is not numerical then an analytical result will be returned (if \
$StrongErrorChecking is not True) that assumes that PaymentNumber is greater \
than Payments1+Payments2+...+Payments(M-1). 

For all of the forms given above, if PaymentNumber is replaced by \
{PaymentNumber1, PaymentNumber2} then the returned value will be the total of \
the interest paid between PaymentNumber1 and PaymentNumber2 inclusive.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalInterestPaid"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["TotalInterestPaid", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalInterestPaid"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalInterestPaid"],

Cell[TextData[{
  "Default options for ",
  StyleBox["TotalInterestPaid", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalInterestPaid"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalInterestPaid"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["TotalInterestPaid", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalInterestPaid"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"TotalInterestPaid"],

Cell["\<\
Compare the total interest paid over the life of a loan where the \
number of payments per year is 12  and 24.\
\>", "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"TotalInterestPaid", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", "7.0", ",", 
          " ", "30"}], "]"}], "-", 
      RowBox[{"TemporarySetPaymentsPerYear", "[", 
        RowBox[{"24", ",", " ", 
          RowBox[{"TotalInterestPaid", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", "7.0", 
              ",", " ", "30"}], "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"TotalInterestPaid"],

Cell[BoxData["92.04487809805141`"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"TotalInterestPaid"]
}, Open  ]],

Cell["\<\
Now assume a variable interest rate loan that starts at 6% with a \
maximum change in the rate of 0.25% per year and a lifetime cap of \
7.5%.\
\>", "Text",
  CellTags->"TotalInterestPaid"],

Cell["Here is the interest rate table for the loan.", "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"interestRateTable", "=", 
      RowBox[{"Table", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"6", " ", "+", 
                RowBox[{"0.25", " ", "i"}]}], ",", "12"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"TotalInterestPaid"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"6", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.25`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.5`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.75`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.25`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7.5`", ",", "12"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"TotalInterestPaid"]
}, Open  ]],

Cell["\<\
Look at a comparative graph of the variable rate loan versus a \
fixed rate loan at 7%.\
\>", "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"TotalInterestPaid", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", "7.0", 
                ",", " ", "30", ",", "\[Mu]"}], "]"}], "-", " ", 
            RowBox[{"TotalInterestPaid", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", 
                "interestRateTable", ",", " ", "30", ",", "\[Mu]"}], "]"}]}], 
          ",", 
          RowBox[{"{", 
            RowBox[{"\[Mu]", ",", "1", ",", "360"}], "}"}], ",", 
          RowBox[{"Axes", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"True", ",", "False"}], "}"}]}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"TotalInterestPaid"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 0.417568 7.99739e-05 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0177 -30 -4.5 ]
[-0.0125 .0177 0 4.5 ]
[-0.0125 .09767 -30 -4.5 ]
[-0.0125 .09767 0 4.5 ]
[-0.0125 .17765 -30 -4.5 ]
[-0.0125 .17765 0 4.5 ]
[-0.0125 .25762 -30 -4.5 ]
[-0.0125 .25762 0 4.5 ]
[-0.0125 .33759 -30 -4.5 ]
[-0.0125 .33759 0 4.5 ]
[-0.0125 .41757 -6 -4.5 ]
[-0.0125 .41757 0 4.5 ]
[-0.0125 .49754 -24 -4.5 ]
[-0.0125 .49754 0 4.5 ]
[-0.0125 .57752 -24 -4.5 ]
[-0.0125 .57752 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0177 m
.00625 .0177 L
s
[(-5000)] -0.0125 .0177 1 0 Mshowa
0 .09767 m
.00625 .09767 L
s
[(-4000)] -0.0125 .09767 1 0 Mshowa
0 .17765 m
.00625 .17765 L
s
[(-3000)] -0.0125 .17765 1 0 Mshowa
0 .25762 m
.00625 .25762 L
s
[(-2000)] -0.0125 .25762 1 0 Mshowa
0 .33759 m
.00625 .33759 L
s
[(-1000)] -0.0125 .33759 1 0 Mshowa
0 .41757 m
.00625 .41757 L
s
[(0)] -0.0125 .41757 1 0 Mshowa
0 .49754 m
.00625 .49754 L
s
[(1000)] -0.0125 .49754 1 0 Mshowa
0 .57752 m
.00625 .57752 L
s
[(2000)] -0.0125 .57752 1 0 Mshowa
.125 Mabswid
0 .03369 m
.00375 .03369 L
s
0 .04969 m
.00375 .04969 L
s
0 .06568 m
.00375 .06568 L
s
0 .08168 m
.00375 .08168 L
s
0 .11367 m
.00375 .11367 L
s
0 .12966 m
.00375 .12966 L
s
0 .14566 m
.00375 .14566 L
s
0 .16165 m
.00375 .16165 L
s
0 .19364 m
.00375 .19364 L
s
0 .20964 m
.00375 .20964 L
s
0 .22563 m
.00375 .22563 L
s
0 .24163 m
.00375 .24163 L
s
0 .27362 m
.00375 .27362 L
s
0 .28961 m
.00375 .28961 L
s
0 .3056 m
.00375 .3056 L
s
0 .3216 m
.00375 .3216 L
s
0 .35359 m
.00375 .35359 L
s
0 .36958 m
.00375 .36958 L
s
0 .38558 m
.00375 .38558 L
s
0 .40157 m
.00375 .40157 L
s
0 .43356 m
.00375 .43356 L
s
0 .44956 m
.00375 .44956 L
s
0 .46555 m
.00375 .46555 L
s
0 .48155 m
.00375 .48155 L
s
0 .51354 m
.00375 .51354 L
s
0 .52953 m
.00375 .52953 L
s
0 .54553 m
.00375 .54553 L
s
0 .56152 m
.00375 .56152 L
s
0 .0017 m
.00375 .0017 L
s
0 .59351 m
.00375 .59351 L
s
0 .60951 m
.00375 .60951 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0177 m
1 .0177 L
s
.99375 .09767 m
1 .09767 L
s
.99375 .17765 m
1 .17765 L
s
.99375 .25762 m
1 .25762 L
s
.99375 .33759 m
1 .33759 L
s
.99375 .41757 m
1 .41757 L
s
.99375 .49754 m
1 .49754 L
s
.99375 .57752 m
1 .57752 L
s
.125 Mabswid
.99625 .03369 m
1 .03369 L
s
.99625 .04969 m
1 .04969 L
s
.99625 .06568 m
1 .06568 L
s
.99625 .08168 m
1 .08168 L
s
.99625 .11367 m
1 .11367 L
s
.99625 .12966 m
1 .12966 L
s
.99625 .14566 m
1 .14566 L
s
.99625 .16165 m
1 .16165 L
s
.99625 .19364 m
1 .19364 L
s
.99625 .20964 m
1 .20964 L
s
.99625 .22563 m
1 .22563 L
s
.99625 .24163 m
1 .24163 L
s
.99625 .27362 m
1 .27362 L
s
.99625 .28961 m
1 .28961 L
s
.99625 .3056 m
1 .3056 L
s
.99625 .3216 m
1 .3216 L
s
.99625 .35359 m
1 .35359 L
s
.99625 .36958 m
1 .36958 L
s
.99625 .38558 m
1 .38558 L
s
.99625 .40157 m
1 .40157 L
s
.99625 .43356 m
1 .43356 L
s
.99625 .44956 m
1 .44956 L
s
.99625 .46555 m
1 .46555 L
s
.99625 .48155 m
1 .48155 L
s
.99625 .51354 m
1 .51354 L
s
.99625 .52953 m
1 .52953 L
s
.99625 .54553 m
1 .54553 L
s
.99625 .56152 m
1 .56152 L
s
.99625 .0017 m
1 .0017 L
s
.99625 .59351 m
1 .59351 L
s
.99625 .60951 m
1 .60951 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .41757 m
1 .41757 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02646 .42357 m
.04521 .46613 L
.06498 .50579 L
.07549 .52381 L
.08127 .53373 L
.08674 .54311 L
.09182 .54934 L
.09735 .55578 L
.107 .56702 L
.11658 .57819 L
.11777 .57958 L
.11891 .5809 L
.12021 .58179 L
.12141 .58253 L
.12416 .58424 L
.12673 .58584 L
.13629 .59177 L
.14495 .59714 L
.14732 .59861 L
.14856 .59938 L
.14987 .6002 L
.15103 .60079 L
.15229 .60089 L
.15451 .60107 L
.1647 .60191 L
.16921 .60228 L
.17412 .60268 L
.17636 .60286 L
.17875 .60306 L
.18079 .60322 L
.18195 .60332 L
.18304 .60314 L
.18428 .60258 L
.18559 .60199 L
.18794 .60094 L
.19321 .59857 L
.20249 .59439 L
.20731 .59222 L
.20996 .59102 L
.21245 .5899 L
.21314 .58958 L
.21387 .58926 L
.21467 .58869 L
.21541 .58797 L
.2181 .58535 L
.22335 .58024 L
.26113 .54335 L
.30136 .50402 L
.34008 .46619 L
.38124 .42609 L
Mistroke
.42089 .38771 L
.45903 .35115 L
.49961 .31279 L
.53869 .27657 L
.5802 .23909 L
.62021 .20422 L
.65871 .17212 L
.69965 .13989 L
.73908 .11111 L
.777 .08593 L
.81736 .06234 L
.85621 .04332 L
.87601 .03523 L
.89751 .02779 L
.91819 .02209 L
.92805 .0199 L
.9373 .01818 L
.94695 .01674 L
.9558 .01575 L
.96058 .01534 L
.96562 .01503 L
.96824 .0149 L
.97067 .01482 L
.97207 .01478 L
.97334 .01475 L
.97405 .01474 L
.97481 .01473 L
.97553 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009P3oool2
000001/0oooo0`0000040?ooo`8000005P3oool3000000@0oooo0P0000040?ooo`8000004P3oool3
000000<0oooo0`0000040?ooo`8000004P3oool5000000<0oooo0P0000040?ooo`8000004P3oool5
00000080oooo0`0000040?ooo`8000004P3oool3000000@0oooo0P0000040?ooo`8000004`3oool3
000000<0oooo0`0000040?ooo`8000001`3oool002D0oooo00@000000?ooo`3oool000006@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000005P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000B0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000004@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0
oooo000U0?ooo`040000003oool0oooo000001d0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`009@3oool010000000oooo
0?ooo`00000M0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
4P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0@0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000001<0oooo0P0000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0103oool002D0oooo00@000000?ooo`3oool000006@3oool4000000<0oooo00@000000?ooo`3o
ool000005P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000004P3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool0
00004@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000A0?ooo`060000003oool0oooo0?ooo`000000oooo100000030?ooo`04
0000003oool0oooo000001@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`0000000`0000030?ooo`040000003o
ool0oooo000000H0oooo000U0?ooo`040000003oool0oooo000001T0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`00000E0?ooo`800000103oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000140oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000004@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000A0?ooo`070000003oool0oooo0?ooo`000000oooo0000
00060?ooo`040000003oool0oooo00000100oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000004@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000001P3oool010000000oooo0?ooo`0000060?ooo`009P3oool2000001X0oooo
1@0000030?ooo`8000005`3oool00`000000oooo0?ooo`030?ooo`800000103oool2000001<0oooo
00@000000?ooo`3oool0oooo1@0000030?ooo`8000004`3oool3000000@0oooo0P0000040?ooo`80
00004`3oool300000080oooo1@0000030?ooo`8000004P3oool3000000@0oooo0P0000040?ooo`80
00004`3oool300000080oooo1@0000030?ooo`8000001`3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00240oooooP0000010?ooo`008@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`001`3oool3000000@0oooo0P00
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0nP3oool100000040oooo0006
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3a0?oo
o`@0V@001@3oool100000040oooo0005000000D0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool200000>T0oooo3@2I00040?ooo`8000000@3oool000X0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3T0?ooo`l0V@001`3oool100000040oooo00060?ooo`@00000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3Q0?ooo`P0V@004@3oool100000040oooo00060?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0gP3oool709T001D0oooo
0@0000010?ooo`001P3oool5000000<0oooo0P0000040?ooo`800000103oool2000000D0oooo0P00
003L0?ooo`L0V@005`3oool200000040oooo000Q0?ooo`030000003oool0oooo0=T0oooo1P2I000K
0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0eP3oool609T001h0oooo0@0000010?oo
o`008@3oool00`000000oooo0?ooo`3D0?ooo`H0V@00803oool100000040oooo000Q0?ooo`800000
d`3oool509T00280oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`3@0?ooo`D0V@009@3o
ool100000040oooo000Q0?ooo`030000003oool0oooo0<h0oooo1@2I000W0?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool0c03oool509T002T0oooo0@0000010?ooo`008@3oool200000</0
oooo1@2I000Z0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0b03oool509T002d0oooo
0@0000010?ooo`008@3oool00`000000oooo0?ooo`370?ooo`@0V@00;`3oool100000040oooo000Q
0?ooo`030000003oool0oooo0<D0oooo102I000a0?ooo`4000000@3oool00240oooo0P0000340?oo
o`D0V@00<@3oool200000040oooo000Q0?ooo`030000003oool0oooo0<80oooo102I000d0?ooo`40
00000@3oool000P0oooo0`0000030?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo0<00oooo102I000f0?ooo`4000000@3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0;h0oooo1@2I000g0?ooo`4000000@3oool000D0
000000<0oooo0000000000000`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000_P3oool409T003P0oooo0P00
00010?ooo`001P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0;/0oooo102I000k0?ooo`4000000@3oool000L0oooo00<000000?ooo`0000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`2i0?ooo`D0V@00?03oool100000040oooo00080?ooo`8000000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`2h0?ooo`@0V@00?P3oool100000040oooo00090?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
]P3oool409T00400oooo0@0000010?ooo`008@3oool200000;H0oooo102I00100?ooo`8000000@3o
ool00240oooo00<000000?ooo`3oool0/`3oool409T004<0oooo0@0000010?ooo`008@3oool00`00
0000oooo0?ooo`2b0?ooo`@0V@00A03oool100000040oooo000Q0?ooo`030000003oool0oooo0;40
oooo0`2I00160?ooo`4000000@3oool00240oooo0P00002`0?ooo`@0V@00AP3oool200000040oooo
000Q0?ooo`030000003oool0oooo0:h0oooo102I00180?ooo`4000000@3oool00240oooo00<00000
0?ooo`3oool0[03oool409T004X0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2[0?oo
o`@0V@00B`3oool100000040oooo000Q0?ooo`800000Z`3oool309T004`0oooo0P0000010?ooo`00
8@3oool00`000000oooo0?ooo`2Y0?ooo`<0V@00CP3oool100000040oooo000Q0?ooo`030000003o
ool0oooo0:L0oooo102I001?0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0YP3oool4
09T00500oooo0@0000010?ooo`008@3oool200000:H0oooo0`2I001A0?ooo`8000000@3oool000L0
oooo0`0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0:@0
oooo0`2I001C0?ooo`4000000@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0:80oooo102I001D0?ooo`4000000@3oool000D000001@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:40oooo102I001E0?ooo`40
00000@3oool000P0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`800000X@3oool309T005H0oooo0P000001
0?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09l0oooo
0`2I001H0?ooo`4000000@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo09h0oooo0`2I001I0?ooo`4000000@3oool000L0oooo0`0000040?oo
o`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo09d0oooo0`2I001J0?oo
o`4000000@3oool00240oooo0P00002M0?ooo`<0V@00FP3oool200000040oooo000Q0?ooo`030000
003oool0oooo09/0oooo0`2I001L0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0VP3o
ool309T005d0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2H0?ooo`@0V@00GP3oool1
00000040oooo000Q0?ooo`800000V03oool409T005h0oooo0P0000010?ooo`008@3oool00`000000
oooo0?ooo`2F0?ooo`<0V@00H@3oool100000040oooo000Q0?ooo`030000003oool0oooo09D0oooo
0`2I001R0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0T`3oool409T006<0oooo0@00
00010?ooo`008@3oool2000009<0oooo102I001S0?ooo`8000000@3oool00240oooo00<000000?oo
o`3oool0T@3oool309T006H0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2@0?ooo`<0
V@00I`3oool100000040oooo000Q0?ooo`030000003oool0oooo08h0oooo102I001X0?ooo`400000
0@3oool00240oooo0P00002>0?ooo`@0V@00J03oool200000040oooo000Q0?ooo`030000003oool0
oooo08`0oooo0`2I001[0?ooo`4000000@3oool000H0oooo1@0000030?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo08/0oooo0`2I001/0?ooo`4000000@3oool000L0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2:0?ooo`<0V@00
K@3oool100000040oooo0005000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool20000
08X0oooo0`2I001]0?ooo`8000000@3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo08P0oooo0`2I001_0?ooo`4000000@3oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo08L0oooo0`2I001`0?oo
o`4000000@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo08H0oooo0`2I001a0?ooo`4000000@3oool000L0oooo0`0000040?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`800000QP3oool309T00740oooo0P0000010?ooo`008@3oool0
0`000000oooo0?ooo`230?ooo`@0V@00L`3oool100000040oooo000Q0?ooo`030000003oool0oooo
0880oooo102I001d0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0P@3oool309T007H0
oooo0@0000010?ooo`008@3oool200000840oooo0`2I001f0?ooo`8000000@3oool00240oooo00<0
00000?ooo`3oool0O`3oool309T007P0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`1n
0?ooo`<0V@00N@3oool100000040oooo000Q0?ooo`030000003oool0oooo07d0oooo0`2I001j0?oo
o`4000000@3oool00240oooo0P00001m0?ooo`<0V@00NP3oool200000040oooo000Q0?ooo`030000
003oool0oooo07/0oooo0`2I001l0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0NP3o
ool309T007d0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`1i0?ooo`<0V@00OP3oool1
00000040oooo000Q0?ooo`800000N@3oool309T007h0oooo0P0000010?ooo`008@3oool00`000000
oooo0?ooo`1g0?ooo`<0V@00P03oool100000040oooo00070?ooo`<00000103oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1f0?ooo`<0V@00P@3oool100000040oooo
00080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M@3oool309T0
0880oooo0@0000010?ooo`001@0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P00
001e0?ooo`<0V@00PP3oool200000040oooo00080?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0L`3oool309T008@0oooo0@0000010?ooo`00203oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0780oooo0`2I00250?ooo`4000000@3oool0
00L0oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0740oooo0`2I00260?ooo`400000
0@3oool000P0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`8000001@3o
ool200000700oooo102I00260?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0KP3oool4
09T008P0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`1]0?ooo`<0V@00RP3oool10000
0040oooo000Q0?ooo`030000003oool0oooo06`0oooo0`2I002;0?ooo`4000000@3oool00240oooo
0P00001/0?ooo`<0V@00R`3oool200000040oooo000Q0?ooo`030000003oool0oooo06X0oooo0`2I
002=0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0J@3oool309T008h0oooo0@000001
0?ooo`008@3oool00`000000oooo0?ooo`1X0?ooo`<0V@00S`3oool100000040oooo000Q0?ooo`03
0000003oool0oooo06L0oooo0`2I002@0?ooo`4000000@3oool00240oooo0P00001W0?ooo`<0V@00
T03oool200000040oooo000Q0?ooo`030000003oool0oooo06D0oooo0`2I002B0?ooo`4000000@3o
ool00240oooo00<000000?ooo`3oool0I03oool309T009<0oooo0@0000010?ooo`008@3oool00`00
0000oooo0?ooo`1S0?ooo`<0V@00U03oool100000040oooo000Q0?ooo`800000H`3oool309T009@0
oooo0P0000010?ooo`006P3oool2000000D0oooo00<000000?ooo`3oool0H@3oool309T009H0oooo
0@0000010?ooo`006@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0600oooo
0`2I002G0?ooo`4000000@3oool001T0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1O0?ooo`<0V@00V03oool100000040oooo000I0?ooo`040000003oool0oooo000000@0oooo
H@00000309T009X000000@3oool001T0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooo`80V@00F@3oool309T009X0oooo0@0000010?ooo`006@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo0P2I001H0?ooo`<0V@00V`3oool100000040oooo
000J0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<0V@00EP3oool309T009`0oooo0@00
00010?ooo`008@3oool2000000@0oooo0P2I001E0?ooo`<0V@00W03oool200000040oooo000Q0?oo
o`030000003oool0oooo00<0oooo0`2I001C0?ooo`<0V@00WP3oool100000040oooo000Q0?ooo`03
0000003oool0oooo00@0oooo0P2I001B0?ooo`<0V@00W`3oool100000040oooo000Q0?ooo`030000
003oool0oooo00@0oooo0`2I001@0?ooo`<0V@00X03oool100000040oooo000Q0?ooo`8000001P3o
ool209T004l0oooo0`2I002P0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool01@3oool2
09T004h0oooo0`2I002R0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool01@3oool309T0
04`0oooo0`2I002S0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool01P3oool209T004/0
oooo0`2I002T0?ooo`4000000@3oool00240oooo0P0000070?ooo`<0V@00B@3oool309T00:@0oooo
0P0000010?ooo`008@3oool00`000000oooo0?ooo`070?ooo`80V@00B03oool309T00:H0oooo0@00
00010?ooo`008@3oool00`000000oooo0?ooo`070?ooo`<0V@00AP3oool309T00:L0oooo0@000001
0?ooo`008@3oool00`000000oooo0?ooo`080?ooo`80V@00A@3oool309T00:P0oooo0@0000010?oo
o`008@3oool2000000T0oooo0`2I00130?ooo`<0V@00Z03oool200000040oooo00070?ooo`<00000
103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`80V@00
@P3oool309T00:X0oooo0@0000010?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00T0oooo0`2I00100?ooo`<0V@00Z`3oool100000040oooo00080?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool209T003l0oooo0`2I
002/0?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000000/0
oooo0`2I000m0?ooo`<0V@00[03oool200000040oooo00080?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool02`3oool209T003`0oooo0`2I002^0?ooo`4000000@3oool0
00L0oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00/0oooo0`2I000j0?ooo`<0V@00
[`3oool100000040oooo00080?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0303oool209T003T0oooo0`2I002`0?ooo`4000000@3o
ool00240oooo0P00000=0?ooo`<0V@00=`3oool309T00;00oooo0P0000010?ooo`008@3oool00`00
0000oooo0?ooo`0=0?ooo`<0V@00=@3oool309T00;80oooo0@0000010?ooo`008@3oool00`000000
oooo0?ooo`0>0?ooo`80V@00=03oool309T00;<0oooo0@0000010?ooo`008@3oool00`000000oooo
0?ooo`0>0?ooo`<0V@00<P3oool309T00;@0oooo0@0000010?ooo`008@3oool200000100oooo0P2I
000a0?ooo`<0V@00]03oool200000040oooo000Q0?ooo`030000003oool0oooo00l0oooo0`2I000_
0?ooo`<0V@00]P3oool100000040oooo000Q0?ooo`030000003oool0oooo0100oooo0P2I000^0?oo
o`<0V@00]`3oool100000040oooo000Q0?ooo`030000003oool0oooo0100oooo0`2I000/0?ooo`<0
V@00^03oool100000040oooo000Q0?ooo`8000004P3oool309T002T0oooo102I002h0?ooo`800000
0@3oool00240oooo00<000000?ooo`3oool04P3oool309T002L0oooo102I002j0?ooo`4000000@3o
ool00240oooo00<000000?ooo`3oool04`3oool209T002H0oooo0`2I002l0?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool04`3oool309T002@0oooo0`2I002m0?ooo`4000000@3oool00240
oooo0P00000E0?ooo`<0V@008P3oool309T00;d0oooo0P0000010?ooo`008@3oool00`000000oooo
0?ooo`0E0?ooo`<0V@00803oool309T00;l0oooo0@0000010?ooo`001P3oool5000000<0oooo0P00
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool05P3oool309T001h0oooo0`2I
00300?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0G0?ooo`<0V@00703oool309T00<40oooo0@0000010?ooo`00203oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`8000006@3oool309T001X0oooo0`2I00310?ooo`8000000@3o
ool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0
oooo0`2I000H0?ooo`<0V@00``3oool100000040oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0J0?ooo`@0V@005@3oool309T00<@0oooo0@00
00010?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool06P3oool509T001<0oooo0`2I00350?ooo`4000000@3oool000L0oooo0`0000040?ooo`80
0000103oool2000000@0oooo0P0000050?ooo`8000007P3oool409T000l0oooo102I00350?ooo`80
00000@3oool00240oooo00<000000?ooo`3oool07P3oool409T000`0oooo1@2I00370?ooo`400000
0@3oool00240oooo00<000000?ooo`3oool0803oool809T000<0oooo1P2I00390?ooo`4000000@3o
ool00240oooo00<000000?ooo`3oool08@3oool>09T00</0oooo0@0000010?ooo`008@3oool20000
02P0oooo1@2I003=0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`008@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`008@3oooon00000040oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-58.4252, -6017.62, 1.48994, \
49.2866}},
  CellTags->"TotalInterestPaid"]
}, Open  ]],

Cell["The crossover point is somewhere near payment 150. ", "Text",
  CellTags->"TotalInterestPaid"],

Cell[TextData[{
  "Use ",
  StyleBox["FindRoot", "MR"],
  " to determine when the break even point is for the variable rate loan (in \
a worst case scenario) relative to the fixed rate loan."
}], "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FindRoot", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"TotalInterestPaid", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", "7.0", 
              ",", " ", "30", ",", "\[Mu]"}], "]"}], "==", " ", 
          RowBox[{"TotalInterestPaid", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"100000", ",", " ", "10"}], "}"}], ",", " ", 
              "interestRateTable", ",", " ", "30", ",", "\[Mu]"}], "]"}]}], 
        ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "150", ",", "155"}], "}"}]}], "]"}]], "Input",\

  CellLabel->"In[5]:=",
  CellTags->"TotalInterestPaid"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\[Mu]", "\[Rule]", "138.42788953259583`"}], "}"}]], "Output",
  CellLabel->"Out[5]=",
  CellTags->"TotalInterestPaid"]
}, Open  ]],

Cell[TextData[{
  "Thus the break even point is at ",
  Cell[BoxData[
      RowBox[{
        FractionBox["138.428", "$PaymentsPerYear"], "=", 
        "11.535666666666666`"}]]],
  " years."
}], "Text",
  CellTags->"TotalInterestPaid"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"TotalPayments"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"TotalPayments"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalPayments"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalPayments"],

Cell[CellGroupData[{

Cell["TotalPayments", "Section",
  CellTags->"TotalPayments"],

Cell["\<\
TotalPayments[{HomeCost, PercentageDownPayment}, InterestRate, \
Years, PaymentNumber] gives the total amount paid for all payments through \
the payment given by PaymentNumber for a loan on a house of initial value \
given by HomeCost with a down payment given by PercentageDownPayment for a \
loan amortized over the number of years given by Years with the fixed \
interest rate given by InterestRate. 

TotalPayments[{HomeCost, PercentageDownPayment}, InterestRate, Years] gives \
the total paid over the life of the loan. 

TotalPayments[LoanAmount, InterestRate, Years, PaymentNumber] assumes a loan \
amount given by LoanAmount. 

TotalPayments[LoanAmount, InterestRate, Years] again gives the total paid \
over the life of the loan. The results returned by TotalPayments only include \
payments to interest and principal. 

For each of the forms above, if InterestRate is replaced by {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, then \
the calculation is done for a variable rate loan with interest rate \
InterestRate1 for a number of payments given by Payments1 followed by \
InterestRate2 for a number of payments given by Payments2, and so on. If \
PaymentNumber is greater than Payments1+Payments2+...+PaymentsM then the \
interest rate is assumed to be InterestRateM for that payment. If \
PaymentNumber is not numerical then an analytical result will be returned (if \
$StrongErrorChecking is not True) that assumes that PaymentNumber is greater \
than Payments1+Payments2+...+Payments(M-1). 

For all of the forms given above, if PaymentNumber is replaced by \
{PaymentNumber1, PaymentNumber2} then the returned value will be the total of \
the payments between PaymentNumber1 and PaymentNumber2 inclusive.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPayments"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["TotalPayments", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPayments"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPayments"],

Cell[TextData[{
  "Default options for ",
  StyleBox["TotalPayments", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPayments"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPayments"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["TotalPayments", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPayments"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"TotalPayments"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"TotalPayments"],

Cell["Here is the total paid over the life of a loan", "MathCaption",
  CellTags->"TotalPayments"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TotalPayments", "[", 
      RowBox[{"100000", ",", " ", "7.3", ",", "30"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"TotalPayments"],

Cell[BoxData["246805.534211528811247341771976`13.07"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"TotalPayments"]
}, Open  ]],

Cell["\<\
If the number of payments per year is doubled you save about $100\
\
\>", "MathCaption",
  CellTags->"TotalPayments"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TemporarySetPaymentsPerYear", "[", 
      RowBox[{"24", ",", 
        RowBox[{"TotalPayments", "[", 
          RowBox[{"100000", ",", " ", "7.3", ",", "30"}], "]"}]}], 
      "]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"TotalPayments"],

Cell[BoxData["246702.012618643569914091153975`12.7693"], "Output",
  CellLabel->"Out[3]=",
  CellTags->"TotalPayments"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[CellGroupData[{

Cell["ActualPayment", "Section",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[{
  "The function ",
  StyleBox["ActualPayment", "MR"],
  " computes the actual payment including a variety of other costs both \
deductible and nondeductible."
}], "Text",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell["\<\
ActualPayment[{HomeCost, PercentageDownPayment}, InterestRate, \
Years,{AnnualMortgageInsurance, {AnnualDeductiblePropertyTaxes, \
AnnualNonDeductiblePropertyTaxes}, AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts, AnnualNonDeductibleOtherCosts}}], gives the \
total payment including all the various other costs in addition to principal \
and interest. It does not include the potential benefits of deductible \
interest etc. The function EffectivePayment compensates for such potential \
deductions. 

ActualPayment[{HomeCost, PercentageDownPayment}, InterestRate, Years] assumes \
each of {AnnualMortgageInsurance, {AnnualDeductiblePropertyTaxes, \
AnnualNonDeductiblePropertyTaxes}, AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts,AnnualNonDeductibleOtherCosts}} to be zero. 

ActualPayment[LoanAmount, InterestRate, Years, {AnnualMortgageInsurance, \
{AnnualDeductiblePropertyTaxes, AnnualNonDeductiblePropertyTaxes}, \
AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts,AnnualNonDeductibleOtherCosts}}] assumes a loan \
of size LoanAmount. 

ActualPayment[{HomeCost, PercentageDownPayment}, {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber,{AnnualMortgageInsurance, {AnnualDeductiblePropertyTaxes, \
AnnualNonDeductiblePropertyTaxes}, AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts, AnnualNonDeductibleOtherCosts}}] calculates for \
a variable rate loan with interest rate InterestRate1 for a number of \
payments given by Payments1 followed by InterestRate2 for a number of \
payments given by Payments2, and so on. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. If PaymentNumber is not numerical then an \
analytical result will be returned (if $StrongErrorChecking is not True) that \
assumes that PaymentNumber is greater than \
Payments1+Payments2+...+Payments(M-1).

ActualPayment[{HomeCost, PercentageDownPayment}, {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber] is a valid input. 

ActualPayment[LoanAmount, {{{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, Years, PaymentNumber] is a valid \
input.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["ActualPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["ActualPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["ActualPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[TextData[{
  "The function ",
  StyleBox["ActualPayment", "MR"],
  " computes the total out of pocket expenses (including a variety of other \
expenses in addition to the loan payment) without taking into consideration \
the possible benefits of deductible interest and other deductible expenses."
}], "MathCaption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ActualPayment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"100000", ",", " ", "12"}], "}"}], ",", " ", "7.", ",", " ",
         "30", ",", " ", 
        RowBox[{"{", 
          RowBox[{"1200", ",", " ", 
            RowBox[{"{", 
              RowBox[{"3000", ",", " ", "0"}], "}"}], ",", " ", "200", ",", 
            " ", 
            RowBox[{"{", 
              RowBox[{"0", ",", " ", "1000"}], "}"}]}], "}"}]}], 
      "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[BoxData["1035.466195757680426359749516`13.3148"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"TotalPayments"]
}, Open  ]],

Cell[TextData[{
  "Of course this should give the same result as using ",
  StyleBox["EffectivePayment", "MR"],
  " with a marginal tax bracket of 0%"
}], "MathCaption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"EffectivePayment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"100000", ",", " ", "12"}], "}"}], ",", "7.", ",", " ", 
        "30", ",", "\[Mu]", ",", "0", ",", " ", 
        RowBox[{"{", 
          RowBox[{"1200", ",", " ", 
            RowBox[{"{", 
              RowBox[{"3000", ",", " ", "0"}], "}"}], ",", " ", "200", ",", 
            " ", 
            RowBox[{"{", 
              RowBox[{"0", ",", " ", "1000"}], "}"}]}], "}"}]}], 
      "]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[BoxData["1035.466195757680426359749516`13.3148"], "Output",
  CellLabel->"Out[3]=",
  CellTags->"TotalPayments"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"EffectivePayment"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"EffectivePayment"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"EffectivePayment"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"EffectivePayment"],

Cell[CellGroupData[{

Cell["EffectivePayment", "Section",
  CellTags->"EffectivePayment"],

Cell[TextData[{
  "The function ",
  StyleBox["EffectivePayment", "MR"],
  " computes the effective payment including a variety of other costs both \
deductible and nondeductible."
}], "Text",
  CellTags->"EffectivePayment"],

Cell["\<\
EffectivePayment[{HomeCost, PercentageDownPayment}, InterestRate, \
Years, PaymentNumber, MarginalTaxBracket, {AnnualMortgageInsurance, \
{AnnualDeductiblePropertyTaxes, AnnualNonDeductiblePropertyTaxes}, \
AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts,AnnualNonDeductibleOtherCosts}}], gives the \
effective cost of a payment taking into account the tax advantage, etc as \
well as the cost of other items in addition to the loan principal and \
interest. 

EffectivePayment[{HomeCost, PercentageDownPayment}, InterestRate, Years, \
PaymentNumber, MarginalTaxBracket] assumes that each of \
{AnnualMortgageInsurance, {AnnualDeductiblePropertyTaxes, \
AnnualNonDeductiblePropertyTaxes}, AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts,AnnualNonDeductibleOtherCosts}} is zero. 

EffectivePayment[LoanAmount, InterestRate, Years, PaymentNumber, \
MarginalTaxBracket, {AnnualMortgageInsurance, {AnnualDeductiblePropertyTaxes, \
AnnualNonDeductiblePropertyTaxes}, AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts,AnnualNonDeductibleOtherCosts}}] assumes a loan \
of size LoanAmount. 

EffectivePayment[{HomeCost, PercentageDownPayment}, {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber, MarginalTaxBracket, {AnnualMortgageInsurance, \
{AnnualDeductiblePropertyTaxes, AnnualNonDeductiblePropertyTaxes}, \
AnnualHazardInsurance, \
{AnnualDeductibleOtherCosts,AnnualNonDeductibleOtherCosts}}] calculates for a \
variable rate loan with interest rate InterestRate1 for a number of payments \
given by Payments1 followed by InterestRate2 for a number of payments given \
by Payments2, and so on. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. If PaymentNumber is not numerical then an \
analytical result will be returned (if $StrongErrorChecking is not True) that \
assumes that PaymentNumber is greater than \
Payments1+Payments2+...+Payments(M-1).

EffectivePayment[{HomeCost, PercentageDownPayment}, {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber, MarginalTaxBracket] is a valid input. 

EffectivePayment[LoanAmount, {{{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, Years, PaymentNumber, \
MarginalTaxBracket] is a valid input.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EffectivePayment"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["EffectivePayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EffectivePayment"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EffectivePayment"],

Cell[TextData[{
  "Default options for ",
  StyleBox["EffectivePayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EffectivePayment"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EffectivePayment"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["EffectivePayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EffectivePayment"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"EffectivePayment"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"EffectivePayment"],

Cell[TextData[{
  "The function ",
  StyleBox["EffectivePayment", "MR"],
  " computes the effective cost (including a variety of other expenses in \
addition to the loan payment) taking into consideration the possible benefits \
of deductible interest and other deductible expenses. Here a 28% marginal tax \
bracket is assumed."
}], "MathCaption",
  CellTags->"EffectivePayment"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"EffectivePayment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", "7.5", ",", 
        " ", "30", ",", " ", "\[Mu]", ",", " ", "28", ",", " ", 
        RowBox[{"{", 
          RowBox[{"0", ",", " ", 
            RowBox[{"{", 
              RowBox[{"0", ",", " ", "3000"}], "}"}], ",", " ", "1000", ",", 
            " ", 
            RowBox[{"{", 
              RowBox[{"0", ",", "2000"}], "}"}]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"EffectivePayment"],

Cell[BoxData[
    RowBox[{"500", "+", 
      RowBox[{"0.13333333333333333`", " ", 
        RowBox[{"(", 
          RowBox[{"713198.798723836543868737713545`13.0716", "-", 
            RowBox[{"75698.79872383655`", " ", 
              SuperscriptBox["1.00625`", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "\[Mu]"}]]}]}], ")"}]}], "-", 
      RowBox[{"0.13333333333333333`", " ", 
        RowBox[{"(", 
          RowBox[{"713198.798723836543868737713545`13.0716", "-", 
            RowBox[{"75698.79872383655`", " ", 
              SuperscriptBox["1.00625`", "\[Mu]"]}]}], ")"}]}], "+", 
      RowBox[{
        FractionBox["18", "25"], " ", 
        RowBox[{"(", 
          RowBox[{"594.332332269863786557281428`13.0716", "-", 
            RowBox[{"0.13333333333333333`", " ", 
              RowBox[{"(", 
                RowBox[{"713198.798723836543868737713545`13.0716", "-", 
                  RowBox[{"75698.79872383655`", " ", 
                    SuperscriptBox["1.00625`", 
                      RowBox[{
                        RowBox[{"-", "1"}], "+", "\[Mu]"}]]}]}], ")"}]}], "+",
             
            RowBox[{"0.13333333333333333`", " ", 
              RowBox[{"(", 
                RowBox[{"713198.798723836543868737713545`13.0716", "-", 
                  RowBox[{"75698.79872383655`", " ", 
                    SuperscriptBox["1.00625`", "\[Mu]"]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"EffectivePayment"]
}, Open  ]],

Cell["\<\
Over the course of the loan the tax benefits of deductible expenses \
(such as deductible interest) wear off as a greater fraction of the each \
payment is paid into principal. The effective payment therefore grows with \
time.\
\>", "MathCaption",
  CellTags->"EffectivePayment"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"EffectivePayment", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", "7.5", 
              ",", " ", "30", ",", " ", "\[Mu]", ",", " ", "28", ",", " ", 
              RowBox[{"{", 
                RowBox[{"0", ",", " ", 
                  RowBox[{"{", 
                    RowBox[{"0", ",", " ", "3000"}], "}"}], ",", " ", "1000", 
                  ",", " ", 
                  RowBox[{"{", 
                    RowBox[{"0", ",", "2000"}], "}"}]}], "}"}]}], "]"}], ",", 
          
          RowBox[{"{", 
            RowBox[{"\[Mu]", ",", "0", ",", "360"}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"EffectivePayment"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0026455 -3.7499 0.00398173 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -6 -9 ]
[.15608 -0.0125 6 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -9 -9 ]
[.55291 -0.0125 9 0 ]
[.68519 -0.0125 -9 -9 ]
[.68519 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -9 -9 ]
[.94974 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07256 -18 -4.5 ]
[-0.0125 .07256 0 4.5 ]
[-0.0125 .15219 -18 -4.5 ]
[-0.0125 .15219 0 4.5 ]
[-0.0125 .23183 -24 -4.5 ]
[-0.0125 .23183 0 4.5 ]
[-0.0125 .31146 -24 -4.5 ]
[-0.0125 .31146 0 4.5 ]
[-0.0125 .3911 -24 -4.5 ]
[-0.0125 .3911 0 4.5 ]
[-0.0125 .47073 -24 -4.5 ]
[-0.0125 .47073 0 4.5 ]
[-0.0125 .55037 -24 -4.5 ]
[-0.0125 .55037 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(50)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(100)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(150)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(200)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(250)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(300)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(350)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07256 m
.00625 .07256 L
s
[(960)] -0.0125 .07256 1 0 Mshowa
0 .15219 m
.00625 .15219 L
s
[(980)] -0.0125 .15219 1 0 Mshowa
0 .23183 m
.00625 .23183 L
s
[(1000)] -0.0125 .23183 1 0 Mshowa
0 .31146 m
.00625 .31146 L
s
[(1020)] -0.0125 .31146 1 0 Mshowa
0 .3911 m
.00625 .3911 L
s
[(1040)] -0.0125 .3911 1 0 Mshowa
0 .47073 m
.00625 .47073 L
s
[(1060)] -0.0125 .47073 1 0 Mshowa
0 .55037 m
.00625 .55037 L
s
[(1080)] -0.0125 .55037 1 0 Mshowa
.125 Mabswid
0 .09247 m
.00375 .09247 L
s
0 .11238 m
.00375 .11238 L
s
0 .13229 m
.00375 .13229 L
s
0 .1721 m
.00375 .1721 L
s
0 .19201 m
.00375 .19201 L
s
0 .21192 m
.00375 .21192 L
s
0 .25174 m
.00375 .25174 L
s
0 .27165 m
.00375 .27165 L
s
0 .29155 m
.00375 .29155 L
s
0 .33137 m
.00375 .33137 L
s
0 .35128 m
.00375 .35128 L
s
0 .37119 m
.00375 .37119 L
s
0 .41101 m
.00375 .41101 L
s
0 .43092 m
.00375 .43092 L
s
0 .45082 m
.00375 .45082 L
s
0 .49064 m
.00375 .49064 L
s
0 .51055 m
.00375 .51055 L
s
0 .53046 m
.00375 .53046 L
s
0 .05265 m
.00375 .05265 L
s
0 .03274 m
.00375 .03274 L
s
0 .01283 m
.00375 .01283 L
s
0 .57028 m
.00375 .57028 L
s
0 .59018 m
.00375 .59018 L
s
0 .61009 m
.00375 .61009 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07256 m
1 .07256 L
s
.99375 .15219 m
1 .15219 L
s
.99375 .23183 m
1 .23183 L
s
.99375 .31146 m
1 .31146 L
s
.99375 .3911 m
1 .3911 L
s
.99375 .47073 m
1 .47073 L
s
.99375 .55037 m
1 .55037 L
s
.125 Mabswid
.99625 .09247 m
1 .09247 L
s
.99625 .11238 m
1 .11238 L
s
.99625 .13229 m
1 .13229 L
s
.99625 .1721 m
1 .1721 L
s
.99625 .19201 m
1 .19201 L
s
.99625 .21192 m
1 .21192 L
s
.99625 .25174 m
1 .25174 L
s
.99625 .27165 m
1 .27165 L
s
.99625 .29155 m
1 .29155 L
s
.99625 .33137 m
1 .33137 L
s
.99625 .35128 m
1 .35128 L
s
.99625 .37119 m
1 .37119 L
s
.99625 .41101 m
1 .41101 L
s
.99625 .43092 m
1 .43092 L
s
.99625 .45082 m
1 .45082 L
s
.99625 .49064 m
1 .49064 L
s
.99625 .51055 m
1 .51055 L
s
.99625 .53046 m
1 .53046 L
s
.99625 .05265 m
1 .05265 L
s
.99625 .03274 m
1 .03274 L
s
.99625 .01283 m
1 .01283 L
s
.99625 .57028 m
1 .57028 L
s
.99625 .59018 m
1 .59018 L
s
.99625 .61009 m
1 .61009 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02381 .01472 m
.06244 .02137 L
.10458 .02936 L
.14415 .03762 L
.18221 .04632 L
.22272 .05648 L
.26171 .06722 L
.30316 .07977 L
.34309 .09307 L
.3815 .10711 L
.42237 .12351 L
.46172 .14086 L
.49955 .15913 L
.53984 .18046 L
.57861 .20299 L
.61984 .22931 L
.65954 .2572 L
.69774 .2866 L
.73838 .32093 L
.77751 .35724 L
.81909 .39968 L
.85916 .44469 L
.89771 .49219 L
.93871 .54769 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00803oool2000001`0oooo0`0000040?ooo`800000
5`3oool3000000@0oooo0P0000040?ooo`8000004`3oool3000000<0oooo0`0000040?ooo`800000
4P3oool5000000<0oooo0P0000040?ooo`8000004`3oool500000080oooo0`0000040?ooo`800000
4`3oool3000000@0oooo0P0000040?ooo`8000004`3oool3000000<0oooo0`0000040?ooo`800000
203oool001l0oooo00@000000?ooo`3oool000006P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000004`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000C0?ooo`060000003o
ool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000004@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo000O0?ooo`040000003oool0oooo
000001h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000C0?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000D0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0C0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`050?ooo`007`3oool010000000oooo0?ooo`00000N0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`800000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001<0oooo0P0000060?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool001l0oooo00@000000?oo
o`3oool000006P3oool4000000<0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004`3oool010000000
oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool000004@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000B0?ooo`06
0000003oool0oooo0?ooo`000000oooo100000030?ooo`040000003oool0oooo000001D0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`0000000`0000030?ooo`040000003oool0oooo000000L0oooo000O0?ooo`04
0000003oool0oooo000001X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000F
0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000180oooo
0P0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000004@3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000B0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo0000
0140oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000004@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01000
0000oooo0?ooo`0000070?ooo`00803oool2000001/0oooo1@0000030?ooo`800000603oool00`00
0000oooo0?ooo`030?ooo`800000103oool2000001@0oooo00@000000?ooo`3oool0oooo1@000003
0?ooo`8000004`3oool3000000@0oooo0P0000040?ooo`800000503oool300000080oooo1@000003
0?ooo`8000004`3oool3000000@0oooo0P0000040?ooo`8000004`3oool300000080oooo1@000003
0?ooo`800000203oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool001/0ooooo`00000500000040oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool100000040oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool001/0oooo0P00003o0?ooo`40oooo
0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`L0V@00m`3oool100000040oooo000K
0?ooo`030000003oool0oooo0080oooo3P2I003`0?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0203oool<09T00>`0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`P0
V@00j@3oool100000040oooo000K0?ooo`800000503oool909T00><0oooo0P0000010?ooo`006`3o
ool00`000000oooo0?ooo`0F0?ooo`/0V@00g`3oool100000040oooo000K0?ooo`030000003oool0
oooo01/0oooo2`2I003J0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0803oool;09T0
0=D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`X0V@00d@3oool100000040
oooo000K0?ooo`030000003oool0oooo02X0oooo2@2I003=0?ooo`4000000@3oool001/0oooo0P00
000_0?ooo`P0V@00b@3oool200000040oooo000K0?ooo`030000003oool0oooo0380oooo2@2I0035
0?ooo`4000000@3oool000L0oooo0P0000040?ooo`<00000103oool2000000D0oooo00<000000?oo
o`3oool0=@3oool;09T00<00oooo0@0000010?ooo`002@3oool010000000oooo0?ooo`0000030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j
0?ooo`T0V@00_@3oool100000040oooo000:0?ooo`030000003oool0000000<0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo1`2I002j
0?ooo`4000000@3oool000L0oooo100000000`3oool0000000000002000000<0oooo00@000000?oo
o`3oool00000103oool2000004<0oooo1P2I002g0?ooo`8000000@3oool000H0oooo00L000000?oo
o`3oool0oooo0000003oool0000000H0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`150?ooo`H0V@00]@3oool100000040oooo00060?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0A`3oool709T00;80oooo0@0000010?ooo`001`3oool3000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`1:0?ooo`P0V@00[P3oool100000040oooo000K0?ooo`030000003o
ool0oooo04d0oooo202I002[0?ooo`4000000@3oool001/0oooo0P00001B0?ooo`L0V@00Y`3oool2
00000040oooo000K0?ooo`030000003oool0oooo05@0oooo1`2I002U0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0E`3oool609T00:<0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`1J0?ooo`H0V@00X03oool100000040oooo000K0?ooo`030000003oool0oooo05`0oooo1P2I
002N0?ooo`4000000@3oool001/0oooo0P00001P0?ooo`H0V@00VP3oool200000040oooo000K0?oo
o`030000003oool0oooo0640oooo1P2I002I0?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool0I03oool609T009H0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1V0?ooo`H0V@00
U03oool100000040oooo000K0?ooo`030000003oool0oooo06T0oooo1P2I002A0?ooo`4000000@3o
ool001/0oooo0P00001/0?ooo`L0V@00S@3oool200000040oooo000K0?ooo`030000003oool0oooo
06h0oooo1`2I002;0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0L@3oool609T008T0
oooo0@0000010?ooo`001`3oool2000000@0oooo0`0000040?ooo`8000001@3oool00`000000oooo
0?ooo`1d0?ooo`D0V@00Q`3oool100000040oooo00090?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07H0
oooo1@2I00250?ooo`4000000@3oool000X0oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P00001i0?ooo`@0V@00P`3oool200000040
oooo00070?ooo`@000000P3oool3000000<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1j0?ooo`@0V@00PP3oool100000040oooo00060?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1k0?ooo`D0V@00P03oool100000040oooo00060?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1m0?ooo`D0V@00OP3oool100000040oooo00070?ooo`<000000`3o
ool3000000@0oooo0P0000050?ooo`030000003oool0oooo07l0oooo1@2I001l0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool0P@3oool409T007/0oooo0@0000010?ooo`006`3oool20000
08@0oooo102I001h0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0Q03oool509T007L0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`260?ooo`D0V@00M@3oool100000040oooo
000K0?ooo`030000003oool0oooo08P0oooo1@2I001c0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool0RP3oool409T00780oooo0@0000010?ooo`006`3oool2000008d0oooo102I001_0?oo
o`8000000@3oool001/0oooo00<000000?ooo`3oool0S@3oool509T006h0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`2?0?ooo`@0V@00K@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0940oooo102I001[0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0TP3oool5
09T006T0oooo0@0000010?ooo`006`3oool2000009D0oooo1@2I001V0?ooo`8000000@3oool001/0
oooo00<000000?ooo`3oool0UP3oool409T006H0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`2H0?ooo`@0V@00I03oool100000040oooo0000103oool000000000000000040?ooo`800000
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo09T0oooo1@2I001R0?ooo`400000
0@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2K0?oo
o`D0V@00H03oool100000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P00
002N0?ooo`@0V@00GP3oool200000040oooo00020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0W`3oool309T005h0oooo0@0000010?ooo`000P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0:00oooo0`2I001M0?ooo`4000000@3oool0
00030?ooo`000000000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0X@3oool409T005/0oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`800000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0:80oooo102I001J0?ooo`4000000@3oool001/0oooo0P00002U
0?ooo`<0V@00F03oool200000040oooo000K0?ooo`030000003oool0oooo0:D0oooo0`2I001H0?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool0YP3oool409T005H0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`2W0?ooo`@0V@00E@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0:T0oooo102I001C0?ooo`4000000@3oool001/0oooo0P00002[0?ooo`@0V@00D@3oool2
00000040oooo000K0?ooo`030000003oool0oooo0:`0oooo0`2I001A0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0[@3oool409T004l0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`2^0?ooo`@0V@00CP3oool100000040oooo000K0?ooo`030000003oool0oooo0;00oooo102I
001<0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0/@3oool409T004/0oooo0@000001
0?ooo`006`3oool200000;@0oooo0`2I00190?ooo`8000000@3oool001/0oooo00<000000?ooo`3o
ool0]03oool309T004T0oooo0@0000010?ooo`0000@0oooo0000000000000000103oool200000080
oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`2e0?ooo`<0V@00B03oool100000040
oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0]P3oool3
09T004L0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0;L0oooo0`2I00160?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`800000^@3oool309T004@0oooo0P0000010?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0^@3oool309T004@0oooo0@0000010?oo
o`0000<0oooo000000000000103oool01P000000oooo0?ooo`000000oooo000000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;X0oooo102I
00120?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`000004
0?ooo`8000001@3oool00`000000oooo0?ooo`2k0?ooo`@0V@00@@3oool100000040oooo000K0?oo
o`030000003oool0oooo0;d0oooo0`2I00100?ooo`4000000@3oool001/0oooo0P00002o0?ooo`<0
V@00?P3oool200000040oooo000K0?ooo`030000003oool0oooo0;l0oooo0`2I000n0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0`03oool309T003d0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`310?ooo`<0V@00?03oool100000040oooo000K0?ooo`030000003oool0oooo
0<80oooo0`2I000k0?ooo`4000000@3oool001/0oooo0P0000340?ooo`<0V@00>@3oool200000040
oooo000K0?ooo`030000003oool0oooo0<@0oooo0`2I000i0?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0a@3oool309T003P0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`36
0?ooo`80V@00>03oool100000040oooo000K0?ooo`030000003oool0oooo0<H0oooo0`2I000g0?oo
o`4000000@3oool001/0oooo0P0000380?ooo`<0V@00=@3oool200000040oooo000K0?ooo`030000
003oool0oooo0<P0oooo0`2I000e0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0b@3o
ool309T003@0oooo0@0000010?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0`00
00030?ooo`8000001@3oool00`000000oooo0?ooo`3:0?ooo`<0V@00<`3oool100000040oooo0002
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3;0?ooo`<0V@00
<P3oool100000040oooo00020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool00000
0?ooo`0500000080oooo00@000000?ooo`3oool00000103oool200000<d0oooo0`2I000`0?ooo`80
00000@3oool00080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo0000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0c@3oool309T00300oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0<h0oooo0`2I000_0?ooo`4000000@3oool000030?ooo`000000
000000@0oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3?0?ooo`<0V@00;P3oool100000040oooo00020?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003o
ool0oooo0=00oooo0`2I000]0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0d@3oool3
09T002`0oooo0@0000010?ooo`006`3oool200000=<0oooo0`2I000Z0?ooo`8000000@3oool001/0
oooo00<000000?ooo`3oool0d`3oool309T002X0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`3D0?ooo`<0V@00:@3oool100000040oooo000K0?ooo`030000003oool0oooo0=D0oooo0`2I
000X0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0eP3oool309T002L0oooo0@000001
0?ooo`006`3oool200000=P0oooo0`2I000U0?ooo`8000000@3oool001/0oooo00<000000?ooo`3o
ool0f03oool309T002D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3I0?ooo`<0V@00
903oool100000040oooo000K0?ooo`030000003oool0oooo0=X0oooo0`2I000S0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool0f`3oool209T002<0oooo0@0000010?ooo`006`3oool20000
0=`0oooo0`2I000Q0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0g03oool309T00240
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3M0?ooo`<0V@00803oool100000040oooo
0000103oool000000000000000040?ooo`8000000`3oool3000000@0oooo0P0000050?ooo`030000
003oool0oooo0=h0oooo0P2I000P0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0=h0oooo0`2I000O0?ooo`4000000@3oool00080
oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000h03oool309T001d0oooo0P00
00010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool01000
00030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0h03oool309T001d0oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool0
00001P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>40oooo0`2I000L0?oo
o`4000000@3oool000030?ooo`000000000000@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0hP3oool2
09T001`0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0>80oooo0`2I000K0?ooo`4000000@3oool001/0
oooo0P00003T0?ooo`<0V@006@3oool200000040oooo000K0?ooo`030000003oool0oooo0>@0oooo
0`2I000I0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0i@3oool209T001T0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`3U0?ooo`<0V@00603oool100000040oooo000K0?oo
o`030000003oool0oooo0>H0oooo0`2I000G0?ooo`4000000@3oool001/0oooo0P00003X0?ooo`<0
V@005@3oool200000040oooo000K0?ooo`030000003oool0oooo0>P0oooo0P2I000F0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0j03oool309T001D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`3Y0?ooo`<0V@00503oool100000040oooo000K0?ooo`030000003oool0oooo
0>X0oooo0P2I000D0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0jP3oool309T001<0
oooo0@0000010?ooo`006`3oool200000>`0oooo0`2I000A0?ooo`8000000@3oool001/0oooo00<0
00000?ooo`3oool0k03oool309T00140oooo0@0000010?ooo`0000@0oooo0000000000000000103o
ool2000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`3]0?ooo`80V@004@3o
ool100000040oooo00020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3]0?ooo`<0V@00403oool100000040oooo00020?ooo`030000003oool0oooo0080oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3^0?ooo`<0V@003`3oool100000040oooo00020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool3000000<0oooo00@00000
0?ooo`3oool00000103oool200000?00oooo0P2I000>0?ooo`8000000@3oool00080oooo00<00000
0?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>l0oooo0`2I000>0?ooo`40
00000@3oool000030?ooo`000000000000@0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3`
0?ooo`<0V@003@3oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo0P0000030?oo
o`<00000103oool2000000D0oooo00<000000?ooo`3oool0l@3oool209T000d0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`3a0?ooo`<0V@00303oool100000040oooo000K0?ooo`800000
l`3oool309T000X0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`3c0?ooo`80V@002`3o
ool100000040oooo000K0?ooo`030000003oool0oooo0?<0oooo0`2I000:0?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool0m03oool309T000T0oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`3e0?ooo`80V@002@3oool100000040oooo000K0?ooo`800000mP3oool309T000L0oooo
0P0000010?ooo`006`3oool00`000000oooo0?ooo`3f0?ooo`<0V@001`3oool100000040oooo000K
0?ooo`030000003oool0oooo0?L0oooo0P2I00070?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0m`3oool309T000H0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3h0?ooo`<0
V@001@3oool100000040oooo000K0?ooo`800000nP3oool209T000@0oooo0P0000010?ooo`006`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`006`3ooooo
000000D000000@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-48.6694, 927.883, 1.45594, \
0.967338}},
  CellTags->"EffectivePayment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"PaymentsRemaining"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"PaymentsRemaining"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentsRemaining"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell["PaymentsRemaining", "Section",
  CellTags->"PaymentsRemaining"],

Cell["\<\
PaymentsRemaining[Principal, InterestRate, Payment] gives the \
number of payments remaining on a loan of interest InterestRate when the \
principal is given by Principal if the amount of each payment is Payment. \
This function can be used to compute the remaining number of payments after \
one has made a payment to principal on a loan with a previously fixed payment \
amount or can be used to compute the total number of payments on a loan that \
is paid off at a rate that is different than the required payment. Note that, \
for a variable rate loan this function only computes the remaining payments \
at the fixed interest rate given by InterestRate.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemaining"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PaymentsRemaining", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemaining"],

Cell[TextData[{
  "Default options for ",
  StyleBox["PaymentsRemaining", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemaining"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PaymentsRemaining", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemaining"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"PaymentsRemaining"],

Cell["\<\
Assume that you have taken out a 30 year loan for $100000 at 7.5% \
and have made 100 payments on it. \
\>", "Text",
  CellTags->"PaymentsRemaining"],

Cell[TextData[{
  "This is the remaining principal after the ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["100", "th"], TraditionalForm]]],
  " payment."
}], "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"principal", "=", 
      RowBox[{"Principal", "[", 
        RowBox[{"100000", ",", " ", "7.5", ",", " ", "30", ",", " ", "100"}], 
        "]"}]}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData["89733.27526968224`"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell["Of course there are 260 remaining payments on this loan.", "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"payment", "=", 
        RowBox[{"Payment", "[", 
          RowBox[{"100000", ",", " ", "7.5", ",", " ", "30"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{"PaymentsRemaining", "[", 
      RowBox[{"principal", ",", " ", "7.5", ",", " ", "payment"}], 
      "]"}]}], "Input",
  CellLabel->"In[3]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData["260.00000000000136`"], "Output",
  CellLabel->"Out[4]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell["\<\
You now choose to make a payment to the principal of $10000. \
\>", \
"Text",
  CellTags->"PaymentsRemaining"],

Cell["\<\
Here are the number of payments remaining on the reduced principal.\
\
\>", "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaymentsRemaining", "[", 
      RowBox[{
        RowBox[{"principal", "-", "10000"}], ",", " ", "7.5", ",", " ", 
        "payment"}], "]"}]], "Input",
  CellLabel->"In[5]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData["200.18172593858824`"], "Output",
  CellLabel->"Out[5]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell["\<\
If, in each payment period, you make a payment that is less than \
the interest that has accrued in that period, it will take an infinite amount \
time to pay off your loan.\
\>", "Text",
  CellTags->"PaymentsRemaining"],

Cell["\<\
At the beginning of a loan the payment to interest does not depend \
on the length of the loan.\
\>", "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Simplify", "[", 
      RowBox[{"PaymentToInterest", "[", 
        RowBox[{"\[Lambda]", ",", "\[Rho]", ",", "\[Tau]", ",", "1"}], "]"}], 
      "]"}]], "Input",
  CellLabel->"In[6]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    FractionBox[
      RowBox[{"\[Lambda]", " ", "\[Rho]"}], "1200"]], "Output",
  CellLabel->"Out[6]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell["Here is a numerical example.", "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaymentToInterest", "[", 
      RowBox[{"100000", ",", "7.5", ",", "30", ",", "1"}], "]"}]], "Input",
  CellLabel->"In[7]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData["624.9999999999927`"], "Output",
  CellLabel->"Out[7]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell["\<\
If the amount of your payment is less than the required payment to \
interest then it will take an infinite time to pay off the loan.\
\>", \
"MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaymentsRemaining", "[", 
      RowBox[{"100000", ",", " ", "7.5", ",", "624"}], "]"}]], "Input",
  CellLabel->"In[8]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    InterpretationBox["\[Infinity]",
      DirectedInfinity[ 1]]], "Output",
  CellLabel->"Out[8]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell[TextData[{
  "If you create an analytical expression (as a function of payment ",
  StyleBox["p", "MR"],
  " for example) then the result will have an imaginary part if the payment \
is not large enough to compensate for the increase in principal due to \
accumulated interest. This is the indication that the number of payments \
remaining is infinite."
}], "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"analyticalPaymentsRemaining", "=", 
      RowBox[{"PaymentsRemaining", "[", 
        RowBox[{"100000", ",", " ", "7.5", ",", "p"}], "]"}]}]], "Input",
  CellLabel->"In[9]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    RowBox[{"160.49948078786014`", " ", 
      RowBox[{"Log", "[", 
        FractionBox[
          RowBox[{"1200", " ", "p"}], 
          RowBox[{
            RowBox[{"-", "750000.`"}], "+", 
            RowBox[{"1200", " ", "p"}]}]], "]"}]}]], "Output",
  CellLabel->"Out[9]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"analyticalPaymentsRemaining", "/.", 
      RowBox[{"p", "\[Rule]", "624"}]}]], "Input",
  CellLabel->"In[10]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    RowBox[{
      RowBox[{"1032.998792395888`", "\[InvisibleSpace]"}], "+", 
      RowBox[{"504.22398974811756`", " ", "\[ImaginaryI]"}]}]], "Output",
  CellLabel->"Out[10]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"analyticalPaymentsRemaining", "/.", 
      RowBox[{"p", "\[Rule]", "626"}]}]], "Input",
  CellLabel->"In[11]:=",
  CellTags->"PaymentsRemaining"],

Cell[BoxData["1033.5123911726803`"], "Output",
  CellLabel->"Out[11]=",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell["Clear the variables the we just used", "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{
      "payment", ",", "principal", ",", "analyticalPaymentsRemaining"}], 
      "]"}]], "Input",
  CellLabel->"In[12]:=",
  CellTags->"PaymentsRemaining"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{

Cell["Principal", "Section",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[TextData[{
  StyleBox["Principal", "MR"],
  " computes the remaining principal on a loan after a specified number of \
payments have been made."
}], "Text",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell["\<\
Principal[{HomeCost, PercentageDownPayment}, InterestRate, Years, \
PaymentNumber] gives the remaining principal to be paid off after the payment \
given by PaymentNumber on a loan on the purchase of a home of cost HomeCost \
with a down payment given by PercentageDownPayment amortized over the number \
of years given by Years with the fixed interest rate given by InterestRate. 

Principal[LoanAmount, InterestRate, Years, PaymentNumber] assumes a loan \
amount given by LoanAmount. 

Principal[{HomeCost, PercentageDownPayment}, {{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber] calculates the principal for a variable rate loan with \
interest rate InterestRate1 for a number of payments given by Payments1 \
followed by InterestRate2 for a number of payments given by Payments2, and so \
on. If PaymentNumber is greater than Payments1+Payments2+...+PaymentsM then \
the interest rate is assumed to be InterestRateM for that payment. If \
PaymentNumber is not numerical then an analytical result will be returned (if \
$StrongErrorChecking is not True) that assumes that PaymentNumber is greater \
than Payments1+Payments2+...+Payments(M-1).

Principal[LoanAmount, {{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, Years, PaymentNumber] is also a \
valid input as it is for the fixed rate loan form above.\
\>", "DefinitionBox",\

  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["Principal", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["Principal", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["Principal", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell["\<\
Here is the remaining principal on a $100000 loan for 30 years at \
7.3% after 36 payments.\
\>", "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Principal", "[", 
      RowBox[{"100000", ",", " ", "7.3", ",", " ", "30", ",", " ", "36"}], 
      "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[BoxData["96901.95962464275`"], "Output",
  CellLabel->"Out[2]=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]],

Cell["\<\
You can use the function YearsToPaymentNumber to give the input in \
years\
\>", "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Principal", "[", 
      RowBox[{"100000", ",", " ", "7.3", ",", " ", "30", ",", " ", 
        RowBox[{"YearsToPaymentNumber", "[", "3", "]"}]}], "]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[BoxData["96901.95962464275`"], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]],

Cell["\<\
YearsToPaymentNumber[Year] changes the year into payment number \
under the simple assumption that a year is broken into $PaymentsPerYear equal \
intervals.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["YearsToPaymentNumber", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["YearsToPaymentNumber", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["YearsToPaymentNumber", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],

Cell["\<\
PaymentNumberToYears[PaymentNumber] changes the payment number into \
years under the simple assumption that a year is broken into $PaymentsPerYear \
equal intervals.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PaymentNumberToYears", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["PaymentNumberToYears", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PaymentNumberToYears", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],

Cell["\<\
In this case the principal has only decreased by roughly 25% after \
half the life of the mortgage.\
\>", "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Principal", "[", 
      RowBox[{"100000", ",", " ", "7.3", ",", " ", "30", ",", " ", 
        RowBox[{"YearsToPaymentNumber", "[", "15", "]"}]}], "]"}]], "Input",
  CellLabel->"In[6]:=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[BoxData["74869.84753404654`"], "Output",
  CellLabel->"Out[6]=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]],

Cell["\<\
Here is the behavior of the principle over the life of the \
mortgage.\
\>", "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Principal", "[", 
            RowBox[{"100000", ",", " ", "7.3", ",", " ", "30", ",", " ", 
              RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", "30"}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[7]:=",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 5.88604e-06 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -30 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -30 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -30 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -30 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -36 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(20000)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(40000)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(60000)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(80000)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(100000)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02381 .60332 m
.06244 .5964 L
.10458 .58812 L
.14415 .57958 L
.18221 .5706 L
.22272 .56014 L
.26171 .54912 L
.30316 .53626 L
.34309 .52267 L
.3815 .50837 L
.42237 .4917 L
.46172 .47411 L
.49955 .45563 L
.53984 .43411 L
.57861 .41143 L
.61984 .38501 L
.65954 .35708 L
.69774 .32771 L
.73838 .29349 L
.77751 .2574 L
.81909 .21533 L
.85916 .17081 L
.89771 .12394 L
.93871 .06933 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00:`3oool2000002D0oooo0`00000Q0?ooo`<00000103oool2000001h0oooo0`0000030?oo
o`<000007P3oool5000000<0oooo0P00000M0?ooo`D000000P3oool3000001h0oooo0`0000040?oo
o`800000103oool002X0oooo00@000000?ooo`3oool000008`3oool01@000000oooo0?ooo`3oool0
00000240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000N0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0L0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000007@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000`3oool002X0oooo00@000000?ooo`3oool000009`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000N
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0040oooo000Z0?ooo`040000003oool0oooo000002L0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0703oool2000000<0oooo00@000000?ooo`3oool000000`3oool002X0oooo00@000000?ooo`3o
ool000008`3oool400000280oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000N
0?ooo`040000003oool0oooo0?ooo`@000007P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000703oool01P000000oooo0?ooo`3oool000000?ooo`@000008@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0040oooo000Z0?ooo`040000003oool0
oooo000002<0oooo00<000000?ooo`3oool08P3oool2000000@0oooo00@000000?ooo`3oool00000
7@3oool2000000<0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool00000703oool01`000000oooo0?ooo`3oool000000?ooo`000000803o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool002/0oooo
0P00000T0?ooo`D000008@3oool00`000000oooo0?ooo`030?ooo`8000007`3oool010000000oooo
0?ooo`3oool5000001h0oooo0`0000040?ooo`8000007P3oool300000080oooo1@00000M0?ooo`<0
0000103oool2000000@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo000W0?ooooP000000@3oool00200oooo0P0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool100000040oooo000O0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`4000000@3oool001l0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`3d0?ooo`4000000@3oool001l0oooo00@0
00000?ooo`3oool00000103oool200000>h0oooo0P2I00040?ooo`8000000@3oool001l0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`3]0?ooo`80V@001@3oool100000040oooo
000O0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0k03oool309T000D0oooo
0@0000010?ooo`00803oool2000000D0oooo00<000000?ooo`3oool0j`3oool309T000H0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`3[0?ooo`80V@001`3oool100000040oooo000W0?oo
o`030000003oool0oooo0>X0oooo0`2I00070?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0j@3oool309T000P0oooo0@0000010?ooo`009`3oool200000>T0oooo0`2I00080?ooo`800000
0@3oool002L0oooo00<000000?ooo`3oool0j03oool209T000X0oooo0@0000010?ooo`009`3oool0
0`000000oooo0?ooo`3W0?ooo`<0V@002P3oool100000040oooo000W0?ooo`030000003oool0oooo
0>H0oooo0`2I000;0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0iP3oool209T000`0
oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`3U0?ooo`<0V@00303oool100000040oooo
000W0?ooo`030000003oool0oooo0>@0oooo0`2I000=0?ooo`4000000@3oool002L0oooo0P00003U
0?ooo`80V@003@3oool200000040oooo000W0?ooo`030000003oool0oooo0><0oooo0`2I000>0?oo
o`4000000@3oool002L0oooo00<000000?ooo`3oool0hP3oool309T000l0oooo0@0000010?ooo`00
9`3oool00`000000oooo0?ooo`3Q0?ooo`<0V@00403oool100000040oooo000W0?ooo`030000003o
ool0oooo0>40oooo0P2I000A0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0h03oool3
09T00140oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`3O0?ooo`<0V@004P3oool10000
0040oooo000W0?ooo`030000003oool0oooo0=l0oooo0P2I000C0?ooo`4000000@3oool002L0oooo
0P00003O0?ooo`<0V@004P3oool200000040oooo000W0?ooo`030000003oool0oooo0=d0oooo0`2I
000D0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0g03oool309T001D0oooo0@000001
0?ooo`009`3oool00`000000oooo0?ooo`3L0?ooo`80V@005P3oool100000040oooo00060?ooo`D0
00000`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0f`3oool309T001H0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0fP3oool309T001L0oooo
0@0000010?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0fP3oool209T001P0oooo0@0000010?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool200000=X0
oooo0`2I000G0?ooo`8000000@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0f03oool309T001T0oooo
0@0000010?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`3G0?ooo`<0V@006P3oool100000040oooo0007
0?ooo`<00000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0eP3oool309T001/0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`3E0?oo
o`<0V@00703oool100000040oooo000W0?ooo`030000003oool0oooo0=@0oooo0`2I000M0?ooo`40
00000@3oool002L0oooo00<000000?ooo`3oool0d`3oool309T001h0oooo0@0000010?ooo`009`3o
ool200000=<0oooo0`2I000N0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0d@3oool3
09T00200oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`3@0?ooo`<0V@008@3oool10000
0040oooo000W0?ooo`030000003oool0oooo0=00oooo0P2I000R0?ooo`4000000@3oool002L0oooo
00<000000?ooo`3oool0c`3oool309T00280oooo0@0000010?ooo`009`3oool00`000000oooo0?oo
o`3>0?ooo`<0V@008`3oool100000040oooo000W0?ooo`030000003oool0oooo0<d0oooo0`2I000T
0?ooo`4000000@3oool002L0oooo0P00003=0?ooo`<0V@00903oool200000040oooo000W0?ooo`03
0000003oool0oooo0</0oooo0`2I000V0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0
b`3oool209T002L0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`3:0?ooo`<0V@009`3o
ool100000040oooo000W0?ooo`030000003oool0oooo0<T0oooo0`2I000X0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool0b03oool309T002T0oooo0@0000010?ooo`009`3oool00`000000
oooo0?ooo`370?ooo`<0V@00:P3oool100000040oooo000W0?ooo`030000003oool0oooo0<H0oooo
0`2I000[0?ooo`4000000@3oool002L0oooo0P0000360?ooo`<0V@00:`3oool200000040oooo000W
0?ooo`030000003oool0oooo0<@0oooo0`2I000]0?ooo`4000000@3oool002L0oooo00<000000?oo
o`3oool0``3oool309T002h0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`320?ooo`<0
V@00;`3oool100000040oooo000W0?ooo`030000003oool0oooo0<40oooo0`2I000`0?ooo`400000
0@3oool000P0oooo0`0000030?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`300?ooo`<0V@00<@3oool100000040oooo00090?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0;l0oooo0`2I000b0?ooo`4000000@3oool000H0oooo1@0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo0P00002o0?ooo`<0V@00<P3oool200000040oooo00060?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`2m0?ooo`<0V@00=03oool100000040oooo00070?ooo`030000003oool0000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2l0?ooo`<0V@00=@3oool10000
0040oooo00080?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0;/0oooo0`2I000f0?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0^P3o
ool309T003L0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2i0?ooo`<0V@00>03oool1
00000040oooo000W0?ooo`030000003oool0oooo0;P0oooo0`2I000i0?ooo`4000000@3oool002L0
oooo0P00002h0?ooo`<0V@00>@3oool200000040oooo000W0?ooo`030000003oool0oooo0;H0oooo
0`2I000k0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0]@3oool309T003`0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`2d0?ooo`<0V@00?@3oool100000040oooo000W0?oo
o`030000003oool0oooo0;80oooo102I000n0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0/@3oool409T003l0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2`0?ooo`<0V@00
@@3oool100000040oooo000W0?ooo`030000003oool0oooo0:h0oooo102I00120?ooo`4000000@3o
ool002L0oooo0P00002^0?ooo`@0V@00@P3oool200000040oooo000W0?ooo`030000003oool0oooo
0:/0oooo102I00150?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0ZP3oool409T004H0
oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2Y0?ooo`<0V@00B03oool100000040oooo
000W0?ooo`030000003oool0oooo0:L0oooo102I00190?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool0YP3oool409T004X0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2U0?oo
o`<0V@00C03oool100000040oooo000W0?ooo`800000Y@3oool309T004`0oooo0P0000010?ooo`00
9`3oool00`000000oooo0?ooo`2S0?ooo`<0V@00CP3oool100000040oooo000W0?ooo`030000003o
ool0oooo0:80oooo0`2I001?0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0X@3oool3
09T00500oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2P0?ooo`<0V@00D@3oool10000
0040oooo00070?ooo`<00000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0WP3oool409T00580oooo0@0000010?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`2L0?ooo`D0V@00D`3oool100000040oooo00060?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000W03oool409T005@0oooo0P00
00010?ooo`001P3oool4000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`2I0?ooo`@0V@00E`3oool100000040oooo00060?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2G0?ooo`D0V@00
F03oool100000040oooo00070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`2F0?ooo`@0V@00FP3oool100000040oooo00080?oo
o`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0U03oool409T005`0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2C0?ooo`@0
V@00G@3oool100000040oooo000W0?ooo`030000003oool0oooo0940oooo102I001O0?ooo`400000
0@3oool002L0oooo00<000000?ooo`3oool0T03oool409T00600oooo0@0000010?ooo`009`3oool2
00000900oooo0`2I001Q0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0S@3oool409T0
06<0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2<0?ooo`@0V@00I03oool100000040
oooo000W0?ooo`030000003oool0oooo08X0oooo102I001V0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0R03oool509T006L0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`27
0?ooo`@0V@00J@3oool100000040oooo000W0?ooo`030000003oool0oooo08D0oooo102I001[0?oo
o`4000000@3oool002L0oooo0P0000240?ooo`D0V@00J`3oool200000040oooo000W0?ooo`030000
003oool0oooo0880oooo102I001^0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0P03o
ool409T00700oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`D0V@00L@3oool1
00000040oooo000W0?ooo`030000003oool0oooo07`0oooo1@2I001c0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool0NP3oool509T007D0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`1h0?ooo`D0V@00M`3oool100000040oooo000W0?ooo`800000M`3oool509T007P0oooo0P00
00010?ooo`009`3oool00`000000oooo0?ooo`1d0?ooo`D0V@00N`3oool100000040oooo000W0?oo
o`030000003oool0oooo0780oooo1@2I001m0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0L@3oool409T007l0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1_0?ooo`@0V@00
P@3oool100000040oooo00070?ooo`<00000103oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0K@3oool509T00880oooo0@0000010?ooo`001P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1Z0?ooo`H0V@00Q03oool100000040oooo00060?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000J@3oool609T0
08D0oooo0P0000010?ooo`001`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1U0?ooo`H0V@00R@3oool100000040oooo00060?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo06<0oooo1P2I002;0?ooo`4000000@3oool000H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0H03oool6
09T008h0oooo0@0000010?ooo`001`3oool3000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo05h0oooo1P2I002@0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool0F`3oool609T009<0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`1I0?ooo`H0V@00U@3oool100000040oooo000W0?ooo`030000003oool0oooo05L0oooo1@2I
002H0?ooo`4000000@3oool002L0oooo0P00001E0?ooo`H0V@00V@3oool200000040oooo000W0?oo
o`030000003oool0oooo0580oooo1P2I002L0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0C`3oool609T009l0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1<0?ooo`L0V@00
X@3oool100000040oooo000W0?ooo`030000003oool0oooo04T0oooo1`2I002T0?ooo`4000000@3o
ool002L0oooo00<000000?ooo`3oool0A@3oool809T00:L0oooo0@0000010?ooo`009`3oool00`00
0000oooo0?ooo`110?ooo`T0V@00ZP3oool100000040oooo000W0?ooo`800000?`3oool809T00:d0
oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`0k0?ooo`L0V@00/P3oool100000040oooo
000W0?ooo`030000003oool0oooo03P0oooo1`2I002e0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool0=@3oool709T00;P0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0a0?oo
o`P0V@00^`3oool100000040oooo000W0?ooo`030000003oool0oooo02`0oooo2P2I002n0?ooo`40
00000@3oool002L0oooo00<000000?ooo`3oool09`3oool;09T00<80oooo0@0000010?ooo`009`3o
ool2000002D0oooo2@2I00360?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool08@3oool7
09T00<`0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`P0V@00c`3oool10000
0040oooo000W0?ooo`030000003oool0oooo01P0oooo2P2I003B0?ooo`4000000@3oool002L0oooo
00<000000?ooo`3oool04`3oool;09T00=H0oooo0@0000010?ooo`0000@0oooo0000000000000000
103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo00h0oooo2`2I003K0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool02@3oool;09T00>00oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`040?ooo`/0V@00i@3oool100000040oooo00020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`8000000P3oool909T00>T0oooo0P0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`3oool409T00>l0oooo0@0000010?ooo`0000<0oooo000000000000103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`4000000@3oool00080oooo00<000000?ooo`3oool0
0`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooooP00000
0@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.72064, -14515.4, \
0.127131, 685.676}},
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"HomeValue"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"HomeValue"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"HomeValue"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"HomeValue"],

Cell[CellGroupData[{

Cell["HomeValue", "Section",
  CellTags->"HomeValue"],

Cell["\<\
HomeValue computes the value for a home based on a fixed \
appreciation rate. HomeValue can be used repeatedly to make computations for \
changing appreciation rates.\
\>", "Text",
  CellTags->"HomeValue"],

Cell["\<\
HomeValue[InitialHomeValue, AppreciationRate, PaymentNumber] gives \
the value of a home (that has the initial value given by InitialHomeValue) at \
the time of the payment given by PaymentNumber. Note that the first variable \
is referred to as InitialHomeValue and is not restricted to be the actual \
cost of the home at purchase. The property is assumed to appreciate at the \
fixed rate given by AppreciationRate. Note that AppreciationRate can be \
negative and that the assessed value of the house at purchase may or may not \
be equal to its purchase price.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValue"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["HomeValue", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValue"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValue"],

Cell[TextData[{
  "Default options for ",
  StyleBox["HomeValue", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValue"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValue"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["HomeValue", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValue"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"HomeValue"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"HomeValue"],

Cell["\<\
Here is the value of a home after 3 years that initially has a \
value of $110000. The appreciation rate is 3%.\
\>", "MathCaption",
  CellTags->"HomeValue"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HomeValue", "[", 
      RowBox[{"110000", ",", " ", "3.0", ",", " ", "36"}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"HomeValue"],

Cell[BoxData["120345.65408501489`"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"HomeValue"]
}, Open  ]],

Cell["\<\
Over the next 5 years the house depreciates in value at a rate of \
1%. This is the value of the home after the total 8 year time span.\
\>", \
"MathCaption",
  CellTags->"HomeValue"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HomeValue", "[", 
      RowBox[{
        RowBox[{"HomeValue", "[", 
          RowBox[{"110000", ",", " ", "3.0", ",", " ", "36"}], "]"}], ",", 
        " ", 
        RowBox[{"-", "1.0"}], ",", " ", "60"}], "]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"HomeValue"],

Cell[BoxData["114473.94105204963`"], "Output",
  CellLabel->"Out[3]=",
  CellTags->"HomeValue"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"Equity"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"Equity"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Equity"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Equity"],

Cell[CellGroupData[{

Cell["Equity", "Section",
  CellTags->"Equity"],

Cell["\<\
Equity[{HomeCost, PercentageDownPayment}, {InterestRate, \
AppreciationRate}, Years, PaymentNumber] gives the equity in a home (that has \
the initial value given by HomeCost) at the time of the payment given by \
PaymentNumber. The house is purchased with a down payment given by \
PercentageDownPayment and the loan has an interest rate given by InterestRate \
and is amortized over loan amortized over the number of years given by Years. \
The property is assumed to appreciate at the fixed rate given by \
AppreciationRate. Note that AppreciationRate can be negative and that the \
assessed value of the house at purchase is assumed to be equal to its \
purchase price given by HomeCost. 

Equity[{{HomeCost, InitialHomeValue}, PercentageDownPayment}, {InterestRate, \
AppreciationRate}, Years, PaymentNumber] allows for the initial value of the \
home to be different from the home cost. 

Equity[{HomeCost, PercentageDownPayment}, {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, \
AppreciationRate}, Years, PaymentNumber] calculates for a variable rate loan \
with interest rate InterestRate1 for a number of payments given by Payments1 \
followed by InterestRate2 for a number of payments given by Payments2, and so \
on. Note that PaymentNumber must be given. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. If PaymentNumber is not numerical then an \
analytical result will be returned (if $StrongErrorChecking is not True) that \
assumes that PaymentNumber is greater than \
Payments1+Payments2+...+Payments(M-1).

Equity[LoanAmount, {{{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, AppreciationRate}, Years, \
PaymentNumber] is also a valid input.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Equity"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["Equity", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Equity"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Equity"],

Cell[TextData[{
  "Default options for ",
  StyleBox["Equity", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Equity"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Equity"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["Equity", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Equity"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"Equity"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Equity"],

Cell["\<\
Here is the equity as a function of time (in years) in a house \
purchased for $100000 with a 15% down payment. The property is assumed to \
appreciate at an average rate of 3% per year and the interest rate on the \
loan is 7.2%.\
\>", "MathCaption",
  CellTags->"Equity"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Equity", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", 
        RowBox[{"{", 
          RowBox[{"7.2", ",", " ", "3"}], "}"}], ",", " ", "30", ",", " ", 
        RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Equity"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["2", 
          RowBox[{"5", "-", 
            RowBox[{"48", " ", "y"}]}]], " ", 
        SuperscriptBox["5", 
          RowBox[{"5", "-", 
            RowBox[{"24", " ", "y"}]}]], " ", 
        SuperscriptBox["401", 
          RowBox[{"12", " ", "y"}]]}], "-", 
      RowBox[{"0.1388888888888889`", " ", 
        RowBox[{"(", 
          RowBox[{"692363.973656816045347551294474`13.0691", "-", 
            RowBox[{"80363.97365681606`", " ", 
              SuperscriptBox["1.006`", 
                RowBox[{"12", " ", "y"}]]}]}], ")"}]}]}]], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Equity", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", 
              RowBox[{"{", 
                RowBox[{"7.2", ",", " ", "3"}], "}"}], ",", " ", "30", ",", 
              " ", 
              RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", "30"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Equity"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 -0.0235583 2.55156e-06 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10402 -30 -4.5 ]
[-0.0125 .10402 0 4.5 ]
[-0.0125 .2316 -36 -4.5 ]
[-0.0125 .2316 0 4.5 ]
[-0.0125 .35918 -36 -4.5 ]
[-0.0125 .35918 0 4.5 ]
[-0.0125 .48675 -36 -4.5 ]
[-0.0125 .48675 0 4.5 ]
[-0.0125 .61433 -36 -4.5 ]
[-0.0125 .61433 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10402 m
.00625 .10402 L
s
[(50000)] -0.0125 .10402 1 0 Mshowa
0 .2316 m
.00625 .2316 L
s
[(100000)] -0.0125 .2316 1 0 Mshowa
0 .35918 m
.00625 .35918 L
s
[(150000)] -0.0125 .35918 1 0 Mshowa
0 .48675 m
.00625 .48675 L
s
[(200000)] -0.0125 .48675 1 0 Mshowa
0 .61433 m
.00625 .61433 L
s
[(250000)] -0.0125 .61433 1 0 Mshowa
.125 Mabswid
0 .12954 m
.00375 .12954 L
s
0 .15505 m
.00375 .15505 L
s
0 .18057 m
.00375 .18057 L
s
0 .20608 m
.00375 .20608 L
s
0 .25711 m
.00375 .25711 L
s
0 .28263 m
.00375 .28263 L
s
0 .30814 m
.00375 .30814 L
s
0 .33366 m
.00375 .33366 L
s
0 .38469 m
.00375 .38469 L
s
0 .41021 m
.00375 .41021 L
s
0 .43572 m
.00375 .43572 L
s
0 .46124 m
.00375 .46124 L
s
0 .51227 m
.00375 .51227 L
s
0 .53778 m
.00375 .53778 L
s
0 .5633 m
.00375 .5633 L
s
0 .58882 m
.00375 .58882 L
s
0 .0785 m
.00375 .0785 L
s
0 .05299 m
.00375 .05299 L
s
0 .02747 m
.00375 .02747 L
s
0 .00196 m
.00375 .00196 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10402 m
1 .10402 L
s
.99375 .2316 m
1 .2316 L
s
.99375 .35918 m
1 .35918 L
s
.99375 .48675 m
1 .48675 L
s
.99375 .61433 m
1 .61433 L
s
.125 Mabswid
.99625 .12954 m
1 .12954 L
s
.99625 .15505 m
1 .15505 L
s
.99625 .18057 m
1 .18057 L
s
.99625 .20608 m
1 .20608 L
s
.99625 .25711 m
1 .25711 L
s
.99625 .28263 m
1 .28263 L
s
.99625 .30814 m
1 .30814 L
s
.99625 .33366 m
1 .33366 L
s
.99625 .38469 m
1 .38469 L
s
.99625 .41021 m
1 .41021 L
s
.99625 .43572 m
1 .43572 L
s
.99625 .46124 m
1 .46124 L
s
.99625 .51227 m
1 .51227 L
s
.99625 .53778 m
1 .53778 L
s
.99625 .5633 m
1 .5633 L
s
.99625 .58882 m
1 .58882 L
s
.99625 .0785 m
1 .0785 L
s
.99625 .05299 m
1 .05299 L
s
.99625 .02747 m
1 .02747 L
s
.99625 .00196 m
1 .00196 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.6 0 0 r
2 Mabswid
.02381 .01472 m
.06244 .02679 L
.10458 .04063 L
.14415 .05431 L
.18221 .06813 L
.22272 .08358 L
.26171 .09924 L
.30316 .11677 L
.34309 .13459 L
.3815 .15264 L
.42237 .1729 L
.46172 .19349 L
.49955 .21436 L
.53984 .23782 L
.57861 .26168 L
.61984 .28852 L
.65954 .31592 L
.69774 .3438 L
.73838 .37524 L
.77751 .40734 L
.81909 .44357 L
.85916 .48072 L
.89771 .51867 L
.93871 .5616 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00:`3oool2
000002D0oooo0`00000Q0?ooo`<00000103oool2000001h0oooo0`0000030?ooo`<000007P3oool5
000000<0oooo0P00000M0?ooo`D000000P3oool3000001h0oooo0`0000040?ooo`800000103oool0
02X0oooo00@000000?ooo`3oool000008`3oool01@000000oooo0?ooo`3oool000000240oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000N0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0L0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000007@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
6P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool002X0
oooo00@000000?ooo`3oool000009`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000N0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0040oooo000Z0?ooo`040000003oool0oooo000002L0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool20000
00<0oooo00@000000?ooo`3oool000000`3oool002X0oooo00@000000?ooo`3oool000008`3oool4
00000280oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000N0?ooo`040000003o
ool0oooo0?ooo`@000007P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000703oool01P000000oooo0?ooo`3oool000000?ooo`@000008@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0040oooo000Z0?ooo`040000003oool0oooo000002<0oooo
00<000000?ooo`3oool08P3oool2000000@0oooo00@000000?ooo`3oool000007@3oool2000000<0
oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000703oool01`000000oooo0?ooo`3oool000000?ooo`000000803oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool002/0oooo0P00000T0?ooo`D0
00008@3oool00`000000oooo0?ooo`030?ooo`8000007`3oool010000000oooo0?ooo`3oool50000
01h0oooo0`0000040?ooo`8000007P3oool300000080oooo1@00000M0?ooo`<00000103oool20000
00@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000W0?oo
ooP000000@3oool002L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`40
00000@3oool002L0oooo00<000000?ooo`3oool0m03oool100000040oooo000W0?ooo`040000003o
ool0oooo0?ooo`@0V@00k`3oool100000040oooo000W0?ooo`040000003oool0oooo0?ooo`L0V@00
k03oool100000040oooo000W0?ooo`030000003oool0oooo00@0oooo1`2I003Y0?ooo`4000000@3o
ool002L0oooo00<000000?ooo`3oool01`3oool709T00>H0oooo0@0000010?ooo`009`3oool20000
00/0oooo1`2I003R0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool03@3oool709T00>00
oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0@0?ooo`L0V@00g@3oool100000040oooo
000W0?ooo`030000003oool0oooo01<0oooo1`2I003J0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool05P3oool709T00=L0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0I0?oo
o`L0V@00e03oool100000040oooo000W0?ooo`8000007@3oool609T00=40oooo0P0000010?ooo`00
9`3oool00`000000oooo0?ooo`0O0?ooo`H0V@00c`3oool100000040oooo000W0?ooo`030000003o
ool0oooo0240oooo1P2I003=0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0903oool6
09T00<X0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0V0?ooo`L0V@00a`3oool10000
0040oooo000W0?ooo`030000003oool0oooo02T0oooo1`2I00340?ooo`4000000@3oool002L0oooo
0P00000]0?ooo`L0V@00`03oool200000040oooo000W0?ooo`030000003oool0oooo02l0oooo1`2I
002n0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0<P3oool609T00;`0oooo0@000001
0?ooo`009`3oool00`000000oooo0?ooo`0e0?ooo`H0V@00^@3oool100000040oooo00070?ooo`<0
0000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0=`3oool609T00;L0oooo0@0000010?ooo`001P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j0?ooo`D0V@00
]@3oool100000040oooo000:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool2000003d0oooo1@2I002b0?ooo`8000000@3oool000X0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo1P2I002`0?ooo`4000000@3oool000H0oooo100000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0@03oool609T00:h0oooo0@0000010?ooo`001P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0@`3oool509T00:`0oooo0@0000010?ooo`001P3oool5000000<0oooo0P0000040?ooo`80
0000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04D0oooo1@2I002Z0?ooo`40
00000@3oool002L0oooo00<000000?ooo`3oool0A`3oool609T00:L0oooo0@0000010?ooo`009`3o
ool00`000000oooo0?ooo`190?ooo`H0V@00Y@3oool100000040oooo000W0?ooo`800000C@3oool6
09T00:40oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1>0?ooo`H0V@00X03oool10000
0040oooo000W0?ooo`030000003oool0oooo0540oooo1@2I002N0?ooo`4000000@3oool002L0oooo
00<000000?ooo`3oool0D`3oool509T009`0oooo0@0000010?ooo`009`3oool00`000000oooo0?oo
o`1E0?ooo`@0V@00V`3oool100000040oooo000W0?ooo`030000003oool0oooo05L0oooo102I002I
0?ooo`4000000@3oool002L0oooo0P00001I0?ooo`D0V@00UP3oool200000040oooo000W0?ooo`03
0000003oool0oooo05X0oooo1@2I002E0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0
G03oool509T009<0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1N0?ooo`D0V@00T@3o
ool100000040oooo000W0?ooo`030000003oool0oooo0600oooo1@2I002?0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool0HP3oool509T008d0oooo0@0000010?ooo`009`3oool2000006D0
oooo1@2I002:0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0IP3oool509T008T0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`1X0?ooo`D0V@00Q`3oool100000040oooo000W
0?ooo`030000003oool0oooo06X0oooo1@2I00250?ooo`4000000@3oool002L0oooo00<000000?oo
o`3oool0K03oool509T008<0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1^0?ooo`D0
V@00P@3oool100000040oooo000W0?ooo`030000003oool0oooo0700oooo1@2I001o0?ooo`400000
0@3oool002L0oooo0P00001c0?ooo`@0V@00O@3oool200000040oooo000W0?ooo`030000003oool0
oooo07@0oooo102I001l0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0M@3oool509T0
07X0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`D0V@00N03oool100000040
oooo0000103oool000000000000000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0N@3oool409T007L0oooo0@0000010?ooo`00
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1k0?ooo`@0V@00M@3oool100000040oooo
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`800000O@3oool509T00780oooo0P0000010?ooo`000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1n0?ooo`@0V@00LP3oool100000040oooo00020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0800oooo102I001`0?ooo`4000000@3oool00003
0?ooo`000000000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0840oooo1@2I001^0?ooo`4000000@3oool00080oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo08<0oooo102I001]0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0Q@3oool409T006/0oooo0@0000010?ooo`009`3oool2000008L0oooo1@2I001X
0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0R03oool409T006P0oooo0@0000010?oo
o`009`3oool00`000000oooo0?ooo`2:0?ooo`@0V@00IP3oool100000040oooo000W0?ooo`030000
003oool0oooo08/0oooo1@2I001T0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0S@3o
ool409T006<0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2?0?ooo`@0V@00H@3oool1
00000040oooo000W0?ooo`030000003oool0oooo0900oooo1@2I001O0?ooo`4000000@3oool002L0
oooo0P00002C0?ooo`@0V@00G@3oool200000040oooo000W0?ooo`030000003oool0oooo09@0oooo
102I001L0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0U@3oool409T005/0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`2G0?ooo`@0V@00F@3oool100000040oooo000W0?oo
o`030000003oool0oooo09P0oooo102I001H0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0VP3oool309T005L0oooo0@0000010?ooo`009`3oool2000009`0oooo102I001D0?ooo`800000
0@3oool002L0oooo00<000000?ooo`3oool0W03oool409T005@0oooo0@0000010?ooo`009`3oool0
0`000000oooo0?ooo`2N0?ooo`@0V@00DP3oool100000040oooo000W0?ooo`030000003oool0oooo
09l0oooo102I001A0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0X@3oool309T00500
oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2R0?ooo`@0V@00CP3oool100000040oooo
000W0?ooo`800000Y03oool409T004`0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`2U
0?ooo`<0V@00C03oool100000040oooo000W0?ooo`030000003oool0oooo0:H0oooo0`2I001;0?oo
o`4000000@3oool002L0oooo00<000000?ooo`3oool0Y`3oool409T004T0oooo0@0000010?ooo`00
00@0oooo00000000000000000`3oool3000000@0oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0:P0oooo102I00180?ooo`4000000@3oool00080oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2Z0?ooo`<0V@00A`3oool100000040oooo
00020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0:/0oooo102I00150?ooo`4000000@3oool0
0080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo0P00002]0?ooo`@0V@00@`3oool200000040oooo00020?ooo`040000
003oool0oooo0?ooo`@000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0:h0oooo102I00120?ooo`4000000@3oool000030?ooo`000000000000<0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0:l0oooo102I00110?ooo`4000000@3oool00080oooo00@000000?ooo`3oool0oooo1@000003
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`2a
0?ooo`<0V@00@03oool100000040oooo000W0?ooo`030000003oool0oooo0;80oooo102I000n0?oo
o`4000000@3oool002L0oooo00<000000?ooo`3oool0/`3oool409T003d0oooo0@0000010?ooo`00
9`3oool200000;H0oooo0`2I000k0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0]P3o
ool309T003/0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`2g0?ooo`<0V@00>P3oool1
00000040oooo000W0?ooo`030000003oool0oooo0;P0oooo0`2I000i0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool0^@3oool309T003P0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`2j0?ooo`<0V@00=`3oool100000040oooo000W0?ooo`800000_03oool409T003@0oooo0P00
00010?ooo`009`3oool00`000000oooo0?ooo`2l0?ooo`@0V@00=03oool100000040oooo000W0?oo
o`030000003oool0oooo0;h0oooo0`2I000c0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0_`3oool309T00380oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`300?ooo`@0V@00
<03oool100000040oooo000W0?ooo`030000003oool0oooo0<40oooo102I000_0?ooo`4000000@3o
ool002L0oooo00<000000?ooo`3oool0``3oool309T002h0oooo0@0000010?ooo`009`3oool20000
0<D0oooo0`2I000/0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0a@3oool309T002`0
oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`360?ooo`<0V@00:`3oool100000040oooo
000W0?ooo`030000003oool0oooo0<L0oooo0`2I000Z0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool0b03oool309T002T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`390?oo
o`<0V@00:03oool100000040oooo000W0?ooo`800000b`3oool309T002H0oooo0P0000010?ooo`00
9`3oool00`000000oooo0?ooo`3;0?ooo`<0V@009P3oool100000040oooo000W0?ooo`030000003o
ool0oooo0<`0oooo0`2I000U0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0c@3oool3
09T002@0oooo0@0000010?ooo`001@0000030?ooo`800000103oool2000000@0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0cP3oool309T002<0oooo0@0000010?oo
o`0000D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3?0?ooo`@0V@008@3oool10000
0040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`800000d@3oool409T001l0oooo0P0000010?ooo`00
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=80oooo0`2I000O0?ooo`400000
0@3oool000050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0d`3oool309T001h0oooo
0@0000010?ooo`0000D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3D0?ooo`<0V@00
7@3oool100000040oooo0000103oool000000000000000040?ooo`800000103oool2000000@0oooo
0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0e@3oool309T001`0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`3F0?ooo`<0V@006`3oool100000040oooo000W
0?ooo`030000003oool0oooo0=L0oooo0`2I000J0?ooo`4000000@3oool002L0oooo0P00003I0?oo
o`<0V@00603oool200000040oooo000W0?ooo`030000003oool0oooo0=T0oooo0`2I000H0?ooo`40
00000@3oool002L0oooo00<000000?ooo`3oool0fP3oool209T001P0oooo0@0000010?ooo`009`3o
ool00`000000oooo0?ooo`3J0?ooo`<0V@005`3oool100000040oooo000W0?ooo`030000003oool0
oooo0=/0oooo0`2I000F0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0g03oool309T0
01D0oooo0@0000010?ooo`009`3oool200000=h0oooo0`2I000C0?ooo`8000000@3oool002L0oooo
00<000000?ooo`3oool0gP3oool309T001<0oooo0@0000010?ooo`009`3oool00`000000oooo0?oo
o`3O0?ooo`<0V@004P3oool100000040oooo000W0?ooo`030000003oool0oooo0>00oooo0`2I000A
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0h@3oool309T00100oooo0@0000010?oo
o`009`3oool00`000000oooo0?ooo`3R0?ooo`<0V@003`3oool100000040oooo000W0?ooo`800000
i03oool309T000d0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`3T0?ooo`80V@003P3o
ool100000040oooo000W0?ooo`030000003oool0oooo0>@0oooo0`2I000=0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool0i@3oool309T000`0oooo0@0000010?ooo`009`3oool00`000000
oooo0?ooo`3V0?ooo`<0V@002`3oool100000040oooo000W0?ooo`030000003oool0oooo0>L0oooo
0`2I000:0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0j03oool309T000T0oooo0@00
00010?ooo`009`3oool200000>X0oooo0`2I00070?ooo`8000000@3oool002L0oooo00<000000?oo
o`3oool0jP3oool309T000L0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`3[0?ooo`<0
V@001P3oool100000040oooo000500000080oooo0`0000040?ooo`800000103oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3/0?ooo`<0V@001@3oool100000040oooo
00001`3oool000000?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0k@3oool209T000D0oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00<0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool200000040oooo00001P000000oooo0?ooo`3oool000000?ooo`@000000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooooP000000@3oool000070000003oool0oooo0?ooo`00
0000oooo000000060?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?d0oooo0000103oool00000
0000000000020?ooo`D000000`3oool2000000@0oooo0P0000040?ooo`800000103oool200000?h0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.72064, -16327.2, \
0.127131, 1581.74}}]
}, Open  ]],

Cell["Here the house is depreciating in value.", "MathCaption",
  CellTags->"Equity"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Equity", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"100000", ",", " ", "15"}], "}"}], ",", " ", 
              RowBox[{"{", 
                RowBox[{"7.2", ",", " ", 
                  RowBox[{"-", "2"}]}], "}"}], ",", " ", "30", ",", " ", 
              RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", "30"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Equity"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 -0.0944126 1.27199e-05 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03279 -30 -4.5 ]
[-0.0125 .03279 0 4.5 ]
[-0.0125 .15998 -30 -4.5 ]
[-0.0125 .15998 0 4.5 ]
[-0.0125 .28718 -30 -4.5 ]
[-0.0125 .28718 0 4.5 ]
[-0.0125 .41438 -30 -4.5 ]
[-0.0125 .41438 0 4.5 ]
[-0.0125 .54158 -30 -4.5 ]
[-0.0125 .54158 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03279 m
.00625 .03279 L
s
[(10000)] -0.0125 .03279 1 0 Mshowa
0 .15998 m
.00625 .15998 L
s
[(20000)] -0.0125 .15998 1 0 Mshowa
0 .28718 m
.00625 .28718 L
s
[(30000)] -0.0125 .28718 1 0 Mshowa
0 .41438 m
.00625 .41438 L
s
[(40000)] -0.0125 .41438 1 0 Mshowa
0 .54158 m
.00625 .54158 L
s
[(50000)] -0.0125 .54158 1 0 Mshowa
.125 Mabswid
0 .05823 m
.00375 .05823 L
s
0 .08367 m
.00375 .08367 L
s
0 .10911 m
.00375 .10911 L
s
0 .13454 m
.00375 .13454 L
s
0 .18542 m
.00375 .18542 L
s
0 .21086 m
.00375 .21086 L
s
0 .2363 m
.00375 .2363 L
s
0 .26174 m
.00375 .26174 L
s
0 .31262 m
.00375 .31262 L
s
0 .33806 m
.00375 .33806 L
s
0 .3635 m
.00375 .3635 L
s
0 .38894 m
.00375 .38894 L
s
0 .43982 m
.00375 .43982 L
s
0 .46526 m
.00375 .46526 L
s
0 .4907 m
.00375 .4907 L
s
0 .51614 m
.00375 .51614 L
s
0 .00735 m
.00375 .00735 L
s
0 .56702 m
.00375 .56702 L
s
0 .59246 m
.00375 .59246 L
s
0 .6179 m
.00375 .6179 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03279 m
1 .03279 L
s
.99375 .15998 m
1 .15998 L
s
.99375 .28718 m
1 .28718 L
s
.99375 .41438 m
1 .41438 L
s
.99375 .54158 m
1 .54158 L
s
.125 Mabswid
.99625 .05823 m
1 .05823 L
s
.99625 .08367 m
1 .08367 L
s
.99625 .10911 m
1 .10911 L
s
.99625 .13454 m
1 .13454 L
s
.99625 .18542 m
1 .18542 L
s
.99625 .21086 m
1 .21086 L
s
.99625 .2363 m
1 .2363 L
s
.99625 .26174 m
1 .26174 L
s
.99625 .31262 m
1 .31262 L
s
.99625 .33806 m
1 .33806 L
s
.99625 .3635 m
1 .3635 L
s
.99625 .38894 m
1 .38894 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .46526 m
1 .46526 L
s
.99625 .4907 m
1 .4907 L
s
.99625 .51614 m
1 .51614 L
s
.99625 .00735 m
1 .00735 L
s
.99625 .56702 m
1 .56702 L
s
.99625 .59246 m
1 .59246 L
s
.99625 .6179 m
1 .6179 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.6 0 0 r
2 Mabswid
.02381 .09639 m
.06244 .07873 L
.10458 .06168 L
.14415 .04784 L
.18221 .03664 L
.22272 .02709 L
.26171 .02036 L
.28302 .01775 L
.29279 .01682 L
.30316 .01601 L
.31266 .01544 L
.31807 .01518 L
.32313 .015 L
.32777 .01487 L
.32997 .01482 L
.33201 .01478 L
.33436 .01475 L
.33559 .01474 L
.33691 .01473 L
.33817 .01472 L
.33935 .01472 L
.34042 .01472 L
.34157 .01472 L
.34281 .01472 L
.34394 .01473 L
.34525 .01474 L
.34649 .01475 L
.34868 .01478 L
.35107 .01482 L
.35649 .01496 L
.36151 .01514 L
.37172 .01566 L
.38257 .01644 L
.39194 .01731 L
.40204 .01845 L
.42032 .02105 L
.44036 .02475 L
.46146 .02962 L
.49957 .04107 L
.54013 .05727 L
.57918 .07705 L
.62068 .10294 L
.66066 .13301 L
.69912 .16707 L
.74004 .20928 L
.77945 .25623 L
.81733 .30771 L
.85767 .36991 L
.8965 .43757 L
.93777 .51865 L
Mistroke
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009P3oool2
000002D0oooo0`00000R0?ooo`<00000103oool200000200oooo0`0000030?ooo`<000007P3oool5
000000<0oooo0P00000N0?ooo`D000000P3oool3000001l0oooo0`0000040?ooo`800000103oool0
02D0oooo00@000000?ooo`3oool000008`3oool01@000000oooo0?ooo`3oool000000280oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000P0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0L0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000007P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
6`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool002D0
oooo00@000000?ooo`3oool000009`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000O0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool07`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0040oooo000U0?ooo`040000003oool0oooo000002L0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool20000
00<0oooo00@000000?ooo`3oool000000`3oool002D0oooo00@000000?ooo`3oool000008`3oool4
000002<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000P0?ooo`040000003o
ool0oooo0?ooo`@000007P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000007@3oool01P000000oooo0?ooo`3oool000000?ooo`@000008P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0040oooo000U0?ooo`040000003oool0oooo000002<0oooo
00<000000?ooo`3oool08`3oool2000000@0oooo00@000000?ooo`3oool000007`3oool2000000<0
oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000007@3oool01`000000oooo0?ooo`3oool000000?ooo`0000008@3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool002H0oooo0P00000T0?ooo`D0
00008P3oool00`000000oooo0?ooo`030?ooo`8000008@3oool010000000oooo0?ooo`3oool50000
01h0oooo0`0000040?ooo`8000007`3oool300000080oooo1@00000N0?ooo`<00000103oool20000
00@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000Q0?oo
ooh000000@3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`40
00000@3oool00240oooo0P00003j0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0C`3o
ool809T00:<0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`110?ooobD0V@00U03oool1
00000040oooo000Q0?ooo`030000003oool0oooo03`0oooo502I00060?oooaD0V@00S`3oool10000
0040oooo0000103oool000000000000000040?ooo`800000103oool2000000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`0g0?ooo`/0V@008`3oool;09T008X0oooo0@0000010?oo
o`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0<P3oool;09T002d0oooo2`2I00250?ooo`4000000@3oool00080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000;P3oool;
09T003L0oooo2@2I00210?ooo`8000000@3oool00080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02P0oooo2`2I00110?ooo`L0
V@00O`3oool100000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0U0?ooo`T0V@00B@3oool609T007d0oooo0@00
00010?ooo`0000<0oooo000000000000103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0280oooo1`2I001A0?ooo`H0V@00NP3oool100000040oooo00020?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo01h0oooo202I001F0?ooo`L0V@00M`3oool100000040oooo000Q0?ooo`030000
003oool0oooo01/0oooo202I001L0?ooo`L0V@00M03oool100000040oooo000Q0?ooo`8000006@3o
ool709T006<0oooo1P2I001a0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool05@3oool7
09T006T0oooo1@2I001`0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool04`3oool609T0
06h0oooo1@2I001^0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool04@3oool509T007<0
oooo1@2I001/0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool03`3oool509T007L0oooo
1@2I001Z0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool03@3oool509T007/0oooo1@2I
001X0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool02`3oool509T007l0oooo102I001W
0?ooo`4000000@3oool00240oooo0P0000090?ooo`H0V@00P`3oool409T006@0oooo0P0000010?oo
o`008@3oool00`000000oooo0?ooo`060?ooo`H0V@00QP3oool409T006@0oooo0@0000010?ooo`00
8@3oool00`000000oooo0?ooo`030?ooo`H0V@00R`3oool309T006<0oooo0@0000010?ooo`008@3o
ool00`000000oooo0?ooo`020?ooo`D0V@00SP3oool409T00640oooo0@0000010?ooo`008@3oool0
0`000000oooo0?ooo`020?ooo`80V@00TP3oool409T00600oooo0@0000010?ooo`008@3oool00`00
0000oooo0?ooo`2H0?ooo`@0V@00GP3oool100000040oooo000Q0?ooo`800000VP3oool409T005`0
oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`2K0?ooo`@0V@00F`3oool100000040oooo
000Q0?ooo`030000003oool0oooo09`0oooo102I001J0?ooo`4000000@3oool00240oooo00<00000
0?ooo`3oool0WP3oool309T005T0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2O0?oo
o`@0V@00E`3oool100000040oooo000Q0?ooo`030000003oool0oooo0:00oooo102I001F0?ooo`40
00000@3oool00240oooo00<000000?ooo`3oool0XP3oool409T005@0oooo0@0000010?ooo`008@3o
ool200000:@0oooo102I001B0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0Y@3oool3
09T00580oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2V0?ooo`<0V@00D@3oool10000
0040oooo000Q0?ooo`030000003oool0oooo0:L0oooo0`2I001@0?ooo`4000000@3oool000D00000
0`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
Z03oool309T004l0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0Z@3oool309T004h0oooo0@00
00010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo0P00002[0?ooo`<0V@00C03oool200000040oooo00030?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:/0oooo
0`2I001<0?ooo`4000000@3oool000050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0:`0oooo0`2I001;0?ooo`4000000@3o
ool000050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0:d0oooo0P2I001;0?ooo`4000000@3oool000040?ooo`0000000000
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0:d0oooo0`2I001:0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0[P3oool309T0
04T0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`2_0?ooo`<0V@00B03oool100000040
oooo000Q0?ooo`800000/@3oool309T004H0oooo0P0000010?ooo`008@3oool00`000000oooo0?oo
o`2a0?ooo`<0V@00AP3oool100000040oooo000Q0?ooo`030000003oool0oooo0;80oooo0`2I0015
0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0/`3oool309T004@0oooo0@0000010?oo
o`008@3oool00`000000oooo0?ooo`2d0?ooo`<0V@00@`3oool100000040oooo000Q0?ooo`030000
003oool0oooo0;D0oooo0`2I00120?ooo`4000000@3oool00240oooo0P00002g0?ooo`<0V@00@03o
ool200000040oooo000Q0?ooo`030000003oool0oooo0;L0oooo0P2I00110?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool0]`3oool309T00400oooo0@0000010?ooo`008@3oool00`000000
oooo0?ooo`2h0?ooo`<0V@00?`3oool100000040oooo000Q0?ooo`030000003oool0oooo0;T0oooo
0`2I000n0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0^P3oool309T003d0oooo0@00
00010?ooo`008@3oool00`000000oooo0?ooo`2k0?ooo`<0V@00?03oool100000040oooo000Q0?oo
o`800000_@3oool209T003/0oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`2l0?ooo`<0
V@00>`3oool100000040oooo000Q0?ooo`030000003oool0oooo0;d0oooo0`2I000j0?ooo`400000
0@3oool00240oooo00<000000?ooo`3oool0_P3oool309T003T0oooo0@0000010?ooo`008@3oool0
0`000000oooo0?ooo`2o0?ooo`<0V@00>03oool100000040oooo000Q0?ooo`030000003oool0oooo
0<00oooo0`2I000g0?ooo`4000000@3oool00240oooo0P0000320?ooo`80V@00=P3oool200000040
oooo000Q0?ooo`030000003oool0oooo0<40oooo0`2I000f0?ooo`4000000@3oool00240oooo00<0
00000?ooo`3oool0`P3oool309T003D0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`33
0?ooo`<0V@00=03oool100000040oooo0000103oool000000000000000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`340?ooo`80V@00=03oool1
00000040oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`340?ooo`<0V@00<`3oool100000040oooo00040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`350?ooo`<0V@00<P3oool100000040oooo00020?ooo`8000000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`800000a`3oool309T00300oooo0P0000010?ooo`00103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0a`3oool309T00300oooo0@0000010?ooo`0000D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0b03oool209T00300oooo
0@0000010?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000040?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0b03oool309T002l0oooo0@0000010?ooo`008@3o
ool00`000000oooo0?ooo`390?ooo`<0V@00;P3oool100000040oooo000Q0?ooo`030000003oool0
oooo0<X0oooo0`2I000]0?ooo`4000000@3oool00240oooo0P00003<0?ooo`80V@00;03oool20000
0040oooo000Q0?ooo`030000003oool0oooo0</0oooo0`2I000/0?ooo`4000000@3oool00240oooo
00<000000?ooo`3oool0c03oool309T002/0oooo0@0000010?ooo`008@3oool00`000000oooo0?oo
o`3=0?ooo`80V@00:`3oool100000040oooo000Q0?ooo`030000003oool0oooo0<d0oooo0`2I000Z
0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0cP3oool209T002X0oooo0@0000010?oo
o`008@3oool200000<l0oooo0`2I000X0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0
c`3oool309T002P0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3@0?ooo`80V@00:03o
ool100000040oooo000Q0?ooo`030000003oool0oooo0=00oooo0`2I000W0?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool0d@3oool309T002H0oooo0@0000010?ooo`008@3oool00`000000
oooo0?ooo`3B0?ooo`80V@009P3oool100000040oooo000Q0?ooo`030000003oool0oooo0=80oooo
0`2I000U0?ooo`4000000@3oool00240oooo0P00003D0?ooo`80V@00903oool200000040oooo000Q
0?ooo`030000003oool0oooo0=<0oooo0`2I000T0?ooo`4000000@3oool00240oooo00<000000?oo
o`3oool0e03oool309T002<0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3E0?ooo`80
V@008`3oool100000040oooo000Q0?ooo`030000003oool0oooo0=D0oooo0`2I000R0?ooo`400000
0@3oool00240oooo00<000000?ooo`3oool0eP3oool209T00280oooo0@0000010?ooo`008@3oool2
00000=L0oooo0`2I000P0?ooo`8000000@3oool00240oooo00<000000?ooo`3oool0e`3oool309T0
0200oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3H0?ooo`80V@00803oool100000040
oooo000Q0?ooo`030000003oool0oooo0=P0oooo0`2I000O0?ooo`4000000@3oool00080oooo0`00
00030?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`3I0?ooo`80V@007`3oool100000040oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=T0oooo0`2I000N0?oo
o`4000000@3oool000D000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0=X0oooo0`2I000M0?ooo`4000000@3oool000040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool200000=`0oooo0P2I000L0?ooo`8000000@3o
ool000040?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3K0?ooo`<0V@00703oool100000040oooo00020?ooo`8000000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0=`0oooo0P2I000L0?ooo`40
00000@3oool000<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0g03oool309T001/0oooo0@0000010?ooo`008@3o
ool00`000000oooo0?ooo`3M0?ooo`<0V@006P3oool100000040oooo000Q0?ooo`030000003oool0
oooo0=h0oooo0P2I000J0?ooo`4000000@3oool00240oooo0P00003O0?ooo`<0V@00603oool20000
0040oooo000Q0?ooo`030000003oool0oooo0=l0oooo0P2I000I0?ooo`4000000@3oool00240oooo
00<000000?ooo`3oool0g`3oool309T001P0oooo0@0000010?ooo`008@3oool00`000000oooo0?oo
o`3P0?ooo`80V@00603oool100000040oooo000Q0?ooo`030000003oool0oooo0>00oooo0`2I000G
0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0h@3oool209T001L0oooo0@0000010?oo
o`008@3oool00`000000oooo0?ooo`3Q0?ooo`<0V@005P3oool100000040oooo000Q0?ooo`800000
h`3oool309T001@0oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`3S0?ooo`80V@005@3o
ool100000040oooo000Q0?ooo`030000003oool0oooo0><0oooo0`2I000D0?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool0i03oool209T001@0oooo0@0000010?ooo`008@3oool00`000000
oooo0?ooo`3T0?ooo`<0V@004`3oool100000040oooo000Q0?ooo`030000003oool0oooo0>D0oooo
0P2I000C0?ooo`4000000@3oool00240oooo0P00003V0?ooo`<0V@004@3oool200000040oooo000Q
0?ooo`030000003oool0oooo0>H0oooo0P2I000B0?ooo`4000000@3oool00240oooo00<000000?oo
o`3oool0iP3oool309T00140oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`3W0?ooo`<0
V@00403oool100000040oooo000Q0?ooo`030000003oool0oooo0>P0oooo0P2I000@0?ooo`400000
0@3oool00240oooo00<000000?ooo`3oool0j03oool309T000l0oooo0@0000010?ooo`008@3oool0
0`000000oooo0?ooo`3Y0?ooo`80V@003`3oool100000040oooo000Q0?ooo`800000jP3oool309T0
00d0oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`3Z0?ooo`80V@003P3oool100000040
oooo000Q0?ooo`030000003oool0oooo0>X0oooo0`2I000=0?ooo`4000000@3oool00240oooo00<0
00000?ooo`3oool0j`3oool209T000d0oooo0@0000010?ooo`0000@0oooo0000000000000000103o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0j`3o
ool209T000d0oooo0@0000010?ooo`0000D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0j`3oool309T000`0oooo0@000001
0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo0P00003]0?ooo`80V@002`3oool200000040oooo00040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3/0?ooo`<0V@002`3o
ool100000040oooo0004000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`3]0?ooo`80V@002`3oool100000040oooo00000`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0k@3oool209T000/0oooo
0@0000010?ooo`001@0000030?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`3]0?ooo`<0V@002P3oool100000040oooo000Q0?ooo`030000003oool0
oooo0>h0oooo0P2I000:0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0kP3oool309T0
00T0oooo0@0000010?ooo`008@3oool200000?00oooo0P2I00080?ooo`8000000@3oool00240oooo
00<000000?ooo`3oool0k`3oool309T000P0oooo0@0000010?ooo`008@3oool00`000000oooo0?oo
o`3`0?ooo`80V@00203oool100000040oooo000Q0?ooo`030000003oool0oooo0?00oooo0P2I0008
0?ooo`4000000@3oool00240oooo00<000000?ooo`3oool0l03oool309T000L0oooo0@0000010?oo
o`008@3oool00`000000oooo0?ooo`3a0?ooo`80V@001`3oool100000040oooo000Q0?ooo`800000
lP3oool309T000D0oooo0P0000010?ooo`008@3oool00`000000oooo0?ooo`3b0?ooo`80V@001P3o
ool100000040oooo000Q0?ooo`030000003oool0oooo0?80oooo0P2I00060?ooo`4000000@3oool0
0240oooo00<000000?ooo`3oool0lP3oool309T000D0oooo0@0000010?ooo`008@3oool00`000000
oooo0?ooo`3c0?ooo`80V@001@3oool100000040oooo000Q0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool00`3oool100000040oooo000Q0?ooo`800000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`8000000@3oool00240oooooP0000010?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.86877, 2415.72, 0.124162, \
309.88}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell["EquityTargetPayment", "Section",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell["\<\
EquityTargetPayment[{HomeCost, \
PercentageDownPayment},{InterestRate, AppreciationRate}, Years, \
TargetEquityPercentage] gives the payment number when the equity in the home \
is equal to the percentage of the total home value given by \
TargetEquityPercentage. The house has an initial value given by HomeCost with \
a down payment given by PercentageDownPayment for a loan amortized over the \
number of years given by Years with the fixed interest rate given by \
InterestRate.  The property is assumed to appreciate at the fixed rate given \
by AppreciationRate. Note that AppreciationRate can be negative and that the \
assessed value of the house at purchase is assumed to be equal to its \
purchase price given by HomeCost. 

EquityTargetPayment[{{HomeCost,InitialHomeValue}, \
PercentageDownPayment}},{InterestRate, AppreciationRate}, Years, \
TargetEquityPercentage] allows for the initial value of the home to be \
different from the home cost. Note that for both forms it is possible, under \
some circumstances, for there to be more that one solution. The algorithm \
uses FindRoot seeded by the value of $EquityFindRootStart. By adjusting the \
value of $EquityFindRootStart you can explore the possibilities of other \
solutions that are exhibited by examining the graph of the Equity function. 

EquityTargetPayment[{HomeCost, PercentageDownPayment}, {{{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, \
AppreciationRate}, Years, TargetEquityPercentage] calculates for a variable \
rate loan with interest rate InterestRate1 for a number of payments given by \
Payments1 followed by InterestRate2 for a number of payments given by \
Payments2, and so on. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. 

EquityTargetPayment[{{HomeCost,InitialHomeValue}, PercentageDownPayment}}, \
{{{InterestRate1, Payments1},{InterestRate2, Payments2},...,{InterestRateM, \
PaymentsM}}, AppreciationRate}, Years, TargetEquityPercentage] is also a \
valid input.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["EquityTargetPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"CalculationBasis", "\[Rule]", "Current"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["EquityTargetPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["EquityTargetPayment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "The function ",
  StyleBox["EquityTargetPayment", "MR"],
  " answers the question of when the equity in the property is equal to a \
given percentage of its value. This is a useful question to answer if there \
is a cost associated with a loan that depends on the equity in the property. \
An example of this is when a mortgage company requires you to purchase \
mortgage insurance if the down payment on the property (and hence the initial \
equity) is less than a specified percentage of its value."
}], "Text",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell["\<\
Here a 5% down payment is made on a $10000 home. The interest rate \
is 7.1% and the appreciation rate is 2%. The mortgage company requires \
mortgage insurance if the equity in the property is less than 20% of its \
value.\
\>", "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaymentNumberToYears", "[", "\[IndentingNewLine]", 
      RowBox[{"EquityTargetPayment", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"100000", ",", " ", "5"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"7.2", ",", " ", "2"}], "}"}], ",", " ", "30", ",", " ", 
          "20"}], "]"}], "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData["5.392719635754198`"], "Output",
  CellLabel->"Out[2]=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],

Cell["\<\
Here is a plot of the ratio of the equity in the property to its \
value. \
\>", "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
            FractionBox[
              RowBox[{"Equity", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"100000", ",", "5"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"7.2", ",", "2"}], "}"}], ",", "30", ",", 
                  RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}], 
              RowBox[{"HomeValue", "[", 
                RowBox[{"100000", ",", "2", ",", 
                  RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}]], 
            "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", "10"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"All", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", ".4"}], "}"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"Line", "[", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"0", ",", ".2"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"10", ",", ".2"}], "}"}]}], "}"}], "]"}]}]}], 
        "]"}], ";"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(0.05)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.1)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.15)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.3)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.35)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.4)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02381 .07725 m
.06244 .09475 L
.10458 .11382 L
.14415 .1317 L
.18221 .14888 L
.22272 .16716 L
.26171 .18474 L
.30316 .20342 L
.34309 .22141 L
.3815 .23872 L
.42237 .25713 L
.46172 .27487 L
.49955 .29194 L
.53984 .31012 L
.57861 .32763 L
.61984 .34627 L
.65954 .36425 L
.69774 .38157 L
.73838 .40002 L
.77751 .41783 L
.81909 .43679 L
.85916 .4551 L
.89771 .47276 L
.93871 .49159 L
.97619 .50885 L
s
0 g
.5 Mabswid
.02381 .30902 m
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool2000002h0oooo1@00000^0?ooo`<00000;@3oool3000002l0oooo0`00000[0?oo
o`<00000103oool2000000@0oooo000O0?ooo`040000003oool0oooo000002h0oooo00@000000?oo
o`3oool00000;`3oool00`000000oooo0?ooo`0[0?ooo`050000003oool0oooo0?ooo`000000;@3o
ool01@000000oooo0?ooo`3oool0000002/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`007`3oool010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo02`0
oooo1@00000/0?ooo`050000003oool0oooo0?ooo`000000;@3oool01@000000oooo0?ooo`3oool0
000002/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`007`3oool0
10000000oooo0?ooo`00000`0?ooo`030000003oool0oooo02/0oooo00@000000?ooo`3oool00000
;@3oool4000002l0oooo0`00000/0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool001l0oooo00@000000?ooo`3oool00000;@3oool01@000000oooo0?ooo`3oool00000
02d0oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo
0?ooo`000000:`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo000O
0?ooo`040000003oool0oooo000002d0oooo00D000000?ooo`3oool0oooo0000000^0?ooo`800000
;P3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000:P3oool2000000@0
oooo00@000000?ooo`3oool000000`3oool00200oooo0P00000_0?ooo`<00000<03oool00`000000
oooo0?ooo`0]0?ooo`800000;`3oool3000002`0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000K0?ooool0
00001@0000010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`4000000@3oool001/0oooo0P00003o0?ooo`40oooo0P0000010?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool2
00000?l0oooo0@3oool200000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000
003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`800000o`3oool10?ooo`8000000@3o
ool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`40
00000@3oool001/0oooo0P00003o0?ooo`40oooo0P0000010?ooo`000P3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000<0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo0@3o
ool100000040oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool10?ooo`40
00000@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo0080oooo0`0000020?ooo`<0V@00nP3oool200000040oooo00001@3oool000000?ooo`3oool0
000000P0oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo00<000000?ooo`3oool00P3o
ool609T00?P0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003o
ool0oooo0000003oool00000203oool00`000000oooo0?ooo`040?ooo`H0V@00mP3oool100000040
oooo00020?ooo`8000002P3oool200000080oooo1@0000040?ooo`030000003oool0oooo00L0oooo
1P2I003c0?ooo`4000000@3oool001/0oooo0P00000:0?ooo`H0V@00l03oool200000040oooo000K
0?ooo`030000003oool0oooo00`0oooo1@2I003_0?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool03P3oool609T00>`0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`H0
V@00jP3oool100000040oooo000K0?ooo`800000503oool509T00>L0oooo0P0000010?ooo`006`3o
ool00`000000oooo0?ooo`0E0?ooo`D0V@00iP3oool100000040oooo000K0?ooo`030000003oool0
oooo01L0oooo1@2I003T0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool06@3oool509T0
0>80oooo0@0000010?ooo`006`3oool2000001`0oooo1@2I003O0?ooo`8000000@3oool001/0oooo
00<000000?ooo`3oool07@3oool509T00=h0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`0O0?ooo`D0V@00g03oool100000040oooo000K0?ooo`030000003oool0oooo0240oooo1P2I003I
0?ooo`4000000@3oool001/0oooo0P00000T0?ooo`H0V@00eP3oool200000040oooo00080?ooo`80
0000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0V0?ooo`H0
V@00e03oool100000040oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0X0?ooo`H0V@00dP3oool100000040oooo00070?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`D0
V@00d03oool100000040oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool3000002d0oooo1P2I003<0?ooo`8000000@3oool000L0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02l0oooo1P2I003;0?ooo`40
00000@3oool000L0oooo00@000000?ooo`3oool00000203oool2000000H0oooo00<000000?ooo`3o
ool0<P3oool509T00<T0oooo0@0000010?ooo`00203oool2000000X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0d0?ooo`D0V@00a`3oool100000040oooo000K0?ooo`800000=`3o
ool509T00<@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0h0?ooo`D0V@00``3oool1
00000040oooo000K0?ooo`030000003oool0oooo03X0oooo1@2I00310?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0?03oool509T00;l0oooo0@0000010?ooo`006`3oool2000003l0oooo
1@2I002l0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0@03oool509T00;/0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`120?ooo`H0V@00^03oool100000040oooo000K0?oo
o`030000003oool0oooo04@0oooo1P2I002f0?ooo`4000000@3oool001/0oooo0P0000180?ooo`D0
V@00/`3oool200000040oooo000K0?ooo`030000003oool0oooo04T0oooo1@2I002b0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0B`3oool609T00:l0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`1=0?ooo`H0V@00[@3oool100000040oooo000K0?ooo`800000D@3oool609T0
0:T0oooo0P0000010?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0
oooo0`0000050?ooo`030000003oool0oooo0580oooo1P2I002X0?ooo`4000000@3oool000050?oo
o`000000oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1E0?ooo`D0V@00YP3oool100000040oooo00001@3oool0
00000?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo05L0oooo1@2I002T0?ooo`4000000@3oool000050?ooo`000000oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00001I0?oo
o`D0V@00X@3oool200000040oooo00001@3oool000000?ooo`3oool0000000T0oooo00@000000?oo
o`3oool0oooo100000050?ooo`030000003oool0oooo05/0oooo1@2I002P0?ooo`4000000@3oool0
00050?ooo`000000oooo0?ooo`000000203oool2000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1M0?ooo`D0V@00WP3oool100000040oooo00020?ooo`8000002P3oool01000
0000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool0G`3oool609T009/0oooo0@000001
0?ooo`006`3oool200000680oooo1P2I002H0?ooo`8000000@3oool001/0oooo00<000000?ooo`3o
ool0I03oool609T009H0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1V0?ooo`H0V@00
U03oool100000040oooo000K0?ooo`030000003oool0oooo06T0oooo1@2I002B0?ooo`4000000@3o
ool001/0oooo0P00001/0?ooo`H0V@00SP3oool200000040oooo000K0?ooo`030000003oool0oooo
06d0oooo1P2I002=0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0L03oool509T008/0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`D0V@00R@3oool100000040oooo
000K0?ooo`800000M@3oool509T008H0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`1f
0?ooo`H0V@00Q03oool100000040oooo000K0?ooo`030000003oool0oooo07P0oooo1P2I00220?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool0N`3oool509T00800oooo0@0000010?ooo`00
6`3oool2000007h0oooo1@2I001m0?ooo`8000000@3oool000P0oooo0P0000040?ooo`040000003o
ool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`1o0?ooo`H0V@00N`3oool100000040oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`210?ooo`H0V@00N@3oool100000040oooo00070?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`240?ooo`D0V@00M`3oool100000040
oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool3000000<0
oooon00000040?ooo`8000000@3oool000L0oooo00@000000?ooo`3oool000001`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0R03oool509T007<0oooo0@0000010?oo
o`001`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`2:0?ooo`D0V@00L@3oool100000040oooo00080?ooo`8000002@3oool30000
00D0oooo00<000000?ooo`3oool0S03oool509T006l0oooo0@0000010?ooo`006`3oool2000008l0
oooo1@2I001/0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0T03oool509T006/0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`2B0?ooo`D0V@00J@3oool100000040oooo000K
0?ooo`030000003oool0oooo09@0oooo1P2I001V0?ooo`4000000@3oool001/0oooo0P00002G0?oo
o`H0V@00H`3oool200000040oooo000K0?ooo`030000003oool0oooo09T0oooo1@2I001R0?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool0V`3oool509T00600oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`2M0?ooo`H0V@00G@3oool100000040oooo000K0?ooo`800000X03oool6
09T005X0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`2R0?ooo`H0V@00F03oool10000
0040oooo000K0?ooo`030000003oool0oooo0:@0oooo1P2I001F0?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool0Y`3oool509T005@0oooo0@0000010?ooo`006`3oool200000:X0oooo1@2I
001A0?ooo`8000000@3oool00080oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000000P3o
ool3000000D0oooo00<000000?ooo`3oool0Z`3oool509T00500oooo0@0000010?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0:d0oooo1@2I001>0?ooo`4000000@3oool000050?oo
o`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0[`3oool509T004`0oooo0@0000010?ooo`0000D0oooo0000003oool0
oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool300000;40
oooo1P2I00180?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01P000000
oooo0?ooo`3oool000000?ooo`@000001@3oool00`000000oooo0?ooo`2c0?ooo`H0V@00A`3oool1
00000040oooo00001@3oool000000?ooo`3oool0000000L0oooo00L000000?ooo`3oool0oooo0000
003oool0000000P0oooo00<000000?ooo`3oool0]P3oool609T004@0oooo0@0000010?ooo`000P3o
ool2000000T0oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`2h0?ooo`H0V@00@P3o
ool100000040oooo000K0?ooo`800000_03oool509T003l0oooo0P0000010?ooo`006`3oool00`00
0000oooo0?ooo`2m0?ooo`D0V@00?P3oool100000040oooo000K0?ooo`030000003oool0oooo0;l0
oooo1@2I000l0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0`@3oool509T003X0oooo
0@0000010?ooo`006`3oool200000<@0oooo1@2I000g0?ooo`8000000@3oool001/0oooo00<00000
0?ooo`3oool0a@3oool509T003H0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`370?oo
o`H0V@00<`3oool100000040oooo000K0?ooo`030000003oool0oooo0<T0oooo1P2I000a0?ooo`40
00000@3oool001/0oooo0P00003=0?ooo`D0V@00;P3oool200000040oooo000K0?ooo`030000003o
ool0oooo0<h0oooo1@2I000]0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0d03oool5
09T002/0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3B0?ooo`H0V@00:03oool10000
0040oooo000K0?ooo`800000e@3oool609T002D0oooo0P0000010?ooo`00203oool2000000@0oooo
00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0e`3oool509T002@0oooo
0@0000010?ooo`001`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`3I0?ooo`D0V@008P3oool100000040oooo00070?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3K0?ooo`H0
V@007`3oool100000040oooo00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`<0
0000g@3oool609T001`0oooo0P0000010?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0h03oool609T001X0oooo0@0000010?ooo`00
1`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`3R0?ooo`H0V@00603oool100000040oooo00080?ooo`8000002@3oool3000000D0
oooo00<000000?ooo`3oool0i@3oool509T001H0oooo0@0000010?ooo`006`3oool200000>P0oooo
1@2I000C0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0j@3oool509T00180oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`3[0?ooo`D0V@00403oool100000040oooo000K0?oo
o`030000003oool0oooo0>d0oooo1@2I000>0?ooo`4000000@3oool001/0oooo0P00003`0?ooo`D0
V@002`3oool200000040oooo000K0?ooo`030000003oool0oooo0?40oooo1@2I000:0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0l`3oool509T000P0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`3e0?ooo`D0V@001P3oool100000040oooo000K0?ooo`800000n03oool409T0
00@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`3i0?ooo`80V@001@3oool100000040
oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`800000o`3oool10?ooo`8000000@3oool0
0080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`<000001@3oool00`00
0000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000070?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool10?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000002`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
ool10?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000002@3oool2000000H0oooo00<0
00000?ooo`3oool00P3oool300000?l0oooo0P0000010?ooo`0000D0oooo0000003oool0oooo0000
000;0?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@00
00010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`070000003oool0oooo0?ooo`000000
oooo000000080?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo00020?ooo`800000
2@3oool300000080oooo1@0000040?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo
000K0?ooo`800000o`3oool10?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo0P00003o0?ooo`40oooo
0P0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`40oooo0@0000010?ooo`006`3oool200000?l0oooo0@3oool200000040oooo000K0?ooo`030000
003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3o
ool100000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?oo
o`800000o`3oool10?ooo`8000000@3oool000P0oooo0P0000040?ooo`030000003oool0oooo00<0
oooo0`0000040?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo00070?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?ooo`40
00000@3oool000L0oooo00@000000?ooo`3oool000001`3oool5000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool100000040oooo00070?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3o
ool000001@3ooooo000000D000000@3oool000L0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0000003o0?ooo`/0oooo00070?ooo`040000003oool0oooo000000T0oooo0P00003o0?oo
o`/0oooo00080?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.36219, -0.0305647, \
0.0405086, 0.00249694}},
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],

Cell[TextData[{
  "The following are some parameters and options associated with ",
  StyleBox["EquityTargetPayment", "MR"],
  "."
}], "Text",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell["\<\
CalculationBasis is an option for EquityTargetPayment that \
indicates whether the calculation is done on the basis of the original value \
of the home or the current value as calculated by HomeValue. These option \
values are called respectively \"Original\" and \"Current\". The default \
value is \"Current\". A fixed numerical value of your own choosing may also \
be supplied. In addition you may use a pure function of one variable. In this \
case the current value as calculated by HomeValue is supplied as the argument \
to the  pure function. For example, if you wanted to calculate the target \
payment relative to the home value plus a fixed numerical offset \[Delta] \
then you would use CalculationBasis -> (#+\[Delta] &).\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["CalculationBasis", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["CalculationBasis", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["CalculationBasis", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "This calculates the time when the equity in the property is 20% of its ",
  StyleBox["original",
    FontSlant->"Italic"],
  " (purchase) value."
}], "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaymentNumberToYears", "[", "\[IndentingNewLine]", 
      RowBox[{"EquityTargetPayment", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"100000", ",", " ", "5"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"7.2", ",", " ", "2"}], "}"}], ",", " ", "30", ",", " ", 
          "20", ",", 
          RowBox[{"CalculationBasis", "\[Rule]", "Original"}]}], "]"}], 
      "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[5]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData["4.742482800686733`"], "Output",
  CellLabel->"Out[5]=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],

Cell[TextData[{
  "Here is a plot of the ratio of the equity in the property to its ",
  StyleBox["original",
    FontSlant->"Italic"],
  " value. "
}], "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
            FractionBox[
              RowBox[{"Equity", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"100000", ",", "5"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"7.2", ",", "2"}], "}"}], ",", "30", ",", 
                  RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}], 
              "100000"], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", "10"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"All", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", ".4"}], "}"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"Line", "[", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"0", ",", ".2"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"10", ",", ".2"}], "}"}]}], "}"}], "]"}]}]}], 
        "]"}], ";"}]], "Input",
  CellLabel->"In[6]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(0.05)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.1)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.15)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.3)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.35)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.4)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02381 .07725 m
.06244 .09553 L
.10458 .11576 L
.14415 .13507 L
.18221 .15391 L
.22272 .17428 L
.26171 .19419 L
.30316 .2157 L
.34309 .23675 L
.3815 .25732 L
.42237 .27956 L
.46172 .30133 L
.49955 .32258 L
.53984 .34558 L
.57861 .36808 L
.61984 .3924 L
.65954 .41623 L
.69774 .43952 L
.73838 .46473 L
.77751 .48942 L
.81909 .51611 L
.85916 .54228 L
.89771 .5679 L
.93871 .59563 L
s
.93871 .59563 m
.97128 .61803 L
s
0 g
.5 Mabswid
.02381 .30902 m
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool2000002h0oooo1@00000^0?ooo`<00000;@3oool3000002l0oooo0`00000[0?oo
o`<00000103oool2000000@0oooo000O0?ooo`040000003oool0oooo000002h0oooo00@000000?oo
o`3oool00000;`3oool00`000000oooo0?ooo`0[0?ooo`050000003oool0oooo0?ooo`000000;@3o
ool01@000000oooo0?ooo`3oool0000002/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`007`3oool010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo02`0
oooo1@00000/0?ooo`050000003oool0oooo0?ooo`000000;@3oool01@000000oooo0?ooo`3oool0
000002/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`007`3oool0
10000000oooo0?ooo`00000`0?ooo`030000003oool0oooo02/0oooo00@000000?ooo`3oool00000
;@3oool4000002l0oooo0`00000/0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool001l0oooo00@000000?ooo`3oool00000;@3oool01@000000oooo0?ooo`3oool00000
02d0oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo
0?ooo`000000:`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo000O
0?ooo`040000003oool0oooo000002d0oooo00D000000?ooo`3oool0oooo0000000^0?ooo`800000
;P3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000:P3oool2000000@0
oooo00@000000?ooo`3oool000000`3oool00200oooo0P00000_0?ooo`<00000<03oool00`000000
oooo0?ooo`0]0?ooo`800000;`3oool3000002`0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000K0?ooool0
00001@0000010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`4000000@3oool001/0oooo0P00003o0?ooo`40oooo0P0000010?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool2
00000?l0oooo0@3oool200000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000
003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`800000o`3oool10?ooo`8000000@3o
ool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`40
00000@3oool001/0oooo0P00003o0?ooo`40oooo0P0000010?ooo`000P3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000<0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo0@3o
ool100000040oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool10?ooo`40
00000@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo0080oooo0`0000020?ooo`<0V@00nP3oool200000040oooo00001@3oool000000?ooo`3oool0
000000P0oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo00<000000?ooo`3oool00P3o
ool509T00?T0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003o
ool0oooo0000003oool00000203oool00`000000oooo0?ooo`040?ooo`D0V@00m`3oool100000040
oooo00020?ooo`8000002P3oool200000080oooo1@0000040?ooo`030000003oool0oooo00H0oooo
1@2I003e0?ooo`4000000@3oool001/0oooo0P0000090?ooo`D0V@00lP3oool200000040oooo000K
0?ooo`030000003oool0oooo00X0oooo1@2I003a0?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0303oool509T00>l0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0>0?ooo`H0
V@00k03oool100000040oooo000K0?ooo`8000004@3oool609T00>T0oooo0P0000010?ooo`006`3o
ool00`000000oooo0?ooo`0C0?ooo`D0V@00j03oool100000040oooo000K0?ooo`030000003oool0
oooo01D0oooo1@2I003V0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool05`3oool509T0
0>@0oooo0@0000010?ooo`006`3oool2000001X0oooo1@2I003Q0?ooo`8000000@3oool001/0oooo
00<000000?ooo`3oool06`3oool509T00>00oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`0M0?ooo`D0V@00gP3oool100000040oooo000K0?ooo`030000003oool0oooo01l0oooo1@2I003L
0?ooo`4000000@3oool001/0oooo0P00000R0?ooo`D0V@00f@3oool200000040oooo00080?ooo`80
0000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0S0?ooo`D0
V@00f03oool100000040oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0U0?ooo`D0V@00eP3oool100000040oooo00070?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`D0
V@00e03oool100000040oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool3000002T0oooo1@2I003A0?ooo`8000000@3oool000L0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02/0oooo1@2I003@0?ooo`40
00000@3oool000L0oooo00@000000?ooo`3oool00000203oool2000000H0oooo00<000000?ooo`3o
ool0;@3oool609T00<d0oooo0@0000010?ooo`00203oool2000000X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0_0?ooo`H0V@00b`3oool100000040oooo000K0?ooo`800000<`3o
ool509T00<P0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0d0?ooo`D0V@00a`3oool1
00000040oooo000K0?ooo`030000003oool0oooo03H0oooo1@2I00350?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0>03oool509T00<<0oooo0@0000010?ooo`006`3oool2000003/0oooo
1@2I00300?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0?03oool509T00;l0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`0n0?ooo`D0V@00_@3oool100000040oooo000K0?oo
o`030000003oool0oooo0400oooo1@2I002k0?ooo`4000000@3oool001/0oooo0P0000130?ooo`D0
V@00^03oool200000040oooo000K0?ooo`030000003oool0oooo04@0oooo102I002h0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0AP3oool409T00;H0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`170?ooo`D0V@00]03oool100000040oooo000K0?ooo`800000BP3oool509T0
0;40oooo0P0000010?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0
oooo0`0000050?ooo`030000003oool0oooo04/0oooo1@2I002`0?ooo`4000000@3oool000050?oo
o`000000oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`D0V@00[P3oool100000040oooo00001@3oool0
00000?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo04l0oooo1@2I002/0?ooo`4000000@3oool000050?ooo`000000oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00001A0?oo
o`D0V@00Z@3oool200000040oooo00001@3oool000000?ooo`3oool0000000T0oooo00@000000?oo
o`3oool0oooo100000050?ooo`030000003oool0oooo05<0oooo1@2I002X0?ooo`4000000@3oool0
00050?ooo`000000oooo0?ooo`000000203oool2000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1E0?ooo`D0V@00YP3oool100000040oooo00020?ooo`8000002P3oool01000
0000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool0E`3oool509T00:@0oooo0@000001
0?ooo`006`3oool2000005X0oooo1@2I002Q0?ooo`8000000@3oool001/0oooo00<000000?ooo`3o
ool0F`3oool509T00:00oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1M0?ooo`D0V@00
WP3oool100000040oooo000K0?ooo`030000003oool0oooo05l0oooo1@2I002L0?ooo`4000000@3o
ool001/0oooo0P00001R0?ooo`@0V@00VP3oool200000040oooo000K0?ooo`030000003oool0oooo
06<0oooo102I002I0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0I03oool509T009L0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1V0?ooo`@0V@00UP3oool100000040oooo
000K0?ooo`800000J@3oool409T009<0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`1Y
0?ooo`D0V@00TP3oool100000040oooo000K0?ooo`030000003oool0oooo06/0oooo1@2I002@0?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool0K@3oool409T008l0oooo0@0000010?ooo`00
6`3oool200000700oooo102I002<0?ooo`8000000@3oool000P0oooo0P0000040?ooo`040000003o
ool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`1`0?ooo`D0V@00R`3oool100000040oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1b0?ooo`D0V@00R@3oool100000040oooo00070?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1d0?ooo`D0V@00Q`3oool100000040
oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool3000000<0
oooon00000040?ooo`8000000@3oool000L0oooo00@000000?ooo`3oool000001`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0N03oool409T008@0oooo0@0000010?oo
o`001`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`1j0?ooo`@0V@00PP3oool100000040oooo00080?ooo`8000002@3oool30000
00D0oooo00<000000?ooo`3oool0N`3oool509T00800oooo0@0000010?ooo`006`3oool2000007h0
oooo1@2I001m0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0O`3oool509T007`0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`210?ooo`@0V@00N`3oool100000040oooo000K
0?ooo`030000003oool0oooo08<0oooo102I001i0?ooo`4000000@3oool001/0oooo0P0000250?oo
o`D0V@00MP3oool200000040oooo000K0?ooo`030000003oool0oooo08H0oooo1@2I001e0?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool0R03oool509T007<0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`2:0?ooo`@0V@00LP3oool100000040oooo000K0?ooo`800000S@3oool4
09T006l0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`2=0?ooo`D0V@00KP3oool10000
0040oooo000K0?ooo`030000003oool0oooo08l0oooo102I001]0?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool0T@3oool409T006/0oooo0@0000010?ooo`006`3oool2000009<0oooo102I
001Y0?ooo`8000000@3oool00080oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000000P3o
ool3000000D0oooo00<000000?ooo`3oool0U03oool409T006P0oooo0@0000010?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo09D0oooo1@2I001V0?ooo`4000000@3oool000050?oo
o`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0U`3oool409T006D0oooo0@0000010?ooo`0000D0oooo0000003oool0
oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000009T0
oooo102I001R0?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01P000000
oooo0?ooo`3oool000000?ooo`@000001@3oool00`000000oooo0?ooo`2J0?ooo`@0V@00HP3oool1
00000040oooo00001@3oool000000?ooo`3oool0000000L0oooo00L000000?ooo`3oool0oooo0000
003oool0000000P0oooo00<000000?ooo`3oool0W03oool409T00600oooo0@0000010?ooo`000P3o
ool2000000T0oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`2M0?ooo`D0V@00GP3o
ool100000040oooo000K0?ooo`800000X03oool409T005`0oooo0P0000010?ooo`006`3oool00`00
0000oooo0?ooo`2Q0?ooo`@0V@00F`3oool100000040oooo000K0?ooo`030000003oool0oooo0:80
oooo1@2I001I0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0Y03oool409T005P0oooo
0@0000010?ooo`006`3oool200000:L0oooo102I001E0?ooo`8000000@3oool001/0oooo00<00000
0?ooo`3oool0Y`3oool509T005@0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`2Y0?oo
o`@0V@00D`3oool100000040oooo000K0?ooo`030000003oool0oooo0:/0oooo102I001A0?ooo`40
00000@3oool001/0oooo0P00002]0?ooo`D0V@00CP3oool200000040oooo000K0?ooo`030000003o
ool0oooo0:h0oooo102I001>0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0/03oool4
09T004`0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`2a0?ooo`D0V@00BP3oool10000
0040oooo000K0?ooo`800000]03oool409T004P0oooo0P0000010?ooo`00203oool2000000@0oooo
00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0]@3oool409T004L0oooo
0@0000010?ooo`001`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`2f0?ooo`D0V@00A@3oool100000040oooo00070?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2h0?ooo`@0
V@00A03oool100000040oooo00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`<0
0000^P3oool409T00440oooo0P0000010?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0^`3oool409T00440oooo0@0000010?ooo`00
1`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`2m0?ooo`@0V@00?`3oool100000040oooo00080?ooo`8000002@3oool3000000D0
oooo00<000000?ooo`3oool0_P3oool409T003h0oooo0@0000010?ooo`006`3oool200000<40oooo
0`2I000l0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0`@3oool409T003/0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`320?ooo`@0V@00>P3oool100000040oooo000K0?oo
o`030000003oool0oooo0<@0oooo102I000h0?ooo`4000000@3oool001/0oooo0P0000360?ooo`@0
V@00=P3oool200000040oooo000K0?ooo`030000003oool0oooo0<L0oooo102I000e0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0b03oool509T003<0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`3:0?ooo`@0V@00<P3oool100000040oooo000K0?ooo`800000c@3oool409T0
02l0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`3=0?ooo`@0V@00;`3oool100000040
oooo000K0?ooo`030000003oool0oooo0<l0oooo102I000]0?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0d03oool509T002/0oooo0@0000010?ooo`006`3oool200000=<0oooo1@2I000X
0?ooo`8000000@3oool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000030?oo
o`<000001@3oool00`000000oooo0?ooo`3D0?ooo`@0V@00:03oool100000040oooo00001@3oool0
00000?ooo`3oool0000000L0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3F0?ooo`@0V@009P3oool100000040oooo0000
1@3oool000000?ooo`3oool0000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0=L0oooo1@2I000T0?ooo`4000000@3oool000050?ooo`000000
oooo0?ooo`0000002@3oool2000000H0oooo00<000000?ooo`3oool00P3oool300000=T0oooo1@2I
000Q0?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`0000002`3oool00`000000oooo0000
0003000000D0oooo00<000000?ooo`3oool0f`3oool409T00240oooo0@0000010?ooo`0000D0oooo
0000003oool0oooo000000070?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`03
0000003oool0oooo0=d0oooo102I000O0?ooo`4000000@3oool00080oooo0P0000090?ooo`<00000
0P3oool5000000@0oooo00<000000?ooo`3oool0gP3oool409T001h0oooo0@0000010?ooo`006`3o
ool200000>40oooo0`2I000L0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0h@3oool4
09T001/0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3R0?ooo`@0V@006P3oool10000
0040oooo000K0?ooo`030000003oool0oooo0>@0oooo102I000H0?ooo`4000000@3oool001/0oooo
0P00003V0?ooo`@0V@005P3oool200000040oooo000K0?ooo`030000003oool0oooo0>L0oooo102I
000E0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0j03oool409T001@0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`3Z0?ooo`<0V@004`3oool100000040oooo000K0?ooo`80
0000k03oool409T00100oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`3/0?ooo`@0V@00
403oool100000040oooo000K0?ooo`030000003oool0oooo0>h0oooo102I000>0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool0k`3oool409T000d0oooo0@0000010?ooo`006`3oool20000
0?80oooo102I000:0?ooo`8000000@3oool000P0oooo0P0000040?ooo`030000003oool0oooo00<0
oooo0`0000040?ooo`030000003oool0oooo0?80oooo102I000:0?ooo`4000000@3oool000L0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0X0?ooo`@0V@000P3oool00`000000
oooo0?ooo`030?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000001`3oool5000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0
oooo102I00000`3oool000000?ooo`040?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool0
00001`3oool010000000oooo0?ooo`0000050?ooooX000000`2I000700000040oooo00070?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`000000o`3oool10?ooo`80V@00203oool000L0
oooo00@000000?ooo`3oool000002@3oool200000?l0oooo2`3oool000P0oooo0P00000;0?ooo`03
0000003oool0oooo0?l0oooo2@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.36219, -0.0305647, \
0.0405086, 0.00249694}},
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],

Cell["\<\
This calculates when the equity in the property is 20% of its \
current value plus an offset of $20000.\
\>", "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaymentNumberToYears", "[", "\[IndentingNewLine]", 
      RowBox[{"EquityTargetPayment", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"100000", ",", " ", "5"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"7.2", ",", " ", "2"}], "}"}], ",", " ", "30", ",", " ", 
          "20", ",", 
          RowBox[{"CalculationBasis", "\[Rule]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"#", "+", "20000"}], "&"}], ")"}]}]}], "]"}], 
      "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[7]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData["6.6492889432563205`"], "Output",
  CellLabel->"Out[7]=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],

Cell["\<\
Here is a plot of the ratio of the equity in the property to its \
current value plus an offset of $20000. \
\>", "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
            FractionBox[
              RowBox[{"Equity", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"100000", ",", "5"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"7.2", ",", "2"}], "}"}], ",", "30", ",", 
                  RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], "]"}], 
              RowBox[{"20000", "+", 
                RowBox[{"HomeValue", "[", 
                  RowBox[{"100000", ",", "2", ",", 
                    RowBox[{"YearsToPaymentNumber", "[", "y", "]"}]}], 
                  "]"}]}]], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", "10"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"All", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", ".4"}], "}"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"Line", "[", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"0", ",", ".2"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"10", ",", ".2"}], "}"}]}], "}"}], "]"}]}]}], 
        "]"}], ";"}]], "Input",
  CellLabel->"In[8]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(0.05)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.1)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.15)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.2)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.3)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.35)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.4)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.02381 .06438 m
.06244 .07907 L
.10458 .09511 L
.14415 .11021 L
.18221 .12475 L
.22272 .14025 L
.26171 .15521 L
.30316 .17114 L
.34309 .18652 L
.3815 .20136 L
.42237 .21718 L
.46172 .23246 L
.49955 .24719 L
.53984 .26293 L
.57861 .27812 L
.61984 .29433 L
.65954 .30999 L
.69774 .32512 L
.73838 .34127 L
.77751 .35689 L
.81909 .37356 L
.85916 .38969 L
.89771 .40528 L
.93871 .42194 L
.97619 .43725 L
s
0 g
.5 Mabswid
.02381 .30902 m
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool2000002h0oooo1@00000^0?ooo`<00000;@3oool3000002l0oooo0`00000[0?oo
o`<00000103oool2000000@0oooo000O0?ooo`040000003oool0oooo000002h0oooo00@000000?oo
o`3oool00000;`3oool00`000000oooo0?ooo`0[0?ooo`050000003oool0oooo0?ooo`000000;@3o
ool01@000000oooo0?ooo`3oool0000002/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`007`3oool010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo02`0
oooo1@00000/0?ooo`050000003oool0oooo0?ooo`000000;@3oool01@000000oooo0?ooo`3oool0
000002/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`007`3oool0
10000000oooo0?ooo`00000`0?ooo`030000003oool0oooo02/0oooo00@000000?ooo`3oool00000
;@3oool4000002l0oooo0`00000/0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool001l0oooo00@000000?ooo`3oool00000;@3oool01@000000oooo0?ooo`3oool00000
02d0oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo
0?ooo`000000:`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo000O
0?ooo`040000003oool0oooo000002d0oooo00D000000?ooo`3oool0oooo0000000^0?ooo`800000
;P3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000:P3oool2000000@0
oooo00@000000?ooo`3oool000000`3oool00200oooo0P00000_0?ooo`<00000<03oool00`000000
oooo0?ooo`0]0?ooo`800000;`3oool3000002`0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000K0?ooool0
00001@0000010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`4000000@3oool001/0oooo0P00003o0?ooo`40oooo0P0000010?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool2
00000?l0oooo0@3oool200000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000
003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`800000o`3oool10?ooo`8000000@3o
ool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`40
00000@3oool001/0oooo0P0000030?ooo`<0V@00nP3oool200000040oooo00020?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool00P3o
ool609T00?P0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo1P2I003f0?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool609T0
0?<0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool00P3oool3000000T0oooo1P2I003`0?ooo`8000000@3oool0
00050?ooo`000000oooo0?ooo`000000203oool01@000000oooo0?ooo`000000oooo00@000001@3o
ool00`000000oooo0?ooo`0<0?ooo`H0V@00kP3oool100000040oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003oool0oooo00h0
oooo1`2I003[0?ooo`4000000@3oool00080oooo0P00000:0?ooo`8000000P3oool5000000@0oooo
00<000000?ooo`3oool04@3oool709T00>P0oooo0@0000010?ooo`006`3oool2000001D0oooo1P2I
003U0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool05`3oool609T00><0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`H0V@00h@3oool100000040oooo000K0?ooo`03
0000003oool0oooo01`0oooo1P2I003N0?ooo`4000000@3oool001/0oooo0P00000O0?ooo`H0V@00
f`3oool200000040oooo000K0?ooo`030000003oool0oooo0240oooo1P2I003I0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool08`3oool609T00=L0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`0V0?ooo`H0V@00e03oool100000040oooo000K0?ooo`800000:@3oool609T00=40
oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0[0?ooo`H0V@00c`3oool100000040oooo
000K0?ooo`030000003oool0oooo02d0oooo1`2I003<0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool0<03oool709T00<T0oooo0@0000010?ooo`006`3oool2000003@0oooo1P2I00360?oo
o`8000000@3oool000P0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`03
0000003oool0oooo03H0oooo1P2I00340?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03P0oooo1P2I00320?ooo`40
00000@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03/0oooo1P2I002o0?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`040?ooo`<00000?@3oool609T00;`0oooo0P0000010?ooo`00
1`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0@03oool609T00;X0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`80
00001P3oool00`000000oooo0?ooo`120?ooo`L0V@00]`3oool100000040oooo00080?ooo`800000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04D0oooo1`2I002d0?ooo`400000
0@3oool001/0oooo0P0000190?ooo`H0V@00/@3oool200000040oooo000K0?ooo`030000003oool0
oooo04/0oooo1P2I002_0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0C@3oool609T0
0:d0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1@0?ooo`H0V@00ZP3oool100000040
oooo000K0?ooo`800000D`3oool609T00:L0oooo0P0000010?ooo`006`3oool00`000000oooo0?oo
o`1E0?ooo`H0V@00Y@3oool100000040oooo000K0?ooo`030000003oool0oooo05L0oooo1P2I002S
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0FP3oool609T00:00oooo0@0000010?oo
o`006`3oool2000005d0oooo1P2I002M0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0
G`3oool609T009/0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1Q0?ooo`H0V@00V@3o
ool100000040oooo000K0?ooo`030000003oool0oooo06@0oooo1P2I002F0?ooo`4000000@3oool0
01/0oooo0P00001W0?ooo`H0V@00T`3oool200000040oooo00020?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool0J@3oool609T00940
oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000090?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06/0oooo1`2I002>0?oo
o`4000000@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0KP3oool709T008/0oooo0@0000010?oo
o`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool300000740oooo1P2I00280?ooo`8000000@3oool000050?ooo`000000oooo0?oo
o`0000002@3oool010000000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3oool0M03oool5
09T008L0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`8000000`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo07H0oooo1P2I00240?ooo`4000000@3oool0
0080oooo0P00000:0?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`1h
0?ooo`H0V@00PP3oool100000040oooo000K0?ooo`800000O03oool509T007l0oooo0P0000010?oo
o`006`3oool00`000000oooo0?ooo`1m0?ooo`H0V@00O@3oool100000040oooo000K0?ooo`030000
003oool0oooo07l0oooo1`2I001j0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0PP3o
ool709T007L0oooo0@0000010?ooo`006`3oool2000008H0oooo1P2I001d0?ooo`8000000@3oool0
01/0oooo00<000000?ooo`3oool0R03oool609T00780oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`2:0?ooo`H0V@00L03oool100000040oooo000K0?ooo`030000003oool0oooo08d0oooo
1P2I001]0?ooo`4000000@3oool001/0oooo0P00002@0?ooo`H0V@00JP3oool200000040oooo000K
0?ooo`030000003oool0oooo0980oooo1P2I001X0?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0U03oool709T006D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`2G0?ooo`L0
V@00HP3oool100000040oooo000K0?ooo`800000V`3oool609T005l0oooo0P0000010?ooo`00203o
ool2000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000003oool0oooo09d0oooo
1P2I001M0?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo09l0oooo1P2I001K0?ooo`4000000@3oool000L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:80
oooo1P2I001H0?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`030?ooo`<000000`3ooooh000000@0oooo0P0000010?ooo`001`3oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2W0?oo
o`H0V@00D`3oool100000040oooo00070?ooo`040000003oool0oooo000000L0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0:T0oooo1P2I001A0?ooo`4000000@3oool0
00P0oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`2/0?ooo`H0V@00CP3oool10000
0040oooo000K0?ooo`800000[`3oool609T004/0oooo0P0000010?ooo`006`3oool00`000000oooo
0?ooo`2a0?ooo`H0V@00B@3oool100000040oooo000K0?ooo`030000003oool0oooo0;<0oooo1P2I
00170?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0]P3oool609T004@0oooo0@000001
0?ooo`006`3oool200000;T0oooo1P2I00110?ooo`8000000@3oool001/0oooo00<000000?ooo`3o
ool0^`3oool609T003l0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`2m0?ooo`H0V@00
?@3oool100000040oooo000K0?ooo`030000003oool0oooo0<00oooo1P2I000j0?ooo`4000000@3o
ool001/0oooo0P0000330?ooo`H0V@00=`3oool200000040oooo000K0?ooo`030000003oool0oooo
0<D0oooo1@2I000f0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0a`3oool609T003<0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`390?ooo`H0V@00<@3oool100000040oooo
000K0?ooo`800000c@3oool509T002h0oooo0P0000010?ooo`000P3oool2000000@0oooo00@00000
0?ooo`3oool0oooo1@0000020?ooo`<000001@3oool00`000000oooo0?ooo`3>0?ooo`D0V@00;@3o
ool100000040oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0d03oool609T002X0
oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3B0?ooo`L0V@009`3oool100000040
oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`<00000e@3oool709T002<0oooo0P0000010?ooo`0000D0oooo0000003oool0
oooo000000070?ooo`060000003oool0oooo0?ooo`000000oooo100000050?ooo`030000003oool0
oooo0=P0oooo1P2I000R0?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo0?ooo`3K0?ooo`H0V@00
7`3oool100000040oooo00020?ooo`8000002@3oool300000080oooo1@0000040?ooo`030000003o
ool0oooo0=d0oooo1P2I000M0?ooo`4000000@3oool001/0oooo0P00003Q0?ooo`H0V@006@3oool2
00000040oooo000K0?ooo`030000003oool0oooo0>80oooo1P2I000H0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0i@3oool609T001D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`3W0?ooo`H0V@004`3oool100000040oooo000K0?ooo`800000j`3oool609T000l0oooo0P00
00010?ooo`006`3oool00`000000oooo0?ooo`3/0?ooo`H0V@003P3oool100000040oooo000K0?oo
o`030000003oool0oooo0>l0oooo1P2I000;0?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool0l@3oool609T000T0oooo0@0000010?ooo`006`3oool200000?D0oooo1P2I00050?ooo`800000
0@3oool001/0oooo00<000000?ooo`3oool0mP3oool509T000D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`3i0?ooo`80V@001@3oool100000040oooo000K0?ooo`030000003oool0oooo
0?l0oooo0@3oool100000040oooo000K0?ooo`800000o`3oool10?ooo`8000000@3oool000P0oooo
0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0?l0oooo
0@3oool100000040oooo00070?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo00070?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`40
oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool300000?l0
oooo0P0000010?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool0
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0o`3oool10?oo
o`4000000@3oool000P0oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`3o0?ooo`40
oooo0@0000010?ooo`006`3oool200000?l0oooo0@3oool200000040oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool1
00000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`80
0000o`3oool10?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo0P00003o0?ooo`40oooo0P0000010?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@00
00010?ooo`006`3oool200000?l0oooo0@3oool200000040oooo00020?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool0o`3oool10?oo
o`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo0@3o
ool100000040oooo00001@3oool000000?ooo`3oool0000000/0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo0000
1@3oool000000?ooo`3oool0000000T0oooo0P0000060?ooo`030000003oool0oooo0080oooo0`00
003o0?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`0000002`3oool00`000000oooo0000
0003000000D0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool000050?ooo`000000
oooo0?ooo`0000001`3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000
oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`000P3oool2000000T0oooo0`0000020?ooo`D00000
103oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool200000?l0oooo0@3o
ool200000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?oo
o`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?ooo`030000003oool0oooo0?l0
oooo0@3oool100000040oooo000K0?ooo`800000o`3oool10?ooo`8000000@3oool001/0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool001/0
oooo0P00003o0?ooo`40oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool200000?l0oooo0@3oool20000
0040oooo00080?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000000
oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool100000040oooo00070?ooo`040000
003oool0oooo000000L0oooo1@0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00
1`3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000D0ooooo`0000050000
0040oooo00070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`000000o`3oool;0?oo
o`001`3oool010000000oooo0?ooo`0000090?ooo`800000o`3oool;0?ooo`00203oool2000000/0
oooo00<000000?ooo`3oool0o`3oool90?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.36219, -0.0305647, \
0.0405086, 0.00249694}},
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],

Cell["\<\
Current is a possible value for the CalculationBasis option to \
EquityTargetPayment.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["Current", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["Current", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["Current", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],

Cell["\<\
Original is a possible value for the CalculationBasis option to \
EquityTargetPayment.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["Original", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["Original", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["Original", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],

Cell["\<\
$EquityFindRootStart seeds a FindRoot function that is used in the \
EquityTargetPayment calculation. Since there may be multiple solutions to the \
EquityTargetPayment problem you may need to experiment with changing the \
value of $EquityFindRootStart to obtain the desired solution.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["$EquityFindRootStart", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["$EquityFindRootStart", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],

Cell[BoxData[
    RowBox[{"{", "ReadProtected", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["$EquityFindRootStart", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],

Cell[TextData[{
  "This is the default value for ",
  StyleBox["$EquityFindRootStart", "MR"],
  StyleBox[".", "Text"]
}], "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{

Cell[BoxData["$EquityFindRootStart"], "Input",
  CellLabel->"In[12]:=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[BoxData["20"], "Output",
  CellLabel->"Out[12]=",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell["Error Checking", "Section",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "The behavior of the functions in the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package is governed by two variables ",
  StyleBox["$ErrorChecking", "MR"],
  " and ",
  StyleBox["$StrongErrorChecking", "MR"],
  "."
}], "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["\<\
$ErrorChecking is a variable that determines whether some of the \
functions in this package check their arguments for reasonable numerical \
values. The default value of False allows results to be obtained without \
certain error messages being generated (some error messages will be generated \
independent of the value of this variable). However, this permits \
unreasonable values to be supplied to the arguments of these functions \
without warning. If you want the functions only to accept permissible \
numerical values, then $ErrorChecking should be set to True. Note that if the \
variable $StrongErrorChecking is set to True, it will override the setting of \
$ErrorChecking.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["$ErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["$ErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Protected", ",", "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["$ErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["\<\
$StrongErrorChecking is a variable that determines whether some of \
the functions in this package check their arguments for correct numerical \
values. If correct numerical values are not supplied then the function \
returns unevaluated. The default value of False allows analytic results to be \
obtained for those functions that can supply them. However, this permits \
unreasonable values to be supplied to the arguments of these functions. If \
you want the functions only to accept permissible numerical values, then \
$StrongErrorChecking should be set to True.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["$StrongErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["$StrongErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Protected", ",", "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["$StrongErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "The values for ",
  StyleBox["$ErrorChecking", "MR"],
  " and ",
  StyleBox["$StrongErrorChecking", "MR"],
  " can be changed with the function ",
  StyleBox["SetErrorChecking", "MR"],
  "."
}], "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["\<\
SetErrorChecking[ErrorCheckingValue, StrongErrorCheckingValue] sets \
the values of the two variables $ErrorChecking and $StrongErrorChecking to \
the values ErrorCheckingValue and StrongErrorCheckingValue respectively. \
ErrorCheckingValue and StrongErrorCheckingValue can only have the values True \
or False. Executing SetErrorChecking[] will return a list of the current \
values of $ErrorChecking and $StrongErrorChecking.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["SetErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["SetErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["SetErrorChecking", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Here are the default values  for ",
  StyleBox["$ErrorChecking", "MR"],
  " and ",
  StyleBox["$StrongErrorChecking", "MR"],
  ". "
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetErrorChecking", "[", "]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"False", ",", "False"}], "}"}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "The difference between  ",
  StyleBox["$ErrorChecking", "MR"],
  " and ",
  StyleBox["$StrongErrorChecking", "MR"],
  " is that ",
  StyleBox["$ErrorChecking", "MR"],
  " enables error checking that determine whether the values supplied to the \
arguments of a function are valid numerical inputs; however, it does not \
suppress the calculation in those cases where the inputs are not valid. In \
contrast ",
  StyleBox["$StrongErrorChecking", "MR"],
  " causes the calculation to return unevaluated in the cases where incorrect \
numerical inputs are supplied. Note that a nonnumeric variable is by default \
not considered to be valid input and will therefore cause error messages to \
be returned when ",
  StyleBox["$ErrorChecking", "MR"],
  " or ",
  StyleBox["$StrongErrorChecking", "MR"],
  " are set to ",
  StyleBox["True", "MR"],
  ". The prime advantage to setting ",
  StyleBox["$StrongErrorChecking", "MR"],
  " to ",
  StyleBox["False", "MR"],
  " is that this allows analytical results to be returned when they are \
available."
}], "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Here are examples of the different behaviors using the function ",
  StyleBox["Payment", "MR"],
  "."
}], "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["\<\
Payment[{HomeCost, PercentageDownPayment}, InterestRate, Years] \
uses the home cost and the percentage down payment as inputs (and calculates \
the loan amount from HomeCost(1-PercentageDownPayment). 

Payment[LoanAmount, InterestRate, Years] gives the payments (for principal \
and interest) on a loan of size LoanAmount at an interest rate of \
InterestRate (expressed as a percentage) amortized over a number of years \
given by Years. The number of payments per year is given by $PaymentsPerYear. \


Payment[{HomeCost, PercentageDownPayment}, {{InterestRate1, \
Payments1},{InterestRate2, Payments2},...,{InterestRateM, PaymentsM}}, Years, \
PaymentNumber] calculates the payment for a variable rate loan with interest \
rate InterestRate1 for a number of payments given by Payments1 followed by \
InterestRate2 for a number of payments given by Payments2, and so on. Note \
that PaymentNumber must be given. If PaymentNumber is greater than \
Payments1+Payments2+...+PaymentsM then the interest rate is assumed to be \
InterestRateM for that payment. 

Payment[LoanAmount, {{InterestRate1, Payments1},{InterestRate2, \
Payments2},...,{InterestRateM, PaymentsM}}, Years, PaymentNumber] is also a \
valid input. If PaymentNumber is not numerical then an analytical result will \
be returned (if $StrongErrorChecking is not True) that assumes that \
PaymentNumber is greater than Payments1+Payments2+...+Payments(M-1).\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Usage message for ",
  StyleBox["Payment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Default options for ",
  StyleBox["Payment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      "Locked", ",", "NumericFunction", ",", "Protected", ",", 
        "ReadProtected"}], "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Attributes for ",
  StyleBox["Payment", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "With the default settings for ",
  StyleBox["$ErrorChecking", "MR"],
  " and ",
  StyleBox["$StrongErrorChecking", "MR"],
  " analytical results are returned without warning messages."
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"h", ",", " ", "p"}], "}"}], ",", " ", "\[Rho]", ",", "y"}],
       "]"}]], "Input",
  CellLabel->"In[5]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    FractionBox[
      RowBox[{"h", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            FractionBox["p", "100"]}], ")"}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"12", "+", 
              FractionBox["\[Rho]", "100"]}], ")"}], 
          RowBox[{"12", " ", "y"}]], " ", "\[Rho]"}], 
      RowBox[{"1200", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["12", 
                RowBox[{"12", " ", "y"}]]}], "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"12", "+", 
                  FractionBox["\[Rho]", "100"]}], ")"}], 
              RowBox[{"12", " ", "y"}]]}], ")"}]}]]], "Output",
  CellLabel->"Out[5]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "If you want the expression with the number of payments per year rendered \
as a variable you can use the following form (this doesn't change the global \
value of ",
  StyleBox["$PaymentsPerYear", "MR"],
  ")."
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Block", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"$PaymentsPerYear", "=", "\[Psi]"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Payment", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"h", ",", " ", "p"}], "}"}], ",", " ", "\[Rho]", ",", 
            "y"}], "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[6]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    FractionBox[
      RowBox[{"h", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            FractionBox["p", "100"]}], ")"}], " ", "\[Rho]", " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FractionBox["\[Rho]", "100"], "+", "\[Psi]"}], ")"}], 
          RowBox[{"y", " ", "\[Psi]"}]]}], 
      RowBox[{"100", " ", "\[Psi]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["\[Psi]", 
                RowBox[{"y", " ", "\[Psi]"}]]}], "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FractionBox["\[Rho]", "100"], "+", "\[Psi]"}], ")"}], 
              RowBox[{"y", " ", "\[Psi]"}]]}], ")"}]}]]], "Output",
  CellLabel->"Out[6]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "With ",
  StyleBox["$ErrorChecking", "MR"],
  " set to ",
  StyleBox["True", "MR"],
  " the analytical result is returned but a warning is issued"
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetErrorChecking", "[", 
      RowBox[{"True", ",", "False"}], "]"}]], "Input",
  CellLabel->"In[7]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]], "Output",
  CellLabel->"Out[7]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"k", ",", " ", "p"}], "}"}], ",", " ", "\[Rho]", ",", "y"}],
       "]"}]], "Input",
  CellLabel->"In[8]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[8]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[8]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    FractionBox[
      RowBox[{"k", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            FractionBox["p", "100"]}], ")"}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"12", "+", 
              FractionBox["\[Rho]", "100"]}], ")"}], 
          RowBox[{"12", " ", "y"}]], " ", "\[Rho]"}], 
      RowBox[{"1200", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["12", 
                RowBox[{"12", " ", "y"}]]}], "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"12", "+", 
                  FractionBox["\[Rho]", "100"]}], ")"}], 
              RowBox[{"12", " ", "y"}]]}], ")"}]}]]], "Output",
  CellLabel->"Out[8]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "This is useful when some or all of the arguments are numerical (the ",
  StyleBox["-100000", "MR"],
  " is not a valid input and the result consequently is nonsense)"
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", "100000"}], ",", " ", "5"}], "}"}], ",", " ", "7.5", 
        ",", "30"}], "]"}]], "Input",
  CellLabel->"In[9]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[9]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[9]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"-", "664.253783125141879093440523`13.0716"}]], "Output",
  CellLabel->"Out[9]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "When ",
  StyleBox["$StrongErrorChecking", "MR"],
  " is set to ",
  StyleBox["True", "MR"],
  " the function is returned unevaluated in situations like this. The value \
of ",
  StyleBox["$StrongErrorChecking", "MR"],
  " overrides that of ",
  StyleBox["$ErrorChecking", "MR"],
  "."
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetErrorChecking", "[", 
      RowBox[{"False", ",", "True"}], "]"}]], "Input",
  CellLabel->"In[10]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"False", ",", "True"}], "}"}]], "Output",
  CellLabel->"Out[10]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", "100000"}], ",", " ", "5"}], "}"}], ",", " ", "7.5", 
        ",", "30"}], "]"}]], "Input",
  CellLabel->"In[11]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[11]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", "100000"}], ",", "5"}], "}"}], ",", "7.5`", ",", 
        "30"}], "]"}]], "Output",
  CellLabel->"Out[11]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell["This is also true for purely analytical results", "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"h", ",", " ", "p"}], "}"}], ",", " ", "\[Rho]", ",", "y"}],
       "]"}]], "Input",
  CellLabel->"In[12]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[12]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"Payment", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"h", ",", "p"}], "}"}], ",", "\[Rho]", ",", "y"}], 
      "]"}]], "Output",
  CellLabel->"Out[12]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell["Reset the defaults.", "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"ResetLoanFunctionsDefaults", "[", "]"}]], "Input",
  CellLabel->"In[13]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["\<\
The error checking settings are returned to their default values.\
\
\>", "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetErrorChecking", "[", "]"}]], "Input",
  CellLabel->"In[14]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"False", ",", "False"}], "}"}]], "Output",
  CellLabel->"Out[14]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "The error checking settings have an effect on whether or not plots are \
generated for certain functions. This is because, if ",
  StyleBox["$StrongErrorChecking", "MR"],
  " set to ",
  StyleBox["True", "MR"],
  " then numerical values will not be returned in certain cases."
}], "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["\<\
To illustrate this assume a variable interest rate loan that starts \
at 6% and, for five years, changes each year by a random amount between \
\[PlusMinus]0.5%.\
\>", "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell["Here is the interest rate table for the loan.", "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"interestRateTable", "=", 
      RowBox[{
        RowBox[{"NestList", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"#", " ", "+", 
                RowBox[{"Random", "[", 
                  RowBox[{"Real", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"-", "1"}], "/", "2"}], ",", 
                        RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}], "&"}], 
            ",", "6", ",", "4"}], "]"}], "/.", 
        RowBox[{
          RowBox[{"z_", "?", "NumberQ"}], "\[RuleDelayed]", 
          RowBox[{"{", 
            RowBox[{"z", ",", "12"}], "}"}]}]}]}]], "Input",
  CellLabel->"In[15]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"6", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.2243898666791155`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.434549165316947`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.880764457388641`", ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6.579645248410214`", ",", "12"}], "}"}]}], "}"}]], "Output",\

  CellLabel->"Out[15]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell["\<\
Here is a plot of the payment for the first 10 years according to \
this interest rate table.\
\>", "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Payment", "[", 
            RowBox[{
            "100000", ",", " ", "interestRateTable", ",", " ", "30", ",", 
              "\[Mu]"}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"\[Mu]", ",", "0", ",", "120"}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[16]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00793651 -8.64874 0.014137 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11621 -18 -4.5 ]
[-0.0125 .11621 0 4.5 ]
[-0.0125 .25758 -18 -4.5 ]
[-0.0125 .25758 0 4.5 ]
[-0.0125 .39895 -18 -4.5 ]
[-0.0125 .39895 0 4.5 ]
[-0.0125 .54032 -18 -4.5 ]
[-0.0125 .54032 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(20)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(40)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(60)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(80)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(100)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(120)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11621 m
.00625 .11621 L
s
[(620)] -0.0125 .11621 1 0 Mshowa
0 .25758 m
.00625 .25758 L
s
[(630)] -0.0125 .25758 1 0 Mshowa
0 .39895 m
.00625 .39895 L
s
[(640)] -0.0125 .39895 1 0 Mshowa
0 .54032 m
.00625 .54032 L
s
[(650)] -0.0125 .54032 1 0 Mshowa
.125 Mabswid
0 .14448 m
.00375 .14448 L
s
0 .17276 m
.00375 .17276 L
s
0 .20103 m
.00375 .20103 L
s
0 .22931 m
.00375 .22931 L
s
0 .28585 m
.00375 .28585 L
s
0 .31413 m
.00375 .31413 L
s
0 .3424 m
.00375 .3424 L
s
0 .37068 m
.00375 .37068 L
s
0 .42722 m
.00375 .42722 L
s
0 .4555 m
.00375 .4555 L
s
0 .48377 m
.00375 .48377 L
s
0 .51205 m
.00375 .51205 L
s
0 .08794 m
.00375 .08794 L
s
0 .05966 m
.00375 .05966 L
s
0 .03139 m
.00375 .03139 L
s
0 .00311 m
.00375 .00311 L
s
0 .56859 m
.00375 .56859 L
s
0 .59687 m
.00375 .59687 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11621 m
1 .11621 L
s
.99375 .25758 m
1 .25758 L
s
.99375 .39895 m
1 .39895 L
s
.99375 .54032 m
1 .54032 L
s
.125 Mabswid
.99625 .14448 m
1 .14448 L
s
.99625 .17276 m
1 .17276 L
s
.99625 .20103 m
1 .20103 L
s
.99625 .22931 m
1 .22931 L
s
.99625 .28585 m
1 .28585 L
s
.99625 .31413 m
1 .31413 L
s
.99625 .3424 m
1 .3424 L
s
.99625 .37068 m
1 .37068 L
s
.99625 .42722 m
1 .42722 L
s
.99625 .4555 m
1 .4555 L
s
.99625 .48377 m
1 .48377 L
s
.99625 .51205 m
1 .51205 L
s
.99625 .08794 m
1 .08794 L
s
.99625 .05966 m
1 .05966 L
s
.99625 .03139 m
1 .03139 L
s
.99625 .00311 m
1 .00311 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59687 m
1 .59687 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
2 Mabswid
.11981 0 m
.11999 .02769 L
.12125 .02769 L
.12196 .02769 L
.12261 .02769 L
.12387 .02769 L
.12507 .02769 L
.12627 .02769 L
.12736 .02769 L
.12861 .02769 L
.1298 .02769 L
.1309 .02769 L
.13191 .02769 L
.13302 .02769 L
.13419 .02769 L
.13538 .02769 L
.13665 .02769 L
.13785 .02769 L
.13894 .02769 L
.14022 .02769 L
.14095 .02769 L
.14162 .02769 L
.14285 .02769 L
.14415 .02769 L
.14529 .02769 L
.14653 .02769 L
.14783 .02769 L
.14904 .02769 L
.15018 .02769 L
.15121 .02769 L
.1524 .02769 L
.15352 .02769 L
.15475 .02769 L
.15604 .02769 L
.15715 .02769 L
.15837 .02769 L
.15968 .02769 L
.16041 .02769 L
.16108 .02769 L
.16239 .02769 L
.16362 .02769 L
.16476 .02769 L
.16582 .02769 L
.16705 .02769 L
.16816 .02769 L
.16922 .02769 L
.17018 .02769 L
.17125 .02769 L
.17237 .02769 L
.17351 .02769 L
Mistroke
.17472 .02769 L
.17587 .02769 L
.17692 .02769 L
.17814 .02769 L
.17884 .02769 L
.17948 .02769 L
.18065 .02769 L
.1819 .02769 L
.18304 .02769 L
.18429 .02769 L
.18551 .02769 L
.18681 .02769 L
.18803 .02769 L
.18913 .02769 L
.19025 .02769 L
.1913 .02769 L
.19253 .02769 L
.19383 .02769 L
.19494 .02769 L
.19615 .02769 L
.19747 .02769 L
.1982 .02769 L
.19887 .02769 L
.20018 .02769 L
.20141 .02769 L
.20246 .02769 L
.20362 .02769 L
.20482 .02769 L
.20596 .02769 L
.20702 .02769 L
.20799 .02769 L
.20905 .02769 L
.21017 .02769 L
.21131 .02769 L
.21253 .02769 L
.21368 .02769 L
.21472 .21316 L
.21595 .21316 L
.21664 .21316 L
.21728 .21316 L
.21846 .21316 L
.21971 .21316 L
.22091 .21316 L
.22223 .21316 L
.22339 .21316 L
.22463 .21316 L
.22585 .21316 L
.22696 .21316 L
.22808 .21316 L
.22913 .21316 L
Mistroke
.23036 .21316 L
.23166 .21316 L
.23277 .21316 L
.23399 .21316 L
.23531 .21316 L
.23604 .21316 L
.23671 .21316 L
.23802 .21316 L
.23925 .21316 L
.24031 .21316 L
.24146 .21316 L
.24268 .21316 L
.24381 .21316 L
.24487 .21316 L
.24584 .21316 L
.2469 .21316 L
.24803 .21316 L
.24917 .21316 L
.25039 .21316 L
.25144 .21316 L
.25258 .21316 L
.25328 .21316 L
.25392 .21316 L
.25519 .21316 L
.25634 .21316 L
.25756 .21316 L
.25877 .21316 L
.26009 .21316 L
.26134 .21316 L
.2625 .21316 L
.26364 .21316 L
.26468 .21316 L
.26588 .21316 L
.26701 .21316 L
.26824 .21316 L
.26955 .21316 L
.27066 .21316 L
.27188 .21316 L
.2732 .21316 L
.27394 .21316 L
.27461 .21316 L
.27591 .21316 L
.27715 .21316 L
.2782 .21316 L
.27937 .21316 L
.28058 .21316 L
.28172 .21316 L
.28278 .21316 L
.28375 .21316 L
.28487 .21316 L
Mistroke
.28593 .21316 L
.28708 .21316 L
.2883 .21316 L
.28945 .21316 L
.29049 .21316 L
.29172 .21316 L
.29241 .21316 L
.29305 .21316 L
.29423 .21316 L
.29547 .21316 L
.29669 .21316 L
.29737 .21316 L
.29801 .21316 L
.29916 .21316 L
.30042 .21316 L
.30155 .21316 L
.30261 .21316 L
.30373 .21316 L
.30494 .21316 L
.30617 .21316 L
.30687 .21316 L
.30752 .21316 L
.30883 .21316 L
.30957 .60332 L
.31024 .60332 L
.31144 .60332 L
.31274 .60332 L
.31396 .60332 L
.3151 .60332 L
.31615 .60332 L
.31729 .60332 L
.31836 .60332 L
.31933 .60332 L
.32048 .60332 L
.32173 .60332 L
.32291 .60332 L
.324 .60332 L
.32513 .60332 L
.32635 .60332 L
.3275 .60332 L
.32856 .60332 L
.32981 .60332 L
.33112 .60332 L
.33222 .60332 L
.33343 .60332 L
.33463 .60332 L
.33576 .60332 L
.33694 .60332 L
.33824 .60332 L
.33955 .60332 L
Mistroke
.34028 .60332 L
.34095 .60332 L
.34218 .60332 L
.34347 .60332 L
.3446 .60332 L
.34582 .60332 L
.34696 .60332 L
.34801 .60332 L
.34923 .60332 L
.34992 .60332 L
.35056 .60332 L
.35172 .60332 L
.35297 .60332 L
.35428 .60332 L
.3555 .60332 L
.35625 .60332 L
.35696 .60332 L
.35759 .60332 L
.35829 .60332 L
.35896 .60332 L
.3597 .60332 L
.36048 .60332 L
.36121 .60332 L
.36251 .60332 L
.36324 .60332 L
.36392 .60332 L
.36512 .60332 L
.36623 .60332 L
.36746 .60332 L
.36877 .60332 L
.36943 .60332 L
.37015 .60332 L
.37145 .60332 L
.37272 .60332 L
.37389 .60332 L
.37514 .60332 L
.37632 .60332 L
.37739 .60332 L
.37855 .60332 L
.37981 .60332 L
.38051 .60332 L
.38115 .60332 L
.38239 .60332 L
.38356 .60332 L
.38466 .60332 L
.38584 .60332 L
.38695 .60332 L
.38797 .60332 L
.38911 .60332 L
.39019 .60332 L
Mistroke
.39135 .60332 L
.39262 .60332 L
.39392 .60332 L
.39458 .60332 L
.3953 .60332 L
.39658 .60332 L
.39778 .60332 L
.39898 .60332 L
.40007 .60332 L
.40127 .60332 L
.40253 .60332 L
.40381 .60332 L
.40453 .60332 L
.40518 .34545 L
.40645 .34545 L
.40765 .34545 L
.40896 .34545 L
.40961 .34545 L
.41034 .34545 L
.41112 .34545 L
.41185 .34545 L
.41253 .34545 L
.41325 .34545 L
.41394 .34545 L
.41459 .34545 L
.4158 .34545 L
.4171 .34545 L
.41783 .34545 L
.41851 .34545 L
.41974 .34545 L
.42088 .34545 L
.42208 .34545 L
.42338 .34545 L
.42407 .34545 L
.42482 .34545 L
.42548 .34545 L
.42618 .34545 L
.4275 .34545 L
.42872 .34545 L
.42939 .34545 L
.43012 .34545 L
.43144 .34545 L
.43224 .34545 L
.433 .34545 L
.43368 .34545 L
.43443 .34545 L
.43508 .34545 L
.43579 .34545 L
.43707 .34545 L
.43832 .34545 L
Mistroke
.43947 .34545 L
.44072 .34545 L
.44143 .34545 L
.44209 .34545 L
.44278 .34545 L
.44352 .34545 L
.44416 .34545 L
.44485 .34545 L
.44609 .34545 L
.44723 .34545 L
.44846 .34545 L
.44916 .34545 L
.44982 .34545 L
.451 .34545 L
.45209 .34545 L
.45328 .34545 L
.45453 .34545 L
.45577 .34545 L
.45646 .34545 L
.4571 .34545 L
.45828 .34545 L
.45953 .34545 L
.46064 .34545 L
.46169 .34545 L
.46283 .34545 L
.46407 .34545 L
.46537 .34545 L
.46611 .34545 L
.4668 .34545 L
.46805 .34545 L
.46875 .34545 L
.46939 .34545 L
.47059 .34545 L
.4719 .34545 L
.47313 .34545 L
.47426 .34545 L
.47532 .34545 L
.47646 .34545 L
.47754 .34545 L
.47852 .34545 L
.47967 .34545 L
.48092 .34545 L
.4821 .34545 L
.48319 .34545 L
.48431 .34545 L
.48536 .34545 L
.48652 .34545 L
.48776 .34545 L
.489 .34545 L
.4903 .34545 L
Mistroke
.49141 .34545 L
.49262 .34545 L
.49394 .34545 L
.49516 .34545 L
.4958 .34545 L
.4965 .34545 L
.49723 .34545 L
.49791 .34545 L
.49917 .34545 L
.50032 .34545 L
.50096 .34545 L
.50165 .34545 L
.50291 .34545 L
.50414 .34545 L
.50526 .34545 L
.50646 .34545 L
.50776 .34545 L
.50896 .34545 L
.51007 .34545 L
.51113 .34545 L
.51225 .34545 L
.51356 .34545 L
.51475 .34545 L
.51541 .34545 L
.51613 .34545 L
.51743 .34545 L
.51864 .34545 L
.51993 .34545 L
.52104 .34545 L
.52225 .34545 L
.52292 .34545 L
.52365 .34545 L
.52434 .34545 L
.52497 .34545 L
.52572 .34545 L
.52651 .34545 L
.52724 .34545 L
.52791 .34545 L
.52859 .34545 L
.52934 .34545 L
.52999 .34545 L
.53069 .34545 L
.53189 .34545 L
.53321 .34545 L
.53451 .34545 L
.53572 .34545 L
.53634 .34545 L
.53704 .34545 L
.53776 .34545 L
.53845 .34545 L
Mistroke
.53969 .34545 L
.54083 .34545 L
.54209 .34545 L
.54341 .34545 L
.54452 .34545 L
.54571 .34545 L
.54674 .34545 L
.54785 .34545 L
.54916 .34545 L
.5504 .34545 L
.5516 .34545 L
.55271 .34545 L
.55392 .34545 L
.55521 .34545 L
.55643 .34545 L
.55755 .34545 L
.55885 .34545 L
.55959 .34545 L
.56028 .34545 L
.56153 .34545 L
.56223 .34545 L
.56287 .34545 L
.56355 .34545 L
.56426 .34545 L
.56553 .34545 L
.56624 .34545 L
.56691 .34545 L
.56763 .34545 L
.56841 .34545 L
.56908 .34545 L
.56981 .34545 L
.5705 .34545 L
.57114 .34545 L
.57235 .34545 L
.57363 .34545 L
.57477 .34545 L
.57602 .34545 L
.57732 .34545 L
.57853 .34545 L
.57965 .34545 L
.5807 .34545 L
.58192 .34545 L
.58302 .34545 L
.58425 .34545 L
.58555 .34545 L
.58666 .34545 L
.58787 .34545 L
.58919 .34545 L
.58992 .34545 L
.59059 .34545 L
Mistroke
.5919 .34545 L
.59313 .34545 L
.59534 .34545 L
.59654 .34545 L
.59768 .34545 L
.59864 .34545 L
.59968 .34545 L
.60083 .34545 L
.60189 .34545 L
.60304 .34545 L
.60411 .34545 L
.60528 .34545 L
.60653 .34545 L
.60785 .34545 L
.60909 .34545 L
.61021 .34545 L
.61142 .34545 L
.61265 .34545 L
.61377 .34545 L
.61507 .34545 L
.6163 .34545 L
.61744 .34545 L
.61849 .34545 L
.61964 .34545 L
.62087 .34545 L
.62157 .34545 L
.62222 .34545 L
.62293 .34545 L
.62368 .34545 L
.62633 .34545 L
.62747 .34545 L
.62868 .34545 L
.62939 .34545 L
.63002 .34545 L
.63127 .34545 L
.63258 .34545 L
.63329 .34545 L
.63396 .34545 L
.63514 .34545 L
.63645 .34545 L
.64208 .34545 L
.65231 .34545 L
.66214 .34545 L
.6725 .34545 L
.68134 .34545 L
.68259 .34545 L
.68376 .34545 L
.68441 .34545 L
.68512 .34545 L
.68635 .34545 L
Mistroke
.68753 .34545 L
.68877 .34545 L
.68984 .34545 L
.69101 .34545 L
.6923 .34545 L
.69351 .34545 L
.69482 .34545 L
.69556 .34545 L
.69623 .34545 L
.69745 .34545 L
.69814 .34545 L
.69878 .34545 L
.70118 .34545 L
.71047 .34545 L
.71177 .34545 L
.71301 .34545 L
.71369 .34545 L
.71443 .34545 L
.71573 .34545 L
.71697 .34545 L
.71828 .34545 L
.7194 .34545 L
.72064 .34545 L
.72191 .34545 L
.72262 .34545 L
.72328 .34545 L
.72455 .34545 L
.72575 .34545 L
.72643 .34545 L
.72714 .34545 L
.72844 .34545 L
.72923 .34545 L
.72997 .34545 L
.73064 .34545 L
.73136 .34545 L
.7326 .34545 L
.73373 .34545 L
.73504 .34545 L
.73627 .34545 L
.73741 .34545 L
.73847 .34545 L
.73963 .34545 L
.74086 .34545 L
.74209 .34545 L
.74278 .34545 L
.74342 .34545 L
.74458 .34545 L
.74582 .34545 L
.74647 .34545 L
.74717 .34545 L
Mistroke
.74843 .34545 L
.7492 .34545 L
.74993 .34545 L
.75129 .34545 L
.76139 .34545 L
.76208 .34545 L
.76282 .34545 L
.76352 .34545 L
.76416 .34545 L
.76488 .34545 L
.76556 .34545 L
.76629 .34545 L
.76709 .34545 L
.76841 .34545 L
.76915 .34545 L
.76982 .34545 L
.77112 .34545 L
.77235 .34545 L
.77351 .34545 L
.77476 .34545 L
.77594 .34545 L
.77701 .34545 L
.77827 .34545 L
.77899 .34545 L
.77964 .34545 L
.78213 .34545 L
.78328 .34545 L
.78449 .34545 L
.78513 .34545 L
.78582 .34545 L
.78704 .34545 L
.78774 .34545 L
.78849 .34545 L
.78919 .34545 L
.78983 .34545 L
.79048 .34545 L
.79118 .34545 L
.79245 .34545 L
.79353 .34545 L
.79472 .34545 L
.79596 .34545 L
.79712 .34545 L
.7982 .34545 L
.79919 .34545 L
.80034 .34545 L
.80142 .34545 L
.80256 .34545 L
.80363 .34545 L
.80474 .34545 L
.80597 .34545 L
Mistroke
.80721 .34545 L
.80791 .34545 L
.80855 .34545 L
.80971 .34545 L
.81094 .34545 L
.81216 .34545 L
.81281 .34545 L
.8135 .34545 L
.81476 .34545 L
.81592 .34545 L
.81703 .34545 L
.81808 .34545 L
.81922 .34545 L
.82046 .34545 L
.82318 .34545 L
.82453 .34545 L
.82577 .34545 L
.8269 .34545 L
.8281 .34545 L
.82879 .34545 L
.82943 .34545 L
.83064 .34545 L
.8317 .34545 L
.83287 .34545 L
.83409 .34545 L
.83523 .34545 L
.8363 .34545 L
.83727 .34545 L
.83839 .34545 L
.83946 .34545 L
.84061 .34545 L
.84183 .34545 L
.84287 .34545 L
.84403 .34545 L
.84526 .34545 L
.84595 .34545 L
.84659 .34545 L
.84776 .34545 L
.84899 .34545 L
.85023 .34545 L
.85093 .34545 L
.85157 .34545 L
.85275 .34545 L
.854 .34545 L
.85511 .34545 L
.85616 .34545 L
.85731 .34545 L
.85854 .34545 L
.85985 .34545 L
.86059 .34545 L
Mistroke
.86127 .34545 L
.86253 .34545 L
.86323 .34545 L
.86387 .34545 L
.86508 .34545 L
.86638 .34545 L
.86874 .34545 L
.8699 .34545 L
.87115 .34545 L
.87233 .34545 L
.8734 .34545 L
.8746 .34545 L
.87574 .34545 L
.87697 .34545 L
.87767 .34545 L
.87831 .34545 L
.87929 .34545 L
.88034 .34545 L
.8815 .34545 L
.88258 .34545 L
.8838 .34545 L
.88495 .34545 L
.88599 .34545 L
.88711 .34545 L
.88836 .34545 L
.88951 .34545 L
.89208 .34545 L
.8967 .34545 L
.89913 .34545 L
.8998 .34545 L
.90051 .34545 L
.9018 .34545 L
.90249 .34545 L
.90325 .34545 L
.90396 .34545 L
.90462 .34545 L
.90586 .34545 L
.90649 .34545 L
.90719 .34545 L
.90782 .34545 L
.90852 .34545 L
.90924 .34545 L
.90992 .34545 L
.91113 .34545 L
.91242 .34545 L
.91315 .34545 L
.91395 .34545 L
.91469 .34545 L
.91538 .34545 L
.91669 .34545 L
Mistroke
.91735 .34545 L
.91807 .34545 L
.9283 .34545 L
.94773 .34545 L
.95332 .34545 L
.95401 .34545 L
.95466 .34545 L
.9554 .34545 L
.95608 .34545 L
.95731 .34545 L
.958 .34545 L
.95864 .34545 L
.95974 .34545 L
.96096 .34545 L
.96222 .34545 L
.96341 .34545 L
.96472 .34545 L
.96592 .34545 L
.96658 .34545 L
.9673 .34545 L
.96861 .34545 L
.96951 .34545 L
.97036 .34545 L
.97129 .34545 L
.97229 .34545 L
.97328 .34545 L
.97432 .34545 L
.97522 .34545 L
.97619 .34545 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`006P3oool2000002<0oooo1@0000030?ooo`8000008P3oool3000000<0
oooo0P00000P0?ooo`<00000103oool200000240oooo0`0000040?ooo`8000007P3oool3000000@0
oooo0P0000040?ooo`8000006`3oool300000080oooo1@0000030?ooo`8000000`3oool001T0oooo
00@000000?ooo`3oool000008`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000280oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001l0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo000I0?ooo`04
0000003oool0oooo000002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000O
0?ooo`D000000P3oool010000000oooo0?ooo`00000N0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00000O0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`00000N0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`006@3oool010000000oooo0?ooo`00000U0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`3oool000007P3oool4000000<0oooo00@000000?ooo`3oool00000
803oool3000000<0oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000000P3oool100000040oooo0@3oool001T0oooo00@00000
0?ooo`3oool000008P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000803oool00`000000oooo000000030?ooo`040000003oool0oooo000001h0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`00000O0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000K0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`006@3oool010000000oooo0?ooo`00
000R0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000Q0?ooo`80
00000`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000007`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
7@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000J0?oo
o`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool001X0oooo0P00000T0?ooo`<00000103oool2000002<0oooo00<000000?ooo`3oool00P3oool2
00000240oooo0P0000040?ooo`8000008@3oool3000000@0oooo0P00000O0?ooo`030000003oool0
oooo00<0oooo0P0000040?ooo`800000703oool00`000000oooo0?ooo`020?ooo`<00000103oool2
000000<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E
0?oooah000000P2I003X000000<0oooo000E0?ooo`800000103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P2I00050?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo0P0000030?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0
oooo0P2I000@0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo01/0oooo
0P2I003W0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo01/0oooo0P2I
003W0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo01/0oooo0P2I003W
0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo01/0oooo0P2I003W0?oo
o`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo01/0oooo6`2I003>0?ooo`03
0000003oool0oooo0040oooo000E0?ooo`800000703ooolK09T00<d0oooo0P0000030?ooo`005@3o
ool00`000000oooo0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool0
0`000000oooo0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`00
0000oooo0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000
oooo0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo
0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?oo
o`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`0d
0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool2000003D0oooo0P2I003=0?oo
o`8000000`3oool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3o
ool00@3oool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool0
0@3oool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3o
ool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool0
01D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool001D0
oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool001D0oooo
0P00000e0?ooo`80V@00c@3oool2000000<0oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I
003>0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I003>
0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I003>0?oo
o`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I003>0?ooo`03
0000003oool0oooo0040oooo0000103oool000000000000000020?ooo`D000000`3oool2000000D0
oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool000050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool0
00050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo0P00000e0?ooo`80V@00c03oool3000000<0oooo0004000000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool209T00<h0oooo00<000000?ooo`3oool00@3oool000030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool000030?ooo`000000oooo00<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool00080oooo0P0000030?ooo`<00000
103oool2000000D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool0
0@3oool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3o
ool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool0
01D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3oool001D0
oooo0P00000e0?ooo`80V@00c@3oool2000000<0oooo000E0?ooo`030000003oool0oooo03@0oooo
0P2I003>0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I
003>0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I003>
0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I003>0?oo
o`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I003>0?ooo`03
0000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo03@0oooo0P2I003>0?ooo`030000
003oool0oooo0040oooo000E0?ooo`800000=@3oool209T00<d0oooo0P0000030?ooo`005@3oool0
0`000000oooo0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`00
0000oooo0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000
oooo0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo
0?ooo`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?oo
o`0d0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`0d
0?ooo`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`0d0?oo
o`80V@00cP3oool00`000000oooo0?ooo`010?ooo`005@3oool2000003D0oooo0P2I003=0?ooo`80
00000`3oool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool0
0@3oool001D0oooo00<000000?ooo`3oool0=03oool209T00<h0oooo00<000000?ooo`3oool00@3o
ool001D0oooo00<000000?ooo`3oool0=03ooolK09T00;D0oooo00<000000?ooo`3oool00@3oool0
01D0oooo00<000000?ooo`3oool0=03ooolK09T00;D0oooo00<000000?ooo`3oool00@3oool001D0
oooo00<000000?ooo`3oool0C@3oool209T00;D0oooo00<000000?ooo`3oool00@3oool001D0oooo
00<000000?ooo`3oool0C@3oool209T00;D0oooo00<000000?ooo`3oool00@3oool001D0oooo0P00
001>0?ooo`80V@00]03oool2000000<0oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e
0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?oo
o`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`03
0000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000
003oool0oooo0040oooo0000103oool000000000000000030?ooo`<00000103oool2000000D0oooo
00<000000?ooo`3oool0C@3oool209T00;D0oooo00<000000?ooo`3oool00@3oool000070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`80V@00]@3oool00`000000oooo0?ooo`010?oo
o`0000D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`80V@00]@3oool00`000000oooo0?ooo`01
0?ooo`00100000040?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`800000CP3oool2
09T00;<0oooo0`0000030?ooo`0000<000000?ooo`3oool01`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool209T00;D0oooo00<00000
0?ooo`3oool00@3oool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0C@3oool209T00;D0oooo00<0
00000?ooo`3oool00@3oool00080oooo0P0000030?ooo`<00000103oool2000000D0oooo00<00000
0?ooo`3oool0C@3oool209T00;D0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?oo
o`3oool0C@3oool209T00;D0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3o
ool0C@3oool209T00;D0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0
C@3oool209T00;D0oooo00<000000?ooo`3oool00@3oool001D0oooo0P00001>0?ooo`80V@00]03o
ool2000000<0oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000003oool0
oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000003oool0oooo
0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000003oool0oooo0040
oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000003oool0oooo0040oooo
000E0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000003oool0oooo0040oooo000E
0?ooo`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000003oool0oooo0040oooo000E0?oo
o`030000003oool0oooo04d0oooo0P2I002e0?ooo`030000003oool0oooo0040oooo000E0?ooo`80
0000CP3oool209T00;@0oooo0P0000030?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@00
]@3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@00]@3o
ool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@00]@3oool0
0`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@00]@3oool00`00
0000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@00]@3oool00`000000
oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@00]@3oool00`000000oooo
0?ooo`010?ooo`005@3oool2000004h0oooo0P2I002d0?ooo`8000000`3oool001D0oooo00<00000
0?ooo`3oool0C@3oool209T001L0ooooV@2I00050?ooo`030000003oool0oooo0040oooo000E0?oo
o`030000003oool0oooo04d0oooo0P2I000G0?oooiT0V@001@3oool00`000000oooo0?ooo`010?oo
o`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3o
ool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000
003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03o
ool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool2
09T009`0oooo00<000000?ooo`3oool00@3oool001D0oooo0P00001>0?ooo`80V@005`3oool209T0
09/0oooo0P0000030?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0
oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo
0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I
000G0?ooo`80V@00W03oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=
0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3oool00@3oool000040?ooo`0000000000
000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool2
09T009`0oooo00<000000?ooo`3oool00@3oool000050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3oool00@3oool000060000003oool0
oooo0?ooo`000000oooo1@0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000400000080oooo
00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000040?ooo`800000CP3oool209T0
01L0oooo0P2I002J0?ooo`<000000`3oool000030000003oool0oooo00@0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04d0oooo0P2I000G0?oo
o`80V@00W03oool00`000000oooo0?ooo`010?ooo`0000<0oooo0000003oool01@3oool2000000<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T0
09`0oooo00<000000?ooo`3oool00@3oool00080oooo0P0000050?ooo`030000003oool0oooo0080
oooo0P0000050?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`000000
oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo
00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I
002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I000G
0?ooo`80V@00W03oool00`000000oooo0?ooo`010?ooo`005@3oool2000004h0oooo0P2I000G0?oo
o`80V@00V`3oool2000000<0oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80
V@00W03oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@00
5`3oool209T009`0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0C@3o
ool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0
oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`000000oooo0?ooo`010?ooo`005@3oool00`00
0000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3oool00@3oool001D0
oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040
oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`000000oooo
0?ooo`010?ooo`005@3oool2000004h0oooo0P2I000G0?ooo`80V@00V`3oool2000000<0oooo000E
0?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`000000oooo0?ooo`01
0?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?oo
o`3oool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`03
0000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00
W03oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3o
ool209T009`0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool2
09T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`800000CP3oool209T0
01L0oooo0P2I002K0?ooo`8000000`3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0
oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo
0P2I000G0?ooo`80V@00W03oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?oo
o`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3oool00@3oool001D0oooo00<00000
0?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?oo
o`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`000000oooo0?ooo`010?oo
o`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3o
ool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000
003oool0oooo0040oooo000E0?ooo`800000CP3oool209T001L0oooo0P2I002K0?ooo`8000000`3o
ool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0
oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`00
0000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0
oooo00<000000?ooo`3oool00@3oool000040?ooo`0000000000000000<0oooo0`0000040?ooo`80
00001@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3o
ool00@3oool000070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool2
09T009`0oooo00<000000?ooo`3oool00@3oool000050000003oool0oooo0?ooo`0000001@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3o
ool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo0004000000H0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000CP3oool209T001L0oooo0P2I
002J0?ooo`<000000`3oool000030000003oool0oooo00<0oooo100000030?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003o
ool0oooo0040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo00<0
00000?ooo`3oool00@3oool00080oooo0P0000020?ooo`D000000`3oool2000000D0oooo00<00000
0?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?oo
o`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`000000oooo0?ooo`010?oo
o`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3o
ool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000
003oool0oooo0040oooo000E0?ooo`800000CP3oool209T001L0oooo0P2I002K0?ooo`8000000`3o
ool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0
oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I000G0?ooo`80V@00W03oool00`00
0000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=0?ooo`80V@005`3oool209T009`0
oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0C@3oool209T001L0oooo
0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo04d0oooo0P2I
000G0?ooo`80V@00W03oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`1=
0?ooo`80V@005`3oool209T009`0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?oo
o`3oool0C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`80
0000CP3oool209T001L0oooo0P2I002K0?ooo`8000000`3oool001D0oooo00<000000?ooo`3oool0
C@3oool209T001L0oooo0P2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003o
ool0oooo04d0oooo6`2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0
oooo04d0oooo6`2I002L0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`005@3ooooo000000T0
00000`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.2001, 608.189, 0.479139, \
0.268989}},
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "A very important point is that, if you use ",
  StyleBox["Evaluate", "MR"],
  " within the plot command here the results that are returned will not be \
correct. This is because ",
  StyleBox["Evaluate", "MR"],
  " returns an analytical result but the \[Mu] in that result is assumed to \
be greater than or equal to the last payment number in the interest rate \
table."
}], "Commentary",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[TextData[{
  "Here an incorrect plot is returned because the ",
  StyleBox["Evaluate", "MR"],
  " creates a function that is valid only for \[Mu] greater than or equal to \
48."
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Evaluate", "[", 
            RowBox[{"Payment", "[", 
              RowBox[{
              "100000", ",", " ", "interestRateTable", ",", " ", "30", ",", 
                "\[Mu]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"\[Mu]", ",", "0", ",", "120"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[17]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00793651 -1.12294e+13 1.76503e+10 [
[.02381 -0.01231 -3 -9 ]
[.02381 -0.01231 3 0 ]
[.18254 -0.01231 -6 -9 ]
[.18254 -0.01231 6 0 ]
[.34127 -0.01231 -6 -9 ]
[.34127 -0.01231 6 0 ]
[.5 -0.01231 -6 -9 ]
[.5 -0.01231 6 0 ]
[.65873 -0.01231 -6 -9 ]
[.65873 -0.01231 6 0 ]
[.81746 -0.01231 -9 -9 ]
[.81746 -0.01231 9 0 ]
[.97619 -0.01231 -9 -9 ]
[.97619 -0.01231 9 0 ]
[ 0 -0.00027 -0.125 0 ]
[-0.0125 .01177 -42 -4.5 ]
[-0.0125 .01177 0 4.5 ]
[-0.0125 .10006 -42 -4.5 ]
[-0.0125 .10006 0 4.5 ]
[-0.0125 .18835 -42 -4.5 ]
[-0.0125 .18835 0 4.5 ]
[-0.0125 .27664 -42 -4.5 ]
[-0.0125 .27664 0 4.5 ]
[-0.0125 .36493 -42 -4.5 ]
[-0.0125 .36493 0 4.5 ]
[-0.0125 .45322 -42 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .54151 -42 -4.5 ]
[-0.0125 .54151 0 4.5 ]
[ 0 -0.00027 -0.125 0 ]
[ 0 .61777 .125 0 ]
[ 1 -0.00027 .125 0 ]
[ 0 -0.00027 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 -0.00027 m
.02381 .00575 L
s
[(0)] .02381 -0.01231 0 1 Mshowa
.18254 -0.00027 m
.18254 .00575 L
s
[(20)] .18254 -0.01231 0 1 Mshowa
.34127 -0.00027 m
.34127 .00575 L
s
[(40)] .34127 -0.01231 0 1 Mshowa
.5 -0.00027 m
.5 .00575 L
s
[(60)] .5 -0.01231 0 1 Mshowa
.65873 -0.00027 m
.65873 .00575 L
s
[(80)] .65873 -0.01231 0 1 Mshowa
.81746 -0.00027 m
.81746 .00575 L
s
[(100)] .81746 -0.01231 0 1 Mshowa
.97619 -0.00027 m
.97619 .00575 L
s
[(120)] .97619 -0.01231 0 1 Mshowa
.125 Mabswid
.06349 -0.00027 m
.06349 .00374 L
s
.10317 -0.00027 m
.10317 .00374 L
s
.14286 -0.00027 m
.14286 .00374 L
s
.22222 -0.00027 m
.22222 .00374 L
s
.2619 -0.00027 m
.2619 .00374 L
s
.30159 -0.00027 m
.30159 .00374 L
s
.38095 -0.00027 m
.38095 .00374 L
s
.42063 -0.00027 m
.42063 .00374 L
s
.46032 -0.00027 m
.46032 .00374 L
s
.53968 -0.00027 m
.53968 .00374 L
s
.57937 -0.00027 m
.57937 .00374 L
s
.61905 -0.00027 m
.61905 .00374 L
s
.69841 -0.00027 m
.69841 .00374 L
s
.7381 -0.00027 m
.7381 .00374 L
s
.77778 -0.00027 m
.77778 .00374 L
s
.85714 -0.00027 m
.85714 .00374 L
s
.89683 -0.00027 m
.89683 .00374 L
s
.93651 -0.00027 m
.93651 .00374 L
s
.25 Mabswid
0 -0.00027 m
1 -0.00027 L
s
0 .01177 m
.00625 .01177 L
s
[(636.216)] -0.0125 .01177 1 0 Mshowa
0 .10006 m
.00625 .10006 L
s
[(636.216)] -0.0125 .10006 1 0 Mshowa
0 .18835 m
.00625 .18835 L
s
[(636.216)] -0.0125 .18835 1 0 Mshowa
0 .27664 m
.00625 .27664 L
s
[(636.216)] -0.0125 .27664 1 0 Mshowa
0 .36493 m
.00625 .36493 L
s
[(636.216)] -0.0125 .36493 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(636.216)] -0.0125 .45322 1 0 Mshowa
0 .54151 m
.00625 .54151 L
s
[(636.216)] -0.0125 .54151 1 0 Mshowa
.125 Mabswid
0 .02983 m
.00375 .02983 L
s
0 .04789 m
.00375 .04789 L
s
0 .06394 m
.00375 .06394 L
s
0 .082 m
.00375 .082 L
s
0 .11812 m
.00375 .11812 L
s
0 .13618 m
.00375 .13618 L
s
0 .15223 m
.00375 .15223 L
s
0 .17029 m
.00375 .17029 L
s
0 .20641 m
.00375 .20641 L
s
0 .22447 m
.00375 .22447 L
s
0 .24052 m
.00375 .24052 L
s
0 .25858 m
.00375 .25858 L
s
0 .2947 m
.00375 .2947 L
s
0 .31276 m
.00375 .31276 L
s
0 .32881 m
.00375 .32881 L
s
0 .34687 m
.00375 .34687 L
s
0 .38299 m
.00375 .38299 L
s
0 .40105 m
.00375 .40105 L
s
0 .41711 m
.00375 .41711 L
s
0 .43516 m
.00375 .43516 L
s
0 .47128 m
.00375 .47128 L
s
0 .48934 m
.00375 .48934 L
s
0 .5054 m
.00375 .5054 L
s
0 .52346 m
.00375 .52346 L
s
0 .55957 m
.00375 .55957 L
s
0 .57763 m
.00375 .57763 L
s
0 .59569 m
.00375 .59569 L
s
0 .61375 m
.00375 .61375 L
s
.25 Mabswid
0 -0.00027 m
0 .61777 L
s
.02381 .61175 m
.02381 .61777 L
s
.18254 .61175 m
.18254 .61777 L
s
.34127 .61175 m
.34127 .61777 L
s
.5 .61175 m
.5 .61777 L
s
.65873 .61175 m
.65873 .61777 L
s
.81746 .61175 m
.81746 .61777 L
s
.97619 .61175 m
.97619 .61777 L
s
.125 Mabswid
.06349 .61375 m
.06349 .61777 L
s
.10317 .61375 m
.10317 .61777 L
s
.14286 .61375 m
.14286 .61777 L
s
.22222 .61375 m
.22222 .61777 L
s
.2619 .61375 m
.2619 .61777 L
s
.30159 .61375 m
.30159 .61777 L
s
.38095 .61375 m
.38095 .61777 L
s
.42063 .61375 m
.42063 .61777 L
s
.46032 .61375 m
.46032 .61777 L
s
.53968 .61375 m
.53968 .61777 L
s
.57937 .61375 m
.57937 .61777 L
s
.61905 .61375 m
.61905 .61777 L
s
.69841 .61375 m
.69841 .61777 L
s
.7381 .61375 m
.7381 .61777 L
s
.77778 .61375 m
.77778 .61777 L
s
.85714 .61375 m
.85714 .61777 L
s
.89683 .61375 m
.89683 .61777 L
s
.93651 .61375 m
.93651 .61777 L
s
.25 Mabswid
0 .61777 m
1 .61777 L
s
.99375 .01177 m
1 .01177 L
s
.99375 .10006 m
1 .10006 L
s
.99375 .18835 m
1 .18835 L
s
.99375 .27664 m
1 .27664 L
s
.99375 .36493 m
1 .36493 L
s
.99375 .45322 m
1 .45322 L
s
.99375 .54151 m
1 .54151 L
s
.125 Mabswid
.99625 .02983 m
1 .02983 L
s
.99625 .04789 m
1 .04789 L
s
.99625 .06394 m
1 .06394 L
s
.99625 .082 m
1 .082 L
s
.99625 .11812 m
1 .11812 L
s
.99625 .13618 m
1 .13618 L
s
.99625 .15223 m
1 .15223 L
s
.99625 .17029 m
1 .17029 L
s
.99625 .20641 m
1 .20641 L
s
.99625 .22447 m
1 .22447 L
s
.99625 .24052 m
1 .24052 L
s
.99625 .25858 m
1 .25858 L
s
.99625 .2947 m
1 .2947 L
s
.99625 .31276 m
1 .31276 L
s
.99625 .32881 m
1 .32881 L
s
.99625 .34687 m
1 .34687 L
s
.99625 .38299 m
1 .38299 L
s
.99625 .40105 m
1 .40105 L
s
.99625 .41711 m
1 .41711 L
s
.99625 .43516 m
1 .43516 L
s
.99625 .47128 m
1 .47128 L
s
.99625 .48934 m
1 .48934 L
s
.99625 .5054 m
1 .5054 L
s
.99625 .52346 m
1 .52346 L
s
.99625 .55957 m
1 .55957 L
s
.99625 .57763 m
1 .57763 L
s
.99625 .59569 m
1 .59569 L
s
.99625 .61375 m
1 .61375 L
s
.25 Mabswid
1 -0.00027 m
1 .61777 L
s
.6 0 0 r
2 Mabswid
.02381 .25056 m
.02499 .16628 L
.02605 .2345 L
.02721 .34888 L
.02846 .38701 L
.02961 .2646 L
.03068 .3248 L
.0317 .27865 L
.03279 .1422 L
.03395 .21444 L
.0352 .42513 L
.03638 .17029 L
.03746 .24454 L
.03873 .37095 L
.03944 .37898 L
.04011 .29069 L
.04132 .27062 L
.04262 .27464 L
.04387 .2626 L
.04519 .31678 L
.04588 .29671 L
.04664 .25457 L
.04733 .25658 L
.04797 .2947 L
.04925 .33885 L
.05041 .35691 L
.05105 .28868 L
.05175 .32881 L
.05302 .19036 L
.05414 .22848 L
.05539 .18233 L
.05669 .32881 L
.05791 .27464 L
.05905 .20441 L
.06009 .32681 L
.06124 .27464 L
.06244 .39503 L
.0631 .26862 L
.0638 .35691 L
.06509 .30072 L
.06633 .28467 L
.06748 .24052 L
.06873 .26862 L
.06944 .45523 L
.0701 .28066 L
.0708 .48734 L
.07144 .36493 L
.07217 .20842 L
.07287 .36493 L
.07404 .44319 L
Mistroke
.07528 .17832 L
.07645 .27464 L
.07751 .24654 L
.07876 .28868 L
.07947 .33885 L
.08012 .1121 L
.08131 .30072 L
.08257 .43516 L
.08327 .21644 L
.08394 .30474 L
.08519 .36895 L
.08585 .32681 L
.08654 .42513 L
.0873 .19839 L
.088 .34687 L
.08925 .19237 L
.09041 .26059 L
.09169 .27664 L
.09241 .18835 L
.09307 .27664 L
.09374 .31878 L
.09446 .28266 L
.09575 .10006 L
.09654 .38099 L
.09729 .33885 L
.09796 .27263 L
.09868 .1121 L
.09939 .27263 L
.10017 .29671 L
.10099 .38701 L
.10175 .23852 L
.10246 .42714 L
.10312 .2927 L
.10387 .28467 L
.10458 .18233 L
.10572 .35891 L
.10694 .36694 L
.1081 .2024 L
.10916 .32079 L
.11033 .29872 L
.11162 .25658 L
.11298 .2024 L
.11422 .14621 L
.11554 .41309 L
.11678 .16026 L
.1181 .27865 L
.11884 .20842 L
.11952 .15424 L
.12067 .27464 L
.12192 .30273 L
Mistroke
.12324 .24052 L
.12446 .28467 L
.1256 .27464 L
.12684 .23651 L
.12801 .42914 L
.1291 .28066 L
.13018 .22648 L
.13115 .34888 L
.13228 .27664 L
.13334 .15023 L
.1345 .19638 L
.13573 .28066 L
.13677 .28266 L
.13792 .27263 L
.13916 .08 L
.13985 .3248 L
.14048 .25256 L
.14171 .1422 L
.14288 .2646 L
.14402 .12815 L
.14525 .2947 L
.14641 .15625 L
.14747 .34888 L
.14865 .25658 L
.14994 .22246 L
.15064 .2626 L
.1513 .33283 L
.15254 .15023 L
.15377 .35891 L
.15447 .2325 L
.15511 .28467 L
.15575 .12615 L
.15645 .35691 L
.15718 .28066 L
.15786 .18835 L
.1591 .30072 L
.16024 .13217 L
.16156 .26661 L
.1628 .37296 L
.16397 .15023 L
.16502 .22447 L
.16615 .39303 L
.16738 .37095 L
.16852 .24253 L
.16956 .22648 L
.17056 .27062 L
.17162 .29671 L
.17276 .28266 L
.17383 .32881 L
.17507 .41109 L
Mistroke
.1762 .43918 L
.17745 .2024 L
.17815 .42112 L
.1788 .18635 L
.17998 .37095 L
.18123 .26862 L
.18243 .33283 L
.18374 .22848 L
.18498 .28668 L
.18614 .29872 L
.18728 .13417 L
.18831 .24855 L
.18951 .20441 L
.19063 .13819 L
.19186 .10408 L
.19316 .27664 L
.19427 .19638 L
.19549 .4773 L
.1968 .43115 L
.19754 .20441 L
.19821 .24454 L
.19952 .31276 L
.20075 .28868 L
.2018 .17832 L
.20296 .21243 L
.20417 .40908 L
.2053 .34085 L
.20629 .29069 L
.20733 .24855 L
.20847 .2325 L
.20951 .31276 L
.21065 .16427 L
.21187 .42112 L
.21302 .37898 L
.21407 .26661 L
.2153 .37497 L
.21599 .25056 L
.21663 .2947 L
.2178 .17029 L
.21905 .30072 L
.22026 .1723 L
.22158 .13016 L
.22282 .13417 L
.22398 .19036 L
.22509 .41711 L
.2263 .19839 L
.22743 .24253 L
.22848 .40105 L
.22973 .23852 L
.23106 .25056 L
Mistroke
.23217 .2646 L
.23339 .31678 L
.23469 .43115 L
.23543 .33684 L
.23609 .37296 L
.23739 .14019 L
.23861 .39704 L
.23967 .2927 L
.24083 .17631 L
.24204 .22848 L
.24317 .21644 L
.24423 .31477 L
.2452 .38901 L
.24627 .16427 L
.24739 .25858 L
.24853 .25658 L
.24975 .31076 L
.2508 .43115 L
.25195 .43316 L
.25264 .27263 L
.25329 .32881 L
.25456 .37095 L
.25571 .30674 L
.25692 .24052 L
.25814 .30273 L
.25946 .27464 L
.26071 .34286 L
.26187 .42513 L
.26291 .38701 L
.26405 .51142 L
.26525 .28668 L
.26638 .30072 L
.26762 .41109 L
.26893 .11411 L
.27004 .25457 L
.27126 .22848 L
.27258 .4452 L
.27332 .39102 L
.27399 .23852 L
.27529 .23852 L
.27653 .30072 L
.27758 .12815 L
.27875 .11411 L
.27996 .2947 L
.2811 .37497 L
.28216 .40105 L
.28313 .27263 L
.28425 .31678 L
.28532 .4452 L
.28646 .31276 L
Mistroke
.28768 .09003 L
.28883 .2024 L
.28988 .34888 L
.29111 .19839 L
.2918 .33885 L
.29244 .15424 L
.29361 .2345 L
.29485 .34487 L
.29607 .16628 L
.29676 .29069 L
.2974 .31878 L
.29855 .38099 L
.29981 .39704 L
.30094 .385 L
.302 .26059 L
.30312 .54954 L
.30433 .22848 L
.30557 .082 L
.30627 .34085 L
.30692 .16829 L
.30823 .36493 L
.30897 .50941 L
.30963 .39102 L
.31083 .24855 L
.31214 .39303 L
.31336 .28668 L
.3145 .2325 L
.31555 .36493 L
.31669 .25457 L
.31776 .33283 L
.31874 .20842 L
.31988 .14621 L
.32113 .14621 L
.32231 .29069 L
.3234 .29671 L
.32464 .12013 L
.3258 .3248 L
.32684 .45523 L
.32797 .52948 L
.3292 .21243 L
.3305 .41309 L
.33161 .17832 L
.33283 .08602 L
.33414 .48132 L
.33535 .19237 L
.33598 .14822 L
.33668 .2947 L
.33741 .10006 L
.33809 .27263 L
.33934 .37697 L
Mistroke
.34049 .26862 L
.34181 .04588 L
.34307 .36493 L
.34418 .55355 L
.34538 .16829 L
.3465 .29671 L
.34752 .20842 L
.34872 .17631 L
.35002 .41911 L
.35125 .27062 L
.35238 .20441 L
.35359 .10608 L
.35489 .30674 L
.35612 .20039 L
.35723 .45523 L
.35854 .2024 L
.35928 .38701 L
.35997 .25457 L
.36122 .43717 L
.36186 .21043 L
.36256 .36293 L
.36324 .29069 L
.36395 .31477 L
.36523 .07799 L
.36594 .43717 L
.3666 .2646 L
.36733 .22447 L
.36811 .26862 L
.3693 .48132 L
.37059 .34085 L
.37132 .15223 L
.372 .2325 L
.37332 .52948 L
.37395 .3549 L
.37464 .31878 L
.3759 .31276 L
.37659 .12615 L
.37732 .43516 L
.37864 .07598 L
.37927 .16227 L
.37996 .37095 L
.38121 .15424 L
.38243 .2325 L
.38355 .22648 L
.38419 .2024 L
.38488 .34687 L
.38612 .40306 L
.38688 .13417 L
.3876 .43918 L
.38824 .16026 L
Mistroke
.38894 .2325 L
.38968 .30674 L
.39038 .4151 L
.3911 .2646 L
.3919 .11411 L
.39322 .27865 L
.39391 .35891 L
.39464 .4773 L
.39591 .11812 L
.39709 .30273 L
.39781 .39303 L
.39849 .31276 L
.39977 .43316 L
.40042 .15424 L
.40111 .08802 L
.40235 .06996 L
.40304 .29872 L
.40369 .24253 L
.4044 .15023 L
.40516 .46326 L
.40639 .25658 L
.40709 .33082 L
.40774 .10408 L
.40893 .2646 L
.41019 .38099 L
.41143 .36493 L
.4126 .13016 L
.41365 .30273 L
.41479 .24855 L
.41604 .31878 L
.41717 .46526 L
.41849 .28668 L
.41973 .2927 L
.42088 .15023 L
.42194 .36694 L
.4231 .35691 L
.42433 .13618 L
.42557 .36895 L
.42626 .19237 L
.4269 .32881 L
.42813 .32681 L
.42931 .27664 L
.42996 .24253 L
.43066 .08 L
.43193 .37296 L
.4327 .29671 L
.43343 .11411 L
.43408 .55957 L
.43479 .42313 L
.4361 .11009 L
Mistroke
.43733 .33082 L
.43804 .43516 L
.43868 .49135 L
.43942 .38901 L
.44013 .2947 L
.44081 .27062 L
.44153 .45122 L
.44283 .3248 L
.44355 .49135 L
.44422 .09204 L
.44497 .49336 L
.44577 .34687 L
.44699 .1121 L
.44769 .34286 L
.44833 .24855 L
.44964 .47128 L
.45037 .29872 L
.45104 .15424 L
.45223 .01378 L
.45352 .29671 L
.45475 .46125 L
.45587 .26862 L
.45712 .40707 L
.45831 .24855 L
.45938 .27263 L
.46054 .40105 L
.4618 .34888 L
.46251 .26059 L
.46315 .14822 L
.46439 .19437 L
.46556 .28668 L
.46667 .52747 L
.46783 .36092 L
.46883 .08602 L
.46992 .38701 L
.4711 .11009 L
.47236 .2927 L
.47346 .27865 L
.47463 .53549 L
.47529 .49737 L
.47601 .24654 L
.47729 .09404 L
.47801 .28868 L
.47878 .37095 L
.47951 .49737 L
.48018 .26661 L
.4814 .45322 L
.4821 .13618 L
.48274 .33483 L
.48404 .28668 L
Mistroke
.48477 .37095 L
.48543 .28467 L
.4867 .43316 L
.48786 .35289 L
.48912 .42714 L
.48983 .42112 L
.4905 .12615 L
.49161 .28066 L
.49282 .22648 L
.4941 .43115 L
.49527 .32279 L
.49644 .34487 L
.49755 .36293 L
.49876 .40908 L
.50006 .20441 L
.50136 .12414 L
.50201 .22046 L
.50272 .33885 L
.50399 .24654 L
.50516 .34286 L
.50636 .20641 L
.50748 .31477 L
.50849 .30474 L
.50959 .2927 L
.51079 .44118 L
.51205 .26862 L
.51322 .25858 L
.51433 .03786 L
.51561 .16427 L
.51678 .18033 L
.51805 .24454 L
.51876 .30875 L
.51943 .37296 L
.52064 .1723 L
.52174 .082 L
.52301 .33483 L
.5242 .20441 L
.52483 .43717 L
.52553 .19437 L
.52625 .36293 L
.52693 .27664 L
.52813 .40908 L
.52943 .21644 L
.53016 .18434 L
.53095 .41309 L
.53169 .41711 L
.53238 .37898 L
.53369 .34085 L
.53435 .28668 L
.53508 .34286 L
Mistroke
.5363 .34487 L
.53743 .41109 L
.53867 .46326 L
.53937 .43717 L
.54 .47931 L
.54128 .33283 L
.542 .2927 L
.54266 .33483 L
.54389 .17631 L
.54518 .25256 L
.54627 .20842 L
.5473 .20842 L
.5485 .32881 L
.54959 .44319 L
.55079 .54553 L
.55209 .24454 L
.55331 .34487 L
.55444 .53549 L
.55575 .27664 L
.55649 .26059 L
.55717 .23049 L
.55842 .51342 L
.55974 .20039 L
.56093 .32279 L
.56203 .21845 L
.56324 .43918 L
.56454 .10006 L
.56526 .46928 L
.56593 .16829 L
.56666 .41109 L
.56744 .27263 L
.56874 .27464 L
.56948 .35289 L
.57017 .28066 L
.57146 .27464 L
.57264 .18635 L
.57329 .25858 L
.574 .38701 L
.5753 .31477 L
.57594 .48332 L
.57662 .60372 L
.57785 .28066 L
.57916 .42914 L
.57991 .33283 L
.5806 .32881 L
.58187 .01779 L
.58302 .12815 L
.58367 .43115 L
.58436 .15625 L
.58561 .41711 L
Mistroke
.5867 .33283 L
.5879 .43516 L
.58919 .33483 L
.59041 .40306 L
.59155 .46727 L
.5926 .31477 L
.59375 .15023 L
.59496 .14019 L
.59627 .53148 L
.59746 .2927 L
.59812 .17431 L
.59884 .24052 L
.60014 .26661 L
.60136 .40306 L
.60265 .57563 L
.60376 .08602 L
.60497 .25658 L
.6057 .59971 L
.60639 .43115 L
.6077 .43316 L
.60842 .44118 L
.6091 .32881 L
.60984 .53951 L
.61063 .31678 L
.61132 .24253 L
.61206 .15424 L
.61271 .082 L
.61341 .03585 L
.61472 .11009 L
.61592 .35891 L
.61715 .10608 L
.61784 .38299 L
.61848 .39303 L
.61965 .13618 L
.62089 .13417 L
.622 .13618 L
.62305 .13618 L
.62419 .13417 L
.62542 .13819 L
.62666 .13618 L
.62736 .13417 L
.62801 .13417 L
.62869 .13417 L
.62942 .13618 L
.63073 .13819 L
.63193 .13417 L
.63323 .13417 L
.63559 .13417 L
.64507 .13417 L
.65393 .13417 L
Mistroke
.65505 .13618 L
.65628 .13618 L
.65743 .13417 L
.6585 .13417 L
.65975 .13618 L
.66107 .13618 L
.66341 .13618 L
.66836 .13618 L
.66972 .13618 L
.67043 .13417 L
.67118 .13618 L
.67184 .13417 L
.67256 .13417 L
.67383 .13819 L
.67451 .13417 L
.67525 .13618 L
.67595 .13618 L
.67659 .13417 L
.67781 .13417 L
.6791 .13417 L
.67982 .13417 L
.6805 .13618 L
.68129 .13618 L
.68201 .13217 L
.68331 .13618 L
.68405 .13217 L
.68473 .13417 L
.68596 .13417 L
.68707 .13417 L
.68835 .13819 L
.68956 .13618 L
.69021 .13417 L
.6909 .13618 L
.69212 .13618 L
.69489 .13618 L
.69977 .13618 L
.70509 .13618 L
.70752 .13618 L
.71011 .13618 L
.71117 .13417 L
.71231 .13618 L
.71357 .13417 L
.71475 .13417 L
.71589 .13618 L
.71695 .13618 L
.71935 .13618 L
.7242 .13618 L
.73286 .13618 L
.74229 .13618 L
.7436 .13618 L
Mistroke
.74433 .13417 L
.74501 .13417 L
.74626 .13618 L
.74757 .13618 L
.74986 .13618 L
.75116 .13618 L
.75237 .13417 L
.75367 .13417 L
.75508 .13417 L
.75632 .13618 L
.75701 .13618 L
.75764 .13417 L
.75893 .13417 L
.76014 .13618 L
.76125 .13217 L
.76246 .13618 L
.76377 .13618 L
.7652 .13618 L
.7666 .13618 L
.76737 .13819 L
.7681 .13618 L
.76877 .13618 L
.76951 .13217 L
.77078 .13417 L
.77209 .13618 L
.77329 .13417 L
.77447 .13417 L
.77571 .13417 L
.77678 .13417 L
.77794 .13618 L
.77919 .13618 L
.77989 .13618 L
.78053 .13417 L
.78177 .13618 L
.78294 .13618 L
.79199 .13618 L
.81261 .13618 L
.81504 .13618 L
.81574 .13819 L
.8164 .13618 L
.81765 .13417 L
.81882 .13417 L
.8199 .13417 L
.82236 .13417 L
.82358 .13417 L
.82474 .13417 L
.82594 .13618 L
.82658 .13819 L
.82727 .13618 L
.82792 .13417 L
Mistroke
.82864 .13618 L
.82939 .13618 L
.83008 .13417 L
.83133 .13819 L
.83203 .13618 L
.83266 .13618 L
.83722 .13618 L
.83846 .13819 L
.83962 .13417 L
.84083 .13417 L
.84147 .13618 L
.84216 .13618 L
.84341 .13618 L
.8446 .13417 L
.84566 .13417 L
.84683 .13417 L
.84791 .13618 L
.84906 .13417 L
.85015 .13618 L
.85113 .13217 L
.85233 .13618 L
.85346 .13618 L
.85601 .13618 L
.86117 .13618 L
.86345 .13618 L
.86458 .13217 L
.86562 .13618 L
.86682 .13417 L
.86812 .13417 L
.87039 .13417 L
.88049 .13417 L
.88169 .13217 L
.88295 .13618 L
.88361 .13618 L
.88433 .13217 L
.88559 .13417 L
.88632 .13417 L
.8871 .13819 L
.88783 .13417 L
.8885 .13217 L
.88917 .13417 L
.8899 .13618 L
.89122 .13618 L
.89234 .13618 L
.89353 .14019 L
.89484 .13417 L
.89605 .13618 L
.89728 .13417 L
.89845 .13618 L
.89949 .13618 L
Mistroke
.90062 .13819 L
.90126 .13618 L
.90196 .13417 L
.90269 .13618 L
.90338 .13417 L
.9046 .13618 L
.9059 .13819 L
.9072 .13217 L
.90842 .13417 L
.90953 .13417 L
.91072 .13417 L
.91142 .13819 L
.91216 .13819 L
.91287 .13618 L
.91352 .13417 L
.91424 .13618 L
.91493 .13819 L
.91567 .13417 L
.91648 .13618 L
.91718 .13819 L
.91782 .13417 L
.91855 .13819 L
.91924 .13417 L
.92047 .13417 L
.92116 .13417 L
.9218 .13819 L
.92304 .13417 L
.9242 .13417 L
.92684 .13417 L
.92816 .13417 L
.92941 .13417 L
.9301 .13618 L
.93085 .13618 L
.93216 .13618 L
.93462 .13618 L
.93728 .13618 L
.9385 .13618 L
.93979 .13618 L
.94089 .13417 L
.94209 .13417 L
.9471 .13417 L
.94782 .13618 L
.94849 .13618 L
.94926 .13618 L
.94997 .13417 L
.95125 .13417 L
.95197 .13417 L
.95264 .13618 L
.95373 .13217 L
.9549 .13618 L
Mistroke
.95601 .13417 L
.95702 .13417 L
.9582 .13417 L
.95949 .13217 L
.96071 .13618 L
.96184 .13217 L
.96312 .13618 L
.96432 .13417 L
.9654 .13417 L
.96656 .13417 L
.96784 .13618 L
.96848 .13417 L
.96918 .13417 L
.97043 .13819 L
.97159 .13819 L
.97282 .13618 L
.974 .13618 L
.97619 .13618 L
Mfstroke
0 -0.00027 m
1 -0.00027 L
1 .61777 L
0 .61777 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool2000001l0oooo1@00
00030?ooo`8000007P3oool3000000<0oooo0P00000M0?ooo`<00000103oool2000001d0oooo0`00
00040?ooo`8000006P3oool3000000@0oooo0P0000040?ooo`8000005`3oool300000080oooo1@00
00030?ooo`8000000`3oool00300oooo00@000000?ooo`3oool000007`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000001h0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000001/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001X0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000001L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo000`0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000K0?ooo`D000000P3oool010000000oooo0?ooo`00000K0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000K0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`00<03oool0
10000000oooo0?ooo`00000Q0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0I0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000006`3oool40000
00<0oooo00@000000?ooo`3oool00000703oool3000000<0oooo00@000000?ooo`3oool000006P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00005`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool10000
0040oooo0@3oool00300oooo00@000000?ooo`3oool000007P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000703oool00`000000oooo000000030?ooo`040000003o
ool0oooo000001/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000K0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000G0?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`4000000@3oool10?oo
o`00<03oool010000000oooo0?ooo`00000N0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000M0?ooo`8000000`3oool010000000oooo0?ooo`00000L0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000006@3oool2000000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000F0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00340oooo0P00000P0?ooo`<00000103oool2000001l0
oooo00<000000?ooo`3oool00P3oool2000001h0oooo0P0000040?ooo`8000007@3oool3000000@0
oooo0P00000K0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000603oool00`000000
oooo0?ooo`020?ooo`<00000103oool2000000<0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo000/0?oooo000000103oool000040?ooo`0000000000000000<0
oooo0`0000030?ooo`<00000103oool010000000oooo0?ooo`3oool500000080oooo0`0000030?oo
o`<00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool000070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`0000D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3oool300000>/0oooo0P000004
0?ooo`00100000040?ooo`8000000P3oool4000000/0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool0J03oool209T001d0oooo0P2I001S
0?ooo`030000003oool0oooo0080oooo00000`000000oooo0?ooo`070?ooo`030000003oool00000
00/0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo0?ooo`1X0?ooo`80V@007@3oool209T006<0oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06P0oooo0P2I000M0?ooo`80V@00H`3oool00`000000oooo
0?ooo`020?ooo`000P3oool2000000<0oooo0`0000040?ooo`8000002@3oool3000000@0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0P00001Y0?ooo`80V@007@3oool209T00680oooo0P00
00040?ooo`00;03oool00`000000oooo0?ooo`1X0?ooo`80V@007@3oool209T006<0oooo00<00000
0?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0J03oool209T000d0oooo0P2I000>0?oo
o`80V@001P3oool209T005/0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3o
ool0J03oool209T000d0oooo0P2I000>0?ooo`80V@001P3oool209T005/0oooo00<000000?ooo`3o
ool00P3oool002`0oooo00<000000?ooo`3oool0CP3oool209T001P0oooo0P2I000=0?ooo`80V@00
3P3oool209T000H0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000C`3o
ool209T001P0oooo0P2I000=0?ooo`80V@003P3oool209T000H0oooo0P2I001J0?ooo`800000103o
ool002`0oooo00<000000?ooo`3oool0CP3oool209T001P0oooo0P2I000=0?ooo`80V@003P3oool2
09T000H0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo
04h0oooo0P2I000H0?ooo`80V@003@3oool209T000h0oooo0P2I00060?ooo`80V@00F`3oool00`00
0000oooo0?ooo`020?ooo`00;03oool2000004l0oooo0P2I000H0?ooo`80V@003@3oool209T000h0
oooo0P2I00060?ooo`80V@00FP3oool2000000@0oooo000/0?ooo`030000003oool0oooo04h0oooo
0P2I000H0?ooo`80V@003@3oool209T000h0oooo0P2I00060?ooo`80V@00F`3oool00`000000oooo
0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1>0?ooo`80V@003@3oool209T000T0oooo0P2I
000=0?ooo`80V@003P3oool209T000H0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/
0?ooo`030000003oool0oooo04h0oooo0P2I00070?ooo`80V@00103oool209T000T0oooo0P2I000=
0?ooo`80V@003P3oool309T000D0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/0?oo
o`030000003oool0oooo01h0oooo0P2I000^0?ooo`80V@00103oool209T000030?ooo`2I0000V@00
00@0oooo0P2I00040?ooo`80V@000`3oool209T000d0oooo0P2I000>0?ooo`<0V@001@3oool209T0
05/0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00000O0?ooo`80V@009@3oool209T000L0
oooo0P2I00040?ooo`80V@0000<0oooo09T0002I00000`3oool309T000@0oooo0P2I00030?ooo`80
V@003@3oool409T000`0oooo0`2I00050?ooo`80V@00FP3oool2000000@0oooo000/0?ooo`030000
003oool0oooo01h0oooo0P2I000U0?ooo`80V@001@3oool409T000@0oooo0P2I00000`3oool0V@00
09T000030?ooo`<0V@00103oool209T000<0oooo0P2I00020?ooo`80V@002@3oool409T000`0oooo
0`2I00030?ooo`@0V@00F`3oool00`000000oooo0?ooo`020?ooo`0000@0oooo0000000000000000
0`3oool3000000<0oooo0`0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000<0
oooo0`0000040?ooo`030000003oool0oooo01h0oooo0P2I000Q0?ooo`80V@000P3oool209T000D0
oooo102I00040?ooo`80V@0000<0oooo09T0002I00000`3oool309T000@0oooo0P2I00020?ooo`<0
V@000P3oool209T000T0oooo102I000<0?ooo`<0V@000`3oool409T005/0oooo00<000000?ooo`3o
ool00P3oool000070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000200oooo0P2I000Q0?ooo`80V@00
0P3oool209T000D0oooo102I00040?ooo`80V@0000<0oooo09T0002I00000`3oool309T000@0oooo
0P2I00020?ooo`<0V@000P3oool409T000L0oooo102I000<0?ooo`<0V@000`3oool409T005/0oooo
00<000000?ooo`3oool00P3oool000050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0oooo0`00000C0?ooo`80V@002@3oool209T0
0240oooo0P2I00020?ooo`80V@001@3oool409T000@0oooo0P2I00000`3oool0V@0009T000030?oo
o`<0V@00103oool209T00080oooo0`2I00020?ooo`@0V@001`3oool409T000P0oooo0P2I00020?oo
o`<0V@000`3oool409T005X0oooo0P0000040?ooo`00100000040?ooo`8000000P3oool4000000/0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool4000000@0oooo00<000000?oo
o`3oool04`3oool209T000T0oooo0P2I000:0?ooo`80V@005@3oool209T00080oooo0P2I00050?oo
o`@0V@00103oool209T000030?ooo`2I0000V@0000<0oooo102I00030?ooo`80V@000P3oool309T0
0080oooo102I00070?ooo`@0V@00203oool209T00080oooo0`2I00030?ooo`@0V@00F`3oool00`00
0000oooo0?ooo`020?ooo`0000<000000?ooo`3oool01`3oool00`000000oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool04`3oool209T000T0oooo0P2I000:0?ooo`80V@005@3oool209T00080oooo0P2I0005
0?ooo`@0V@0000@0oooo09T0002I0000oooo0P2I00000`3oool0V@0009T000030?ooo`@0V@000`3o
ool209T00080oooo0`2I00020?ooo`@0V@001`3oool409T000P0oooo0P2I00020?ooo`<0V@000`3o
ool509T005X0oooo00<000000?ooo`3oool00P3oool000030?ooo`000000oooo00<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo
0P2I0000103oool0V@0009T0002I00080?ooo`80V@002P3oool209T00140oooo1P2I00020?ooo`80
V@001@3oool409T000040?ooo`2I0000V@000?ooo`80V@0000@0oooo09T0002I0000oooo1P2I0003
0?ooo`L0V@000P3oool409T000L0oooo102I00080?ooo`80V@000P3oool309T000<0oooo1@2I001J
0?ooo`030000003oool0oooo0080oooo00020?ooo`8000000`3oool3000000@0oooo0P0000090?oo
o`<00000103oool00`000000oooo0?ooo`030?ooo`800000103oool200000140oooo0P2I0000103o
ool0V@0009T0002I00080?ooo`80V@002P3oool209T00140oooo1P2I00020?ooo`80V@001@3oool4
09T000040?ooo`2I0000V@000?ooo`80V@0000@0oooo09T0002I0000oooo1P2I00030?ooo`L0V@00
0P3oool409T000L0oooo102I00080?ooo`80V@000P3oool309T000<0oooo1@2I001I0?ooo`800000
103oool002`0oooo00<000000?ooo`3oool0403oool209T000040?ooo`2I0000V@0009T000P0oooo
0P2I000:0?ooo`80V@004@3oool609T00080oooo0P2I00030?ooo`H0V@0000@0oooo09T0002I0000
oooo0P2I0000103oool0V@0009T0003oool609T000<0oooo1`2I00020?ooo`@0V@001`3oool409T0
00P0oooo0P2I00020?ooo`<0V@000`3oool509T005X0oooo00<000000?ooo`3oool00P3oool002`0
oooo00<000000?ooo`3oool0403oool209T000040?ooo`2I0000V@0009T000P0oooo0P2I00020?oo
o`80V@001P3oool209T00140oooo1P2I00020?ooo`80V@000`3oool609T000040?ooo`2I0000V@00
0?ooo`D0V@0000<0oooo09T0002I0000102I00030?ooo`L0V@000P3oool409T00080oooo102I0000
0`3oool0V@0009T0000209T000P0oooo0P2I00020?ooo`<0V@000`3oool509T005X0oooo00<00000
0?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0403oool209T000040?ooo`2I0000V@00
09T000P0oooo0`2I00000`3oool0V@0009T000060?ooo`80V@001@3oool209T000X0oooo1P2I0002
0?ooo`80V@000`3oool609T000040?ooo`2I0000V@000?ooo`D0V@0000<0oooo09T0002I00001@2I
00020?ooo`L0V@000P3oool409T00080oooo102I00000`3oool0V@0009T0000209T000P0oooo0P2I
00020?ooo`<0V@000`3oool509T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<00000
0?ooo`3oool0403oool209T000040?ooo`2I0000V@0009T000P0oooo0`2I0000103oool0V@0009T0
002I00040?ooo`<0V@001@3oool309T000T0oooo1P2I00020?ooo`80V@000`3oool609T000040?oo
o`2I0000V@000?ooo`d0V@000P3oool709T00080oooo102I00020?ooo`@0V@0000<0oooo09T0002I
00000P2I00080?ooo`80V@000P3oool309T000<0oooo3`2I00000`3oool0V@0009T0000409T000<0
oooo0`2I00050?ooo`/0V@001`3oool:09T000030?ooo`2I0000V@0000l0V@0000<0oooo09T0002I
00001`2I00060?ooo`030000003oool0oooo0080oooo000/0?ooo`8000004@3oool209T000040?oo
o`2I0000V@0009T000P0oooo0`2I0000103oool0V@0009T0002I00040?ooo`<0V@001@3oool309T0
00T0oooo1P2I00020?ooo`80V@000`3oool609T000040?ooo`2I0000V@000?ooo`d0V@0000<0oooo
09T0002I00001P2I00020?ooo`X0V@0000<0oooo09T0002I00000P2I00080?ooo`80V@000P3oool3
09T000<0ooooF`2I00030?ooo`800000103oool002`0oooo00<000000?ooo`3oool0103oool209T0
00X0oooo0P2I0000103oool0V@0009T0002I00080?ooo`<0V@0000@0oooo09T0002I0000V@00103o
ool309T000D0oooo0`2I00000`3oool0V@0009T000060?ooo`H0V@000P3oool209T000<0oooo1P2I
0000103oool0V@0009T0003oool=09T000030?ooo`2I0000V@0000H0V@000P3oool:09T000030?oo
o`2I0000V@000080V@00203oool209T00080oooo0`2I00000`3oool0V@0009T0000809T000@0oooo
:02I00000`3oool0V@0009T0000909T00080oooo6@2I00040?ooo`030000003oool0oooo0080oooo
000/0?ooo`030000003oool0oooo00@0oooo0P2I000:0?ooo`80V@0000@0oooo09T0002I0000V@00
0P3oool209T000@0oooo0`2I0000103oool0V@0009T0002I00040?ooo`<0V@001@3oool309T00003
0?ooo`2I0000V@0000H0oooo1P2I00020?ooo`80V@000P3oool709T000040?ooo`2I0000V@000?oo
o`d0V@0000<0oooo09T0002I00001P2I00020?ooo`X0V@0000<0oooo09T0002I00000P2I00080?oo
o`80V@000P3oool309T000030?ooo`2I0000V@0000D0V@00@03oool209T001P0oooo00<000000?oo
o`3oool00P3oool002`0oooo00<000000?ooo`3oool0103oool209T000X0oooo0P2I0000103oool0
V@0009T0002I00020?ooo`80V@000P3oool:09T000<0oooo0`2I00050?ooo`<0V@0000<0oooo09T0
002I00001P3oool609T00080oooo0P2I00020?ooo`L0V@0000@0oooo09T0002I0000oooo5P2I0000
0`3oool0V@0009T0000909T000030?ooo`2I0000V@000080V@00203oool209T00080oooo2`2I001J
0?ooo`030000003oool0oooo0080oooo000/0?ooo`8000001@3oool209T000X0oooo0P2I0000103o
ool0V@0009T0002I00020?ooo`<0V@0000<0oooo09T0002I0000202I00030?ooo`<0V@001@3oool3
09T000030?ooo`2I0000V@0000H0oooo1`2I00000`3oool0V@0009T000020?ooo`L0V@0000@0oooo
09T0002I0000oooo5P2I00000`3oool0V@0009T0000909T000030?ooo`2I0000V@000080V@00203o
ool209T00080oooo2`2I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0103oool2
09T000X0oooo0P2I0000103oool0V@0009T0002I00020?ooo`<0V@0000<0oooo09T0002I0000202I
00030?ooo`<0V@001@3oool309T000030?ooo`2I0000V@0000H0oooo1`2I00000`3oool0V@0009T0
00020?ooo`L0V@0000@0oooo09T0002I0000oooo8P2I00000`3oool0V@0009T0000209T000P0oooo
0P2I00020?ooo`/0V@00FP3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?oo
o`040?ooo`80V@002P3oool209T000040?ooo`2I0000V@0009T00080oooo0`2I00000`3oool0V@00
09T0000809T000<0oooo0`2I00030?ooo`D0V@0000<0oooo09T0002I00000P2I00040?ooo`L0V@00
00<0oooo09T0002I00000P3oool709T000040?ooo`2I0000V@000?ooob80V@0000<0oooo09T0002I
00000P2I00080?ooo`80V@000P3oool;09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo
00<000000?ooo`3oool00P3oool409T000X0oooo0P2I0000103oool0V@0009T0002I00020?ooo`<0
V@0000<0oooo09T0002I0000202I00030?ooo`<0V@000`3oool509T000030?ooo`2I0000V@000080
V@00103oool;09T000030?ooo`2I0000V@0000P0V@0000<0oooo09T0002I0000802I00000`3oool0
V@0009T0000209T000P0oooo0`2I00000`3oool0V@0009T0000909T005X0oooo00<000000?ooo`3o
ool00P3oool002`0oooo0P0000030?ooo`D0V@002@3oool209T000040?ooo`2I0000V@0009T00080
oooo0`2I00000`3oool0V@0009T0000809T000<0oooo0`2I00030?ooo`D0V@0000<0oooo09T0002I
00000P2I00040?ooo`/0V@0000<0oooo09T0002I0000202I00000`3oool0V@0009T0000P09T00003
0?ooo`2I0000V@000080V@00203oool309T000030?ooo`2I0000V@0000T0V@00F@3oool2000000@0
oooo000/0?ooo`030000003oool0oooo0080oooo1@2I00090?ooo`80V@0000@0oooo09T0002I0000
V@000P3oool309T000030?ooo`2I0000V@0000P0V@000`3oool309T000<0oooo1@2I00000`3oool0
V@0009T0000209T000@0oooo2`2I00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200
V@0000<0oooo09T0002I00000P2I00030?ooo`80V@000`3oool309T000030?ooo`2I0000V@0000T0
V@00FP3oool00`000000oooo0?ooo`020?ooo`0000@0oooo00000000000000000`3oool3000000<0
oooo0`0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000<0oooo0`0000040?oo
o`030000003oool0oooo0080oooo1@2I00070?ooo`@0V@0000D0oooo09T0002I0000V@000?ooo`04
09T000030?ooo`2I0000V@0000P0V@000`3oool309T000030?ooo`2I0000V@0000D0V@0000<0oooo
09T0002I00000P2I00040?ooo`/0V@0000<0oooo09T0002I0000202I00000`3oool0V@0009T0000P
09T000030?ooo`2I0000V@000080V@000`3oool209T000<0oooo0`2I00000`3oool0V@0009T00009
09T005X0oooo00<000000?ooo`3oool00P3oool000070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo1@2I00030?ooo`80V@000P3oool409T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0
002I0000202I00030?ooo`<0V@0000<0oooo09T0002I00001@2I00000`3oool0V@0009T0000209T0
00@0oooo2`2I00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200V@0000<0oooo09T0
002I0000102I00000`3oool0V@0009T000030?ooo`<0V@0000<0oooo09T0002I00002@2I001J0?oo
o`030000003oool0oooo0080oooo00001@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo0?ooo`<000000P3oool509T000<0oooo0P2I
00020?ooo`@0V@0000<0oooo09T0002I00001P2I00000`3oool0V@0009T0000809T000030?ooo`2I
0000V@0000<0V@0000<0oooo09T0002I00001@2I00000`3oool0V@0009T0000209T000@0oooo2`2I
00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200V@0000<0oooo09T0002I0000102I
00000`3oool0V@0009T000030?ooo`l0V@00F@3oool2000000@0oooo0004000000@0oooo0P000002
0?ooo`@000002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@00000103o
ool00`000000oooo0?ooo`020?ooo`D0V@000P3oool309T00080oooo3@2I00000`3oool0V@0009T0
000809T000030?ooo`2I0000V@0000/0V@0000<0oooo09T0002I00000P2I00040?ooo`/0V@0000<0
oooo09T0002I0000202I00000`3oool0V@0009T0000P09T000030?ooo`2I0000V@0000@0V@0000<0
oooo09T0002I00000`3oool?09T005X0oooo00<000000?ooo`3oool00P3oool000030000003oool0
oooo00L0oooo00<000000?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0080oooo1@2I00020?ooo`<0V@00
0P3oool=09T000030?ooo`2I0000V@0000P0V@0000<0oooo09T0002I00002`2I00000`3oool0V@00
09T0000209T000@0oooo2`2I00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200V@00
00<0oooo09T0002I0000102I00000`3oool0V@0009T000030?ooo`l0V@00FP3oool00`000000oooo
0?ooo`020?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool509T00080oooo0`2I00020?ooo`d0
V@0000<0oooo09T0002I0000202I00000`3oool0V@0009T0000@09T000@0oooo2`2I00000`3oool0
V@0009T0000[09T000030?ooo`2I0000V@0000@0V@0000<0oooo09T0002I00000P3oool@09T005X0
oooo00<000000?ooo`3oool00P3oool00080oooo0P0000030?ooo`<00000103oool2000000T0oooo
0`0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo
1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0000809T000030?oo
o`2I0000V@000100V@00103oool;09T000030?ooo`2I0000V@0002/0V@0000<0oooo09T0002I0000
102I00000`3oool0V@0009T000020?oooa00V@00FP3oool00`000000oooo0?ooo`020?ooo`00;03o
ool2000000<0oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0
000809T000030?ooo`2I0000V@000100V@00103oool;09T000030?ooo`2I0000V@000380V@0000D0
oooo09T0002I0000V@000?ooo`0@09T005T0oooo0P0000040?ooo`00;03oool00`000000oooo0?oo
o`020?ooo`D0V@000P3oool409T000030?ooo`2I0000V@0000/0V@0000<0oooo09T0002I0000202I
00000`3oool0V@0009T0000A09T000<0oooo2`2I00000`3oool0V@0009T0000b09T000050?ooo`2I
0000V@0009T0003oool0402I001J0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003o
ool0oooo0080oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0
000809T000030?ooo`2I0000V@000140V@000`3oool;09T000030?ooo`2I0000V@000380V@0000D0
oooo09T0002I0000V@000?ooo`0@09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<0
00000?ooo`3oool00P3oool509T00080oooo102I00000`3oool0V@0009T0000;09T000030?ooo`2I
0000V@0000P0V@0000<0oooo09T0002I00004@2I00030?ooo`/0V@0000<0oooo09T0002I0000<P2I
00001@3oool0V@0009T0002I0000oooo0100V@00FP3oool00`000000oooo0?ooo`020?ooo`00;03o
ool2000000<0oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0
000L09T000<0oooo2`2I00000`3oool0V@0009T0000b09T000050?ooo`2I0000V@0009T0003oool0
402I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool00P3oool509T00080oooo102I
00000`3oool0V@0009T0000;09T000030?ooo`2I0000V@0001`0V@000`3oool;09T000030?ooo`2I
0000V@000380V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003oool0oooo0080oooo000/
0?ooo`030000003oool0oooo0080oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I0000
0`3oool0V@0009T0000L09T000<0oooo@02I00000`3oool0V@0009T0000B09T005X0oooo00<00000
0?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool00P3oool509T00080oooo102I00000`3o
ool0V@0009T0000Z09T000<0oooo@02I00000`3oool0V@0009T0000B09T005X0oooo00<000000?oo
o`3oool00P3oool002`0oooo0P0000030?ooo`D0V@000P3ooolc09T000030?ooo`2I0000V@0003h0
V@0000<0oooo09T0002I00004P2I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0
0P3oool509T00080oooo<`2I00000`3oool0V@0009T0000n09T000030?ooo`2I0000V@000180V@00
FP3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`020?ooo`D0V@000P3o
oolc09T000030?ooo`2I0000V@0003h0V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003o
ool0oooo0080oooo000/0?ooo`030000003oool0oooo0080oooo1@2I00000`3oool0V@0009T0000b
09T000030?ooo`2I0000V@0003h0V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003oool0
oooo0080oooo000/0?ooo`800000103oool409T000030?ooo`2I0000V@000380V@0000<0oooo09T0
002I0000?P2I00000`3oool0V@0009T0000B09T005T0oooo0P0000040?ooo`00;03oool00`000000
oooo0?ooo`030?ooogX0V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003oool0oooo0080
oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo00@000000?ooo`3o
ool0oooo1@0000020?ooo`<000000`3oool3000000@0oooo00<000000?ooo`3oool00`3ooomj09T0
00030?ooo`2I0000V@000180V@00FP3oool00`000000oooo0?ooo`020?ooo`0000L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000001@3ooomj09T000030?ooo`2I0000V@000180V@00FP3oool00`000000
oooo0?ooo`020?ooo`0000D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`3oool3000000<0ooooNP2I00000`3oool0V@0009T0000B
09T005T0oooo0P0000040?ooo`00100000040?ooo`8000000P3oool4000000/0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool00`3ooomj
09T000030?ooo`2I0000V@000180V@00FP3oool00`000000oooo0?ooo`020?ooo`0000<000000?oo
o`3oool01`3oool00`000000oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3ooomj09T000030?ooo`2I
0000V@000180V@00FP3oool00`000000oooo0?ooo`020?ooo`0000<0oooo0000003oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool000000080oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3ooon?09T005X0oooo00<000000?ooo`3oool00P3oool00080oooo0P0000030?ooo`<00000103o
ool2000000T0oooo0`0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003o
ool0oooo00<0ooooS`2I001J0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000103ooon?
09T005T0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`030?ooohl0V@00FP3oool00`00
0000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`030?ooohl0V@00FP3oool00`000000
oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`030?oooaL0V@0000<0oooo09T0002I0000
3@2I00000`3oool0V@0009T0001U09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00
00040?oooaL0V@0000<0oooo09T0002I00003@2I00000`3oool0V@0009T0001U09T005T0oooo0P00
00040?ooo`00;03oool00`000000oooo0?ooo`030?oooaL0V@0000<0oooo09T0002I00003@2I0000
0`3oool0V@0009T0001U09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?oo
o`3oool00`3ooolG09T000030?ooo`2I0000V@0000d0V@0000<0oooo09T0002I0000I@2I001J0?oo
o`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00<0oooo402I00000`3oool0
V@0009T0000409T000030?ooo`2I0000V@0000d0V@0000<0oooo09T0002I0000I@2I001J0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`800000103oool@09T000030?ooo`2I0000V@0000@0V@00
00<0oooo09T0002I00003@2I00000`3oool0V@0009T0001U09T005T0oooo0P0000040?ooo`00;03o
ool00`000000oooo0?ooo`030?oooa00V@0000<0oooo09T0002I0000102I0000103oool0V@0009T0
002I00020?ooo`X0V@0000<0oooo09T0002I0000I@2I001J0?ooo`030000003oool0oooo0080oooo
000/0?ooo`030000003oool0oooo00<0oooo402I00000`3oool0V@0009T0000409T000040?ooo`2I
0000V@0009T00080oooo2P2I00000`3oool0V@0009T0001U09T005X0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<000000?ooo`3oool00`3oool@09T000030?ooo`2I0000V@0000@0V@0000@0
oooo09T0002I0000V@000P3oool909T00080ooooI`2I001J0?ooo`030000003oool0oooo0080oooo
000/0?ooo`800000103oool@09T000030?ooo`2I0000V@0000@0V@0000@0oooo09T0002I0000V@00
0P3oool909T00080ooooI`2I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool00`3o
ool@09T000030?ooo`2I0000V@0000@0V@0000@0oooo09T0002I0000V@000P3oool909T00080oooo
I`2I001J0?ooo`030000003oool0oooo0080oooo0000103oool000000000000000030?ooo`<00000
0`3oool3000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<000000`3oool3000000@0
oooo00<000000?ooo`3oool00`3oool509T000030?ooo`2I0000V@0000P0V@0000<0oooo09T0002I
0000102I0000103oool0V@0009T0002I00020?ooo`T0V@000P3ooomW09T005X0oooo00<000000?oo
o`3oool00P3oool000070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo1@2I00000`3oool0
V@0009T0000809T000030?ooo`2I0000V@0000@0V@0000<0oooo09T0002I0000103oool809T00080
oooo602I00000`3oool0V@0009T0001<09T005X0oooo00<000000?ooo`3oool00P3oool000050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo000000030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool0oooo0`0000030?ooo`D0V@000`3oool809T000030?ooo`2I0000V@0000@0V@0000<0oooo
09T0002I0000103oool809T00080oooo602I00000`3oool0V@0009T0001<09T005T0oooo0P000004
0?ooo`00100000040?ooo`8000000P3oool4000000/0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool00`3oool509T000<0oooo202I0000
0`3oool0V@0009T0000409T000030?ooo`2I0000V@0000H0oooo1P2I00020?oooaP0V@0000<0oooo
09T0002I0000C02I001J0?ooo`030000003oool0oooo0080oooo00000`000000oooo0?ooo`070?oo
o`030000003oool0000000/0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`D0V@000`3oool809T000030?ooo`2I
0000V@0000@0V@0000<0oooo09T0002I00001P3oool609T00080oooo602I00000`3oool0V@0009T0
000309T000030?ooo`2I0000V@0004H0V@00FP3oool00`000000oooo0?ooo`020?ooo`0000<0oooo
0000003oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool509T000<0oooo202I00001@3oool0V@0009T0002I0000oooo0080
V@0000<0oooo09T0002I00001P3oool609T00080oooo602I00000`3oool0V@0009T0000309T00003
0?ooo`2I0000V@0001H0V@000P3oool^09T005X0oooo00<000000?ooo`3oool00P3oool00080oooo
0P0000030?ooo`<00000103oool2000000T0oooo0`0000040?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo1@2I00030?ooo`P0V@0000D0oooo09T0002I0000
V@000?ooo`0209T000030?ooo`2I0000V@0000L0oooo1@2I00020?oooaP0V@0000<0oooo09T0002I
00000`2I00000`3oool0V@0009T0000F09T00080oooo502I00020?oooaP0V@00FP3oool00`000000
oooo0?ooo`020?ooo`00;03oool2000000@0oooo1@2I00030?ooo`P0V@0000D0oooo09T0002I0000
V@000?ooo`0209T000030?ooo`2I0000V@0000L0oooo1@2I00020?ooo`H0V@0000<0oooo09T0002I
00003`2I00000`3oool0V@0009T0000309T000030?ooo`2I0000V@0001H0V@000P3ooolD09T00080
oooo602I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool00`3oool409T000@0oooo
202I00020?ooo`80V@0000@0oooo09T0002I0000oooo0P2I00070?ooo`D0V@000P3oool609T00003
0?ooo`2I0000V@0000l0V@0000<0oooo09T0002I00000`2I00000`3oool0V@0009T0000C09T00003
0?ooo`2I0000V@000080oooo502I00020?oooaP0V@00FP3oool00`000000oooo0?ooo`020?ooo`00
;03oool00`000000oooo0?ooo`030?ooo`@0V@00103oool809T00080oooo0P2I0000103oool0V@00
09T0003oool209T000L0oooo1@2I00020?ooo`H0V@0000<0oooo09T0002I00003`2I00000`3oool0
V@0009T0000309T000030?ooo`2I0000V@0001<0V@0000<0oooo09T0002I00000P3ooolD09T00080
oooo602I001J0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00D0oooo
0P2I00040?ooo`P0V@000P3oool209T000040?ooo`2I0000V@000?ooo`80V@001`3oool509T00080
oooo1P2I00000`3oool0V@0009T0000309T000030?ooo`2I0000V@0000T0V@0000<0oooo09T0002I
00000`2I00020?oooa@0V@0000<0oooo09T0002I00000P3ooolD09T00080oooo602I001J0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`8000001P3oool209T000@0oooo202I00020?ooo`80V@00
00@0oooo09T0002I0000oooo0P2I00090?ooo`<0V@000P3oool609T000030?ooo`2I0000V@0000<0
V@0000<0oooo09T0002I00002@2I00000`3oool0V@0009T0000209T000<0oooo502I00000`3oool0
V@0009T000020?oooa@0V@000P3ooolF09T005/0oooo0P0000040?ooo`00;03oool00`000000oooo
0?ooo`050?ooo`80V@001P3oool609T00080oooo0P2I0000103oool0V@0009T0003oool209T000T0
oooo0`2I00020?ooo`H0V@0000<0oooo09T0002I00000`2I00000`3oool0V@0009T0000909T00080
oooo0`2I00030?oooa@0V@0000<0oooo09T0002I00000P3ooolD09T00080oooo5P2I001L0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00D0oooo0P2I00060?ooo`H0V@00
0P3oool209T000040?ooo`2I0000V@000?ooo`80V@002@3oool309T00080oooo1P2I0000103oool0
V@0009T0003oool209T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0002I00000P3oool309T0
00<0oooo502I00000`3oool0V@0009T000020?oooa@0V@000P3ooolF09T005`0oooo00<000000?oo
o`3oool00P3oool002`0oooo00<000000?ooo`3oool01@3oool209T000H0oooo1P2I00020?ooo`80
V@0000@0oooo09T0002I0000oooo0P2I00090?ooo`<0V@000P3oool609T000040?ooo`2I0000V@00
0?ooo`80V@0000<0oooo09T0002I00001P2I00000`3oool0V@0009T000020?ooo`<0V@000`3ooolD
09T000030?ooo`2I0000V@000080oooo1`2I00000`3oool0V@0009T0000:09T00080oooo1@2I0000
0`3oool0V@0009T0000>09T005`0oooo00<000000?ooo`3oool00P3oool002`0oooo0P0000060?oo
o`80V@001P3oool609T00080oooo0P2I0000103oool0V@0009T0003oool209T000T0oooo0`2I0002
0?ooo`80V@000P3oool209T000040?ooo`2I0000V@000?ooo`80V@0000<0oooo09T0002I00001P2I
00000`3oool0V@0009T000020?ooo`<0V@000`3ooolD09T000030?ooo`2I0000V@000080oooo1`2I
00000`3oool0V@0009T0000609T00080oooo0P2I00020?ooo`D0V@0000<0oooo09T0002I00000`2I
00000`3oool0V@0009T0000809T005/0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`05
0?ooo`80V@001P3oool609T00080oooo0P2I00040?ooo`80V@002@3oool309T00080oooo0P2I0002
0?ooo`80V@0000@0oooo09T0002I0000oooo0P2I00000`3oool0V@0009T0000609T000030?ooo`2I
0000V@000080oooo0`2I00030?oooa@0V@0000<0oooo09T0002I00000P3oool709T000030?ooo`2I
0000V@0000H0V@000P3oool209T00080oooo1@2I00000`3oool0V@0009T0000309T000030?ooo`2I
0000V@0000P0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`05
0?ooo`80V@001P3oool609T00080oooo0P2I00040?ooo`80V@002@3oool309T00080oooo0P2I0002
0?ooo`80V@00103oool209T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0002I00000P3oool3
09T000<0oooo1P2I00000`3oool0V@0009T0000;09T000030?ooo`2I0000V@000080oooo1`2I0000
0`3oool0V@0009T0000609T00080oooo0P2I00020?ooo`80V@0000@0oooo09T0002I0000oooo1@2I
00000`3oool0V@0009T0000809T005`0oooo00<000000?ooo`3oool00P3oool002`0oooo00<00000
0?ooo`3oool01@3oool209T000H0oooo1P2I00020?ooo`80V@00103oool209T000X0oooo0P2I0002
0?ooo`80V@00203oool209T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0002I00000P3oool3
09T000<0oooo1P2I00000`3oool0V@0009T0000;09T000030?ooo`2I0000V@000080oooo1`2I0000
0`3oool0V@0009T0000609T00080oooo0P2I00020?ooo`80V@0000@0oooo09T0002I0000oooo1@2I
00000`3oool0V@0009T0000809T005`0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00000>
0?ooo`D0V@002@3oool209T000X0oooo0P2I00020?ooo`80V@00203oool209T000030?ooo`2I0000
V@0000H0V@0000<0oooo09T0002I00000P3oool309T000<0oooo1P2I00000`3oool0V@0009T0000;
09T000030?ooo`2I0000V@000080oooo1`2I00000`3oool0V@0009T0000609T00080oooo0P2I0002
0?ooo`80V@0000@0oooo09T0002I0000oooo1@2I00000`3oool0V@0009T0000809T005/0oooo0P00
00040?ooo`00;03oool00`000000oooo0?ooo`0=0?ooo`D0V@005@3oool209T00080oooo0P2I000<
0?ooo`L0V@0000<0oooo09T0002I00000P3oool309T000<0oooo1P2I00000`3oool0V@0009T0000;
09T000030?ooo`2I0000V@000080oooo1`2I00000`3oool0V@0009T0000509T000<0oooo0P2I0002
0?ooo`80V@0000@0oooo09T0002I0000oooo1@2I0000103oool0V@0009T0003oool709T005`0oooo
00<000000?ooo`3oool00P3oool000040?ooo`0000000000000000<0oooo0`0000030?ooo`<00000
103oool010000000oooo0?ooo`3oool500000080oooo0`0000030?ooo`<00000103oool00`000000
oooo0?ooo`0=0?ooo`<0V@005`3oool209T00080oooo0P2I000>0?ooo`D0V@0000<0oooo09T0002I
00000P3oool309T000<0oooo1P2I00000`3oool0V@0009T0000409T000030?ooo`2I0000V@0000@0
V@0000<0oooo09T0002I00000P3oool709T000030?ooo`2I0000V@0000<0V@001@3oool209T00080
oooo0P2I0000103oool0V@0009T0003oool509T000030?ooo`2I0000V@000080oooo1P2I001L0?oo
o`030000003oool0oooo0080oooo00001`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`<0
V@006`3oool209T000h0oooo1@2I00000`3oool0V@0009T000020?ooo`<0V@000`3oool609T00004
0?ooo`2I0000V@000?ooo`<0V@000`3oool409T000030?ooo`2I0000V@000080oooo1`2I00000`3o
ool0V@0009T0000309T000D0oooo0P2I00050?ooo`80V@0000<0oooo09T0002I00000`2I00000`3o
ool0V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`020?ooo`0000D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3o
ool3000000d0oooo0P2I000L0?ooo`80V@003P3oool509T000030?ooo`2I0000V@000080oooo0`2I
00030?ooo`H0V@0000@0oooo09T0002I0000oooo0`2I00030?ooo`@0V@0000<0oooo09T0002I0000
0P3oool709T000030?ooo`2I0000V@0000<0V@00303oool209T000030?ooo`2I0000V@0000<0V@00
00<0oooo09T0002I00000P3oool609T005/0oooo0P0000040?ooo`00100000040?ooo`8000000P3o
ool4000000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool4000000@0oooo
00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?ooo`80V@001`3oool309T000<0oooo
1P2I0000103oool0V@0009T0003oool309T000<0oooo102I00000`3oool0V@0009T000020?ooo`L0
V@0000<0oooo09T0002I00000`2I000<0?ooo`80V@0000<0oooo09T0002I00000`2I00000`3oool0
V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`020?ooo`0000<000000?ooo`3oool0
1`3oool00`000000oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?oo
o`80V@001`3oool309T000<0oooo1P2I0000103oool0V@0009T0003oool309T000<0oooo102I0000
0`3oool0V@0009T000020?ooo`L0V@0000<0oooo09T0002I00000`2I000<0?ooo`80V@0000<0oooo
09T0002I00000`2I00000`3oool0V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`02
0?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?ooo`80V@001`3o
ool309T000<0oooo0`2I00000`3oool0V@0009T000040?ooo`<0V@000`3oool409T000030?ooo`2I
0000V@000080oooo1`2I00000`3oool0V@0009T0000309T000`0oooo0P2I00000`3oool0V@0009T0
000309T000030?ooo`2I0000V@000080oooo1P2I001L0?ooo`030000003oool0oooo0080oooo0002
0?ooo`8000000`3oool3000000@0oooo0P0000090?ooo`<00000103oool00`000000oooo0?ooo`03
0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`80V@00703oool209T000l0oooo0P2I0007
0?ooo`<0V@000`3oool309T000030?ooo`2I0000V@0000@0oooo0`2I00030?ooo`@0V@0000<0oooo
09T0002I00000P3oool609T00080oooo1@2I000<0?ooo`80V@0000<0oooo09T0002I00000`2I0000
0`3oool0V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool20000
00h0oooo0P2I000L0?ooo`80V@003`3oool209T000L0oooo0`2I00030?ooo`<0V@0000<0oooo09T0
002I0000103oool309T000<0oooo0P2I00070?ooo`H0V@000P3oool509T000`0oooo0P2I00000`3o
ool0V@0009T0000309T000030?ooo`2I0000V@000080oooo1P2I001K0?ooo`800000103oool002`0
oooo00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?ooo`80V@001`3oool309T000<0
oooo0`2I00000`3oool0V@0009T000040?ooo`<0V@000`3oool209T000L0oooo1P2I00020?ooo`D0
V@00303oool209T000030?ooo`2I0000V@000080V@000P3oool209T000<0oooo1@2I001L0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00d0oooo0P2I000L0?ooo`80V@00
3`3oool209T000L0oooo0`2I00030?ooo`<0V@0000<0oooo09T0002I0000103oool309T000<0oooo
0P2I00070?ooo`D0V@000`3oool509T000`0oooo0P2I00000`3oool0V@0009T0000209T00080oooo
0P2I00030?ooo`D0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?oo
o`0=0?ooo`80V@00;@3oool209T000L0oooo0`2I00030?ooo`<0V@0000<0oooo09T0002I0000103o
ool309T000`0oooo1@2I00030?ooo`D0V@00303oool209T000030?ooo`2I0000V@000080V@000P3o
ool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`8000003P3oool2
09T002d0oooo0P2I00070?ooo`<0V@000`3oool209T00080oooo0P2I00050?ooo`80V@00303oool5
09T000<0oooo1@2I000?0?ooo`@0V@000P3oool209T000<0oooo1@2I001K0?ooo`800000103oool0
02`0oooo00<000000?ooo`3oool03@3oool209T002d0oooo0P2I00070?ooo`<0V@000`3oool209T0
0080oooo0P2I00050?ooo`80V@00303oool509T000<0oooo1@2I000?0?ooo`@0V@000P3oool209T0
00<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo03`0
oooo0P2I00070?ooo`<0V@000`3oool209T00080oooo0P2I00050?ooo`80V@00303oool509T000<0
oooo1@2I000?0?ooo`@0V@000P3oool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080
oooo000/0?ooo`030000003oool0oooo03`0oooo0P2I00070?ooo`<0V@000`3oool209T00080oooo
0P2I00050?ooo`80V@00303oool209T000H0oooo1@2I000?0?ooo`@0V@000P3oool209T000<0oooo
1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000?@3oool209T000L0oooo0`2I
00030?ooo`80V@000P3oool209T000D0oooo0P2I000<0?ooo`80V@001P3oool409T00100oooo102I
00020?ooo`80V@000`3oool509T005/0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`0l
0?ooo`80V@001`3oool309T000<0oooo0P2I00020?ooo`80V@001@3oool209T000`0oooo0P2I0006
0?ooo`@0V@00403oool409T00080oooo0P2I00030?ooo`D0V@00G03oool00`000000oooo0?ooo`02
0?ooo`00;03oool00`000000oooo0?ooo`0l0?ooo`80V@001`3oool309T000<0oooo0P2I00020?oo
o`80V@001@3oool209T000`0oooo0P2I00060?ooo`@0V@00403oool409T00080oooo0P2I00030?oo
o`D0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`150?ooo`80
V@00103oool209T00080oooo0P2I00050?ooo`80V@00303oool209T000H0oooo102I000@0?ooo`@0
V@000P3oool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000
AP3oool209T000@0oooo0P2I00020?ooo`80V@001@3oool209T000`0oooo0P2I00060?ooo`@0V@00
403oool309T000<0oooo0P2I00030?ooo`D0V@00F`3oool2000000@0oooo000/0?ooo`030000003o
ool0oooo04D0oooo0P2I00040?ooo`80V@000P3oool209T000D0oooo0P2I000<0?ooo`80V@001P3o
ool409T00100oooo0`2I00030?ooo`80V@000`3oool509T005`0oooo00<000000?ooo`3oool00P3o
ool000040?ooo`0000000000000000<0oooo0`0000030?ooo`<00000103oool010000000oooo0?oo
o`3oool500000080oooo0`0000030?ooo`<00000103oool00`000000oooo0?ooo`150?ooo`80V@00
103oool209T00080oooo0P2I00050?ooo`80V@00303oool209T000H0oooo102I000@0?ooo`<0V@00
0`3oool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo00001`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000170?ooo`80V@00103oool209T00080oooo0P2I00050?ooo`80V@00303o
ool209T000P0oooo0P2I000@0?ooo`<0V@000`3oool209T000<0oooo1@2I001L0?ooo`030000003o
ool0oooo0080oooo00001@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo0?ooo`<00000A@3oool209T000P0oooo0P2I000C0?ooo`80
V@00203oool209T00100oooo0`2I00030?ooo`80V@00103oool409T005/0oooo0P0000040?ooo`00
100000040?ooo`8000000P3oool4000000/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool4000000@0oooo00<000000?ooo`3oool0A@3oool209T000P0oooo0P2I000C0?ooo`80
V@006P3oool209T000@0oooo0P2I00040?ooo`@0V@00G03oool00`000000oooo0?ooo`020?ooo`00
00<000000?ooo`3oool01`3oool00`000000oooo0000000;0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0A@3oool209T0
00P0oooo0P2I000C0?ooo`80V@006P3oool209T000@0oooo0P2I00040?ooo`<0V@00G@3oool00`00
0000oooo0?ooo`020?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo0P000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A@3oool209T000P0oooo0P2I000C
0?ooo`80V@00803oool209T000@0oooo0`2I001M0?ooo`030000003oool0oooo0080oooo00020?oo
o`8000000`3oool3000000@0oooo0P0000090?ooo`<00000103oool00`000000oooo0?ooo`030?oo
o`800000103oool00`000000oooo0?ooo`1?0?ooo`80V@004`3oool209T00200oooo0P2I00040?oo
o`<0V@00G@3oool00`000000oooo0?ooo`020?ooo`00;03oool2000006D0oooo0P2I000P0?ooo`80
V@00103oool309T005`0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1T0?ooo`80V@00
803oool209T000@0oooo0`2I001M0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003o
ool0oooo08H0oooo0P2I00040?ooo`<0V@00G@3oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`260?ooo`80V@00103oool309T005d0oooo00<000000?ooo`3oool00P3oool0
02`0oooo0P0000270?ooo`80V@00103oool309T005`0oooo0P0000040?ooo`00;03oool00`000000
oooo0?ooo`260?ooo`80V@00103oool309T005d0oooo00<000000?ooo`3oool00P3oool002`0oooo
00<000000?ooo`3oool0QP3oool209T000D0oooo0P2I001M0?ooo`030000003oool0oooo0080oooo
000/0?ooo`030000003oool0oooo08H0oooo0P2I00050?ooo`80V@00G@3oool00`000000oooo0?oo
o`020?ooo`00;03oool2000008L0oooo0P2I00050?ooo`80V@00G03oool2000000@0oooo000/0?oo
o`030000003oool0oooo08H0oooo0P2I00050?ooo`80V@00G@3oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`260?ooo`80V@001@3oool209T005d0oooo00<000000?ooo`3o
ool00P3oool002`0oooo00<000000?ooo`3oool0QP3oool209T006@0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo000/0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3oool2000000@0oooo000/
0?oooo000000103oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-26.746, 636.216, 0.527865, \
2.37356*^-13}},
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "If ",
  StyleBox["$ErrorChecking", "MR"],
  " is set to be ",
  StyleBox["True", "MR"],
  " with ",
  StyleBox["$StrongErrorChecking", "MR"],
  " set to ",
  StyleBox["False", "MR"],
  " then error messages will be returned that indicate that there may be a \
problem here."
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetErrorChecking", "[", 
      RowBox[{"True", ",", " ", "False"}], "]"}]], "Input",
  CellLabel->"In[18]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]], "Output",
  CellLabel->"Out[18]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Evaluate", "[", 
            RowBox[{"Payment", "[", 
              RowBox[{
              "100000", ",", " ", "interestRateTable", ",", " ", "30", ",", 
                "\[Mu]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"\[Mu]", ",", "0", ",", "120"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[19]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Principal\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[19]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[19]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Principal\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[19]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"General", "::", "\<\"stop\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Further output of \\!\\(LoanFunctions :: \\\"checkvars\
\\\"\\) will be suppressed during this calculation.\"\>"}]], "Message",
  CellLabel->"From In[19]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00793651 -1.12294e+13 1.76503e+10 [
[.02381 -0.01231 -3 -9 ]
[.02381 -0.01231 3 0 ]
[.18254 -0.01231 -6 -9 ]
[.18254 -0.01231 6 0 ]
[.34127 -0.01231 -6 -9 ]
[.34127 -0.01231 6 0 ]
[.5 -0.01231 -6 -9 ]
[.5 -0.01231 6 0 ]
[.65873 -0.01231 -6 -9 ]
[.65873 -0.01231 6 0 ]
[.81746 -0.01231 -9 -9 ]
[.81746 -0.01231 9 0 ]
[.97619 -0.01231 -9 -9 ]
[.97619 -0.01231 9 0 ]
[ 0 -0.00027 -0.125 0 ]
[-0.0125 .01177 -42 -4.5 ]
[-0.0125 .01177 0 4.5 ]
[-0.0125 .10006 -42 -4.5 ]
[-0.0125 .10006 0 4.5 ]
[-0.0125 .18835 -42 -4.5 ]
[-0.0125 .18835 0 4.5 ]
[-0.0125 .27664 -42 -4.5 ]
[-0.0125 .27664 0 4.5 ]
[-0.0125 .36493 -42 -4.5 ]
[-0.0125 .36493 0 4.5 ]
[-0.0125 .45322 -42 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .54151 -42 -4.5 ]
[-0.0125 .54151 0 4.5 ]
[ 0 -0.00027 -0.125 0 ]
[ 0 .61777 .125 0 ]
[ 1 -0.00027 .125 0 ]
[ 0 -0.00027 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 -0.00027 m
.02381 .00575 L
s
[(0)] .02381 -0.01231 0 1 Mshowa
.18254 -0.00027 m
.18254 .00575 L
s
[(20)] .18254 -0.01231 0 1 Mshowa
.34127 -0.00027 m
.34127 .00575 L
s
[(40)] .34127 -0.01231 0 1 Mshowa
.5 -0.00027 m
.5 .00575 L
s
[(60)] .5 -0.01231 0 1 Mshowa
.65873 -0.00027 m
.65873 .00575 L
s
[(80)] .65873 -0.01231 0 1 Mshowa
.81746 -0.00027 m
.81746 .00575 L
s
[(100)] .81746 -0.01231 0 1 Mshowa
.97619 -0.00027 m
.97619 .00575 L
s
[(120)] .97619 -0.01231 0 1 Mshowa
.125 Mabswid
.06349 -0.00027 m
.06349 .00374 L
s
.10317 -0.00027 m
.10317 .00374 L
s
.14286 -0.00027 m
.14286 .00374 L
s
.22222 -0.00027 m
.22222 .00374 L
s
.2619 -0.00027 m
.2619 .00374 L
s
.30159 -0.00027 m
.30159 .00374 L
s
.38095 -0.00027 m
.38095 .00374 L
s
.42063 -0.00027 m
.42063 .00374 L
s
.46032 -0.00027 m
.46032 .00374 L
s
.53968 -0.00027 m
.53968 .00374 L
s
.57937 -0.00027 m
.57937 .00374 L
s
.61905 -0.00027 m
.61905 .00374 L
s
.69841 -0.00027 m
.69841 .00374 L
s
.7381 -0.00027 m
.7381 .00374 L
s
.77778 -0.00027 m
.77778 .00374 L
s
.85714 -0.00027 m
.85714 .00374 L
s
.89683 -0.00027 m
.89683 .00374 L
s
.93651 -0.00027 m
.93651 .00374 L
s
.25 Mabswid
0 -0.00027 m
1 -0.00027 L
s
0 .01177 m
.00625 .01177 L
s
[(636.216)] -0.0125 .01177 1 0 Mshowa
0 .10006 m
.00625 .10006 L
s
[(636.216)] -0.0125 .10006 1 0 Mshowa
0 .18835 m
.00625 .18835 L
s
[(636.216)] -0.0125 .18835 1 0 Mshowa
0 .27664 m
.00625 .27664 L
s
[(636.216)] -0.0125 .27664 1 0 Mshowa
0 .36493 m
.00625 .36493 L
s
[(636.216)] -0.0125 .36493 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(636.216)] -0.0125 .45322 1 0 Mshowa
0 .54151 m
.00625 .54151 L
s
[(636.216)] -0.0125 .54151 1 0 Mshowa
.125 Mabswid
0 .02983 m
.00375 .02983 L
s
0 .04789 m
.00375 .04789 L
s
0 .06394 m
.00375 .06394 L
s
0 .082 m
.00375 .082 L
s
0 .11812 m
.00375 .11812 L
s
0 .13618 m
.00375 .13618 L
s
0 .15223 m
.00375 .15223 L
s
0 .17029 m
.00375 .17029 L
s
0 .20641 m
.00375 .20641 L
s
0 .22447 m
.00375 .22447 L
s
0 .24052 m
.00375 .24052 L
s
0 .25858 m
.00375 .25858 L
s
0 .2947 m
.00375 .2947 L
s
0 .31276 m
.00375 .31276 L
s
0 .32881 m
.00375 .32881 L
s
0 .34687 m
.00375 .34687 L
s
0 .38299 m
.00375 .38299 L
s
0 .40105 m
.00375 .40105 L
s
0 .41711 m
.00375 .41711 L
s
0 .43516 m
.00375 .43516 L
s
0 .47128 m
.00375 .47128 L
s
0 .48934 m
.00375 .48934 L
s
0 .5054 m
.00375 .5054 L
s
0 .52346 m
.00375 .52346 L
s
0 .55957 m
.00375 .55957 L
s
0 .57763 m
.00375 .57763 L
s
0 .59569 m
.00375 .59569 L
s
0 .61375 m
.00375 .61375 L
s
.25 Mabswid
0 -0.00027 m
0 .61777 L
s
.02381 .61175 m
.02381 .61777 L
s
.18254 .61175 m
.18254 .61777 L
s
.34127 .61175 m
.34127 .61777 L
s
.5 .61175 m
.5 .61777 L
s
.65873 .61175 m
.65873 .61777 L
s
.81746 .61175 m
.81746 .61777 L
s
.97619 .61175 m
.97619 .61777 L
s
.125 Mabswid
.06349 .61375 m
.06349 .61777 L
s
.10317 .61375 m
.10317 .61777 L
s
.14286 .61375 m
.14286 .61777 L
s
.22222 .61375 m
.22222 .61777 L
s
.2619 .61375 m
.2619 .61777 L
s
.30159 .61375 m
.30159 .61777 L
s
.38095 .61375 m
.38095 .61777 L
s
.42063 .61375 m
.42063 .61777 L
s
.46032 .61375 m
.46032 .61777 L
s
.53968 .61375 m
.53968 .61777 L
s
.57937 .61375 m
.57937 .61777 L
s
.61905 .61375 m
.61905 .61777 L
s
.69841 .61375 m
.69841 .61777 L
s
.7381 .61375 m
.7381 .61777 L
s
.77778 .61375 m
.77778 .61777 L
s
.85714 .61375 m
.85714 .61777 L
s
.89683 .61375 m
.89683 .61777 L
s
.93651 .61375 m
.93651 .61777 L
s
.25 Mabswid
0 .61777 m
1 .61777 L
s
.99375 .01177 m
1 .01177 L
s
.99375 .10006 m
1 .10006 L
s
.99375 .18835 m
1 .18835 L
s
.99375 .27664 m
1 .27664 L
s
.99375 .36493 m
1 .36493 L
s
.99375 .45322 m
1 .45322 L
s
.99375 .54151 m
1 .54151 L
s
.125 Mabswid
.99625 .02983 m
1 .02983 L
s
.99625 .04789 m
1 .04789 L
s
.99625 .06394 m
1 .06394 L
s
.99625 .082 m
1 .082 L
s
.99625 .11812 m
1 .11812 L
s
.99625 .13618 m
1 .13618 L
s
.99625 .15223 m
1 .15223 L
s
.99625 .17029 m
1 .17029 L
s
.99625 .20641 m
1 .20641 L
s
.99625 .22447 m
1 .22447 L
s
.99625 .24052 m
1 .24052 L
s
.99625 .25858 m
1 .25858 L
s
.99625 .2947 m
1 .2947 L
s
.99625 .31276 m
1 .31276 L
s
.99625 .32881 m
1 .32881 L
s
.99625 .34687 m
1 .34687 L
s
.99625 .38299 m
1 .38299 L
s
.99625 .40105 m
1 .40105 L
s
.99625 .41711 m
1 .41711 L
s
.99625 .43516 m
1 .43516 L
s
.99625 .47128 m
1 .47128 L
s
.99625 .48934 m
1 .48934 L
s
.99625 .5054 m
1 .5054 L
s
.99625 .52346 m
1 .52346 L
s
.99625 .55957 m
1 .55957 L
s
.99625 .57763 m
1 .57763 L
s
.99625 .59569 m
1 .59569 L
s
.99625 .61375 m
1 .61375 L
s
.25 Mabswid
1 -0.00027 m
1 .61777 L
s
.6 0 0 r
2 Mabswid
.02381 .25056 m
.02499 .16628 L
.02605 .2345 L
.02721 .34888 L
.02846 .38701 L
.02961 .2646 L
.03068 .3248 L
.0317 .27865 L
.03279 .1422 L
.03395 .21444 L
.0352 .42513 L
.03638 .17029 L
.03746 .24454 L
.03873 .37095 L
.03944 .37898 L
.04011 .29069 L
.04132 .27062 L
.04262 .27464 L
.04387 .2626 L
.04519 .31678 L
.04588 .29671 L
.04664 .25457 L
.04733 .25658 L
.04797 .2947 L
.04925 .33885 L
.05041 .35691 L
.05105 .28868 L
.05175 .32881 L
.05302 .19036 L
.05414 .22848 L
.05539 .18233 L
.05669 .32881 L
.05791 .27464 L
.05905 .20441 L
.06009 .32681 L
.06124 .27464 L
.06244 .39503 L
.0631 .26862 L
.0638 .35691 L
.06509 .30072 L
.06633 .28467 L
.06748 .24052 L
.06873 .26862 L
.06944 .45523 L
.0701 .28066 L
.0708 .48734 L
.07144 .36493 L
.07217 .20842 L
.07287 .36493 L
.07404 .44319 L
Mistroke
.07528 .17832 L
.07645 .27464 L
.07751 .24654 L
.07876 .28868 L
.07947 .33885 L
.08012 .1121 L
.08131 .30072 L
.08257 .43516 L
.08327 .21644 L
.08394 .30474 L
.08519 .36895 L
.08585 .32681 L
.08654 .42513 L
.0873 .19839 L
.088 .34687 L
.08925 .19237 L
.09041 .26059 L
.09169 .27664 L
.09241 .18835 L
.09307 .27664 L
.09374 .31878 L
.09446 .28266 L
.09575 .10006 L
.09654 .38099 L
.09729 .33885 L
.09796 .27263 L
.09868 .1121 L
.09939 .27263 L
.10017 .29671 L
.10099 .38701 L
.10175 .23852 L
.10246 .42714 L
.10312 .2927 L
.10387 .28467 L
.10458 .18233 L
.10572 .35891 L
.10694 .36694 L
.1081 .2024 L
.10916 .32079 L
.11033 .29872 L
.11162 .25658 L
.11298 .2024 L
.11422 .14621 L
.11554 .41309 L
.11678 .16026 L
.1181 .27865 L
.11884 .20842 L
.11952 .15424 L
.12067 .27464 L
.12192 .30273 L
Mistroke
.12324 .24052 L
.12446 .28467 L
.1256 .27464 L
.12684 .23651 L
.12801 .42914 L
.1291 .28066 L
.13018 .22648 L
.13115 .34888 L
.13228 .27664 L
.13334 .15023 L
.1345 .19638 L
.13573 .28066 L
.13677 .28266 L
.13792 .27263 L
.13916 .08 L
.13985 .3248 L
.14048 .25256 L
.14171 .1422 L
.14288 .2646 L
.14402 .12815 L
.14525 .2947 L
.14641 .15625 L
.14747 .34888 L
.14865 .25658 L
.14994 .22246 L
.15064 .2626 L
.1513 .33283 L
.15254 .15023 L
.15377 .35891 L
.15447 .2325 L
.15511 .28467 L
.15575 .12615 L
.15645 .35691 L
.15718 .28066 L
.15786 .18835 L
.1591 .30072 L
.16024 .13217 L
.16156 .26661 L
.1628 .37296 L
.16397 .15023 L
.16502 .22447 L
.16615 .39303 L
.16738 .37095 L
.16852 .24253 L
.16956 .22648 L
.17056 .27062 L
.17162 .29671 L
.17276 .28266 L
.17383 .32881 L
.17507 .41109 L
Mistroke
.1762 .43918 L
.17745 .2024 L
.17815 .42112 L
.1788 .18635 L
.17998 .37095 L
.18123 .26862 L
.18243 .33283 L
.18374 .22848 L
.18498 .28668 L
.18614 .29872 L
.18728 .13417 L
.18831 .24855 L
.18951 .20441 L
.19063 .13819 L
.19186 .10408 L
.19316 .27664 L
.19427 .19638 L
.19549 .4773 L
.1968 .43115 L
.19754 .20441 L
.19821 .24454 L
.19952 .31276 L
.20075 .28868 L
.2018 .17832 L
.20296 .21243 L
.20417 .40908 L
.2053 .34085 L
.20629 .29069 L
.20733 .24855 L
.20847 .2325 L
.20951 .31276 L
.21065 .16427 L
.21187 .42112 L
.21302 .37898 L
.21407 .26661 L
.2153 .37497 L
.21599 .25056 L
.21663 .2947 L
.2178 .17029 L
.21905 .30072 L
.22026 .1723 L
.22158 .13016 L
.22282 .13417 L
.22398 .19036 L
.22509 .41711 L
.2263 .19839 L
.22743 .24253 L
.22848 .40105 L
.22973 .23852 L
.23106 .25056 L
Mistroke
.23217 .2646 L
.23339 .31678 L
.23469 .43115 L
.23543 .33684 L
.23609 .37296 L
.23739 .14019 L
.23861 .39704 L
.23967 .2927 L
.24083 .17631 L
.24204 .22848 L
.24317 .21644 L
.24423 .31477 L
.2452 .38901 L
.24627 .16427 L
.24739 .25858 L
.24853 .25658 L
.24975 .31076 L
.2508 .43115 L
.25195 .43316 L
.25264 .27263 L
.25329 .32881 L
.25456 .37095 L
.25571 .30674 L
.25692 .24052 L
.25814 .30273 L
.25946 .27464 L
.26071 .34286 L
.26187 .42513 L
.26291 .38701 L
.26405 .51142 L
.26525 .28668 L
.26638 .30072 L
.26762 .41109 L
.26893 .11411 L
.27004 .25457 L
.27126 .22848 L
.27258 .4452 L
.27332 .39102 L
.27399 .23852 L
.27529 .23852 L
.27653 .30072 L
.27758 .12815 L
.27875 .11411 L
.27996 .2947 L
.2811 .37497 L
.28216 .40105 L
.28313 .27263 L
.28425 .31678 L
.28532 .4452 L
.28646 .31276 L
Mistroke
.28768 .09003 L
.28883 .2024 L
.28988 .34888 L
.29111 .19839 L
.2918 .33885 L
.29244 .15424 L
.29361 .2345 L
.29485 .34487 L
.29607 .16628 L
.29676 .29069 L
.2974 .31878 L
.29855 .38099 L
.29981 .39704 L
.30094 .385 L
.302 .26059 L
.30312 .54954 L
.30433 .22848 L
.30557 .082 L
.30627 .34085 L
.30692 .16829 L
.30823 .36493 L
.30897 .50941 L
.30963 .39102 L
.31083 .24855 L
.31214 .39303 L
.31336 .28668 L
.3145 .2325 L
.31555 .36493 L
.31669 .25457 L
.31776 .33283 L
.31874 .20842 L
.31988 .14621 L
.32113 .14621 L
.32231 .29069 L
.3234 .29671 L
.32464 .12013 L
.3258 .3248 L
.32684 .45523 L
.32797 .52948 L
.3292 .21243 L
.3305 .41309 L
.33161 .17832 L
.33283 .08602 L
.33414 .48132 L
.33535 .19237 L
.33598 .14822 L
.33668 .2947 L
.33741 .10006 L
.33809 .27263 L
.33934 .37697 L
Mistroke
.34049 .26862 L
.34181 .04588 L
.34307 .36493 L
.34418 .55355 L
.34538 .16829 L
.3465 .29671 L
.34752 .20842 L
.34872 .17631 L
.35002 .41911 L
.35125 .27062 L
.35238 .20441 L
.35359 .10608 L
.35489 .30674 L
.35612 .20039 L
.35723 .45523 L
.35854 .2024 L
.35928 .38701 L
.35997 .25457 L
.36122 .43717 L
.36186 .21043 L
.36256 .36293 L
.36324 .29069 L
.36395 .31477 L
.36523 .07799 L
.36594 .43717 L
.3666 .2646 L
.36733 .22447 L
.36811 .26862 L
.3693 .48132 L
.37059 .34085 L
.37132 .15223 L
.372 .2325 L
.37332 .52948 L
.37395 .3549 L
.37464 .31878 L
.3759 .31276 L
.37659 .12615 L
.37732 .43516 L
.37864 .07598 L
.37927 .16227 L
.37996 .37095 L
.38121 .15424 L
.38243 .2325 L
.38355 .22648 L
.38419 .2024 L
.38488 .34687 L
.38612 .40306 L
.38688 .13417 L
.3876 .43918 L
.38824 .16026 L
Mistroke
.38894 .2325 L
.38968 .30674 L
.39038 .4151 L
.3911 .2646 L
.3919 .11411 L
.39322 .27865 L
.39391 .35891 L
.39464 .4773 L
.39591 .11812 L
.39709 .30273 L
.39781 .39303 L
.39849 .31276 L
.39977 .43316 L
.40042 .15424 L
.40111 .08802 L
.40235 .06996 L
.40304 .29872 L
.40369 .24253 L
.4044 .15023 L
.40516 .46326 L
.40639 .25658 L
.40709 .33082 L
.40774 .10408 L
.40893 .2646 L
.41019 .38099 L
.41143 .36493 L
.4126 .13016 L
.41365 .30273 L
.41479 .24855 L
.41604 .31878 L
.41717 .46526 L
.41849 .28668 L
.41973 .2927 L
.42088 .15023 L
.42194 .36694 L
.4231 .35691 L
.42433 .13618 L
.42557 .36895 L
.42626 .19237 L
.4269 .32881 L
.42813 .32681 L
.42931 .27664 L
.42996 .24253 L
.43066 .08 L
.43193 .37296 L
.4327 .29671 L
.43343 .11411 L
.43408 .55957 L
.43479 .42313 L
.4361 .11009 L
Mistroke
.43733 .33082 L
.43804 .43516 L
.43868 .49135 L
.43942 .38901 L
.44013 .2947 L
.44081 .27062 L
.44153 .45122 L
.44283 .3248 L
.44355 .49135 L
.44422 .09204 L
.44497 .49336 L
.44577 .34687 L
.44699 .1121 L
.44769 .34286 L
.44833 .24855 L
.44964 .47128 L
.45037 .29872 L
.45104 .15424 L
.45223 .01378 L
.45352 .29671 L
.45475 .46125 L
.45587 .26862 L
.45712 .40707 L
.45831 .24855 L
.45938 .27263 L
.46054 .40105 L
.4618 .34888 L
.46251 .26059 L
.46315 .14822 L
.46439 .19437 L
.46556 .28668 L
.46667 .52747 L
.46783 .36092 L
.46883 .08602 L
.46992 .38701 L
.4711 .11009 L
.47236 .2927 L
.47346 .27865 L
.47463 .53549 L
.47529 .49737 L
.47601 .24654 L
.47729 .09404 L
.47801 .28868 L
.47878 .37095 L
.47951 .49737 L
.48018 .26661 L
.4814 .45322 L
.4821 .13618 L
.48274 .33483 L
.48404 .28668 L
Mistroke
.48477 .37095 L
.48543 .28467 L
.4867 .43316 L
.48786 .35289 L
.48912 .42714 L
.48983 .42112 L
.4905 .12615 L
.49161 .28066 L
.49282 .22648 L
.4941 .43115 L
.49527 .32279 L
.49644 .34487 L
.49755 .36293 L
.49876 .40908 L
.50006 .20441 L
.50136 .12414 L
.50201 .22046 L
.50272 .33885 L
.50399 .24654 L
.50516 .34286 L
.50636 .20641 L
.50748 .31477 L
.50849 .30474 L
.50959 .2927 L
.51079 .44118 L
.51205 .26862 L
.51322 .25858 L
.51433 .03786 L
.51561 .16427 L
.51678 .18033 L
.51805 .24454 L
.51876 .30875 L
.51943 .37296 L
.52064 .1723 L
.52174 .082 L
.52301 .33483 L
.5242 .20441 L
.52483 .43717 L
.52553 .19437 L
.52625 .36293 L
.52693 .27664 L
.52813 .40908 L
.52943 .21644 L
.53016 .18434 L
.53095 .41309 L
.53169 .41711 L
.53238 .37898 L
.53369 .34085 L
.53435 .28668 L
.53508 .34286 L
Mistroke
.5363 .34487 L
.53743 .41109 L
.53867 .46326 L
.53937 .43717 L
.54 .47931 L
.54128 .33283 L
.542 .2927 L
.54266 .33483 L
.54389 .17631 L
.54518 .25256 L
.54627 .20842 L
.5473 .20842 L
.5485 .32881 L
.54959 .44319 L
.55079 .54553 L
.55209 .24454 L
.55331 .34487 L
.55444 .53549 L
.55575 .27664 L
.55649 .26059 L
.55717 .23049 L
.55842 .51342 L
.55974 .20039 L
.56093 .32279 L
.56203 .21845 L
.56324 .43918 L
.56454 .10006 L
.56526 .46928 L
.56593 .16829 L
.56666 .41109 L
.56744 .27263 L
.56874 .27464 L
.56948 .35289 L
.57017 .28066 L
.57146 .27464 L
.57264 .18635 L
.57329 .25858 L
.574 .38701 L
.5753 .31477 L
.57594 .48332 L
.57662 .60372 L
.57785 .28066 L
.57916 .42914 L
.57991 .33283 L
.5806 .32881 L
.58187 .01779 L
.58302 .12815 L
.58367 .43115 L
.58436 .15625 L
.58561 .41711 L
Mistroke
.5867 .33283 L
.5879 .43516 L
.58919 .33483 L
.59041 .40306 L
.59155 .46727 L
.5926 .31477 L
.59375 .15023 L
.59496 .14019 L
.59627 .53148 L
.59746 .2927 L
.59812 .17431 L
.59884 .24052 L
.60014 .26661 L
.60136 .40306 L
.60265 .57563 L
.60376 .08602 L
.60497 .25658 L
.6057 .59971 L
.60639 .43115 L
.6077 .43316 L
.60842 .44118 L
.6091 .32881 L
.60984 .53951 L
.61063 .31678 L
.61132 .24253 L
.61206 .15424 L
.61271 .082 L
.61341 .03585 L
.61472 .11009 L
.61592 .35891 L
.61715 .10608 L
.61784 .38299 L
.61848 .39303 L
.61965 .13618 L
.62089 .13417 L
.622 .13618 L
.62305 .13618 L
.62419 .13417 L
.62542 .13819 L
.62666 .13618 L
.62736 .13417 L
.62801 .13417 L
.62869 .13417 L
.62942 .13618 L
.63073 .13819 L
.63193 .13417 L
.63323 .13417 L
.63559 .13417 L
.64507 .13417 L
.65393 .13417 L
Mistroke
.65505 .13618 L
.65628 .13618 L
.65743 .13417 L
.6585 .13417 L
.65975 .13618 L
.66107 .13618 L
.66341 .13618 L
.66836 .13618 L
.66972 .13618 L
.67043 .13417 L
.67118 .13618 L
.67184 .13417 L
.67256 .13417 L
.67383 .13819 L
.67451 .13417 L
.67525 .13618 L
.67595 .13618 L
.67659 .13417 L
.67781 .13417 L
.6791 .13417 L
.67982 .13417 L
.6805 .13618 L
.68129 .13618 L
.68201 .13217 L
.68331 .13618 L
.68405 .13217 L
.68473 .13417 L
.68596 .13417 L
.68707 .13417 L
.68835 .13819 L
.68956 .13618 L
.69021 .13417 L
.6909 .13618 L
.69212 .13618 L
.69489 .13618 L
.69977 .13618 L
.70509 .13618 L
.70752 .13618 L
.71011 .13618 L
.71117 .13417 L
.71231 .13618 L
.71357 .13417 L
.71475 .13417 L
.71589 .13618 L
.71695 .13618 L
.71935 .13618 L
.7242 .13618 L
.73286 .13618 L
.74229 .13618 L
.7436 .13618 L
Mistroke
.74433 .13417 L
.74501 .13417 L
.74626 .13618 L
.74757 .13618 L
.74986 .13618 L
.75116 .13618 L
.75237 .13417 L
.75367 .13417 L
.75508 .13417 L
.75632 .13618 L
.75701 .13618 L
.75764 .13417 L
.75893 .13417 L
.76014 .13618 L
.76125 .13217 L
.76246 .13618 L
.76377 .13618 L
.7652 .13618 L
.7666 .13618 L
.76737 .13819 L
.7681 .13618 L
.76877 .13618 L
.76951 .13217 L
.77078 .13417 L
.77209 .13618 L
.77329 .13417 L
.77447 .13417 L
.77571 .13417 L
.77678 .13417 L
.77794 .13618 L
.77919 .13618 L
.77989 .13618 L
.78053 .13417 L
.78177 .13618 L
.78294 .13618 L
.79199 .13618 L
.81261 .13618 L
.81504 .13618 L
.81574 .13819 L
.8164 .13618 L
.81765 .13417 L
.81882 .13417 L
.8199 .13417 L
.82236 .13417 L
.82358 .13417 L
.82474 .13417 L
.82594 .13618 L
.82658 .13819 L
.82727 .13618 L
.82792 .13417 L
Mistroke
.82864 .13618 L
.82939 .13618 L
.83008 .13417 L
.83133 .13819 L
.83203 .13618 L
.83266 .13618 L
.83722 .13618 L
.83846 .13819 L
.83962 .13417 L
.84083 .13417 L
.84147 .13618 L
.84216 .13618 L
.84341 .13618 L
.8446 .13417 L
.84566 .13417 L
.84683 .13417 L
.84791 .13618 L
.84906 .13417 L
.85015 .13618 L
.85113 .13217 L
.85233 .13618 L
.85346 .13618 L
.85601 .13618 L
.86117 .13618 L
.86345 .13618 L
.86458 .13217 L
.86562 .13618 L
.86682 .13417 L
.86812 .13417 L
.87039 .13417 L
.88049 .13417 L
.88169 .13217 L
.88295 .13618 L
.88361 .13618 L
.88433 .13217 L
.88559 .13417 L
.88632 .13417 L
.8871 .13819 L
.88783 .13417 L
.8885 .13217 L
.88917 .13417 L
.8899 .13618 L
.89122 .13618 L
.89234 .13618 L
.89353 .14019 L
.89484 .13417 L
.89605 .13618 L
.89728 .13417 L
.89845 .13618 L
.89949 .13618 L
Mistroke
.90062 .13819 L
.90126 .13618 L
.90196 .13417 L
.90269 .13618 L
.90338 .13417 L
.9046 .13618 L
.9059 .13819 L
.9072 .13217 L
.90842 .13417 L
.90953 .13417 L
.91072 .13417 L
.91142 .13819 L
.91216 .13819 L
.91287 .13618 L
.91352 .13417 L
.91424 .13618 L
.91493 .13819 L
.91567 .13417 L
.91648 .13618 L
.91718 .13819 L
.91782 .13417 L
.91855 .13819 L
.91924 .13417 L
.92047 .13417 L
.92116 .13417 L
.9218 .13819 L
.92304 .13417 L
.9242 .13417 L
.92684 .13417 L
.92816 .13417 L
.92941 .13417 L
.9301 .13618 L
.93085 .13618 L
.93216 .13618 L
.93462 .13618 L
.93728 .13618 L
.9385 .13618 L
.93979 .13618 L
.94089 .13417 L
.94209 .13417 L
.9471 .13417 L
.94782 .13618 L
.94849 .13618 L
.94926 .13618 L
.94997 .13417 L
.95125 .13417 L
.95197 .13417 L
.95264 .13618 L
.95373 .13217 L
.9549 .13618 L
Mistroke
.95601 .13417 L
.95702 .13417 L
.9582 .13417 L
.95949 .13217 L
.96071 .13618 L
.96184 .13217 L
.96312 .13618 L
.96432 .13417 L
.9654 .13417 L
.96656 .13417 L
.96784 .13618 L
.96848 .13417 L
.96918 .13417 L
.97043 .13819 L
.97159 .13819 L
.97282 .13618 L
.974 .13618 L
.97619 .13618 L
Mfstroke
0 -0.00027 m
1 -0.00027 L
1 .61777 L
0 .61777 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool2000001l0oooo1@00
00030?ooo`8000007P3oool3000000<0oooo0P00000M0?ooo`<00000103oool2000001d0oooo0`00
00040?ooo`8000006P3oool3000000@0oooo0P0000040?ooo`8000005`3oool300000080oooo1@00
00030?ooo`8000000`3oool00300oooo00@000000?ooo`3oool000007`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000001h0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000001/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000001X0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000001L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo000`0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000K0?ooo`D000000P3oool010000000oooo0?ooo`00000K0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000K0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`00<03oool0
10000000oooo0?ooo`00000Q0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0I0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000006`3oool40000
00<0oooo00@000000?ooo`3oool00000703oool3000000<0oooo00@000000?ooo`3oool000006P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00005`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool10000
0040oooo0@3oool00300oooo00@000000?ooo`3oool000007P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000703oool00`000000oooo000000030?ooo`040000003o
ool0oooo000001/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000K0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000G0?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`4000000@3oool10?oo
o`00<03oool010000000oooo0?ooo`00000N0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000M0?ooo`8000000`3oool010000000oooo0?ooo`00000L0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000006@3oool2000000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000F0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00340oooo0P00000P0?ooo`<00000103oool2000001l0
oooo00<000000?ooo`3oool00P3oool2000001h0oooo0P0000040?ooo`8000007@3oool3000000@0
oooo0P00000K0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000603oool00`000000
oooo0?ooo`020?ooo`<00000103oool2000000<0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo000/0?oooo000000103oool000040?ooo`0000000000000000<0
oooo0`0000030?ooo`<00000103oool010000000oooo0?ooo`3oool500000080oooo0`0000030?oo
o`<00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool000070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`0000D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3oool300000>/0oooo0P000004
0?ooo`00100000040?ooo`8000000P3oool4000000/0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool0J03oool209T001d0oooo0P2I001S
0?ooo`030000003oool0oooo0080oooo00000`000000oooo0?ooo`070?ooo`030000003oool00000
00/0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo0?ooo`1X0?ooo`80V@007@3oool209T006<0oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06P0oooo0P2I000M0?ooo`80V@00H`3oool00`000000oooo
0?ooo`020?ooo`000P3oool2000000<0oooo0`0000040?ooo`8000002@3oool3000000@0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0P00001Y0?ooo`80V@007@3oool209T00680oooo0P00
00040?ooo`00;03oool00`000000oooo0?ooo`1X0?ooo`80V@007@3oool209T006<0oooo00<00000
0?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0J03oool209T000d0oooo0P2I000>0?oo
o`80V@001P3oool209T005/0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3o
ool0J03oool209T000d0oooo0P2I000>0?ooo`80V@001P3oool209T005/0oooo00<000000?ooo`3o
ool00P3oool002`0oooo00<000000?ooo`3oool0CP3oool209T001P0oooo0P2I000=0?ooo`80V@00
3P3oool209T000H0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000C`3o
ool209T001P0oooo0P2I000=0?ooo`80V@003P3oool209T000H0oooo0P2I001J0?ooo`800000103o
ool002`0oooo00<000000?ooo`3oool0CP3oool209T001P0oooo0P2I000=0?ooo`80V@003P3oool2
09T000H0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo
04h0oooo0P2I000H0?ooo`80V@003@3oool209T000h0oooo0P2I00060?ooo`80V@00F`3oool00`00
0000oooo0?ooo`020?ooo`00;03oool2000004l0oooo0P2I000H0?ooo`80V@003@3oool209T000h0
oooo0P2I00060?ooo`80V@00FP3oool2000000@0oooo000/0?ooo`030000003oool0oooo04h0oooo
0P2I000H0?ooo`80V@003@3oool209T000h0oooo0P2I00060?ooo`80V@00F`3oool00`000000oooo
0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1>0?ooo`80V@003@3oool209T000T0oooo0P2I
000=0?ooo`80V@003P3oool209T000H0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/
0?ooo`030000003oool0oooo04h0oooo0P2I00070?ooo`80V@00103oool209T000T0oooo0P2I000=
0?ooo`80V@003P3oool309T000D0oooo0P2I001K0?ooo`030000003oool0oooo0080oooo000/0?oo
o`030000003oool0oooo01h0oooo0P2I000^0?ooo`80V@00103oool209T000030?ooo`2I0000V@00
00@0oooo0P2I00040?ooo`80V@000`3oool209T000d0oooo0P2I000>0?ooo`<0V@001@3oool209T0
05/0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00000O0?ooo`80V@009@3oool209T000L0
oooo0P2I00040?ooo`80V@0000<0oooo09T0002I00000`3oool309T000@0oooo0P2I00030?ooo`80
V@003@3oool409T000`0oooo0`2I00050?ooo`80V@00FP3oool2000000@0oooo000/0?ooo`030000
003oool0oooo01h0oooo0P2I000U0?ooo`80V@001@3oool409T000@0oooo0P2I00000`3oool0V@00
09T000030?ooo`<0V@00103oool209T000<0oooo0P2I00020?ooo`80V@002@3oool409T000`0oooo
0`2I00030?ooo`@0V@00F`3oool00`000000oooo0?ooo`020?ooo`0000@0oooo0000000000000000
0`3oool3000000<0oooo0`0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000<0
oooo0`0000040?ooo`030000003oool0oooo01h0oooo0P2I000Q0?ooo`80V@000P3oool209T000D0
oooo102I00040?ooo`80V@0000<0oooo09T0002I00000`3oool309T000@0oooo0P2I00020?ooo`<0
V@000P3oool209T000T0oooo102I000<0?ooo`<0V@000`3oool409T005/0oooo00<000000?ooo`3o
ool00P3oool000070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000200oooo0P2I000Q0?ooo`80V@00
0P3oool209T000D0oooo102I00040?ooo`80V@0000<0oooo09T0002I00000`3oool309T000@0oooo
0P2I00020?ooo`<0V@000P3oool409T000L0oooo102I000<0?ooo`<0V@000`3oool409T005/0oooo
00<000000?ooo`3oool00P3oool000050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0oooo0`00000C0?ooo`80V@002@3oool209T0
0240oooo0P2I00020?ooo`80V@001@3oool409T000@0oooo0P2I00000`3oool0V@0009T000030?oo
o`<0V@00103oool209T00080oooo0`2I00020?ooo`@0V@001`3oool409T000P0oooo0P2I00020?oo
o`<0V@000`3oool409T005X0oooo0P0000040?ooo`00100000040?ooo`8000000P3oool4000000/0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool4000000@0oooo00<000000?oo
o`3oool04`3oool209T000T0oooo0P2I000:0?ooo`80V@005@3oool209T00080oooo0P2I00050?oo
o`@0V@00103oool209T000030?ooo`2I0000V@0000<0oooo102I00030?ooo`80V@000P3oool309T0
0080oooo102I00070?ooo`@0V@00203oool209T00080oooo0`2I00030?ooo`@0V@00F`3oool00`00
0000oooo0?ooo`020?ooo`0000<000000?ooo`3oool01`3oool00`000000oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool04`3oool209T000T0oooo0P2I000:0?ooo`80V@005@3oool209T00080oooo0P2I0005
0?ooo`@0V@0000@0oooo09T0002I0000oooo0P2I00000`3oool0V@0009T000030?ooo`@0V@000`3o
ool209T00080oooo0`2I00020?ooo`@0V@001`3oool409T000P0oooo0P2I00020?ooo`<0V@000`3o
ool509T005X0oooo00<000000?ooo`3oool00P3oool000030?ooo`000000oooo00<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo
0P2I0000103oool0V@0009T0002I00080?ooo`80V@002P3oool209T00140oooo1P2I00020?ooo`80
V@001@3oool409T000040?ooo`2I0000V@000?ooo`80V@0000@0oooo09T0002I0000oooo1P2I0003
0?ooo`L0V@000P3oool409T000L0oooo102I00080?ooo`80V@000P3oool309T000<0oooo1@2I001J
0?ooo`030000003oool0oooo0080oooo00020?ooo`8000000`3oool3000000@0oooo0P0000090?oo
o`<00000103oool00`000000oooo0?ooo`030?ooo`800000103oool200000140oooo0P2I0000103o
ool0V@0009T0002I00080?ooo`80V@002P3oool209T00140oooo1P2I00020?ooo`80V@001@3oool4
09T000040?ooo`2I0000V@000?ooo`80V@0000@0oooo09T0002I0000oooo1P2I00030?ooo`L0V@00
0P3oool409T000L0oooo102I00080?ooo`80V@000P3oool309T000<0oooo1@2I001I0?ooo`800000
103oool002`0oooo00<000000?ooo`3oool0403oool209T000040?ooo`2I0000V@0009T000P0oooo
0P2I000:0?ooo`80V@004@3oool609T00080oooo0P2I00030?ooo`H0V@0000@0oooo09T0002I0000
oooo0P2I0000103oool0V@0009T0003oool609T000<0oooo1`2I00020?ooo`@0V@001`3oool409T0
00P0oooo0P2I00020?ooo`<0V@000`3oool509T005X0oooo00<000000?ooo`3oool00P3oool002`0
oooo00<000000?ooo`3oool0403oool209T000040?ooo`2I0000V@0009T000P0oooo0P2I00020?oo
o`80V@001P3oool209T00140oooo1P2I00020?ooo`80V@000`3oool609T000040?ooo`2I0000V@00
0?ooo`D0V@0000<0oooo09T0002I0000102I00030?ooo`L0V@000P3oool409T00080oooo102I0000
0`3oool0V@0009T0000209T000P0oooo0P2I00020?ooo`<0V@000`3oool509T005X0oooo00<00000
0?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0403oool209T000040?ooo`2I0000V@00
09T000P0oooo0`2I00000`3oool0V@0009T000060?ooo`80V@001@3oool209T000X0oooo1P2I0002
0?ooo`80V@000`3oool609T000040?ooo`2I0000V@000?ooo`D0V@0000<0oooo09T0002I00001@2I
00020?ooo`L0V@000P3oool409T00080oooo102I00000`3oool0V@0009T0000209T000P0oooo0P2I
00020?ooo`<0V@000`3oool509T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<00000
0?ooo`3oool0403oool209T000040?ooo`2I0000V@0009T000P0oooo0`2I0000103oool0V@0009T0
002I00040?ooo`<0V@001@3oool309T000T0oooo1P2I00020?ooo`80V@000`3oool609T000040?oo
o`2I0000V@000?ooo`d0V@000P3oool709T00080oooo102I00020?ooo`@0V@0000<0oooo09T0002I
00000P2I00080?ooo`80V@000P3oool309T000<0oooo3`2I00000`3oool0V@0009T0000409T000<0
oooo0`2I00050?ooo`/0V@001`3oool:09T000030?ooo`2I0000V@0000l0V@0000<0oooo09T0002I
00001`2I00060?ooo`030000003oool0oooo0080oooo000/0?ooo`8000004@3oool209T000040?oo
o`2I0000V@0009T000P0oooo0`2I0000103oool0V@0009T0002I00040?ooo`<0V@001@3oool309T0
00T0oooo1P2I00020?ooo`80V@000`3oool609T000040?ooo`2I0000V@000?ooo`d0V@0000<0oooo
09T0002I00001P2I00020?ooo`X0V@0000<0oooo09T0002I00000P2I00080?ooo`80V@000P3oool3
09T000<0ooooF`2I00030?ooo`800000103oool002`0oooo00<000000?ooo`3oool0103oool209T0
00X0oooo0P2I0000103oool0V@0009T0002I00080?ooo`<0V@0000@0oooo09T0002I0000V@00103o
ool309T000D0oooo0`2I00000`3oool0V@0009T000060?ooo`H0V@000P3oool209T000<0oooo1P2I
0000103oool0V@0009T0003oool=09T000030?ooo`2I0000V@0000H0V@000P3oool:09T000030?oo
o`2I0000V@000080V@00203oool209T00080oooo0`2I00000`3oool0V@0009T0000809T000@0oooo
:02I00000`3oool0V@0009T0000909T00080oooo6@2I00040?ooo`030000003oool0oooo0080oooo
000/0?ooo`030000003oool0oooo00@0oooo0P2I000:0?ooo`80V@0000@0oooo09T0002I0000V@00
0P3oool209T000@0oooo0`2I0000103oool0V@0009T0002I00040?ooo`<0V@001@3oool309T00003
0?ooo`2I0000V@0000H0oooo1P2I00020?ooo`80V@000P3oool709T000040?ooo`2I0000V@000?oo
o`d0V@0000<0oooo09T0002I00001P2I00020?ooo`X0V@0000<0oooo09T0002I00000P2I00080?oo
o`80V@000P3oool309T000030?ooo`2I0000V@0000D0V@00@03oool209T001P0oooo00<000000?oo
o`3oool00P3oool002`0oooo00<000000?ooo`3oool0103oool209T000X0oooo0P2I0000103oool0
V@0009T0002I00020?ooo`80V@000P3oool:09T000<0oooo0`2I00050?ooo`<0V@0000<0oooo09T0
002I00001P3oool609T00080oooo0P2I00020?ooo`L0V@0000@0oooo09T0002I0000oooo5P2I0000
0`3oool0V@0009T0000909T000030?ooo`2I0000V@000080V@00203oool209T00080oooo2`2I001J
0?ooo`030000003oool0oooo0080oooo000/0?ooo`8000001@3oool209T000X0oooo0P2I0000103o
ool0V@0009T0002I00020?ooo`<0V@0000<0oooo09T0002I0000202I00030?ooo`<0V@001@3oool3
09T000030?ooo`2I0000V@0000H0oooo1`2I00000`3oool0V@0009T000020?ooo`L0V@0000@0oooo
09T0002I0000oooo5P2I00000`3oool0V@0009T0000909T000030?ooo`2I0000V@000080V@00203o
ool209T00080oooo2`2I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0103oool2
09T000X0oooo0P2I0000103oool0V@0009T0002I00020?ooo`<0V@0000<0oooo09T0002I0000202I
00030?ooo`<0V@001@3oool309T000030?ooo`2I0000V@0000H0oooo1`2I00000`3oool0V@0009T0
00020?ooo`L0V@0000@0oooo09T0002I0000oooo8P2I00000`3oool0V@0009T0000209T000P0oooo
0P2I00020?ooo`/0V@00FP3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?oo
o`040?ooo`80V@002P3oool209T000040?ooo`2I0000V@0009T00080oooo0`2I00000`3oool0V@00
09T0000809T000<0oooo0`2I00030?ooo`D0V@0000<0oooo09T0002I00000P2I00040?ooo`L0V@00
00<0oooo09T0002I00000P3oool709T000040?ooo`2I0000V@000?ooob80V@0000<0oooo09T0002I
00000P2I00080?ooo`80V@000P3oool;09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo
00<000000?ooo`3oool00P3oool409T000X0oooo0P2I0000103oool0V@0009T0002I00020?ooo`<0
V@0000<0oooo09T0002I0000202I00030?ooo`<0V@000`3oool509T000030?ooo`2I0000V@000080
V@00103oool;09T000030?ooo`2I0000V@0000P0V@0000<0oooo09T0002I0000802I00000`3oool0
V@0009T0000209T000P0oooo0`2I00000`3oool0V@0009T0000909T005X0oooo00<000000?ooo`3o
ool00P3oool002`0oooo0P0000030?ooo`D0V@002@3oool209T000040?ooo`2I0000V@0009T00080
oooo0`2I00000`3oool0V@0009T0000809T000<0oooo0`2I00030?ooo`D0V@0000<0oooo09T0002I
00000P2I00040?ooo`/0V@0000<0oooo09T0002I0000202I00000`3oool0V@0009T0000P09T00003
0?ooo`2I0000V@000080V@00203oool309T000030?ooo`2I0000V@0000T0V@00F@3oool2000000@0
oooo000/0?ooo`030000003oool0oooo0080oooo1@2I00090?ooo`80V@0000@0oooo09T0002I0000
V@000P3oool309T000030?ooo`2I0000V@0000P0V@000`3oool309T000<0oooo1@2I00000`3oool0
V@0009T0000209T000@0oooo2`2I00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200
V@0000<0oooo09T0002I00000P2I00030?ooo`80V@000`3oool309T000030?ooo`2I0000V@0000T0
V@00FP3oool00`000000oooo0?ooo`020?ooo`0000@0oooo00000000000000000`3oool3000000<0
oooo0`0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000<0oooo0`0000040?oo
o`030000003oool0oooo0080oooo1@2I00070?ooo`@0V@0000D0oooo09T0002I0000V@000?ooo`04
09T000030?ooo`2I0000V@0000P0V@000`3oool309T000030?ooo`2I0000V@0000D0V@0000<0oooo
09T0002I00000P2I00040?ooo`/0V@0000<0oooo09T0002I0000202I00000`3oool0V@0009T0000P
09T000030?ooo`2I0000V@000080V@000`3oool209T000<0oooo0`2I00000`3oool0V@0009T00009
09T005X0oooo00<000000?ooo`3oool00P3oool000070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo1@2I00030?ooo`80V@000P3oool409T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0
002I0000202I00030?ooo`<0V@0000<0oooo09T0002I00001@2I00000`3oool0V@0009T0000209T0
00@0oooo2`2I00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200V@0000<0oooo09T0
002I0000102I00000`3oool0V@0009T000030?ooo`<0V@0000<0oooo09T0002I00002@2I001J0?oo
o`030000003oool0oooo0080oooo00001@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo0?ooo`<000000P3oool509T000<0oooo0P2I
00020?ooo`@0V@0000<0oooo09T0002I00001P2I00000`3oool0V@0009T0000809T000030?ooo`2I
0000V@0000<0V@0000<0oooo09T0002I00001@2I00000`3oool0V@0009T0000209T000@0oooo2`2I
00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200V@0000<0oooo09T0002I0000102I
00000`3oool0V@0009T000030?ooo`l0V@00F@3oool2000000@0oooo0004000000@0oooo0P000002
0?ooo`@000002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@00000103o
ool00`000000oooo0?ooo`020?ooo`D0V@000P3oool309T00080oooo3@2I00000`3oool0V@0009T0
000809T000030?ooo`2I0000V@0000/0V@0000<0oooo09T0002I00000P2I00040?ooo`/0V@0000<0
oooo09T0002I0000202I00000`3oool0V@0009T0000P09T000030?ooo`2I0000V@0000@0V@0000<0
oooo09T0002I00000`3oool?09T005X0oooo00<000000?ooo`3oool00P3oool000030000003oool0
oooo00L0oooo00<000000?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0080oooo1@2I00020?ooo`<0V@00
0P3oool=09T000030?ooo`2I0000V@0000P0V@0000<0oooo09T0002I00002`2I00000`3oool0V@00
09T0000209T000@0oooo2`2I00000`3oool0V@0009T0000809T000030?ooo`2I0000V@000200V@00
00<0oooo09T0002I0000102I00000`3oool0V@0009T000030?ooo`l0V@00FP3oool00`000000oooo
0?ooo`020?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool509T00080oooo0`2I00020?ooo`d0
V@0000<0oooo09T0002I0000202I00000`3oool0V@0009T0000@09T000@0oooo2`2I00000`3oool0
V@0009T0000[09T000030?ooo`2I0000V@0000@0V@0000<0oooo09T0002I00000P3oool@09T005X0
oooo00<000000?ooo`3oool00P3oool00080oooo0P0000030?ooo`<00000103oool2000000T0oooo
0`0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo
1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0000809T000030?oo
o`2I0000V@000100V@00103oool;09T000030?ooo`2I0000V@0002/0V@0000<0oooo09T0002I0000
102I00000`3oool0V@0009T000020?oooa00V@00FP3oool00`000000oooo0?ooo`020?ooo`00;03o
ool2000000<0oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0
000809T000030?ooo`2I0000V@000100V@00103oool;09T000030?ooo`2I0000V@000380V@0000D0
oooo09T0002I0000V@000?ooo`0@09T005T0oooo0P0000040?ooo`00;03oool00`000000oooo0?oo
o`020?ooo`D0V@000P3oool409T000030?ooo`2I0000V@0000/0V@0000<0oooo09T0002I0000202I
00000`3oool0V@0009T0000A09T000<0oooo2`2I00000`3oool0V@0009T0000b09T000050?ooo`2I
0000V@0009T0003oool0402I001J0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003o
ool0oooo0080oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0
000809T000030?ooo`2I0000V@000140V@000`3oool;09T000030?ooo`2I0000V@000380V@0000D0
oooo09T0002I0000V@000?ooo`0@09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<0
00000?ooo`3oool00P3oool509T00080oooo102I00000`3oool0V@0009T0000;09T000030?ooo`2I
0000V@0000P0V@0000<0oooo09T0002I00004@2I00030?ooo`/0V@0000<0oooo09T0002I0000<P2I
00001@3oool0V@0009T0002I0000oooo0100V@00FP3oool00`000000oooo0?ooo`020?ooo`00;03o
ool2000000<0oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I00000`3oool0V@0009T0
000L09T000<0oooo2`2I00000`3oool0V@0009T0000b09T000050?ooo`2I0000V@0009T0003oool0
402I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool00P3oool509T00080oooo102I
00000`3oool0V@0009T0000;09T000030?ooo`2I0000V@0001`0V@000`3oool;09T000030?ooo`2I
0000V@000380V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003oool0oooo0080oooo000/
0?ooo`030000003oool0oooo0080oooo1@2I00020?ooo`@0V@0000<0oooo09T0002I00002`2I0000
0`3oool0V@0009T0000L09T000<0oooo@02I00000`3oool0V@0009T0000B09T005X0oooo00<00000
0?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool00P3oool509T00080oooo102I00000`3o
ool0V@0009T0000Z09T000<0oooo@02I00000`3oool0V@0009T0000B09T005X0oooo00<000000?oo
o`3oool00P3oool002`0oooo0P0000030?ooo`D0V@000P3ooolc09T000030?ooo`2I0000V@0003h0
V@0000<0oooo09T0002I00004P2I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0
0P3oool509T00080oooo<`2I00000`3oool0V@0009T0000n09T000030?ooo`2I0000V@000180V@00
FP3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`020?ooo`D0V@000P3o
oolc09T000030?ooo`2I0000V@0003h0V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003o
ool0oooo0080oooo000/0?ooo`030000003oool0oooo0080oooo1@2I00000`3oool0V@0009T0000b
09T000030?ooo`2I0000V@0003h0V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003oool0
oooo0080oooo000/0?ooo`800000103oool409T000030?ooo`2I0000V@000380V@0000<0oooo09T0
002I0000?P2I00000`3oool0V@0009T0000B09T005T0oooo0P0000040?ooo`00;03oool00`000000
oooo0?ooo`030?ooogX0V@0000<0oooo09T0002I00004P2I001J0?ooo`030000003oool0oooo0080
oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo00@000000?ooo`3o
ool0oooo1@0000020?ooo`<000000`3oool3000000@0oooo00<000000?ooo`3oool00`3ooomj09T0
00030?ooo`2I0000V@000180V@00FP3oool00`000000oooo0?ooo`020?ooo`0000L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000001@3ooomj09T000030?ooo`2I0000V@000180V@00FP3oool00`000000
oooo0?ooo`020?ooo`0000D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`3oool3000000<0ooooNP2I00000`3oool0V@0009T0000B
09T005T0oooo0P0000040?ooo`00100000040?ooo`8000000P3oool4000000/0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool00`3ooomj
09T000030?ooo`2I0000V@000180V@00FP3oool00`000000oooo0?ooo`020?ooo`0000<000000?oo
o`3oool01`3oool00`000000oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3ooomj09T000030?ooo`2I
0000V@000180V@00FP3oool00`000000oooo0?ooo`020?ooo`0000<0oooo0000003oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool000000080oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3ooon?09T005X0oooo00<000000?ooo`3oool00P3oool00080oooo0P0000030?ooo`<00000103o
ool2000000T0oooo0`0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003o
ool0oooo00<0ooooS`2I001J0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000103ooon?
09T005T0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`030?ooohl0V@00FP3oool00`00
0000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`030?ooohl0V@00FP3oool00`000000
oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`030?oooaL0V@0000<0oooo09T0002I0000
3@2I00000`3oool0V@0009T0001U09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00
00040?oooaL0V@0000<0oooo09T0002I00003@2I00000`3oool0V@0009T0001U09T005T0oooo0P00
00040?ooo`00;03oool00`000000oooo0?ooo`030?oooaL0V@0000<0oooo09T0002I00003@2I0000
0`3oool0V@0009T0001U09T005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?oo
o`3oool00`3ooolG09T000030?ooo`2I0000V@0000d0V@0000<0oooo09T0002I0000I@2I001J0?oo
o`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00<0oooo402I00000`3oool0
V@0009T0000409T000030?ooo`2I0000V@0000d0V@0000<0oooo09T0002I0000I@2I001J0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`800000103oool@09T000030?ooo`2I0000V@0000@0V@00
00<0oooo09T0002I00003@2I00000`3oool0V@0009T0001U09T005T0oooo0P0000040?ooo`00;03o
ool00`000000oooo0?ooo`030?oooa00V@0000<0oooo09T0002I0000102I0000103oool0V@0009T0
002I00020?ooo`X0V@0000<0oooo09T0002I0000I@2I001J0?ooo`030000003oool0oooo0080oooo
000/0?ooo`030000003oool0oooo00<0oooo402I00000`3oool0V@0009T0000409T000040?ooo`2I
0000V@0009T00080oooo2P2I00000`3oool0V@0009T0001U09T005X0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<000000?ooo`3oool00`3oool@09T000030?ooo`2I0000V@0000@0V@0000@0
oooo09T0002I0000V@000P3oool909T00080ooooI`2I001J0?ooo`030000003oool0oooo0080oooo
000/0?ooo`800000103oool@09T000030?ooo`2I0000V@0000@0V@0000@0oooo09T0002I0000V@00
0P3oool909T00080ooooI`2I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool00`3o
ool@09T000030?ooo`2I0000V@0000@0V@0000@0oooo09T0002I0000V@000P3oool909T00080oooo
I`2I001J0?ooo`030000003oool0oooo0080oooo0000103oool000000000000000030?ooo`<00000
0`3oool3000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<000000`3oool3000000@0
oooo00<000000?ooo`3oool00`3oool509T000030?ooo`2I0000V@0000P0V@0000<0oooo09T0002I
0000102I0000103oool0V@0009T0002I00020?ooo`T0V@000P3ooomW09T005X0oooo00<000000?oo
o`3oool00P3oool000070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo1@2I00000`3oool0
V@0009T0000809T000030?ooo`2I0000V@0000@0V@0000<0oooo09T0002I0000103oool809T00080
oooo602I00000`3oool0V@0009T0001<09T005X0oooo00<000000?ooo`3oool00P3oool000050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo000000030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool0oooo0`0000030?ooo`D0V@000`3oool809T000030?ooo`2I0000V@0000@0V@0000<0oooo
09T0002I0000103oool809T00080oooo602I00000`3oool0V@0009T0001<09T005T0oooo0P000004
0?ooo`00100000040?ooo`8000000P3oool4000000/0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool00`3oool509T000<0oooo202I0000
0`3oool0V@0009T0000409T000030?ooo`2I0000V@0000H0oooo1P2I00020?oooaP0V@0000<0oooo
09T0002I0000C02I001J0?ooo`030000003oool0oooo0080oooo00000`000000oooo0?ooo`070?oo
o`030000003oool0000000/0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`D0V@000`3oool809T000030?ooo`2I
0000V@0000@0V@0000<0oooo09T0002I00001P3oool609T00080oooo602I00000`3oool0V@0009T0
000309T000030?ooo`2I0000V@0004H0V@00FP3oool00`000000oooo0?ooo`020?ooo`0000<0oooo
0000003oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool509T000<0oooo202I00001@3oool0V@0009T0002I0000oooo0080
V@0000<0oooo09T0002I00001P3oool609T00080oooo602I00000`3oool0V@0009T0000309T00003
0?ooo`2I0000V@0001H0V@000P3oool^09T005X0oooo00<000000?ooo`3oool00P3oool00080oooo
0P0000030?ooo`<00000103oool2000000T0oooo0`0000040?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo1@2I00030?ooo`P0V@0000D0oooo09T0002I0000
V@000?ooo`0209T000030?ooo`2I0000V@0000L0oooo1@2I00020?oooaP0V@0000<0oooo09T0002I
00000`2I00000`3oool0V@0009T0000F09T00080oooo502I00020?oooaP0V@00FP3oool00`000000
oooo0?ooo`020?ooo`00;03oool2000000@0oooo1@2I00030?ooo`P0V@0000D0oooo09T0002I0000
V@000?ooo`0209T000030?ooo`2I0000V@0000L0oooo1@2I00020?ooo`H0V@0000<0oooo09T0002I
00003`2I00000`3oool0V@0009T0000309T000030?ooo`2I0000V@0001H0V@000P3ooolD09T00080
oooo602I001I0?ooo`800000103oool002`0oooo00<000000?ooo`3oool00`3oool409T000@0oooo
202I00020?ooo`80V@0000@0oooo09T0002I0000oooo0P2I00070?ooo`D0V@000P3oool609T00003
0?ooo`2I0000V@0000l0V@0000<0oooo09T0002I00000`2I00000`3oool0V@0009T0000C09T00003
0?ooo`2I0000V@000080oooo502I00020?oooaP0V@00FP3oool00`000000oooo0?ooo`020?ooo`00
;03oool00`000000oooo0?ooo`030?ooo`@0V@00103oool809T00080oooo0P2I0000103oool0V@00
09T0003oool209T000L0oooo1@2I00020?ooo`H0V@0000<0oooo09T0002I00003`2I00000`3oool0
V@0009T0000309T000030?ooo`2I0000V@0001<0V@0000<0oooo09T0002I00000P3ooolD09T00080
oooo602I001J0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00D0oooo
0P2I00040?ooo`P0V@000P3oool209T000040?ooo`2I0000V@000?ooo`80V@001`3oool509T00080
oooo1P2I00000`3oool0V@0009T0000309T000030?ooo`2I0000V@0000T0V@0000<0oooo09T0002I
00000`2I00020?oooa@0V@0000<0oooo09T0002I00000P3ooolD09T00080oooo602I001J0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`8000001P3oool209T000@0oooo202I00020?ooo`80V@00
00@0oooo09T0002I0000oooo0P2I00090?ooo`<0V@000P3oool609T000030?ooo`2I0000V@0000<0
V@0000<0oooo09T0002I00002@2I00000`3oool0V@0009T0000209T000<0oooo502I00000`3oool0
V@0009T000020?oooa@0V@000P3ooolF09T005/0oooo0P0000040?ooo`00;03oool00`000000oooo
0?ooo`050?ooo`80V@001P3oool609T00080oooo0P2I0000103oool0V@0009T0003oool209T000T0
oooo0`2I00020?ooo`H0V@0000<0oooo09T0002I00000`2I00000`3oool0V@0009T0000909T00080
oooo0`2I00030?oooa@0V@0000<0oooo09T0002I00000P3ooolD09T00080oooo5P2I001L0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00D0oooo0P2I00060?ooo`H0V@00
0P3oool209T000040?ooo`2I0000V@000?ooo`80V@002@3oool309T00080oooo1P2I0000103oool0
V@0009T0003oool209T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0002I00000P3oool309T0
00<0oooo502I00000`3oool0V@0009T000020?oooa@0V@000P3ooolF09T005`0oooo00<000000?oo
o`3oool00P3oool002`0oooo00<000000?ooo`3oool01@3oool209T000H0oooo1P2I00020?ooo`80
V@0000@0oooo09T0002I0000oooo0P2I00090?ooo`<0V@000P3oool609T000040?ooo`2I0000V@00
0?ooo`80V@0000<0oooo09T0002I00001P2I00000`3oool0V@0009T000020?ooo`<0V@000`3ooolD
09T000030?ooo`2I0000V@000080oooo1`2I00000`3oool0V@0009T0000:09T00080oooo1@2I0000
0`3oool0V@0009T0000>09T005`0oooo00<000000?ooo`3oool00P3oool002`0oooo0P0000060?oo
o`80V@001P3oool609T00080oooo0P2I0000103oool0V@0009T0003oool209T000T0oooo0`2I0002
0?ooo`80V@000P3oool209T000040?ooo`2I0000V@000?ooo`80V@0000<0oooo09T0002I00001P2I
00000`3oool0V@0009T000020?ooo`<0V@000`3ooolD09T000030?ooo`2I0000V@000080oooo1`2I
00000`3oool0V@0009T0000609T00080oooo0P2I00020?ooo`D0V@0000<0oooo09T0002I00000`2I
00000`3oool0V@0009T0000809T005/0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`05
0?ooo`80V@001P3oool609T00080oooo0P2I00040?ooo`80V@002@3oool309T00080oooo0P2I0002
0?ooo`80V@0000@0oooo09T0002I0000oooo0P2I00000`3oool0V@0009T0000609T000030?ooo`2I
0000V@000080oooo0`2I00030?oooa@0V@0000<0oooo09T0002I00000P3oool709T000030?ooo`2I
0000V@0000H0V@000P3oool209T00080oooo1@2I00000`3oool0V@0009T0000309T000030?ooo`2I
0000V@0000P0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`05
0?ooo`80V@001P3oool609T00080oooo0P2I00040?ooo`80V@002@3oool309T00080oooo0P2I0002
0?ooo`80V@00103oool209T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0002I00000P3oool3
09T000<0oooo1P2I00000`3oool0V@0009T0000;09T000030?ooo`2I0000V@000080oooo1`2I0000
0`3oool0V@0009T0000609T00080oooo0P2I00020?ooo`80V@0000@0oooo09T0002I0000oooo1@2I
00000`3oool0V@0009T0000809T005`0oooo00<000000?ooo`3oool00P3oool002`0oooo00<00000
0?ooo`3oool01@3oool209T000H0oooo1P2I00020?ooo`80V@00103oool209T000X0oooo0P2I0002
0?ooo`80V@00203oool209T000030?ooo`2I0000V@0000H0V@0000<0oooo09T0002I00000P3oool3
09T000<0oooo1P2I00000`3oool0V@0009T0000;09T000030?ooo`2I0000V@000080oooo1`2I0000
0`3oool0V@0009T0000609T00080oooo0P2I00020?ooo`80V@0000@0oooo09T0002I0000oooo1@2I
00000`3oool0V@0009T0000809T005`0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00000>
0?ooo`D0V@002@3oool209T000X0oooo0P2I00020?ooo`80V@00203oool209T000030?ooo`2I0000
V@0000H0V@0000<0oooo09T0002I00000P3oool309T000<0oooo1P2I00000`3oool0V@0009T0000;
09T000030?ooo`2I0000V@000080oooo1`2I00000`3oool0V@0009T0000609T00080oooo0P2I0002
0?ooo`80V@0000@0oooo09T0002I0000oooo1@2I00000`3oool0V@0009T0000809T005/0oooo0P00
00040?ooo`00;03oool00`000000oooo0?ooo`0=0?ooo`D0V@005@3oool209T00080oooo0P2I000<
0?ooo`L0V@0000<0oooo09T0002I00000P3oool309T000<0oooo1P2I00000`3oool0V@0009T0000;
09T000030?ooo`2I0000V@000080oooo1`2I00000`3oool0V@0009T0000509T000<0oooo0P2I0002
0?ooo`80V@0000@0oooo09T0002I0000oooo1@2I0000103oool0V@0009T0003oool709T005`0oooo
00<000000?ooo`3oool00P3oool000040?ooo`0000000000000000<0oooo0`0000030?ooo`<00000
103oool010000000oooo0?ooo`3oool500000080oooo0`0000030?ooo`<00000103oool00`000000
oooo0?ooo`0=0?ooo`<0V@005`3oool209T00080oooo0P2I000>0?ooo`D0V@0000<0oooo09T0002I
00000P3oool309T000<0oooo1P2I00000`3oool0V@0009T0000409T000030?ooo`2I0000V@0000@0
V@0000<0oooo09T0002I00000P3oool709T000030?ooo`2I0000V@0000<0V@001@3oool209T00080
oooo0P2I0000103oool0V@0009T0003oool509T000030?ooo`2I0000V@000080oooo1P2I001L0?oo
o`030000003oool0oooo0080oooo00001`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`<0
V@006`3oool209T000h0oooo1@2I00000`3oool0V@0009T000020?ooo`<0V@000`3oool609T00004
0?ooo`2I0000V@000?ooo`<0V@000`3oool409T000030?ooo`2I0000V@000080oooo1`2I00000`3o
ool0V@0009T0000309T000D0oooo0P2I00050?ooo`80V@0000<0oooo09T0002I00000`2I00000`3o
ool0V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`020?ooo`0000D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3o
ool3000000d0oooo0P2I000L0?ooo`80V@003P3oool509T000030?ooo`2I0000V@000080oooo0`2I
00030?ooo`H0V@0000@0oooo09T0002I0000oooo0`2I00030?ooo`@0V@0000<0oooo09T0002I0000
0P3oool709T000030?ooo`2I0000V@0000<0V@00303oool209T000030?ooo`2I0000V@0000<0V@00
00<0oooo09T0002I00000P3oool609T005/0oooo0P0000040?ooo`00100000040?ooo`8000000P3o
ool4000000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool4000000@0oooo
00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?ooo`80V@001`3oool309T000<0oooo
1P2I0000103oool0V@0009T0003oool309T000<0oooo102I00000`3oool0V@0009T000020?ooo`L0
V@0000<0oooo09T0002I00000`2I000<0?ooo`80V@0000<0oooo09T0002I00000`2I00000`3oool0
V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`020?ooo`0000<000000?ooo`3oool0
1`3oool00`000000oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?oo
o`80V@001`3oool309T000<0oooo1P2I0000103oool0V@0009T0003oool309T000<0oooo102I0000
0`3oool0V@0009T000020?ooo`L0V@0000<0oooo09T0002I00000`2I000<0?ooo`80V@0000<0oooo
09T0002I00000`2I00000`3oool0V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`02
0?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?ooo`80V@001`3o
ool309T000<0oooo0`2I00000`3oool0V@0009T000040?ooo`<0V@000`3oool409T000030?ooo`2I
0000V@000080oooo1`2I00000`3oool0V@0009T0000309T000`0oooo0P2I00000`3oool0V@0009T0
000309T000030?ooo`2I0000V@000080oooo1P2I001L0?ooo`030000003oool0oooo0080oooo0002
0?ooo`8000000`3oool3000000@0oooo0P0000090?ooo`<00000103oool00`000000oooo0?ooo`03
0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`80V@00703oool209T000l0oooo0P2I0007
0?ooo`<0V@000`3oool309T000030?ooo`2I0000V@0000@0oooo0`2I00030?ooo`@0V@0000<0oooo
09T0002I00000P3oool609T00080oooo1@2I000<0?ooo`80V@0000<0oooo09T0002I00000`2I0000
0`3oool0V@0009T000020?ooo`H0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool20000
00h0oooo0P2I000L0?ooo`80V@003`3oool209T000L0oooo0`2I00030?ooo`<0V@0000<0oooo09T0
002I0000103oool309T000<0oooo0P2I00070?ooo`H0V@000P3oool509T000`0oooo0P2I00000`3o
ool0V@0009T0000309T000030?ooo`2I0000V@000080oooo1P2I001K0?ooo`800000103oool002`0
oooo00<000000?ooo`3oool03@3oool209T001`0oooo0P2I000?0?ooo`80V@001`3oool309T000<0
oooo0`2I00000`3oool0V@0009T000040?ooo`<0V@000`3oool209T000L0oooo1P2I00020?ooo`D0
V@00303oool209T000030?ooo`2I0000V@000080V@000P3oool209T000<0oooo1@2I001L0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo00d0oooo0P2I000L0?ooo`80V@00
3`3oool209T000L0oooo0`2I00030?ooo`<0V@0000<0oooo09T0002I0000103oool309T000<0oooo
0P2I00070?ooo`D0V@000`3oool509T000`0oooo0P2I00000`3oool0V@0009T0000209T00080oooo
0P2I00030?ooo`D0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?oo
o`0=0?ooo`80V@00;@3oool209T000L0oooo0`2I00030?ooo`<0V@0000<0oooo09T0002I0000103o
ool309T000`0oooo1@2I00030?ooo`D0V@00303oool209T000030?ooo`2I0000V@000080V@000P3o
ool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`8000003P3oool2
09T002d0oooo0P2I00070?ooo`<0V@000`3oool209T00080oooo0P2I00050?ooo`80V@00303oool5
09T000<0oooo1@2I000?0?ooo`@0V@000P3oool209T000<0oooo1@2I001K0?ooo`800000103oool0
02`0oooo00<000000?ooo`3oool03@3oool209T002d0oooo0P2I00070?ooo`<0V@000`3oool209T0
0080oooo0P2I00050?ooo`80V@00303oool509T000<0oooo1@2I000?0?ooo`@0V@000P3oool209T0
00<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo03`0
oooo0P2I00070?ooo`<0V@000`3oool209T00080oooo0P2I00050?ooo`80V@00303oool509T000<0
oooo1@2I000?0?ooo`@0V@000P3oool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080
oooo000/0?ooo`030000003oool0oooo03`0oooo0P2I00070?ooo`<0V@000`3oool209T00080oooo
0P2I00050?ooo`80V@00303oool209T000H0oooo1@2I000?0?ooo`@0V@000P3oool209T000<0oooo
1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000?@3oool209T000L0oooo0`2I
00030?ooo`80V@000P3oool209T000D0oooo0P2I000<0?ooo`80V@001P3oool409T00100oooo102I
00020?ooo`80V@000`3oool509T005/0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`0l
0?ooo`80V@001`3oool309T000<0oooo0P2I00020?ooo`80V@001@3oool209T000`0oooo0P2I0006
0?ooo`@0V@00403oool409T00080oooo0P2I00030?ooo`D0V@00G03oool00`000000oooo0?ooo`02
0?ooo`00;03oool00`000000oooo0?ooo`0l0?ooo`80V@001`3oool309T000<0oooo0P2I00020?oo
o`80V@001@3oool209T000`0oooo0P2I00060?ooo`@0V@00403oool409T00080oooo0P2I00030?oo
o`D0V@00G03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`150?ooo`80
V@00103oool209T00080oooo0P2I00050?ooo`80V@00303oool209T000H0oooo102I000@0?ooo`@0
V@000P3oool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000
AP3oool209T000@0oooo0P2I00020?ooo`80V@001@3oool209T000`0oooo0P2I00060?ooo`@0V@00
403oool309T000<0oooo0P2I00030?ooo`D0V@00F`3oool2000000@0oooo000/0?ooo`030000003o
ool0oooo04D0oooo0P2I00040?ooo`80V@000P3oool209T000D0oooo0P2I000<0?ooo`80V@001P3o
ool409T00100oooo0`2I00030?ooo`80V@000`3oool509T005`0oooo00<000000?ooo`3oool00P3o
ool000040?ooo`0000000000000000<0oooo0`0000030?ooo`<00000103oool010000000oooo0?oo
o`3oool500000080oooo0`0000030?ooo`<00000103oool00`000000oooo0?ooo`150?ooo`80V@00
103oool209T00080oooo0P2I00050?ooo`80V@00303oool209T000H0oooo102I000@0?ooo`<0V@00
0`3oool209T000<0oooo1@2I001L0?ooo`030000003oool0oooo0080oooo00001`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000170?ooo`80V@00103oool209T00080oooo0P2I00050?ooo`80V@00303o
ool209T000P0oooo0P2I000@0?ooo`<0V@000`3oool209T000<0oooo1@2I001L0?ooo`030000003o
ool0oooo0080oooo00001@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo0?ooo`<00000A@3oool209T000P0oooo0P2I000C0?ooo`80
V@00203oool209T00100oooo0`2I00030?ooo`80V@00103oool409T005/0oooo0P0000040?ooo`00
100000040?ooo`8000000P3oool4000000/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool4000000@0oooo00<000000?ooo`3oool0A@3oool209T000P0oooo0P2I000C0?ooo`80
V@006P3oool209T000@0oooo0P2I00040?ooo`@0V@00G03oool00`000000oooo0?ooo`020?ooo`00
00<000000?ooo`3oool01`3oool00`000000oooo0000000;0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0A@3oool209T0
00P0oooo0P2I000C0?ooo`80V@006P3oool209T000@0oooo0P2I00040?ooo`<0V@00G@3oool00`00
0000oooo0?ooo`020?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo0P000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A@3oool209T000P0oooo0P2I000C
0?ooo`80V@00803oool209T000@0oooo0`2I001M0?ooo`030000003oool0oooo0080oooo00020?oo
o`8000000`3oool3000000@0oooo0P0000090?ooo`<00000103oool00`000000oooo0?ooo`030?oo
o`800000103oool00`000000oooo0?ooo`1?0?ooo`80V@004`3oool209T00200oooo0P2I00040?oo
o`<0V@00G@3oool00`000000oooo0?ooo`020?ooo`00;03oool2000006D0oooo0P2I000P0?ooo`80
V@00103oool309T005`0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1T0?ooo`80V@00
803oool209T000@0oooo0`2I001M0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003o
ool0oooo08H0oooo0P2I00040?ooo`<0V@00G@3oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`260?ooo`80V@00103oool309T005d0oooo00<000000?ooo`3oool00P3oool0
02`0oooo0P0000270?ooo`80V@00103oool309T005`0oooo0P0000040?ooo`00;03oool00`000000
oooo0?ooo`260?ooo`80V@00103oool309T005d0oooo00<000000?ooo`3oool00P3oool002`0oooo
00<000000?ooo`3oool0QP3oool209T000D0oooo0P2I001M0?ooo`030000003oool0oooo0080oooo
000/0?ooo`030000003oool0oooo08H0oooo0P2I00050?ooo`80V@00G@3oool00`000000oooo0?oo
o`020?ooo`00;03oool2000008L0oooo0P2I00050?ooo`80V@00G03oool2000000@0oooo000/0?oo
o`030000003oool0oooo08H0oooo0P2I00050?ooo`80V@00G@3oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`260?ooo`80V@001@3oool209T005d0oooo00<000000?ooo`3o
ool00P3oool002`0oooo00<000000?ooo`3oool0QP3oool209T006@0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo000/0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3oool2000000@0oooo000/
0?oooo000000103oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-26.746, 636.216, 0.527865, \
2.37356*^-13}},
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[TextData[{
  "If ",
  StyleBox["$StrongErrorChecking", "MR"],
  " set to ",
  StyleBox["True", "MR"],
  " then messages are returned and the plot is not created ",
  StyleBox["whether or not",
    FontSlant->"Italic"],
  " there is an ",
  StyleBox["Evaluate", "MR"],
  " acting within the ",
  StyleBox["Plot", "MR"],
  " function. This is because ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Payment",
          "MR"], 
        StyleBox["[",
          "MR"], 
        RowBox[{
          StyleBox["100000",
            "TI"], 
          StyleBox[",",
            "MR"], 
          StyleBox["interestRateTable",
            "TI"], 
          StyleBox[",",
            "MR"], 
          StyleBox["30",
            "TI"], 
          StyleBox[",",
            "MR"], 
          StyleBox["\[Mu]",
            "TI"]}], 
        StyleBox["]",
          "MR"]}]], "Input",
    GeneratedCell->True],
  " returns unevaluated (and hence is not a number) if ",
  StyleBox["$StrongErrorChecking", "MR"],
  " set to ",
  StyleBox["True", "MR"],
  StyleBox[".", "Text"]
}], "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetErrorChecking", "[", 
      RowBox[{"True", ",", " ", "True"}], "]"}]], "Input",
  CellLabel->"In[20]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"True", ",", "True"}], "}"}]], "Output",
  CellLabel->"Out[20]=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Evaluate", "[", 
            RowBox[{"Payment", "[", 
              RowBox[{
              "100000", ",", " ", "interestRateTable", ",", " ", "30", ",", 
                "\[Mu]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"\[Mu]", ",", "0", ",", "360"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Principal\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"num\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check to be sure that the specific argument values, \
\\!\\({12, 12, 12, 12, 12, \[Mu]}\\), for the function \\!\\(Payment\\) are \
numerical.\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"LoanFunctions", "::", "\<\"checkvars\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Check the values of the arguments of the function \
\\!\\(Payment\\) to be sure that they are valid inputs.\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"General", "::", "\<\"stop\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Further output of \\!\\(LoanFunctions :: \\\"checkvars\
\\\"\\) will be suppressed during this calculation.\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "::", "\<\"plnr\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"\\!\\(\[LeftSkeleton] 1 \[RightSkeleton]\\) is not a \
machine-size real number at \\!\\(\[Mu]\\) = \
\\!\\(0.000014999999999999999`\\).\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "::", "\<\"plnr\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"\\!\\(\[LeftSkeleton] 1 \[RightSkeleton]\\) is not a \
machine-size real number at \\!\\(\[Mu]\\) = \
\\!\\(14.604116966249684`\\).\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "::", "\<\"plnr\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"\\!\\(\[LeftSkeleton] 1 \[RightSkeleton]\\) is not a \
machine-size real number at \\!\\(\[Mu]\\) = \
\\!\\(30.531167949374524`\\).\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"General", "::", "\<\"stop\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"Further output of \\!\\(Plot :: \\\"plnr\\\"\\) will \
be suppressed during this calculation.\"\>"}]], "Message",
  CellLabel->"From In[21]:=",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool2000002/0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000008`3oool2
000000@0oooo00<000000?ooo`3oool00`3oool3000002@0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00000T0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000:P3oool3
000000L0oooo000I0?ooo`040000003oool0oooo000002T0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000R0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008P3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo
0?ooo`060?ooo`006@3oool010000000oooo0?ooo`00000Y0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000070?ooo`D000008`3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008P3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`060?ooo`00
6@3oool010000000oooo0?ooo`00000Y0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool08@3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000002@0oooo00@0
00000?ooo`3oool000001`3oool4000002<0oooo00@000000?ooo`3oool00000203oool3000002/0
oooo00<000000?ooo`3oool01P3oool001T0oooo00@000000?ooo`3oool00000:@3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008P3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0000002@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0T0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000Z0?oo
o`030000003oool0oooo00H0oooo000I0?ooo`040000003oool0oooo000002T0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool000000280oooo00@000000?ooo`3oool00000
2@3oool2000002@0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0S0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`800000203oool0
01X0oooo0P00000[0?ooo`8000002@3oool3000002@0oooo0P00000;0?ooo`030000003oool0oooo
02<0oooo0P00000:0?ooo`800000903oool2000000T0oooo0`00000[0?ooo`030000003oool0oooo
00H0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E0?oo
ool000002`0000010?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool100000040
oooo000=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00`3oool100000040
oooo000=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`40
00000@3oool000d0oooo00@000000?ooo`3oool00000103oool300000?l0oooo1P3oool200000040
oooo000=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`40
00000@3oool000d0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`L0
oooo0@0000010?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool70?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo
0P00003o0?ooo`L0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool200000?l0oooo1`3oool2
00000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`03
0000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo
1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E
0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo
0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040
oooo000E0?ooo`800000o`3oool70?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`400000
0@3oool00080oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo
0?ooo`3o0?ooo`L0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool000050?oo
o`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`<00000o`3oool60?ooo`80
00000@3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?l0oooo1`3oool100000040oooo00001@3oool000000?ooo`3oool0000000L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0?l0oooo1`3oool10000
0040oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo00020?ooo`8000002@3oool30000
00D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo0P00003o
0?ooo`L0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo0@0000010?ooo`005@3oool200000?l0oooo1`3oool200000040oooo000E0?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`03
0000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo
1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E
0?ooo`800000o`3oool70?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool0
0080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`030000003oool0oooo
0?l0oooo1`3oool100000040oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`0000D0oooo0000003o
ool0oooo000000070?ooo`D00000103oool300000?l0oooo1P3oool200000040oooo00001@3oool0
00000?ooo`3oool0000000L0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`3o
0?ooo`L0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool000050?ooo`000000oooo
0?ooo`0000002@3oool2000000D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool0
0080oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool70?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`4000000@3oool001D0oooo0P00003o0?ooo`L0oooo0P0000010?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool200000?l0oooo
1`3oool200000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E
0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo
0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040
oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool1
00000040oooo000E0?ooo`800000o`3oool70?ooo`8000000@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool00080oooo0P0000040?ooo`030000003oool0oooo
0080oooo0`0000050?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo00001@3oool0
00000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0?l0oooo1`3oool100000040oooo00001@3oool000000?ooo`3oool0000000L0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo0000
1@3oool000000?ooo`3oool0000000L0oooo100000050?ooo`<00000o`3oool60?ooo`8000000@3o
ool000050?ooo`000000oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo00001@3oool000000?ooo`3oool0000000P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`000P3oool2
000000X0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?oo
o`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0
oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo
000E0?ooo`800000o`3oool70?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool7
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0o`3oool70?ooo`4000000@3oool001D0oooo0P00003o0?ooo`L0oooo0P0000010?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool2
00000?l0oooo1`3oool200000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool10000
0040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000
003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3o
ool100000040oooo00020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo00000007
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@00
00010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`<000001@3oool300000?l0oooo1P3oool200000040oooo00001@3oool000000?oo
o`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0?l0
oooo1`3oool100000040oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo00020?ooo`80
00002@3oool3000000D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo0P00003o0?ooo`L0
oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool200000?l0oooo1`3oool200000040oooo000E
0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo
0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040
oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool1
00000040oooo000E0?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000E0?ooo`80
0000o`3oool70?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0o`3oool70?oo
o`4000000@3oool000d0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo1`3oool100000040
oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool70?ooo`400000
0@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@00
00010?ooo`003P3oool00`000000oooo0?ooo`040?ooo`<00000o`3oool60?ooo`8000000@3oool0
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?oo
o`003@3oool2000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool00`3oool100000040oooo000>0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool100000040oooo000E0?ooool000002`00
00010?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.10966, -0.103856, \
0.00395636, 0.00640152}},
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"$LoanFunctionsPackageVersion"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[CellGroupData[{

Cell["$LoanFunctionsPackageVersion", "Section",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell["\<\
$LoanFunctionsPackageVersion gives the version of this \
package.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["$LoanFunctionsPackageVersion", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[TextData[{
  "Default options for ",
  StyleBox["$LoanFunctionsPackageVersion", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["$LoanFunctionsPackageVersion", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[CellGroupData[{

Cell[BoxData["$LoanFunctionsPackageVersion"], "Input",
  CellLabel->"In[2]:=",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[BoxData["1.1`"], "Output",
  CellLabel->"Out[2]=",
  CellTags->"$LoanFunctionsPackageVersion"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"AmortizationReport"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"AmortizationReport"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"AmortizationReport"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"AmortizationReport"],

Cell[CellGroupData[{

Cell["AmortizationReport", "Section",
  CellTags->"AmortizationReport"],

Cell[TextData[{
  StyleBox["AmortizationReport", "MR"],
  " creates a separate notebook that contains a formated tabular smortization \
report for the specified loan parameters."
}], "Text",
  CellTags->"AmortizationReport"],

Cell["\<\
AmortizationReport[{HomeCost,PercentageDownPayment},InterestRate,\
Years,{imin,imax}] creates a formatted amortization table report in a \
separate notebook with values of the payment number from imin to imax.  

AmortizationReport[{HomeCost,PercentageDownPayment},InterestRate,Years,{imin,\
imax, di}] is an alternate form that creates the list in steps of di. Note \
that the output from this is formatted in NumberForm is used internally to \
keep only two digits to the right of the decimal point. Also note that the \
iterator is used in a slightly nonstandard fashion: the first element of the \
list is evaluated at imin, and the subsequent elements are evaluated at \
imin-1+(n+1) di where n is an integer.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AmortizationReport"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["AmortizationReport", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AmortizationReport"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AmortizationReport"],

Cell[TextData[{
  "Default options for ",
  StyleBox["AmortizationReport", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AmortizationReport"],

Cell[BoxData[
    RowBox[{"{", "Protected", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AmortizationReport"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["AmortizationReport", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AmortizationReport"],

Cell[TextData[{
  "He is an example of the use of ",
  StyleBox["AmortizationReport", "MR"],
  StyleBox[".", "Text"]
}], "MathCaption",
  CellTags->"AmortizationReport"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AmortizationReport", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"250000", ",", "15"}], "}"}], ",", "8.2", ",", "30", ",", 
        RowBox[{"{", 
          RowBox[{"1", ",", "360", ",", "12"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"AmortizationReport"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"NotebookObject", "[", 
        RowBox[{
        "\[LeftSkeleton]", "\<\"Amortization Report\"\>", 
          "\[RightSkeleton]"}], "]"}],
      NotebookObject[ 
        FrontEndObject[ 
          LinkObject[ "Mathematica 4", 1, 1]], 23]]], "Output",
  CellLabel->"Out[1]=",
  CellTags->"AmortizationReport"]
}, Open  ]],

Cell["\<\
Here is the output that appears in the separate notebook \
window\
\>", "MathCaption",
  CellTags->"AmortizationReport"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Amortization Table", "Section",
  CellDingbat->None,
  TextAlignment->Center,
  CellTags->"AmortizationReport"],

Cell["This is an amortization table for the following values:", "Text",
  CellTags->"AmortizationReport"],

Cell[BoxData[GridBox[{
        {
          RowBox[{"Home", " ", 
            RowBox[{"Cost", ":"}]}], "250000"},
        {
          RowBox[{"Percentage", " ", "Down", " ", 
            RowBox[{"Payment", ":"}]}], "15"},
        {
          RowBox[{"Interest", " ", 
            RowBox[{"Rate", ":"}]}], "8.2"},
        {
          RowBox[{"Years", ":"}], "30"}
        },
      ColumnAlignments->{Left},
      GridFrame->True]], "Text",
  TextAlignment->Center,
  CellTags->"AmortizationReport"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            RowBox[{"Payment", "\n", "Number"}],
            FontFamily->"Times",
            FontWeight->"Bold",
            FontColor->RGBColor[0.500008, 0, 0.300008]], 
          StyleBox["Payment",
            FontFamily->"Times",
            FontWeight->"Bold",
            FontColor->RGBColor[0.500008, 0, 0.300008]], 
          StyleBox["Interest",
            FontFamily->"Times",
            FontWeight->"Bold",
            FontColor->RGBColor[0.500008, 0, 0.300008]], 
          StyleBox["Principal",
            FontFamily->"Times",
            FontWeight->"Bold",
            FontColor->RGBColor[0.500008, 0, 0.300008]], 
          StyleBox[
            RowBox[{"Total", "\n", "Payments"}],
            FontFamily->"Times",
            FontWeight->"Bold",
            FontColor->RGBColor[0.500008, 0, 0.300008]], 
          StyleBox[
            RowBox[{"Total", "\n", "Interest"}],
            FontFamily->"Times",
            FontWeight->"Bold",
            FontColor->RGBColor[0.500008, 0, 0.300008]], 
          StyleBox[
            RowBox[{"Total", "\n", "Principal"}],
            FontFamily->"Times",
            FontWeight->"Bold",
            FontColor->RGBColor[0.500008, 0, 0.300008]]},
        {"1", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1452.08\"\>",
              1452.0833333333228,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"136.89\"\>",
              136.89488437454565,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1452.08\"\>",
              1452.0833333333228,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"136.89\"\>",
              136.89488437454565,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"12", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1441.43\"\>",
              1441.4345218219767,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"147.54\"\>",
              147.54369588589179,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"19067.74\"\>",
              19067.73861249`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"17361.83\"\>",
              17361.832256407932,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1705.91\"\>",
              1705.9063560864888,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"24", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1428.87\"\>",
              1428.8707155114478,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"160.11\"\>",
              160.10750219642068,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"38135.48\"\>",
              38135.47722499`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"34578.40\"\>",
              34578.401261051164,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"3557.08\"\>",
              3557.0759639376774,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"36", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1415.24\"\>",
              1415.2370618715447,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"173.74\"\>",
              173.74115583632374,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"57203.22\"\>",
              57203.21583748`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"51637.34\"\>",
              51637.337394555245,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"5565.88\"\>",
              5565.8784429280204,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"48", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1400.44\"\>",
              1400.4424600623404,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"188.54\"\>",
              188.53575764552807,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"76270.95\"\>",
              76270.95444998`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"68525.22\"\>",
              68525.217725840179,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"7745.74\"\>",
              7745.7367241375032,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"60", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1384.39\"\>",
              1384.3880517228188,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"204.59\"\>",
              204.59016598504968,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"95338.69\"\>",
              95338.69306247`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"85227.48\"\>",
              85227.476319340421,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"10111.22\"\>",
              10111.216743131692,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"72", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1366.97\"\>",
              1366.966560394221,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"222.01\"\>",
              222.01165731364745,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"114406.43\"\>",
              114406.43167497`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"101728.31\"\>",
              101728.30690460475,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"12678.12\"\>",
              12678.124770361785,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"84", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1348.06\"\>",
              1348.0615746920319,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"240.92\"\>",
              240.9166430158366,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"133474.17\"\>",
              133474.1702875`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"118010.56\"\>",
              118010.55725790851,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"15463.61\"\>",
              15463.613029552449,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"96", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1327.55\"\>",
              1327.5467704392302,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"261.43\"\>",
              261.43144726863829,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"152541.91\"\>",
              152541.9089`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"134055.61\"\>",
              134055.61459013066,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"18486.29\"\>",
              18486.294309824705,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"108", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1305.29\"\>",
              1305.2850665606472,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"283.69\"\>",
              283.69315114722122,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"171609.65\"\>",
              171609.6475124`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"149843.28\"\>",
              149843.28117505068,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"21766.37\"\>",
              21766.366337399115,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"120", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1281.13\"\>",
              1281.1277090995952,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"307.85\"\>",
              307.85050860827323,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"190677.39\"\>",
              190677.3861249`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"165351.64\"\>",
              165351.63938700641,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"25325.75\"\>",
              25325.746737937821,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"132", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1254.91\"\>",
              1254.9132772356768,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"334.06\"\>",
              334.06494047219167,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"209745.12\"\>",
              209745.1247374`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"180556.91\"\>",
              180556.90524608764,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"29188.22\"\>",
              29188.219491350988,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"144", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1226.47\"\>",
              1226.4666046616128,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"362.51\"\>",
              362.51161304625566,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"228812.86\"\>",
              228812.8633499`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"195433.27\"\>",
              195433.26949224537,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"33379.59\"\>",
              33379.593857687694,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"156", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1195.60\"\>",
              1195.59760911231,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"393.38\"\>",
              393.38060859555844,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"247880.60\"\>",
              247880.6019624`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"209952.73\"\>",
              209952.72512636529,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"37927.88\"\>",
              37927.876836062205,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"168", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1162.10\"\>",
              1162.1000222243399,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"426.88\"\>",
              426.87819548352854,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"266948.34\"\>",
              266948.3405749`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"224084.88\"\>",
              224084.8802659256,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"42863.46\"\>",
              42863.46030899632,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"180", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1125.75\"\>",
              1125.7500112392097,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"463.23\"\>",
              463.22820646865875,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"286016.08\"\>",
              286016.0791874`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"237796.76\"\>",
              237796.75506472951,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"48219.32\"\>",
              48219.324122686841,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"192", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1086.30\"\>",
              1086.3046833402566,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"502.67\"\>",
              502.67353436761186,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"305083.82\"\>",
              305083.8177999`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"251052.56\"\>",
              251052.56133971919,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"54031.26\"\>",
              54031.256460191536,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"204", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1043.50\"\>",
              1043.5004626291718,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"545.48\"\>",
              545.47775507869665,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"324151.56\"\>",
              324151.5564124`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"263813.46\"\>",
              263813.46343232505,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"60338.09\"\>",
              60338.09298008011,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"216", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"997.05\"\>",
              997.05132889719403,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"591.93\"\>",
              591.92688881067443,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"343219.30\"\>",
              343219.2950249`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"276037.32\"\>",
              276037.3187064121,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"67181.98\"\>",
              67181.97631848749,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"228", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"946.65\"\>",
              946.64690642184883,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"642.33\"\>",
              642.33131128601963,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"362287.03\"\>",
              362287.0336374`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"287678.40\"\>",
              287678.39594881621,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"74608.64\"\>",
              74608.637688577815,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"240", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"891.95\"\>",
              891.9503900188663,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"697.03\"\>",
              697.02782768900215,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"381354.77\"\>",
              381354.7722499`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"298687.07\"\>",
              298687.06979080784,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"82667.70\"\>",
              82667.70245908061,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"252", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"832.60\"\>",
              832.59629449108047,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"756.38\"\>",
              756.38192321678798,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"400422.51\"\>",
              400422.5108624`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"309009.49\"\>",
              309009.48910858785,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"91413.02\"\>",
              91413.021753795038,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"264", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"768.19\"\>",
              768.1880124359102,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"820.79\"\>",
              820.79020527195826,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"419490.25\"\>",
              419490.2494749`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"318587.22\"\>",
              318587.21718705195,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"100903.03\"\>",
              100903.03228782531,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"276", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"698.30\"\>",
              698.29516409224902,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"890.68\"\>",
              890.68305361561943,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"438557.99\"\>",
              438557.9880874`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"327356.84\"\>",
              327356.84124237555,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"111201.15\"\>",
              111201.14684499614,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"288", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"622.45\"\>",
              622.45072151881482,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"966.53\"\>",
              966.52749618905364,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"457625.73\"\>",
              457625.7266999`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"335249.55\"\>",
              335249.54869422753,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"122376.18\"\>",
              122376.17800563859,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"300", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"540.15\"\>",
              540.14788788700548,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1048.83\"\>",
              1048.830329820863,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"476693.47\"\>",
              476693.4653124`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"342190.67\"\>",
              342190.66735624068,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"134502.80\"\>",
              134502.79795611987,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"312", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"450.84\"\>",
              450.83671103628308,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1138.14\"\>",
              1138.1415066715854,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"495761.20\"\>",
              495761.2039249`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"348099.17\"\>",
              348099.16647226491,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"147662.04\"\>",
              147662.03745259007,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"324", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"353.92\"\>",
              353.92040866267212,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1235.06\"\>",
              1235.0578090451963,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"514828.94\"\>",
              514828.9425373`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"352887.12\"\>",
              352887.11526430002,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"161941.83\"\>",
              161941.82727304939,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"336", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"248.75\"\>",
              248.75138058613243,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1340.23\"\>",
              1340.226837121736,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"533896.68\"\>",
              533896.6811498`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"356459.10\"\>",
              356459.09537409456,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"177437.59\"\>",
              177437.58577574929,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"348", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"134.63\"\>",
              134.62688144928484,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1454.35\"\>",
              1454.3513362585836,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"552964.42\"\>",
              552964.4197623`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"358711.56\"\>",
              358711.56327231217,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"194252.86\"\>",
              194252.85649002611,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]},
        {"360", 
          TagBox[
            InterpretationBox["\<\"1588.98\"\>",
              1588.978217708`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"10.78\"\>",
              10.784324934133565,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"1578.19\"\>",
              1578.1938927737349,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"572032.16\"\>",
              572032.1583748`13.0761,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"359532.16\"\>",
              359532.15837484878,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)], 
          TagBox[
            InterpretationBox["\<\"212500.00\"\>",
              212499.99999998393,
              AutoDelete->True],
            (NumberForm[ #, {12, 2}, NumberPadding -> {"", "0"}]&)]}
        },
      ColumnAlignments->{Right},
      GridFrame->True,
      RowLines->{True, False},
      ColumnLines->True]], "Text",
  TextAlignment->Center,
  CellTags->"AmortizationReport"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculators", "Subtitle",
  CellTags->"$CalculatorBackgroundColor"],

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"$CalculatorBackgroundColor"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"$CalculatorBackgroundColor"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"$CalculatorBackgroundColor"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"$CalculatorBackgroundColor"],

Cell[CellGroupData[{

Cell["$CalculatorBackgroundColor", "Section",
  CellTags->"$CalculatorBackgroundColor"],

Cell["\<\
$CalculatorBackgroundColor is a color directive that specifies what \
the background color is for the loan calculators.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$CalculatorBackgroundColor"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["$CalculatorBackgroundColor", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$CalculatorBackgroundColor"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$CalculatorBackgroundColor"],

Cell[TextData[{
  "Default options for ",
  StyleBox["$CalculatorBackgroundColor", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$CalculatorBackgroundColor"],

Cell[BoxData[
    RowBox[{"{", "ReadProtected", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$CalculatorBackgroundColor"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["$CalculatorBackgroundColor", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$CalculatorBackgroundColor"],

Cell[TextData[{
  " This loads",
  " the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. "
}], "MathCaption",
  CellTags->"$CalculatorBackgroundColor"],

Cell[BoxData[
    RowBox[{
    "Needs", "[", "\"\<LoanFunctions`LoanFunctions`\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"$CalculatorBackgroundColor"],

Cell["\<\
The default setting for the background color of the calculators is \
white.\
\>", "MathCaption",
  CellTags->"$CalculatorBackgroundColor"],

Cell[CellGroupData[{

Cell[BoxData["$CalculatorBackgroundColor"], "Input",
  CellLabel->"In[2]:=",
  CellTags->"$CalculatorBackgroundColor"],

Cell[BoxData[
    RowBox[{"GrayLevel", "[", "1", "]"}]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"$CalculatorBackgroundColor"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"EquityCalculator"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"EquityCalculator"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"EquityCalculator"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"EquityCalculator"],

Cell[CellGroupData[{

Cell["EquityCalculator", "Section",
  CellTags->"EquityCalculator"],

Cell["\<\
EquityCalculator[] displays a calculator for performing the \
calculations of Equity from the function Equity.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquityCalculator"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["EquityCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquityCalculator"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquityCalculator"],

Cell[TextData[{
  "Default options for ",
  StyleBox["EquityCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquityCalculator"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquityCalculator"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["EquityCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquityCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"HomeValueCalculator"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"HomeValueCalculator"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"HomeValueCalculator"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"HomeValueCalculator"],

Cell[CellGroupData[{

Cell["HomeValueCalculator", "Section",
  CellTags->"HomeValueCalculator"],

Cell["\<\
HomeValueCalculator[] displays a calculator for performing the \
calculations of home value from the function HomeValue.\
\>", "DefinitionBox",\

  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValueCalculator"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["HomeValueCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValueCalculator"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValueCalculator"],

Cell[TextData[{
  "Default options for ",
  StyleBox["HomeValueCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValueCalculator"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValueCalculator"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["HomeValueCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HomeValueCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"PaymentCalculator"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"PaymentCalculator"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentCalculator"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentCalculator"],

Cell[CellGroupData[{

Cell["PaymentCalculator", "Section",
  CellTags->"PaymentCalculator"],

Cell["\<\
PaymentCalculator[] displays a calculator for computing \
payment-related numbers: this includes the results of Payment, \
PaymentToInterest, and PaymentToPrincipal.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentCalculator"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PaymentCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentCalculator"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentCalculator"],

Cell[TextData[{
  "Default options for ",
  StyleBox["PaymentCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentCalculator"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentCalculator"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PaymentCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"PaymentsRemainingCalculator"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"PaymentsRemainingCalculator"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentsRemainingCalculator"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PaymentsRemainingCalculator"],

Cell[CellGroupData[{

Cell["PaymentsRemainingCalculator", "Section",
  CellTags->"PaymentsRemainingCalculator"],

Cell["\<\
PaymentsRemainingCalculator[] displays a calculator for performing \
the calculations of payments remaining from the function PaymentsRemaining.\
\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemainingCalculator"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PaymentsRemainingCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemainingCalculator"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemainingCalculator"],

Cell[TextData[{
  "Default options for ",
  StyleBox["PaymentsRemainingCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemainingCalculator"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemainingCalculator"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PaymentsRemainingCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaymentsRemainingCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"PrincipalCalculator"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"PrincipalCalculator"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PrincipalCalculator"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"PrincipalCalculator"],

Cell[CellGroupData[{

Cell["PrincipalCalculator", "Section",
  CellTags->"PrincipalCalculator"],

Cell["\<\
PrincipalCalculator[] displays a calculator for performing the \
calculations of Equity from the function Principal.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrincipalCalculator"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["PrincipalCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrincipalCalculator"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrincipalCalculator"],

Cell[TextData[{
  "Default options for ",
  StyleBox["PrincipalCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrincipalCalculator"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrincipalCalculator"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["PrincipalCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrincipalCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"TotalPaymentsCalculator"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"TotalPaymentsCalculator"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalPaymentsCalculator"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"TotalPaymentsCalculator"],

Cell[CellGroupData[{

Cell["TotalPaymentsCalculator", "Section",
  CellTags->"TotalPaymentsCalculator"],

Cell["\<\
TotalPaymentsCalculator[] displays a calculator for computing \
payment-related numbers: this includes the results of TotalPayments, \
TotalInterestPaid, and TotalPrincipalPaid.\
\>", "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPaymentsCalculator"],

Cell[TextData[{
  "Usage message for ",
  StyleBox["TotalPaymentsCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPaymentsCalculator"],

Cell[BoxData[
    RowBox[{"{", "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPaymentsCalculator"],

Cell[TextData[{
  "Default options for ",
  StyleBox["TotalPaymentsCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPaymentsCalculator"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Locked", ",", "Protected", ",", "ReadProtected"}], 
      "}"}]], "DefinitionBox",
  PageWidth->PaperWidth,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPaymentsCalculator"],

Cell[TextData[{
  "Attributes for ",
  StyleBox["TotalPaymentsCalculator", "MR"]
}], "Caption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalPaymentsCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Palettes", "Subtitle",
  CellTags->"Loan Functions Palette"],

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"Loan Functions Palette"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"Loan Functions Palette"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Loan Functions Palette"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Loan Functions Palette"],

Cell[CellGroupData[{

Cell["Loan Functions Palette", "Section",
  CellTags->"Loan Functions Palette"],

Cell[TextData[{
  "The Loan Functions Palette (available under the ",
  StyleBox["File\[RightTriangle]Palettes", "SR"],
  " sub menu) provides a set of function templates for the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. However, note that these are the templates for the fixed loan \
rate calculations. The ",
  StyleBox["Load Package",
    FontWeight->"Bold",
    FontColor->RGBColor[0.6, 0, 0]],
  " button at the top will load the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. Of course you should load the package before using any of the \
functions."
}], "Text",
  CellTags->"Loan Functions Palette"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            ButtonBox[
              StyleBox[
                RowBox[{"Load", " ", "Package"}],
                FontWeight->"Bold",
                FontColor->RGBColor[0.6, 0, 0]],
              ButtonFunction:>(Needs[ "LoanFunctions`LoanFunctions`"]&),
              ButtonEvaluator->Automatic,
              Active->True]},
          {
            ButtonBox[
              StyleBox[
                RowBox[{"Calculators", " ", "Palette"}],
                FontWeight->"Bold",
                FontColor->RGBColor[0, 0, 0.4]],
              ButtonFunction:>FrontEnd`NotebookOpen[ 
                  
                  FrontEnd`ToFileName[ {$TopDirectory, "AddOns", 
                    "Applications", "LoanFunctions", "FrontEnd", "Palettes"}, 
                    "LoanCalculatorsPal.nb"]],
              ButtonEvaluator->None,
              Active->True]},
          {
            ButtonBox[
              RowBox[{"ActualPayment", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\n", 
                  RowBox[{"{", 
                    RowBox[{"\[SelectionPlaceholder]", ",", 
                      RowBox[{"{", 
                        RowBox[{
                        "\[SelectionPlaceholder]", ",", 
                          "\[SelectionPlaceholder]"}], "}"}], ",", 
                      "\[SelectionPlaceholder]", ",", 
                      RowBox[{"{", 
                        RowBox[{
                        "\[SelectionPlaceholder]", ",", 
                          "\[SelectionPlaceholder]"}], "}"}]}], "}"}]}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"DownPayment", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"EffectivePayment", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]", ",", 
                  "\[SelectionPlaceholder]", ",", "\n", 
                  RowBox[{"{", 
                    RowBox[{"\[SelectionPlaceholder]", ",", 
                      RowBox[{"{", 
                        RowBox[{
                        "\[SelectionPlaceholder]", ",", 
                          "\[SelectionPlaceholder]"}], "}"}], ",", 
                      "\[SelectionPlaceholder]", ",", 
                      RowBox[{"{", 
                        RowBox[{
                        "\[SelectionPlaceholder]", ",", 
                          "\[SelectionPlaceholder]"}], "}"}]}], "}"}]}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"Equity", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}],
                 "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"EquityCalculator", "[", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"EquityTargetPayment", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}],
                 "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"HomeCost", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"HomeValue", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"HomeValueCalculator", "[", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"LoanAmount", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"Payment", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}],
                 "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"PaymentCalculator", "[", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{
              "PaymentNumberToYears", "[", "\[SelectionPlaceholder]", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"PaymentsRemaining", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"PaymentsRemainingCalculator", "[", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"PaymentToInterest", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"PaymentToPrincipal", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"PercentageDownPayment", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"Principal", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"PrincipalCalculator", "[", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"ResetLoanFunctionsDefaults", "[", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"SetErrorChecking", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"TemporarySetPaymentsPerYear", "[", 
                RowBox[{
                "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]"}], 
                "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"TotalInterestPaid", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"TotalPayments", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"TotalPaymentsCalculator", "[", "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{"TotalPrincipalPaid", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    "\[SelectionPlaceholder]", ",", 
                      "\[SelectionPlaceholder]"}], "}"}], ",", 
                  "\[SelectionPlaceholder]", ",", "\[SelectionPlaceholder]", 
                  ",", "\[SelectionPlaceholder]"}], "]"}],
              Active->True]},
          {
            ButtonBox[
              RowBox[{
              "YearsToPaymentNumber", "[", "\[SelectionPlaceholder]", "]"}],
              Active->True]}
          },
        RowSpacings->0,
        ColumnSpacings->0,
        ColumnAlignments->{Left}],
      DisplayForm]], NotebookDefault,
  CellMargins->{{Inherited, Inherited}, {7, Inherited}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakAbove->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LineSpacing->{1.25, 0},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ScriptMinSize->9,
  CounterIncrements->"Output",
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->10,
  CellTags->"Loan Functions Palette"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->"Loan Calculators Palette"],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  CellTags->"Loan Calculators Palette"],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Loan Calculators Palette"],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  CellTags->"Loan Calculators Palette"],

Cell[CellGroupData[{

Cell["Loan Calculators Palette", "Section",
  CellTags->"Loan Calculators Palette"],

Cell[TextData[{
  "The Loan Calculators Palette (available under the ",
  StyleBox["File\[RightTriangle]Palettes", "SR"],
  " sub menu) provides a set of buttons templates for the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. However, note that these are the templates for the fixed loan \
rate calculations.  The ",
  StyleBox["Load Package",
    FontWeight->"Bold",
    FontColor->RGBColor[0.6, 0, 0]],
  " button at the top will load the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package. Of course you should load the package before bringing up any of \
the calculators."
}], "Text",
  CellTags->"Loan Calculators Palette"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            ButtonBox[
              StyleBox[
                RowBox[{"Load", " ", "Package"}],
                FontWeight->"Bold",
                FontColor->RGBColor[0.6, 0, 0]],
              ButtonFunction:>(Needs[ "LoanFunctions`LoanFunctions`"]&),
              ButtonEvaluator->Automatic,
              Active->True]},
          {
            ButtonBox[
              StyleBox[
                RowBox[{"Functions", " ", "Palette"}],
                FontWeight->"Bold",
                FontColor->RGBColor[0, 0, 0.4]],
              ButtonFunction:>FrontEnd`NotebookOpen[ 
                  
                  FrontEnd`ToFileName[ {$TopDirectory, "AddOns", 
                    "Applications", "LoanFunctions", "FrontEnd", "Palettes"}, 
                    "LoanFunctionsPal.nb"]],
              ButtonEvaluator->None,
              Active->True]},
          {
            ButtonBox["EquityCalculator",
              ButtonFunction:>(EquityCalculator[ ]&),
              ButtonEvaluator->Automatic,
              Active->True]},
          {
            ButtonBox["HomeValueCalculator",
              ButtonFunction:>(HomeValueCalculator[ ]&),
              ButtonEvaluator->Automatic,
              Active->True]},
          {
            ButtonBox["PaymentCalculator",
              ButtonFunction:>(PaymentCalculator[ ]&),
              ButtonEvaluator->Automatic,
              Active->True]},
          {
            ButtonBox["TotalPaymentsCalculator",
              ButtonFunction:>(TotalPaymentsCalculator[ ]&),
              ButtonEvaluator->Automatic,
              Active->True]},
          {
            ButtonBox["PaymentsRemainingCalculator",
              ButtonFunction:>(PaymentsRemainingCalculator[ ]&),
              ButtonEvaluator->Automatic,
              Active->True]},
          {
            ButtonBox["PrincipalCalculator",
              ButtonFunction:>(PrincipalCalculator[ ]&),
              ButtonEvaluator->Automatic,
              Active->True]}
          },
        RowSpacings->0,
        ColumnSpacings->0,
        ColumnAlignments->{Left}],
      DisplayForm]], NotebookDefault,
  CellMargins->{{Inherited, Inherited}, {7, Inherited}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakAbove->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LineSpacing->{1.25, 0},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ScriptMinSize->9,
  CounterIncrements->"Output",
  StyleMenuListing->None,
  FontFamily->"Courier",
  CellTags->"Loan Calculators Palette"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
ShowPageBreaks->False,
WindowToolbars->"EditBar",
WindowSize->{753, 669},
WindowMargins->{{14, Automatic}, {Automatic, 1}},
IndexCreationOptions->{"Format"->"Text"},
Magnification->1,
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Disclaimer"->{
    Cell[1739, 51, 920, 34, 62, "Subtitle",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[2662, 87, 131, 2, 14, "Caption",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[2796, 91, 210, 4, 14, "Caption",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[3009, 97, 207, 4, 14, "Caption",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[3241, 105, 74, 1, 74, "Section",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[3318, 108, 1507, 27, 347, "DefinitionBox",
      CellTags->{"LoanFunctions", "Disclaimer"}]},
  "LoanFunctions"->{
    Cell[1739, 51, 920, 34, 62, "Subtitle",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[2662, 87, 131, 2, 14, "Caption",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[2796, 91, 210, 4, 14, "Caption",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[3009, 97, 207, 4, 14, "Caption",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[3241, 105, 74, 1, 74, "Section",
      CellTags->{"Disclaimer", "LoanFunctions"}],
    Cell[3318, 108, 1507, 27, 347, "DefinitionBox",
      CellTags->{"LoanFunctions", "Disclaimer"}],
    Cell[4874, 141, 936, 34, 62, "Subtitle",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[5813, 177, 147, 2, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[5963, 181, 226, 4, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6192, 187, 223, 4, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6440, 195, 108, 1, 74, "Section",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6573, 200, 105, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6681, 203, 924, 25, 84, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7642, 233, 95, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7740, 236, 689, 16, 64, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[8466, 257, 91, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[8560, 260, 2875, 74, 240, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[11472, 339, 102, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[11577, 342, 285, 6, 47, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[11865, 350, 175, 6, 29, "MathCaption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12043, 358, 186, 4, 27, "Input",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12232, 364, 195, 5, 29, "MathCaption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12452, 373, 139, 2, 27, "Input",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12594, 377, 123, 2, 26, "Output",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12732, 382, 254, 7, 31, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12989, 391, 5002, 146, 339, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[17994, 539, 204, 4, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[18201, 545, 686, 14, 73, "MathCaption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[18890, 561, 2442, 50, 33, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[21369, 616, 107, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[21479, 619, 506, 8, 62, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[21988, 629, 576, 10, 66, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[22567, 641, 1523, 27, 347, "DefinitionBox",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[24093, 670, 192, 4, 30, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[24288, 676, 254, 8, 31, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[24545, 686, 1225, 27, 75, "Input",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]},
  "LoanFunctions Introduction"->{
    Cell[4874, 141, 936, 34, 62, "Subtitle",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[5813, 177, 147, 2, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[5963, 181, 226, 4, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6192, 187, 223, 4, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6440, 195, 108, 1, 74, "Section",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6573, 200, 105, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6681, 203, 924, 25, 84, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7642, 233, 95, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7740, 236, 689, 16, 64, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[8466, 257, 91, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[8560, 260, 2875, 74, 240, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[11472, 339, 102, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[11577, 342, 285, 6, 47, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[11865, 350, 175, 6, 29, "MathCaption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12043, 358, 186, 4, 27, "Input",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12232, 364, 195, 5, 29, "MathCaption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12452, 373, 139, 2, 27, "Input",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12594, 377, 123, 2, 26, "Output",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12732, 382, 254, 7, 31, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[12989, 391, 5002, 146, 339, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[17994, 539, 204, 4, 14, "Caption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[18201, 545, 686, 14, 73, "MathCaption",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[18890, 561, 2442, 50, 33, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[21369, 616, 107, 1, 56, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[21479, 619, 506, 8, 62, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[21988, 629, 576, 10, 66, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[22567, 641, 1523, 27, 347, "DefinitionBox",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[24093, 670, 192, 4, 30, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[24288, 676, 254, 8, 31, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[24545, 686, 1225, 27, 75, "Input",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]},
  "$PaymentsPerYear"->{
    Cell[25831, 720, 978, 36, 62, "Subtitle",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[26812, 758, 189, 4, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27004, 764, 268, 6, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27275, 772, 265, 6, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27565, 782, 138, 3, 74, "Section",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27706, 787, 311, 8, 47, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28020, 797, 322, 9, 53, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28345, 808, 244, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28592, 818, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28828, 827, 246, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29077, 837, 250, 7, 39, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29330, 846, 241, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29574, 856, 293, 8, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29870, 866, 217, 8, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30090, 876, 228, 6, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30321, 884, 217, 7, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30563, 895, 169, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30735, 901, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30906, 908, 266, 7, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31197, 919, 320, 9, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31520, 930, 172, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31707, 937, 201, 6, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31933, 947, 195, 5, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32131, 954, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32302, 961, 224, 6, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32551, 971, 320, 9, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32874, 982, 194, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[33083, 989, 348, 10, 53, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33434, 1001, 254, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33691, 1011, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33927, 1020, 256, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34186, 1030, 307, 9, 39, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34496, 1041, 251, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34750, 1051, 145, 3, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[34898, 1056, 204, 5, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35127, 1065, 169, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35299, 1071, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35470, 1078, 290, 9, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35763, 1089, 355, 8, 42, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[36143, 1101, 793, 21, 43, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[36939, 1124, 277, 8, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37231, 1135, 241, 6, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37475, 1143, 383, 10, 67, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37861, 1155, 255, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38119, 1165, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38355, 1174, 257, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38615, 1184, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38967, 1196, 252, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39222, 1206, 279, 8, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39526, 1218, 430, 11, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39959, 1231, 195, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40169, 1238, 209, 6, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40403, 1248, 170, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40576, 1254, 157, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}]},
  "TemporarySetPaymentsPerYear"->{
    Cell[25831, 720, 978, 36, 62, "Subtitle",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[26812, 758, 189, 4, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27004, 764, 268, 6, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27275, 772, 265, 6, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27565, 782, 138, 3, 74, "Section",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27706, 787, 311, 8, 47, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28020, 797, 322, 9, 53, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28345, 808, 244, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28592, 818, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28828, 827, 246, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29077, 837, 250, 7, 39, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29330, 846, 241, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29574, 856, 293, 8, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29870, 866, 217, 8, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30090, 876, 228, 6, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30321, 884, 217, 7, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30563, 895, 169, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30735, 901, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30906, 908, 266, 7, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31197, 919, 320, 9, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31520, 930, 172, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31707, 937, 201, 6, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31933, 947, 195, 5, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32131, 954, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32302, 961, 224, 6, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32551, 971, 320, 9, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32874, 982, 194, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[33083, 989, 348, 10, 53, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33434, 1001, 254, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33691, 1011, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33927, 1020, 256, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34186, 1030, 307, 9, 39, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34496, 1041, 251, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34750, 1051, 145, 3, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[34898, 1056, 204, 5, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35127, 1065, 169, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35299, 1071, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35470, 1078, 290, 9, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35763, 1089, 355, 8, 42, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[36143, 1101, 793, 21, 43, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[36939, 1124, 277, 8, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37231, 1135, 241, 6, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37475, 1143, 383, 10, 67, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37861, 1155, 255, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38119, 1165, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38355, 1174, 257, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38615, 1184, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38967, 1196, 252, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39222, 1206, 279, 8, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39526, 1218, 430, 11, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39959, 1231, 195, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40169, 1238, 209, 6, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40403, 1248, 170, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40576, 1254, 157, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}]},
  "ResetLoanFunctionsDefaults"->{
    Cell[25831, 720, 978, 36, 62, "Subtitle",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[26812, 758, 189, 4, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27004, 764, 268, 6, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27275, 772, 265, 6, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27565, 782, 138, 3, 74, "Section",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[27706, 787, 311, 8, 47, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28020, 797, 322, 9, 53, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28345, 808, 244, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28592, 818, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[28828, 827, 246, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29077, 837, 250, 7, 39, "DefinitionBox",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29330, 846, 241, 8, 14, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29574, 856, 293, 8, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[29870, 866, 217, 8, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30090, 876, 228, 6, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30321, 884, 217, 7, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30563, 895, 169, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30735, 901, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[30906, 908, 266, 7, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31197, 919, 320, 9, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31520, 930, 172, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31707, 937, 201, 6, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[31933, 947, 195, 5, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32131, 954, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32302, 961, 224, 6, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32551, 971, 320, 9, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[32874, 982, 194, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[33083, 989, 348, 10, 53, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33434, 1001, 254, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33691, 1011, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[33927, 1020, 256, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34186, 1030, 307, 9, 39, "DefinitionBox",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34496, 1041, 251, 8, 14, "Caption",
      CellTags->{
      "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
        "TemporarySetPaymentsPerYear"}],
    Cell[34750, 1051, 145, 3, 28, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[34898, 1056, 204, 5, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35127, 1065, 169, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35299, 1071, 156, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35470, 1078, 290, 9, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[35763, 1089, 355, 8, 42, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[36143, 1101, 793, 21, 43, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[36939, 1124, 277, 8, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37231, 1135, 241, 6, 31, "Text",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37475, 1143, 383, 10, 67, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[37861, 1155, 255, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38119, 1165, 233, 7, 39, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38355, 1174, 257, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38615, 1184, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[38967, 1196, 252, 8, 14, "Caption",
      CellTags->{
      "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39222, 1206, 279, 8, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39526, 1218, 430, 11, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[39959, 1231, 195, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40169, 1238, 209, 6, 29, "MathCaption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40403, 1248, 170, 4, 27, "Input",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[40576, 1254, 157, 4, 26, "Output",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}]},
  "HomeCost"->{
    Cell[40794, 1265, 899, 34, 62, "Subtitle",
      CellTags->"HomeCost"],
    Cell[41696, 1301, 110, 2, 14, "Caption",
      CellTags->"HomeCost"],
    Cell[41809, 1305, 189, 4, 14, "Caption",
      CellTags->"HomeCost"],
    Cell[42001, 1311, 186, 4, 14, "Caption",
      CellTags->"HomeCost"],
    Cell[42212, 1319, 51, 1, 74, "Section",
      CellTags->"HomeCost"],
    Cell[42266, 1322, 113, 4, 31, "Text",
      CellTags->"HomeCost"],
    Cell[42382, 1328, 378, 9, 81, "DefinitionBox",
      CellTags->"HomeCost"],
    Cell[42763, 1339, 157, 6, 14, "Caption",
      CellTags->"HomeCost"],
    Cell[42923, 1347, 154, 5, 39, "DefinitionBox",
      CellTags->"HomeCost"],
    Cell[43080, 1354, 159, 6, 14, "Caption",
      CellTags->"HomeCost"],
    Cell[43242, 1362, 261, 8, 39, "DefinitionBox",
      CellTags->"HomeCost"],
    Cell[43506, 1372, 154, 6, 14, "Caption",
      CellTags->"HomeCost"],
    Cell[43663, 1380, 138, 6, 29, "MathCaption",
      CellTags->"HomeCost"],
    Cell[43804, 1388, 149, 4, 27, "Input",
      CellTags->"HomeCost"],
    Cell[43956, 1394, 143, 4, 29, "MathCaption",
      CellTags->"HomeCost"],
    Cell[44124, 1402, 152, 4, 27, "Input",
      CellTags->"HomeCost"],
    Cell[44279, 1408, 163, 5, 51, "Output",
      CellTags->"HomeCost"]},
  "LoanAmount"->{
    Cell[44503, 1420, 901, 34, 62, "Subtitle",
      CellTags->"LoanAmount"],
    Cell[45407, 1456, 112, 2, 14, "Caption",
      CellTags->"LoanAmount"],
    Cell[45522, 1460, 191, 4, 14, "Caption",
      CellTags->"LoanAmount"],
    Cell[45716, 1466, 188, 4, 14, "Caption",
      CellTags->"LoanAmount"],
    Cell[45929, 1474, 55, 1, 74, "Section",
      CellTags->"LoanAmount"],
    Cell[45987, 1477, 117, 4, 31, "Text",
      CellTags->"LoanAmount"],
    Cell[46107, 1483, 312, 8, 67, "DefinitionBox",
      CellTags->"LoanAmount"],
    Cell[46422, 1493, 161, 6, 14, "Caption",
      CellTags->"LoanAmount"],
    Cell[46586, 1501, 156, 5, 39, "DefinitionBox",
      CellTags->"LoanAmount"],
    Cell[46745, 1508, 163, 6, 14, "Caption",
      CellTags->"LoanAmount"],
    Cell[46911, 1516, 263, 8, 39, "DefinitionBox",
      CellTags->"LoanAmount"],
    Cell[47177, 1526, 158, 6, 14, "Caption",
      CellTags->"LoanAmount"],
    Cell[47338, 1534, 140, 6, 29, "MathCaption",
      CellTags->"LoanAmount"],
    Cell[47481, 1542, 151, 4, 27, "Input",
      CellTags->"LoanAmount"],
    Cell[47635, 1548, 147, 4, 29, "MathCaption",
      CellTags->"LoanAmount"],
    Cell[47807, 1556, 148, 4, 27, "Input",
      CellTags->"LoanAmount"],
    Cell[47958, 1562, 190, 6, 42, "Output",
      CellTags->"LoanAmount"]},
  "DownPayment"->{
    Cell[48209, 1575, 902, 34, 62, "Subtitle",
      CellTags->"DownPayment"],
    Cell[49114, 1611, 113, 2, 14, "Caption",
      CellTags->"DownPayment"],
    Cell[49230, 1615, 192, 4, 14, "Caption",
      CellTags->"DownPayment"],
    Cell[49425, 1621, 189, 4, 14, "Caption",
      CellTags->"DownPayment"],
    Cell[49639, 1629, 57, 1, 74, "Section",
      CellTags->"DownPayment"],
    Cell[49699, 1632, 114, 4, 31, "Text",
      CellTags->"DownPayment"],
    Cell[49816, 1638, 315, 8, 67, "DefinitionBox",
      CellTags->"DownPayment"],
    Cell[50134, 1648, 163, 6, 14, "Caption",
      CellTags->"DownPayment"],
    Cell[50300, 1656, 157, 5, 39, "DefinitionBox",
      CellTags->"DownPayment"],
    Cell[50460, 1663, 165, 6, 14, "Caption",
      CellTags->"DownPayment"],
    Cell[50628, 1671, 264, 8, 39, "DefinitionBox",
      CellTags->"DownPayment"],
    Cell[50895, 1681, 160, 6, 14, "Caption",
      CellTags->"DownPayment"],
    Cell[51058, 1689, 141, 6, 29, "MathCaption",
      CellTags->"DownPayment"],
    Cell[51202, 1697, 152, 4, 27, "Input",
      CellTags->"DownPayment"],
    Cell[51357, 1703, 149, 5, 29, "MathCaption",
      CellTags->"DownPayment"],
    Cell[51531, 1712, 150, 4, 27, "Input",
      CellTags->"DownPayment"],
    Cell[51684, 1718, 131, 4, 43, "Output",
      CellTags->"DownPayment"]},
  "PercentageDownPayment"->{
    Cell[51876, 1729, 912, 34, 62, "Subtitle",
      CellTags->"PercentageDownPayment"],
    Cell[52791, 1765, 123, 2, 14, "Caption",
      CellTags->"PercentageDownPayment"],
    Cell[52917, 1769, 202, 4, 14, "Caption",
      CellTags->"PercentageDownPayment"],
    Cell[53122, 1775, 199, 4, 14, "Caption",
      CellTags->"PercentageDownPayment"],
    Cell[53346, 1783, 77, 1, 74, "Section",
      CellTags->"PercentageDownPayment"],
    Cell[53426, 1786, 134, 4, 31, "Text",
      CellTags->"PercentageDownPayment"],
    Cell[53563, 1792, 327, 8, 67, "DefinitionBox",
      CellTags->"PercentageDownPayment"],
    Cell[53893, 1802, 183, 6, 14, "Caption",
      CellTags->"PercentageDownPayment"],
    Cell[54079, 1810, 167, 5, 39, "DefinitionBox",
      CellTags->"PercentageDownPayment"],
    Cell[54249, 1817, 185, 6, 14, "Caption",
      CellTags->"PercentageDownPayment"],
    Cell[54437, 1825, 274, 8, 39, "DefinitionBox",
      CellTags->"PercentageDownPayment"],
    Cell[54714, 1835, 180, 6, 14, "Caption",
      CellTags->"PercentageDownPayment"],
    Cell[54897, 1843, 151, 6, 29, "MathCaption",
      CellTags->"PercentageDownPayment"],
    Cell[55051, 1851, 162, 4, 27, "Input",
      CellTags->"PercentageDownPayment"],
    Cell[55216, 1857, 169, 5, 29, "MathCaption",
      CellTags->"PercentageDownPayment"],
    Cell[55410, 1866, 178, 4, 27, "Input",
      CellTags->"PercentageDownPayment"],
    Cell[55591, 1872, 209, 6, 43, "Output",
      CellTags->"PercentageDownPayment"]},
  "Payment"->{
    Cell[55861, 1885, 898, 34, 62, "Subtitle",
      CellTags->"Payment"],
    Cell[56762, 1921, 109, 2, 14, "Caption",
      CellTags->"Payment"],
    Cell[56874, 1925, 188, 4, 14, "Caption",
      CellTags->"Payment"],
    Cell[57065, 1931, 185, 4, 14, "Caption",
      CellTags->"Payment"],
    Cell[57275, 1939, 49, 1, 74, "Section",
      CellTags->"Payment"],
    Cell[57327, 1942, 247, 6, 47, "Text",
      CellTags->"Payment"],
    Cell[57577, 1950, 1555, 30, 347, "DefinitionBox",
      CellTags->"Payment"],
    Cell[59135, 1982, 155, 6, 14, "Caption",
      CellTags->"Payment"],
    Cell[59293, 1990, 153, 5, 39, "DefinitionBox",
      CellTags->"Payment"],
    Cell[59449, 1997, 157, 6, 14, "Caption",
      CellTags->"Payment"],
    Cell[59609, 2005, 260, 8, 39, "DefinitionBox",
      CellTags->"Payment"],
    Cell[59872, 2015, 152, 6, 14, "Caption",
      CellTags->"Payment"],
    Cell[60027, 2023, 137, 6, 29, "MathCaption",
      CellTags->"Payment"],
    Cell[60167, 2031, 148, 4, 27, "Input",
      CellTags->"Payment"],
    Cell[60318, 2037, 122, 4, 28, "MathCaption",
      CellTags->"Payment"],
    Cell[60465, 2045, 165, 4, 27, "Input",
      CellTags->"Payment"],
    Cell[60633, 2051, 110, 2, 26, "Output",
      CellTags->"Payment"],
    Cell[60758, 2056, 229, 5, 42, "MathCaption",
      CellTags->"Payment"],
    Cell[61012, 2065, 399, 11, 27, "Input",
      CellTags->"Payment"],
    Cell[61414, 2078, 624, 18, 26, "Output",
      CellTags->"Payment"],
    Cell[62053, 2099, 146, 4, 28, "MathCaption",
      CellTags->"Payment"],
    Cell[62224, 2107, 531, 15, 27, "Input",
      CellTags->"Payment"],
    Cell[62758, 2124, 32701, 1186, 186, 12472, 930, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Payment"]},
  "PaymentToInterest"->{
    Cell[95520, 3317, 908, 34, 62, "Subtitle",
      CellTags->"PaymentToInterest"],
    Cell[96431, 3353, 119, 2, 14, "Caption",
      CellTags->"PaymentToInterest"],
    Cell[96553, 3357, 198, 4, 14, "Caption",
      CellTags->"PaymentToInterest"],
    Cell[96754, 3363, 195, 4, 14, "Caption",
      CellTags->"PaymentToInterest"],
    Cell[96974, 3371, 69, 1, 74, "Section",
      CellTags->"PaymentToInterest"],
    Cell[97046, 3374, 156, 4, 31, "Text",
      CellTags->"PaymentToInterest"],
    Cell[97205, 3380, 1584, 30, 375, "DefinitionBox",
      CellTags->"PaymentToInterest"],
    Cell[98792, 3412, 175, 6, 14, "Caption",
      CellTags->"PaymentToInterest"],
    Cell[98970, 3420, 163, 5, 39, "DefinitionBox",
      CellTags->"PaymentToInterest"],
    Cell[99136, 3427, 177, 6, 14, "Caption",
      CellTags->"PaymentToInterest"],
    Cell[99316, 3435, 270, 8, 39, "DefinitionBox",
      CellTags->"PaymentToInterest"],
    Cell[99589, 3445, 172, 6, 14, "Caption",
      CellTags->"PaymentToInterest"],
    Cell[99764, 3453, 147, 6, 29, "MathCaption",
      CellTags->"PaymentToInterest"],
    Cell[99914, 3461, 158, 4, 27, "Input",
      CellTags->"PaymentToInterest"],
    Cell[100097, 3469, 533, 14, 27, "Input",
      CellTags->"PaymentToInterest"],
    Cell[100633, 3485, 24752, 733, 186, 6035, 496, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PaymentToInterest"],
    Cell[125422, 4223, 409, 11, 27, "Input",
      CellTags->"PaymentToInterest"],
    Cell[125834, 4236, 634, 18, 26, "Output",
      CellTags->"PaymentToInterest"],
    Cell[126505, 4259, 954, 23, 59, "Input",
      CellTags->"PaymentToInterest"],
    Cell[127462, 4284, 26953, 813, 186, 7207, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PaymentToInterest"],
    Cell[154452, 5102, 187, 5, 27, "Input",
      CellTags->"PaymentToInterest"],
    Cell[154642, 5109, 30261, 922, 186, 8124, 643, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PaymentToInterest"]},
  "PaymentToPrincipal"->{
    Cell[184964, 6038, 909, 34, 62, "Subtitle",
      CellTags->"PaymentToPrincipal"],
    Cell[185876, 6074, 120, 2, 14, "Caption",
      CellTags->"PaymentToPrincipal"],
    Cell[185999, 6078, 199, 4, 14, "Caption",
      CellTags->"PaymentToPrincipal"],
    Cell[186201, 6084, 196, 4, 14, "Caption",
      CellTags->"PaymentToPrincipal"],
    Cell[186422, 6092, 71, 1, 74, "Section",
      CellTags->"PaymentToPrincipal"],
    Cell[186496, 6095, 159, 4, 31, "Text",
      CellTags->"PaymentToPrincipal"],
    Cell[186658, 6101, 1590, 30, 375, "DefinitionBox",
      CellTags->"PaymentToPrincipal"],
    Cell[188251, 6133, 177, 6, 14, "Caption",
      CellTags->"PaymentToPrincipal"],
    Cell[188431, 6141, 164, 5, 39, "DefinitionBox",
      CellTags->"PaymentToPrincipal"],
    Cell[188598, 6148, 179, 6, 14, "Caption",
      CellTags->"PaymentToPrincipal"],
    Cell[188780, 6156, 271, 8, 39, "DefinitionBox",
      CellTags->"PaymentToPrincipal"],
    Cell[189054, 6166, 174, 6, 14, "Caption",
      CellTags->"PaymentToPrincipal"],
    Cell[189231, 6174, 148, 6, 29, "MathCaption",
      CellTags->"PaymentToPrincipal"],
    Cell[189382, 6182, 159, 4, 27, "Input",
      CellTags->"PaymentToPrincipal"],
    Cell[189566, 6190, 535, 14, 27, "Input",
      CellTags->"PaymentToPrincipal"],
    Cell[190104, 6206, 25416, 764, 186, 6354, 523, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PaymentToPrincipal"],
    Cell[215557, 6975, 410, 11, 27, "Input",
      CellTags->"PaymentToPrincipal"],
    Cell[215970, 6988, 635, 18, 26, "Output",
      CellTags->"PaymentToPrincipal"],
    Cell[216642, 7011, 956, 23, 59, "Input",
      CellTags->"PaymentToPrincipal"],
    Cell[217601, 7036, 26008, 789, 186, 6849, 547, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PaymentToPrincipal"],
    Cell[243646, 7830, 188, 5, 27, "Input",
      CellTags->"PaymentToPrincipal"],
    Cell[243837, 7837, 28182, 862, 186, 7552, 601, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"PaymentToPrincipal"]},
  "TotalPrincipalPaid"->{
    Cell[272080, 8706, 909, 34, 62, "Subtitle",
      CellTags->"TotalPrincipalPaid"],
    Cell[272992, 8742, 120, 2, 14, "Caption",
      CellTags->"TotalPrincipalPaid"],
    Cell[273115, 8746, 199, 4, 14, "Caption",
      CellTags->"TotalPrincipalPaid"],
    Cell[273317, 8752, 196, 4, 14, "Caption",
      CellTags->"TotalPrincipalPaid"],
    Cell[273538, 8760, 71, 1, 74, "Section",
      CellTags->"TotalPrincipalPaid"],
    Cell[273612, 8763, 1881, 36, 445, "DefinitionBox",
      CellTags->"TotalPrincipalPaid"],
    Cell[275496, 8801, 177, 6, 14, "Caption",
      CellTags->"TotalPrincipalPaid"],
    Cell[275676, 8809, 164, 5, 39, "DefinitionBox",
      CellTags->"TotalPrincipalPaid"],
    Cell[275843, 8816, 179, 6, 14, "Caption",
      CellTags->"TotalPrincipalPaid"],
    Cell[276025, 8824, 238, 7, 39, "DefinitionBox",
      CellTags->"TotalPrincipalPaid"],
    Cell[276266, 8833, 174, 6, 14, "Caption",
      CellTags->"TotalPrincipalPaid"],
    Cell[276443, 8841, 148, 6, 29, "MathCaption",
      CellTags->"TotalPrincipalPaid"],
    Cell[276594, 8849, 159, 4, 27, "Input",
      CellTags->"TotalPrincipalPaid"],
    Cell[276756, 8855, 156, 4, 28, "MathCaption",
      CellTags->"TotalPrincipalPaid"],
    Cell[276937, 8863, 262, 7, 27, "Input",
      CellTags->"TotalPrincipalPaid"],
    Cell[277202, 8872, 103, 2, 26, "Output",
      CellTags->"TotalPrincipalPaid"],
    Cell[277320, 8877, 185, 4, 30, "Text",
      CellTags->"TotalPrincipalPaid"],
    Cell[277508, 8883, 102, 1, 28, "MathCaption",
      CellTags->"TotalPrincipalPaid"],
    Cell[277635, 8888, 768, 20, 43, "Input",
      CellTags->"TotalPrincipalPaid"],
    Cell[278406, 8910, 2739, 65, 86, "Output",
      CellTags->"TotalPrincipalPaid"],
    Cell[281160, 8978, 153, 4, 28, "MathCaption",
      CellTags->"TotalPrincipalPaid"],
    Cell[281338, 8986, 502, 14, 27, "Input",
      CellTags->"TotalPrincipalPaid"],
    Cell[281843, 9002, 25649, 717, 186, 5768, 466, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"TotalPrincipalPaid"]},
  "TotalInterestPaid"->{
    Cell[307553, 9726, 908, 34, 62, "Subtitle",
      CellTags->"TotalInterestPaid"],
    Cell[308464, 9762, 119, 2, 14, "Caption",
      CellTags->"TotalInterestPaid"],
    Cell[308586, 9766, 198, 4, 14, "Caption",
      CellTags->"TotalInterestPaid"],
    Cell[308787, 9772, 195, 4, 14, "Caption",
      CellTags->"TotalInterestPaid"],
    Cell[309007, 9780, 69, 1, 74, "Section",
      CellTags->"TotalInterestPaid"],
    Cell[309079, 9783, 1872, 36, 445, "DefinitionBox",
      CellTags->"TotalInterestPaid"],
    Cell[310954, 9821, 175, 6, 14, "Caption",
      CellTags->"TotalInterestPaid"],
    Cell[311132, 9829, 163, 5, 39, "DefinitionBox",
      CellTags->"TotalInterestPaid"],
    Cell[311298, 9836, 177, 6, 14, "Caption",
      CellTags->"TotalInterestPaid"],
    Cell[311478, 9844, 270, 8, 39, "DefinitionBox",
      CellTags->"TotalInterestPaid"],
    Cell[311751, 9854, 172, 6, 14, "Caption",
      CellTags->"TotalInterestPaid"],
    Cell[311926, 9862, 147, 6, 29, "MathCaption",
      CellTags->"TotalInterestPaid"],
    Cell[312076, 9870, 158, 4, 27, "Input",
      CellTags->"TotalInterestPaid"],
    Cell[312237, 9876, 174, 4, 28, "MathCaption",
      CellTags->"TotalInterestPaid"],
    Cell[312436, 9884, 594, 15, 43, "Input",
      CellTags->"TotalInterestPaid"],
    Cell[313033, 9901, 102, 2, 26, "Output",
      CellTags->"TotalInterestPaid"],
    Cell[313150, 9906, 199, 5, 30, "Text",
      CellTags->"TotalInterestPaid"],
    Cell[313352, 9913, 101, 1, 28, "MathCaption",
      CellTags->"TotalInterestPaid"],
    Cell[313478, 9918, 409, 11, 27, "Input",
      CellTags->"TotalInterestPaid"],
    Cell[313890, 9931, 634, 18, 26, "Output",
      CellTags->"TotalInterestPaid"],
    Cell[314539, 9952, 151, 4, 28, "MathCaption",
      CellTags->"TotalInterestPaid"],
    Cell[314715, 9960, 901, 23, 59, "Input",
      CellTags->"TotalInterestPaid"],
    Cell[315619, 9985, 29794, 927, 186, 8063, 653, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"TotalInterestPaid"],
    Cell[345428, 10915, 100, 1, 30, "Text",
      CellTags->"TotalInterestPaid"],
    Cell[345531, 10918, 243, 6, 43, "MathCaption",
      CellTags->"TotalInterestPaid"],
    Cell[345799, 10928, 726, 19, 43, "Input",
      CellTags->"TotalInterestPaid"],
    Cell[346528, 10949, 165, 4, 26, "Output",
      CellTags->"TotalInterestPaid"],
    Cell[346708, 10956, 234, 8, 37, "Text",
      CellTags->"TotalInterestPaid"]},
  "TotalPayments"->{
    Cell[346991, 10970, 904, 34, 62, "Subtitle",
      CellTags->"TotalPayments"],
    Cell[347898, 11006, 115, 2, 14, "Caption",
      CellTags->"TotalPayments"],
    Cell[348016, 11010, 194, 4, 14, "Caption",
      CellTags->"TotalPayments"],
    Cell[348213, 11016, 191, 4, 14, "Caption",
      CellTags->"TotalPayments"],
    Cell[348429, 11024, 61, 1, 74, "Section",
      CellTags->"TotalPayments"],
    Cell[348493, 11027, 1906, 37, 459, "DefinitionBox",
      CellTags->"TotalPayments"],
    Cell[350402, 11066, 167, 6, 14, "Caption",
      CellTags->"TotalPayments"],
    Cell[350572, 11074, 159, 5, 39, "DefinitionBox",
      CellTags->"TotalPayments"],
    Cell[350734, 11081, 169, 6, 14, "Caption",
      CellTags->"TotalPayments"],
    Cell[350906, 11089, 266, 8, 39, "DefinitionBox",
      CellTags->"TotalPayments"],
    Cell[351175, 11099, 164, 6, 14, "Caption",
      CellTags->"TotalPayments"],
    Cell[351342, 11107, 143, 6, 29, "MathCaption",
      CellTags->"TotalPayments"],
    Cell[351488, 11115, 154, 4, 27, "Input",
      CellTags->"TotalPayments"],
    Cell[351645, 11121, 98, 1, 28, "MathCaption",
      CellTags->"TotalPayments"],
    Cell[351768, 11126, 172, 4, 27, "Input",
      CellTags->"TotalPayments"],
    Cell[351943, 11132, 117, 2, 26, "Output",
      CellTags->"TotalPayments"],
    Cell[352075, 11137, 127, 4, 28, "MathCaption",
      CellTags->"TotalPayments"],
    Cell[352227, 11145, 271, 7, 27, "Input",
      CellTags->"TotalPayments"],
    Cell[352501, 11154, 119, 2, 26, "Output",
      CellTags->"TotalPayments"],
    Cell[352681, 11163, 923, 34, 62, "Subtitle",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[353607, 11199, 134, 2, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[353744, 11203, 213, 4, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[353960, 11209, 210, 4, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[354195, 11217, 80, 1, 74, "Section",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[354278, 11220, 234, 6, 31, "Text",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[354515, 11228, 2456, 46, 585, "DefinitionBox",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[356974, 11276, 186, 6, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357163, 11284, 178, 5, 39, "DefinitionBox",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357344, 11291, 188, 6, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357535, 11299, 285, 8, 39, "DefinitionBox",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357823, 11309, 183, 6, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358009, 11317, 162, 6, 29, "MathCaption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358174, 11325, 173, 4, 27, "Input",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358350, 11331, 369, 7, 43, "MathCaption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358744, 11342, 557, 15, 27, "Input",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[359304, 11359, 117, 2, 26, "Output",
      CellTags->"TotalPayments"],
    Cell[359436, 11364, 217, 5, 29, "MathCaption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[359678, 11373, 579, 15, 27, "Input",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[360260, 11390, 117, 2, 26, "Output",
      CellTags->"TotalPayments"]},
  "ActualPayment"->{
    Cell[352681, 11163, 923, 34, 62, "Subtitle",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[353607, 11199, 134, 2, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[353744, 11203, 213, 4, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[353960, 11209, 210, 4, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[354195, 11217, 80, 1, 74, "Section",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[354278, 11220, 234, 6, 31, "Text",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[354515, 11228, 2456, 46, 585, "DefinitionBox",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[356974, 11276, 186, 6, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357163, 11284, 178, 5, 39, "DefinitionBox",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357344, 11291, 188, 6, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357535, 11299, 285, 8, 39, "DefinitionBox",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[357823, 11309, 183, 6, 14, "Caption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358009, 11317, 162, 6, 29, "MathCaption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358174, 11325, 173, 4, 27, "Input",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358350, 11331, 369, 7, 43, "MathCaption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[358744, 11342, 557, 15, 27, "Input",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[359436, 11364, 217, 5, 29, "MathCaption",
      CellTags->{"ActualPayment", "TotalPayments"}],
    Cell[359678, 11373, 579, 15, 27, "Input",
      CellTags->{"ActualPayment", "TotalPayments"}]},
  "EffectivePayment"->{
    Cell[360438, 11399, 907, 34, 62, "Subtitle",
      CellTags->"EffectivePayment"],
    Cell[361348, 11435, 118, 2, 14, "Caption",
      CellTags->"EffectivePayment"],
    Cell[361469, 11439, 197, 4, 14, "Caption",
      CellTags->"EffectivePayment"],
    Cell[361669, 11445, 194, 4, 14, "Caption",
      CellTags->"EffectivePayment"],
    Cell[361888, 11453, 67, 1, 74, "Section",
      CellTags->"EffectivePayment"],
    Cell[361958, 11456, 224, 6, 31, "Text",
      CellTags->"EffectivePayment"],
    Cell[362185, 11464, 2548, 48, 627, "DefinitionBox",
      CellTags->"EffectivePayment"],
    Cell[364736, 11514, 173, 6, 14, "Caption",
      CellTags->"EffectivePayment"],
    Cell[364912, 11522, 162, 5, 39, "DefinitionBox",
      CellTags->"EffectivePayment"],
    Cell[365077, 11529, 175, 6, 14, "Caption",
      CellTags->"EffectivePayment"],
    Cell[365255, 11537, 269, 8, 39, "DefinitionBox",
      CellTags->"EffectivePayment"],
    Cell[365527, 11547, 170, 6, 14, "Caption",
      CellTags->"EffectivePayment"],
    Cell[365700, 11555, 146, 6, 29, "MathCaption",
      CellTags->"EffectivePayment"],
    Cell[365849, 11563, 157, 4, 27, "Input",
      CellTags->"EffectivePayment"],
    Cell[366009, 11569, 380, 8, 57, "MathCaption",
      CellTags->"EffectivePayment"],
    Cell[366414, 11581, 566, 14, 27, "Input",
      CellTags->"EffectivePayment"],
    Cell[366983, 11597, 1494, 33, 103, "Output",
      CellTags->"EffectivePayment"],
    Cell[368492, 11633, 290, 6, 42, "MathCaption",
      CellTags->"EffectivePayment"],
    Cell[368807, 11643, 820, 21, 43, "Input",
      CellTags->"EffectivePayment"],
    Cell[369630, 11666, 27389, 806, 186, 6623, 544, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"EffectivePayment"]},
  "PaymentsRemaining"->{
    Cell[397080, 12479, 908, 34, 62, "Subtitle",
      CellTags->"PaymentsRemaining"],
    Cell[397991, 12515, 119, 2, 14, "Caption",
      CellTags->"PaymentsRemaining"],
    Cell[398113, 12519, 198, 4, 14, "Caption",
      CellTags->"PaymentsRemaining"],
    Cell[398314, 12525, 195, 4, 14, "Caption",
      CellTags->"PaymentsRemaining"],
    Cell[398534, 12533, 69, 1, 74, "Section",
      CellTags->"PaymentsRemaining"],
    Cell[398606, 12536, 800, 14, 151, "DefinitionBox",
      CellTags->"PaymentsRemaining"],
    Cell[399409, 12552, 175, 6, 14, "Caption",
      CellTags->"PaymentsRemaining"],
    Cell[399587, 12560, 163, 5, 39, "DefinitionBox",
      CellTags->"PaymentsRemaining"],
    Cell[399753, 12567, 177, 6, 14, "Caption",
      CellTags->"PaymentsRemaining"],
    Cell[399933, 12575, 270, 8, 39, "DefinitionBox",
      CellTags->"PaymentsRemaining"],
    Cell[400206, 12585, 172, 6, 14, "Caption",
      CellTags->"PaymentsRemaining"],
    Cell[400381, 12593, 147, 6, 29, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[400531, 12601, 158, 4, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[400692, 12607, 159, 4, 30, "Text",
      CellTags->"PaymentsRemaining"],
    Cell[400854, 12613, 217, 7, 30, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[401096, 12624, 240, 6, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[401339, 12632, 102, 2, 26, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[401456, 12637, 112, 1, 28, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[401593, 12642, 389, 10, 43, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[401985, 12654, 103, 2, 26, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[402103, 12659, 120, 4, 30, "Text",
      CellTags->"PaymentsRemaining"],
    Cell[402226, 12665, 133, 4, 28, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[402384, 12673, 235, 6, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[402622, 12681, 103, 2, 26, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[402740, 12686, 230, 5, 46, "Text",
      CellTags->"PaymentsRemaining"],
    Cell[402973, 12693, 159, 4, 28, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[403157, 12701, 243, 6, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[403403, 12709, 151, 4, 43, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[403569, 12716, 84, 1, 28, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[403678, 12721, 185, 4, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[403866, 12727, 102, 2, 26, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[403983, 12732, 199, 5, 28, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[404207, 12741, 181, 4, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[404391, 12747, 147, 4, 26, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[404553, 12754, 411, 8, 57, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[404989, 12766, 234, 5, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[405226, 12773, 325, 9, 45, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[405588, 12787, 172, 4, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[405763, 12793, 223, 5, 26, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[406023, 12803, 172, 4, 27, "Input",
      CellTags->"PaymentsRemaining"],
    Cell[406198, 12809, 104, 2, 26, "Output",
      CellTags->"PaymentsRemaining"],
    Cell[406317, 12814, 92, 1, 28, "MathCaption",
      CellTags->"PaymentsRemaining"],
    Cell[406412, 12817, 210, 6, 27, "Input",
      CellTags->"PaymentsRemaining"]},
  "Principal"->{
    Cell[406671, 12829, 950, 34, 62, "Subtitle",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[407624, 12865, 161, 2, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[407788, 12869, 240, 4, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408031, 12875, 237, 4, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408293, 12883, 103, 1, 74, "Section",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408399, 12886, 236, 5, 31, "Text",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408638, 12893, 1599, 29, 361, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410240, 12924, 209, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410452, 12932, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410660, 12939, 211, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410874, 12947, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411189, 12957, 206, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411398, 12965, 189, 6, 29, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411590, 12973, 200, 4, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411793, 12979, 197, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412015, 12987, 242, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412260, 12994, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412419, 12999, 180, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412624, 13007, 287, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412914, 13014, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[413073, 13019, 339, 8, 53, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413415, 13029, 220, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413638, 13037, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413846, 13044, 222, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414071, 13052, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414386, 13062, 217, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414606, 13070, 349, 8, 67, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[414958, 13080, 220, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415181, 13088, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415389, 13095, 222, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415614, 13103, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415929, 13113, 217, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[416149, 13121, 205, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416379, 13129, 288, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416670, 13136, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416829, 13141, 176, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[417030, 13149, 471, 11, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[417504, 13162, 24404, 681, 186, 5485, 442, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]},
  "YearsToPaymentNumber"->{
    Cell[406671, 12829, 950, 34, 62, "Subtitle",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[407624, 12865, 161, 2, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[407788, 12869, 240, 4, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408031, 12875, 237, 4, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408293, 12883, 103, 1, 74, "Section",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408399, 12886, 236, 5, 31, "Text",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408638, 12893, 1599, 29, 361, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410240, 12924, 209, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410452, 12932, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410660, 12939, 211, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410874, 12947, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411189, 12957, 206, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411398, 12965, 189, 6, 29, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411590, 12973, 200, 4, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411793, 12979, 197, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412015, 12987, 242, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412260, 12994, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412419, 12999, 180, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412624, 13007, 287, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412914, 13014, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[413073, 13019, 339, 8, 53, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413415, 13029, 220, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413638, 13037, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413846, 13044, 222, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414071, 13052, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414386, 13062, 217, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414606, 13070, 349, 8, 67, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[414958, 13080, 220, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415181, 13088, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415389, 13095, 222, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415614, 13103, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415929, 13113, 217, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[416149, 13121, 205, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416379, 13129, 288, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416670, 13136, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416829, 13141, 176, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[417030, 13149, 471, 11, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[417504, 13162, 24404, 681, 186, 5485, 442, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]},
  "PaymentNumberToYears"->{
    Cell[406671, 12829, 950, 34, 62, "Subtitle",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[407624, 12865, 161, 2, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[407788, 12869, 240, 4, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408031, 12875, 237, 4, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408293, 12883, 103, 1, 74, "Section",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408399, 12886, 236, 5, 31, "Text",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[408638, 12893, 1599, 29, 361, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410240, 12924, 209, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410452, 12932, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410660, 12939, 211, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[410874, 12947, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411189, 12957, 206, 6, 14, "Caption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411398, 12965, 189, 6, 29, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411590, 12973, 200, 4, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[411793, 12979, 197, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412015, 12987, 242, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412260, 12994, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412419, 12999, 180, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412624, 13007, 287, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[412914, 13014, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[413073, 13019, 339, 8, 53, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413415, 13029, 220, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413638, 13037, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[413846, 13044, 222, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414071, 13052, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414386, 13062, 217, 6, 14, "Caption",
      CellTags->{
      "YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
    Cell[414606, 13070, 349, 8, 67, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[414958, 13080, 220, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415181, 13088, 205, 5, 39, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415389, 13095, 222, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415614, 13103, 312, 8, 39, "DefinitionBox",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[415929, 13113, 217, 6, 14, "Caption",
      CellTags->{
      "PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
    Cell[416149, 13121, 205, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416379, 13129, 288, 5, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416670, 13136, 144, 2, 26, "Output",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[416829, 13141, 176, 4, 28, "MathCaption",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[417030, 13149, 471, 11, 27, "Input",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
    Cell[417504, 13162, 24404, 681, 186, 5485, 442, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]},
  "HomeValue"->{
    Cell[441969, 13850, 900, 34, 62, "Subtitle",
      CellTags->"HomeValue"],
    Cell[442872, 13886, 111, 2, 14, "Caption",
      CellTags->"HomeValue"],
    Cell[442986, 13890, 190, 4, 14, "Caption",
      CellTags->"HomeValue"],
    Cell[443179, 13896, 187, 4, 14, "Caption",
      CellTags->"HomeValue"],
    Cell[443391, 13904, 53, 1, 74, "Section",
      CellTags->"HomeValue"],
    Cell[443447, 13907, 215, 5, 46, "Text",
      CellTags->"HomeValue"],
    Cell[443665, 13914, 698, 13, 137, "DefinitionBox",
      CellTags->"HomeValue"],
    Cell[444366, 13929, 159, 6, 14, "Caption",
      CellTags->"HomeValue"],
    Cell[444528, 13937, 155, 5, 39, "DefinitionBox",
      CellTags->"HomeValue"],
    Cell[444686, 13944, 161, 6, 14, "Caption",
      CellTags->"HomeValue"],
    Cell[444850, 13952, 262, 8, 39, "DefinitionBox",
      CellTags->"HomeValue"],
    Cell[445115, 13962, 156, 6, 14, "Caption",
      CellTags->"HomeValue"],
    Cell[445274, 13970, 139, 6, 29, "MathCaption",
      CellTags->"HomeValue"],
    Cell[445416, 13978, 150, 4, 27, "Input",
      CellTags->"HomeValue"],
    Cell[445569, 13984, 167, 4, 28, "MathCaption",
      CellTags->"HomeValue"],
    Cell[445761, 13992, 169, 4, 27, "Input",
      CellTags->"HomeValue"],
    Cell[445933, 13998, 95, 2, 26, "Output",
      CellTags->"HomeValue"],
    Cell[446043, 14003, 193, 5, 28, "MathCaption",
      CellTags->"HomeValue"],
    Cell[446261, 14012, 298, 8, 27, "Input",
      CellTags->"HomeValue"],
    Cell[446562, 14022, 95, 2, 26, "Output",
      CellTags->"HomeValue"]},
  "Equity"->{
    Cell[446718, 14031, 897, 34, 62, "Subtitle",
      CellTags->"Equity"],
    Cell[447618, 14067, 108, 2, 14, "Caption",
      CellTags->"Equity"],
    Cell[447729, 14071, 187, 4, 14, "Caption",
      CellTags->"Equity"],
    Cell[447919, 14077, 184, 4, 14, "Caption",
      CellTags->"Equity"],
    Cell[448128, 14085, 47, 1, 74, "Section",
      CellTags->"Equity"],
    Cell[448178, 14088, 1968, 35, 445, "DefinitionBox",
      CellTags->"Equity"],
    Cell[450149, 14125, 153, 6, 14, "Caption",
      CellTags->"Equity"],
    Cell[450305, 14133, 152, 5, 39, "DefinitionBox",
      CellTags->"Equity"],
    Cell[450460, 14140, 155, 6, 14, "Caption",
      CellTags->"Equity"],
    Cell[450618, 14148, 259, 8, 39, "DefinitionBox",
      CellTags->"Equity"],
    Cell[450880, 14158, 150, 6, 14, "Caption",
      CellTags->"Equity"],
    Cell[451033, 14166, 136, 6, 29, "MathCaption",
      CellTags->"Equity"],
    Cell[451172, 14174, 147, 4, 27, "Input",
      CellTags->"Equity"],
    Cell[451322, 14180, 283, 6, 42, "MathCaption",
      CellTags->"Equity"],
    Cell[451630, 14190, 362, 9, 27, "Input",
      CellTags->"Equity"],
    Cell[452672, 14223, 635, 16, 43, "Input",
      CellTags->"Equity"],
    Cell[478028, 14948, 85, 1, 28, "MathCaption",
      CellTags->"Equity"],
    Cell[478138, 14953, 654, 16, 43, "Input",
      CellTags->"Equity"]},
  "EquityTargetPayment"->{
    Cell[503750, 15706, 987, 36, 62, "Subtitle",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504740, 15744, 198, 4, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504941, 15750, 277, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505221, 15758, 274, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505520, 15768, 150, 3, 74, "Section",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505673, 15773, 2319, 41, 487, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[507995, 15816, 256, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508254, 15826, 308, 9, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508565, 15837, 258, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508826, 15847, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509178, 15859, 253, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509434, 15869, 226, 8, 29, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509663, 15879, 237, 6, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509903, 15887, 644, 12, 79, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510550, 15901, 366, 8, 42, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510941, 15913, 525, 12, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511469, 15927, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511665, 15934, 217, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511907, 15944, 1547, 37, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[513457, 15983, 22189, 710, 186, 6086, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535661, 16696, 254, 7, 31, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535918, 16705, 955, 17, 151, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[536876, 16724, 253, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537132, 16734, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537377, 16743, 255, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537635, 16753, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537954, 16764, 250, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538207, 16774, 295, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538527, 16786, 601, 14, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539131, 16802, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539327, 16809, 279, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539631, 16821, 1391, 34, 119, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[541025, 16857, 22416, 714, 186, 6103, 506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563456, 17574, 246, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563727, 17584, 698, 17, 75, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564428, 17603, 182, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564625, 17610, 250, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564900, 17620, 1598, 38, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[566501, 17660, 22081, 708, 186, 6088, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[588597, 18371, 305, 9, 53, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[588905, 18382, 244, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589152, 18392, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589397, 18401, 246, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589646, 18411, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589965, 18422, 241, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[590209, 18432, 306, 9, 53, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590518, 18443, 245, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590766, 18453, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591011, 18462, 247, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591261, 18472, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591580, 18483, 242, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591825, 18493, 507, 12, 81, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592335, 18507, 257, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592595, 18517, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592840, 18526, 259, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593102, 18536, 259, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593364, 18545, 254, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593621, 18555, 248, 7, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[593894, 18566, 183, 4, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[594080, 18572, 166, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}]},
  "CalculationBasis"->{
    Cell[503750, 15706, 987, 36, 62, "Subtitle",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504740, 15744, 198, 4, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504941, 15750, 277, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505221, 15758, 274, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505520, 15768, 150, 3, 74, "Section",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505673, 15773, 2319, 41, 487, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[507995, 15816, 256, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508254, 15826, 308, 9, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508565, 15837, 258, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508826, 15847, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509178, 15859, 253, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509434, 15869, 226, 8, 29, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509663, 15879, 237, 6, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509903, 15887, 644, 12, 79, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510550, 15901, 366, 8, 42, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510941, 15913, 525, 12, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511469, 15927, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511665, 15934, 217, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511907, 15944, 1547, 37, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[513457, 15983, 22189, 710, 186, 6086, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535661, 16696, 254, 7, 31, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535918, 16705, 955, 17, 151, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[536876, 16724, 253, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537132, 16734, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537377, 16743, 255, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537635, 16753, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537954, 16764, 250, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538207, 16774, 295, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538527, 16786, 601, 14, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539131, 16802, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539327, 16809, 279, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539631, 16821, 1391, 34, 119, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[541025, 16857, 22416, 714, 186, 6103, 506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563456, 17574, 246, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563727, 17584, 698, 17, 75, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564428, 17603, 182, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564625, 17610, 250, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564900, 17620, 1598, 38, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[566501, 17660, 22081, 708, 186, 6088, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[588597, 18371, 305, 9, 53, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[588905, 18382, 244, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589152, 18392, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589397, 18401, 246, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589646, 18411, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589965, 18422, 241, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[590209, 18432, 306, 9, 53, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590518, 18443, 245, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590766, 18453, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591011, 18462, 247, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591261, 18472, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591580, 18483, 242, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591825, 18493, 507, 12, 81, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592335, 18507, 257, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592595, 18517, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592840, 18526, 259, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593102, 18536, 259, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593364, 18545, 254, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593621, 18555, 248, 7, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[593894, 18566, 183, 4, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[594080, 18572, 166, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}]},
  "Current"->{
    Cell[503750, 15706, 987, 36, 62, "Subtitle",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504740, 15744, 198, 4, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504941, 15750, 277, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505221, 15758, 274, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505520, 15768, 150, 3, 74, "Section",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505673, 15773, 2319, 41, 487, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[507995, 15816, 256, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508254, 15826, 308, 9, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508565, 15837, 258, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508826, 15847, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509178, 15859, 253, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509434, 15869, 226, 8, 29, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509663, 15879, 237, 6, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509903, 15887, 644, 12, 79, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510550, 15901, 366, 8, 42, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510941, 15913, 525, 12, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511469, 15927, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511665, 15934, 217, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511907, 15944, 1547, 37, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[513457, 15983, 22189, 710, 186, 6086, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535661, 16696, 254, 7, 31, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535918, 16705, 955, 17, 151, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[536876, 16724, 253, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537132, 16734, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537377, 16743, 255, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537635, 16753, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537954, 16764, 250, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538207, 16774, 295, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538527, 16786, 601, 14, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539131, 16802, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539327, 16809, 279, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539631, 16821, 1391, 34, 119, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[541025, 16857, 22416, 714, 186, 6103, 506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563456, 17574, 246, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563727, 17584, 698, 17, 75, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564428, 17603, 182, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564625, 17610, 250, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564900, 17620, 1598, 38, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[566501, 17660, 22081, 708, 186, 6088, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[588597, 18371, 305, 9, 53, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[588905, 18382, 244, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589152, 18392, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589397, 18401, 246, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589646, 18411, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589965, 18422, 241, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[590209, 18432, 306, 9, 53, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590518, 18443, 245, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590766, 18453, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591011, 18462, 247, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591261, 18472, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591580, 18483, 242, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591825, 18493, 507, 12, 81, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592335, 18507, 257, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592595, 18517, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592840, 18526, 259, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593102, 18536, 259, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593364, 18545, 254, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593621, 18555, 248, 7, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[593894, 18566, 183, 4, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[594080, 18572, 166, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}]},
  "Original"->{
    Cell[503750, 15706, 987, 36, 62, "Subtitle",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504740, 15744, 198, 4, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504941, 15750, 277, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505221, 15758, 274, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505520, 15768, 150, 3, 74, "Section",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505673, 15773, 2319, 41, 487, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[507995, 15816, 256, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508254, 15826, 308, 9, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508565, 15837, 258, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508826, 15847, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509178, 15859, 253, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509434, 15869, 226, 8, 29, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509663, 15879, 237, 6, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509903, 15887, 644, 12, 79, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510550, 15901, 366, 8, 42, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510941, 15913, 525, 12, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511469, 15927, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511665, 15934, 217, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511907, 15944, 1547, 37, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[513457, 15983, 22189, 710, 186, 6086, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535661, 16696, 254, 7, 31, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535918, 16705, 955, 17, 151, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[536876, 16724, 253, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537132, 16734, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537377, 16743, 255, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537635, 16753, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537954, 16764, 250, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538207, 16774, 295, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538527, 16786, 601, 14, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539131, 16802, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539327, 16809, 279, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539631, 16821, 1391, 34, 119, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[541025, 16857, 22416, 714, 186, 6103, 506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563456, 17574, 246, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563727, 17584, 698, 17, 75, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564428, 17603, 182, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564625, 17610, 250, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564900, 17620, 1598, 38, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[566501, 17660, 22081, 708, 186, 6088, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[588597, 18371, 305, 9, 53, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[588905, 18382, 244, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589152, 18392, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589397, 18401, 246, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589646, 18411, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589965, 18422, 241, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[590209, 18432, 306, 9, 53, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590518, 18443, 245, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590766, 18453, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591011, 18462, 247, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591261, 18472, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591580, 18483, 242, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591825, 18493, 507, 12, 81, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592335, 18507, 257, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592595, 18517, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592840, 18526, 259, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593102, 18536, 259, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593364, 18545, 254, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593621, 18555, 248, 7, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[593894, 18566, 183, 4, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[594080, 18572, 166, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}]},
  "$EquityFindRootStart"->{
    Cell[503750, 15706, 987, 36, 62, "Subtitle",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504740, 15744, 198, 4, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[504941, 15750, 277, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505221, 15758, 274, 6, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505520, 15768, 150, 3, 74, "Section",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[505673, 15773, 2319, 41, 487, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[507995, 15816, 256, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508254, 15826, 308, 9, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508565, 15837, 258, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[508826, 15847, 349, 10, 39, "DefinitionBox",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509178, 15859, 253, 8, 14, "Caption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509434, 15869, 226, 8, 29, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509663, 15879, 237, 6, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[509903, 15887, 644, 12, 79, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510550, 15901, 366, 8, 42, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[510941, 15913, 525, 12, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511469, 15927, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511665, 15934, 217, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[511907, 15944, 1547, 37, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[513457, 15983, 22189, 710, 186, 6086, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535661, 16696, 254, 7, 31, "Text",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[535918, 16705, 955, 17, 151, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[536876, 16724, 253, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537132, 16734, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537377, 16743, 255, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537635, 16753, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[537954, 16764, 250, 8, 14, "Caption",
      CellTags->{
      "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538207, 16774, 295, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[538527, 16786, 601, 14, 59, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539131, 16802, 181, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539327, 16809, 279, 8, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[539631, 16821, 1391, 34, 119, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[541025, 16857, 22416, 714, 186, 6103, 506, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563456, 17574, 246, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[563727, 17584, 698, 17, 75, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564428, 17603, 182, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564625, 17610, 250, 6, 28, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[564900, 17620, 1598, 38, 121, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[566501, 17660, 22081, 708, 186, 6088, 504, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[588597, 18371, 305, 9, 53, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[588905, 18382, 244, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589152, 18392, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589397, 18401, 246, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589646, 18411, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[589965, 18422, 241, 8, 14, "Caption",
      CellTags->{
      "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
        "$EquityFindRootStart"}],
    Cell[590209, 18432, 306, 9, 53, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590518, 18443, 245, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[590766, 18453, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591011, 18462, 247, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591261, 18472, 316, 9, 39, "DefinitionBox",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591580, 18483, 242, 8, 14, "Caption",
      CellTags->{
      "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
        "$EquityFindRootStart"}],
    Cell[591825, 18493, 507, 12, 81, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592335, 18507, 257, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592595, 18517, 242, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[592840, 18526, 259, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593102, 18536, 259, 7, 39, "DefinitionBox",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593364, 18545, 254, 8, 14, "Caption",
      CellTags->{
      "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
        "Current", "Original"}],
    Cell[593621, 18555, 248, 7, 30, "MathCaption",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[593894, 18566, 183, 4, 27, "Input",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}],
    Cell[594080, 18572, 166, 4, 26, "Output",
      CellTags->{
      "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
        "$EquityFindRootStart"}]},
  "SetErrorChecking"->{
    Cell[594307, 18583, 977, 36, 62, "Subtitle",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595287, 18621, 188, 4, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595478, 18627, 267, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595748, 18635, 264, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596037, 18645, 135, 3, 74, "Section",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596175, 18650, 348, 11, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596526, 18663, 895, 17, 151, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597424, 18682, 241, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597668, 18692, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597903, 18701, 243, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598149, 18711, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598436, 18721, 238, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598677, 18731, 778, 15, 137, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599458, 18748, 247, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599708, 18758, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599943, 18767, 249, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600195, 18777, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600482, 18787, 244, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600729, 18797, 216, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[600948, 18807, 227, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601178, 18815, 323, 11, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601504, 18828, 637, 13, 109, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602144, 18843, 243, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602390, 18853, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602625, 18862, 245, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602873, 18872, 306, 9, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603182, 18883, 240, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603425, 18893, 271, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603721, 18906, 193, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603917, 18913, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[604146, 18922, 1177, 30, 114, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605326, 18954, 234, 7, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605563, 18963, 1634, 32, 347, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607200, 18997, 234, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607437, 19007, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607672, 19016, 236, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607911, 19026, 339, 10, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608253, 19038, 231, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608487, 19048, 324, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608836, 19061, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[609147, 19072, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610031, 19100, 350, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610406, 19113, 526, 14, 59, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610935, 19129, 907, 25, 61, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[611857, 19157, 286, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612168, 19170, 232, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612403, 19178, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612653, 19189, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612964, 19200, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613351, 19211, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613738, 19222, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614622, 19250, 306, 7, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614953, 19261, 341, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615297, 19273, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615684, 19284, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616071, 19295, 209, 5, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616295, 19303, 425, 14, 44, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616745, 19321, 233, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616981, 19329, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617232, 19340, 342, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617577, 19352, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617965, 19363, 334, 10, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618314, 19376, 172, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618511, 19383, 309, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618823, 19394, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619211, 19405, 300, 9, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619526, 19417, 144, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619673, 19422, 204, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619880, 19429, 200, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620105, 19439, 194, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620302, 19446, 215, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620532, 19455, 409, 10, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620944, 19467, 287, 7, 30, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621234, 19476, 170, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621429, 19483, 836, 22, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622268, 19507, 613, 17, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622896, 19527, 226, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623147, 19537, 484, 14, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623634, 19553, 35920, 1373, 186, 16321, 1124, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[659569, 20929, 510, 12, 68, "Commentary",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660082, 20943, 303, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660410, 20955, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660998, 20972, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722055, 22803, 414, 14, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722494, 22821, 238, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722735, 22829, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722986, 22840, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723574, 22857, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723964, 22868, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724352, 22879, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724742, 22890, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[725119, 22901, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[786176, 24732, 1188, 45, 61, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787389, 24781, 237, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787629, 24789, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787879, 24800, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788467, 24817, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788857, 24828, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789245, 24839, 414, 10, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789662, 24851, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790050, 24862, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790427, 24873, 400, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790830, 24885, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791228, 24897, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791626, 24909, 360, 9, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791989, 24920, 19165, 541, 186, 4359, 351, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}]},
  "$ErrorChecking"->{
    Cell[594307, 18583, 977, 36, 62, "Subtitle",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595287, 18621, 188, 4, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595478, 18627, 267, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595748, 18635, 264, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596037, 18645, 135, 3, 74, "Section",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596175, 18650, 348, 11, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596526, 18663, 895, 17, 151, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597424, 18682, 241, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597668, 18692, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597903, 18701, 243, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598149, 18711, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598436, 18721, 238, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598677, 18731, 778, 15, 137, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599458, 18748, 247, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599708, 18758, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599943, 18767, 249, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600195, 18777, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600482, 18787, 244, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600729, 18797, 216, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[600948, 18807, 227, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601178, 18815, 323, 11, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601504, 18828, 637, 13, 109, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602144, 18843, 243, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602390, 18853, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602625, 18862, 245, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602873, 18872, 306, 9, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603182, 18883, 240, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603425, 18893, 271, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603721, 18906, 193, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603917, 18913, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[604146, 18922, 1177, 30, 114, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605326, 18954, 234, 7, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605563, 18963, 1634, 32, 347, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607200, 18997, 234, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607437, 19007, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607672, 19016, 236, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607911, 19026, 339, 10, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608253, 19038, 231, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608487, 19048, 324, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608836, 19061, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[609147, 19072, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610031, 19100, 350, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610406, 19113, 526, 14, 59, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610935, 19129, 907, 25, 61, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[611857, 19157, 286, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612168, 19170, 232, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612403, 19178, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612653, 19189, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612964, 19200, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613351, 19211, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613738, 19222, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614622, 19250, 306, 7, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614953, 19261, 341, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615297, 19273, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615684, 19284, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616071, 19295, 209, 5, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616295, 19303, 425, 14, 44, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616745, 19321, 233, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616981, 19329, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617232, 19340, 342, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617577, 19352, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617965, 19363, 334, 10, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618314, 19376, 172, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618511, 19383, 309, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618823, 19394, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619211, 19405, 300, 9, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619526, 19417, 144, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619673, 19422, 204, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619880, 19429, 200, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620105, 19439, 194, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620302, 19446, 215, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620532, 19455, 409, 10, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620944, 19467, 287, 7, 30, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621234, 19476, 170, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621429, 19483, 836, 22, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622268, 19507, 613, 17, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622896, 19527, 226, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623147, 19537, 484, 14, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623634, 19553, 35920, 1373, 186, 16321, 1124, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[659569, 20929, 510, 12, 68, "Commentary",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660082, 20943, 303, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660410, 20955, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660998, 20972, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722055, 22803, 414, 14, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722494, 22821, 238, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722735, 22829, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722986, 22840, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723574, 22857, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723964, 22868, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724352, 22879, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724742, 22890, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[725119, 22901, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[786176, 24732, 1188, 45, 61, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787389, 24781, 237, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787629, 24789, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787879, 24800, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788467, 24817, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788857, 24828, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789245, 24839, 414, 10, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789662, 24851, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790050, 24862, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790427, 24873, 400, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790830, 24885, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791228, 24897, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791626, 24909, 360, 9, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791989, 24920, 19165, 541, 186, 4359, 351, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}]},
  "$StrongErrorChecking"->{
    Cell[594307, 18583, 977, 36, 62, "Subtitle",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595287, 18621, 188, 4, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595478, 18627, 267, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595748, 18635, 264, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596037, 18645, 135, 3, 74, "Section",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596175, 18650, 348, 11, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596526, 18663, 895, 17, 151, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597424, 18682, 241, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597668, 18692, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597903, 18701, 243, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598149, 18711, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598436, 18721, 238, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598677, 18731, 778, 15, 137, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599458, 18748, 247, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599708, 18758, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599943, 18767, 249, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600195, 18777, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600482, 18787, 244, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600729, 18797, 216, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[600948, 18807, 227, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601178, 18815, 323, 11, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601504, 18828, 637, 13, 109, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602144, 18843, 243, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602390, 18853, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602625, 18862, 245, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602873, 18872, 306, 9, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603182, 18883, 240, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603425, 18893, 271, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603721, 18906, 193, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603917, 18913, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[604146, 18922, 1177, 30, 114, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605326, 18954, 234, 7, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605563, 18963, 1634, 32, 347, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607200, 18997, 234, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607437, 19007, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607672, 19016, 236, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607911, 19026, 339, 10, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608253, 19038, 231, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608487, 19048, 324, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608836, 19061, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[609147, 19072, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610031, 19100, 350, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610406, 19113, 526, 14, 59, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610935, 19129, 907, 25, 61, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[611857, 19157, 286, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612168, 19170, 232, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612403, 19178, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612653, 19189, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612964, 19200, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613351, 19211, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613738, 19222, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614622, 19250, 306, 7, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614953, 19261, 341, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615297, 19273, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615684, 19284, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616071, 19295, 209, 5, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616295, 19303, 425, 14, 44, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616745, 19321, 233, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616981, 19329, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617232, 19340, 342, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617577, 19352, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617965, 19363, 334, 10, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618314, 19376, 172, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618511, 19383, 309, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618823, 19394, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619211, 19405, 300, 9, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619526, 19417, 144, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619673, 19422, 204, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619880, 19429, 200, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620105, 19439, 194, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620302, 19446, 215, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620532, 19455, 409, 10, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620944, 19467, 287, 7, 30, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621234, 19476, 170, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621429, 19483, 836, 22, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622268, 19507, 613, 17, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622896, 19527, 226, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623147, 19537, 484, 14, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623634, 19553, 35920, 1373, 186, 16321, 1124, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[659569, 20929, 510, 12, 68, "Commentary",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660082, 20943, 303, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660410, 20955, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660998, 20972, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722055, 22803, 414, 14, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722494, 22821, 238, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722735, 22829, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722986, 22840, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723574, 22857, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723964, 22868, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724352, 22879, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724742, 22890, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[725119, 22901, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[786176, 24732, 1188, 45, 61, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787389, 24781, 237, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787629, 24789, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787879, 24800, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788467, 24817, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788857, 24828, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789245, 24839, 414, 10, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789662, 24851, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790050, 24862, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790427, 24873, 400, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790830, 24885, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791228, 24897, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791626, 24909, 360, 9, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791989, 24920, 19165, 541, 186, 4359, 351, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}]},
  "Error Checking"->{
    Cell[594307, 18583, 977, 36, 62, "Subtitle",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595287, 18621, 188, 4, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595478, 18627, 267, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[595748, 18635, 264, 6, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596037, 18645, 135, 3, 74, "Section",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596175, 18650, 348, 11, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[596526, 18663, 895, 17, 151, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597424, 18682, 241, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597668, 18692, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[597903, 18701, 243, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598149, 18711, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598436, 18721, 238, 8, 14, "Caption",
      CellTags->{
      "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[598677, 18731, 778, 15, 137, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599458, 18748, 247, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599708, 18758, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[599943, 18767, 249, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600195, 18777, 284, 8, 39, "DefinitionBox",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600482, 18787, 244, 8, 14, "Caption",
      CellTags->{
      "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
        "Error Checking"}],
    Cell[600729, 18797, 216, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[600948, 18807, 227, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601178, 18815, 323, 11, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[601504, 18828, 637, 13, 109, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602144, 18843, 243, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602390, 18853, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602625, 18862, 245, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[602873, 18872, 306, 9, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603182, 18883, 240, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603425, 18893, 271, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603721, 18906, 193, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[603917, 18913, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[604146, 18922, 1177, 30, 114, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605326, 18954, 234, 7, 31, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[605563, 18963, 1634, 32, 347, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607200, 18997, 234, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607437, 19007, 232, 7, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607672, 19016, 236, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[607911, 19026, 339, 10, 39, "DefinitionBox",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608253, 19038, 231, 8, 14, "Caption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608487, 19048, 324, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[608836, 19061, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[609147, 19072, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610031, 19100, 350, 9, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610406, 19113, 526, 14, 59, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[610935, 19129, 907, 25, 61, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[611857, 19157, 286, 9, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612168, 19170, 232, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612403, 19178, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612653, 19189, 308, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[612964, 19200, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613351, 19211, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[613738, 19222, 869, 25, 63, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614622, 19250, 306, 7, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[614953, 19261, 341, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615297, 19273, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[615684, 19284, 384, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616071, 19295, 209, 5, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616295, 19303, 425, 14, 44, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616745, 19321, 233, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[616981, 19329, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617232, 19340, 342, 10, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617577, 19352, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[617965, 19363, 334, 10, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618314, 19376, 172, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618511, 19383, 309, 9, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[618823, 19394, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619211, 19405, 300, 9, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619526, 19417, 144, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619673, 19422, 204, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[619880, 19429, 200, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620105, 19439, 194, 5, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620302, 19446, 215, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620532, 19455, 409, 10, 48, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[620944, 19467, 287, 7, 30, "Text",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621234, 19476, 170, 3, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[621429, 19483, 836, 22, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622268, 19507, 613, 17, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[622896, 19527, 226, 6, 28, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623147, 19537, 484, 14, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[623634, 19553, 35920, 1373, 186, 16321, 1124, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[659569, 20929, 510, 12, 68, "Commentary",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660082, 20943, 303, 8, 29, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660410, 20955, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[660998, 20972, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722055, 22803, 414, 14, 43, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722494, 22821, 238, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722735, 22829, 214, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[722986, 22840, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723574, 22857, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[723964, 22868, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724352, 22879, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[724742, 22890, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[725119, 22901, 61042, 1828, 186, 18963, 1302, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[786176, 24732, 1188, 45, 61, "MathCaption",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787389, 24781, 237, 6, 27, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787629, 24789, 213, 6, 26, "Output",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[787879, 24800, 585, 15, 43, "Input",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788467, 24817, 387, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[788857, 24828, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789245, 24839, 414, 10, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[789662, 24851, 385, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790050, 24862, 374, 9, 39, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790427, 24873, 400, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[790830, 24885, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791228, 24897, 395, 10, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791626, 24909, 360, 9, 23, "Message",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}],
    Cell[791989, 24920, 19165, 541, 186, 4359, 351, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
        "Error Checking"}]},
  "$LoanFunctionsPackageVersion"->{
    Cell[811215, 25468, 919, 34, 62, "Subtitle",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[812137, 25504, 130, 2, 14, "Caption",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[812270, 25508, 209, 4, 14, "Caption",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[812482, 25514, 206, 4, 14, "Caption",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[812713, 25522, 91, 1, 74, "Section",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[812807, 25525, 217, 7, 39, "DefinitionBox",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[813027, 25534, 197, 6, 14, "Caption",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[813227, 25542, 174, 5, 39, "DefinitionBox",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[813404, 25549, 199, 6, 14, "Caption",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[813606, 25557, 248, 7, 39, "DefinitionBox",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[813857, 25566, 194, 6, 14, "Caption",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[814054, 25574, 158, 6, 29, "MathCaption",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[814215, 25582, 169, 4, 27, "Input",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[814409, 25590, 122, 2, 27, "Input",
      CellTags->"$LoanFunctionsPackageVersion"],
    Cell[814534, 25594, 99, 2, 26, "Output",
      CellTags->"$LoanFunctionsPackageVersion"]},
  "AmortizationReport"->{
    Cell[814694, 25603, 909, 34, 62, "Subtitle",
      CellTags->"AmortizationReport"],
    Cell[815606, 25639, 120, 2, 14, "Caption",
      CellTags->"AmortizationReport"],
    Cell[815729, 25643, 199, 4, 14, "Caption",
      CellTags->"AmortizationReport"],
    Cell[815931, 25649, 196, 4, 14, "Caption",
      CellTags->"AmortizationReport"],
    Cell[816152, 25657, 71, 1, 74, "Section",
      CellTags->"AmortizationReport"],
    Cell[816226, 25660, 224, 5, 31, "Text",
      CellTags->"AmortizationReport"],
    Cell[816453, 25667, 856, 16, 165, "DefinitionBox",
      CellTags->"AmortizationReport"],
    Cell[817312, 25685, 177, 6, 14, "Caption",
      CellTags->"AmortizationReport"],
    Cell[817492, 25693, 164, 5, 39, "DefinitionBox",
      CellTags->"AmortizationReport"],
    Cell[817659, 25700, 179, 6, 14, "Caption",
      CellTags->"AmortizationReport"],
    Cell[817841, 25708, 177, 5, 39, "DefinitionBox",
      CellTags->"AmortizationReport"],
    Cell[818021, 25715, 174, 6, 14, "Caption",
      CellTags->"AmortizationReport"],
    Cell[818198, 25723, 169, 5, 30, "MathCaption",
      CellTags->"AmortizationReport"],
    Cell[818392, 25732, 321, 8, 27, "Input",
      CellTags->"AmortizationReport"],
    Cell[818716, 25742, 359, 10, 26, "Output",
      CellTags->"AmortizationReport"],
    Cell[819090, 25755, 130, 4, 28, "MathCaption",
      CellTags->"AmortizationReport"],
    Cell[819257, 25764, 117, 3, 74, "Section",
      CellTags->"AmortizationReport"],
    Cell[819377, 25769, 105, 1, 30, "Text",
      CellTags->"AmortizationReport"],
    Cell[819485, 25772, 496, 16, 83, "Text",
      CellTags->"AmortizationReport"],
    Cell[819984, 25790, 40252, 1001, 553, "Text",
      CellTags->"AmortizationReport"]},
  "$CalculatorBackgroundColor"->{
    Cell[860285, 26797, 73, 1, 52, "Subtitle",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[860361, 26800, 917, 34, 62, "Subtitle",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[861281, 26836, 128, 2, 14, "Caption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[861412, 26840, 207, 4, 14, "Caption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[861622, 26846, 204, 4, 14, "Caption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[861851, 26854, 87, 1, 74, "Section",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[861941, 26857, 269, 7, 65, "DefinitionBox",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[862213, 26866, 193, 6, 26, "Caption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[862409, 26874, 172, 5, 51, "DefinitionBox",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[862584, 26881, 195, 6, 26, "Caption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[862782, 26889, 189, 5, 51, "DefinitionBox",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[862974, 26896, 190, 6, 26, "Caption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[863167, 26904, 156, 6, 41, "MathCaption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[863326, 26912, 167, 4, 39, "Input",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[863496, 26918, 148, 4, 40, "MathCaption",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[863669, 26926, 118, 2, 39, "Input",
      CellTags->"$CalculatorBackgroundColor"],
    Cell[863790, 26930, 132, 3, 26, "Output",
      CellTags->"$CalculatorBackgroundColor"]},
  "EquityCalculator"->{
    Cell[863983, 26940, 907, 34, 62, "Subtitle",
      CellTags->"EquityCalculator"],
    Cell[864893, 26976, 118, 2, 14, "Caption",
      CellTags->"EquityCalculator"],
    Cell[865014, 26980, 197, 4, 14, "Caption",
      CellTags->"EquityCalculator"],
    Cell[865214, 26986, 194, 4, 14, "Caption",
      CellTags->"EquityCalculator"],
    Cell[865433, 26994, 67, 1, 74, "Section",
      CellTags->"EquityCalculator"],
    Cell[865503, 26997, 250, 7, 53, "DefinitionBox",
      CellTags->"EquityCalculator"],
    Cell[865756, 27006, 173, 6, 14, "Caption",
      CellTags->"EquityCalculator"],
    Cell[865932, 27014, 162, 5, 39, "DefinitionBox",
      CellTags->"EquityCalculator"],
    Cell[866097, 27021, 175, 6, 14, "Caption",
      CellTags->"EquityCalculator"],
    Cell[866275, 27029, 236, 7, 39, "DefinitionBox",
      CellTags->"EquityCalculator"],
    Cell[866514, 27038, 170, 6, 14, "Caption",
      CellTags->"EquityCalculator"]},
  "HomeValueCalculator"->{
    Cell[866733, 27050, 910, 34, 62, "Subtitle",
      CellTags->"HomeValueCalculator"],
    Cell[867646, 27086, 121, 2, 14, "Caption",
      CellTags->"HomeValueCalculator"],
    Cell[867770, 27090, 200, 4, 14, "Caption",
      CellTags->"HomeValueCalculator"],
    Cell[867973, 27096, 197, 4, 14, "Caption",
      CellTags->"HomeValueCalculator"],
    Cell[868195, 27104, 73, 1, 74, "Section",
      CellTags->"HomeValueCalculator"],
    Cell[868271, 27107, 265, 8, 53, "DefinitionBox",
      CellTags->"HomeValueCalculator"],
    Cell[868539, 27117, 179, 6, 14, "Caption",
      CellTags->"HomeValueCalculator"],
    Cell[868721, 27125, 165, 5, 39, "DefinitionBox",
      CellTags->"HomeValueCalculator"],
    Cell[868889, 27132, 181, 6, 14, "Caption",
      CellTags->"HomeValueCalculator"],
    Cell[869073, 27140, 239, 7, 39, "DefinitionBox",
      CellTags->"HomeValueCalculator"],
    Cell[869315, 27149, 176, 6, 14, "Caption",
      CellTags->"HomeValueCalculator"]},
  "PaymentCalculator"->{
    Cell[869540, 27161, 908, 34, 62, "Subtitle",
      CellTags->"PaymentCalculator"],
    Cell[870451, 27197, 119, 2, 26, "Caption",
      CellTags->"PaymentCalculator"],
    Cell[870573, 27201, 198, 4, 26, "Caption",
      CellTags->"PaymentCalculator"],
    Cell[870774, 27207, 195, 4, 26, "Caption",
      CellTags->"PaymentCalculator"],
    Cell[870994, 27215, 69, 1, 86, "Section",
      CellTags->"PaymentCalculator"],
    Cell[871066, 27218, 306, 8, 79, "DefinitionBox",
      CellTags->"PaymentCalculator"],
    Cell[871375, 27228, 175, 6, 26, "Caption",
      CellTags->"PaymentCalculator"],
    Cell[871553, 27236, 163, 5, 51, "DefinitionBox",
      CellTags->"PaymentCalculator"],
    Cell[871719, 27243, 177, 6, 26, "Caption",
      CellTags->"PaymentCalculator"],
    Cell[871899, 27251, 237, 7, 51, "DefinitionBox",
      CellTags->"PaymentCalculator"],
    Cell[872139, 27260, 172, 6, 26, "Caption",
      CellTags->"PaymentCalculator"]},
  "PaymentsRemainingCalculator"->{
    Cell[872360, 27272, 918, 34, 74, "Subtitle",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[873281, 27308, 129, 2, 26, "Caption",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[873413, 27312, 208, 4, 26, "Caption",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[873624, 27318, 205, 4, 26, "Caption",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[873854, 27326, 89, 1, 86, "Section",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[873946, 27329, 297, 8, 65, "DefinitionBox",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[874246, 27339, 195, 6, 26, "Caption",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[874444, 27347, 173, 5, 51, "DefinitionBox",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[874620, 27354, 197, 6, 26, "Caption",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[874820, 27362, 247, 7, 51, "DefinitionBox",
      CellTags->"PaymentsRemainingCalculator"],
    Cell[875070, 27371, 192, 6, 26, "Caption",
      CellTags->"PaymentsRemainingCalculator"]},
  "PrincipalCalculator"->{
    Cell[875311, 27383, 910, 34, 74, "Subtitle",
      CellTags->"PrincipalCalculator"],
    Cell[876224, 27419, 121, 2, 26, "Caption",
      CellTags->"PrincipalCalculator"],
    Cell[876348, 27423, 200, 4, 26, "Caption",
      CellTags->"PrincipalCalculator"],
    Cell[876551, 27429, 197, 4, 26, "Caption",
      CellTags->"PrincipalCalculator"],
    Cell[876773, 27437, 73, 1, 86, "Section",
      CellTags->"PrincipalCalculator"],
    Cell[876849, 27440, 259, 7, 65, "DefinitionBox",
      CellTags->"PrincipalCalculator"],
    Cell[877111, 27449, 179, 6, 26, "Caption",
      CellTags->"PrincipalCalculator"],
    Cell[877293, 27457, 165, 5, 51, "DefinitionBox",
      CellTags->"PrincipalCalculator"],
    Cell[877461, 27464, 181, 6, 26, "Caption",
      CellTags->"PrincipalCalculator"],
    Cell[877645, 27472, 239, 7, 51, "DefinitionBox",
      CellTags->"PrincipalCalculator"],
    Cell[877887, 27481, 176, 6, 26, "Caption",
      CellTags->"PrincipalCalculator"]},
  "TotalPaymentsCalculator"->{
    Cell[878112, 27493, 914, 34, 74, "Subtitle",
      CellTags->"TotalPaymentsCalculator"],
    Cell[879029, 27529, 125, 2, 26, "Caption",
      CellTags->"TotalPaymentsCalculator"],
    Cell[879157, 27533, 204, 4, 26, "Caption",
      CellTags->"TotalPaymentsCalculator"],
    Cell[879364, 27539, 201, 4, 26, "Caption",
      CellTags->"TotalPaymentsCalculator"],
    Cell[879590, 27547, 81, 1, 86, "Section",
      CellTags->"TotalPaymentsCalculator"],
    Cell[879674, 27550, 324, 8, 79, "DefinitionBox",
      CellTags->"TotalPaymentsCalculator"],
    Cell[880001, 27560, 187, 6, 26, "Caption",
      CellTags->"TotalPaymentsCalculator"],
    Cell[880191, 27568, 169, 5, 51, "DefinitionBox",
      CellTags->"TotalPaymentsCalculator"],
    Cell[880363, 27575, 189, 6, 26, "Caption",
      CellTags->"TotalPaymentsCalculator"],
    Cell[880555, 27583, 243, 7, 51, "DefinitionBox",
      CellTags->"TotalPaymentsCalculator"],
    Cell[880801, 27592, 184, 6, 26, "Caption",
      CellTags->"TotalPaymentsCalculator"]},
  "Loan Functions Palette"->{
    Cell[881034, 27604, 66, 1, 64, "Subtitle",
      CellTags->"Loan Functions Palette"],
    Cell[881103, 27607, 913, 34, 74, "Subtitle",
      CellTags->"Loan Functions Palette"],
    Cell[882019, 27643, 124, 2, 26, "Caption",
      CellTags->"Loan Functions Palette"],
    Cell[882146, 27647, 203, 4, 26, "Caption",
      CellTags->"Loan Functions Palette"],
    Cell[882352, 27653, 200, 4, 26, "Caption",
      CellTags->"Loan Functions Palette"],
    Cell[882577, 27661, 79, 1, 86, "Section",
      CellTags->"Loan Functions Palette"],
    Cell[882659, 27664, 624, 15, 66, "Text",
      CellTags->"Loan Functions Palette"],
    Cell[883286, 27681, 11488, 302, 496, NotebookDefault,
      CellGroupingRules->"OutputGrouping",
      PageBreakAbove->True,
      PageBreakWithin->False,
      CounterIncrements->"Output",
      CellTags->"Loan Functions Palette"]},
  "Loan Calculators Palette"->{
    Cell[894823, 27989, 915, 34, 74, "Subtitle",
      CellTags->"Loan Calculators Palette"],
    Cell[895741, 28025, 126, 2, 26, "Caption",
      CellTags->"Loan Calculators Palette"],
    Cell[895870, 28029, 205, 4, 26, "Caption",
      CellTags->"Loan Calculators Palette"],
    Cell[896078, 28035, 202, 4, 26, "Caption",
      CellTags->"Loan Calculators Palette"],
    Cell[896305, 28043, 83, 1, 86, "Section",
      CellTags->"Loan Calculators Palette"],
    Cell[896391, 28046, 636, 15, 66, "Text",
      CellTags->"Loan Calculators Palette"],
    Cell[897030, 28063, 3062, 83, 142, NotebookDefault,
      CellGroupingRules->"OutputGrouping",
      PageBreakAbove->True,
      PageBreakWithin->False,
      CounterIncrements->"Output",
      CellTags->"Loan Calculators Palette"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Disclaimer", 901093, 28176},
  {"LoanFunctions", 901679, 28189},
  {"LoanFunctions Introduction", 905578, 28262},
  {"$PaymentsPerYear", 908903, 28323},
  {"TemporarySetPaymentsPerYear", 917662, 28540},
  {"ResetLoanFunctionsDefaults", 926420, 28757},
  {"HomeCost", 935160, 28974},
  {"LoanAmount", 936456, 29009},
  {"DownPayment", 937787, 29044},
  {"PercentageDownPayment", 939145, 29079},
  {"Payment", 940659, 29114},
  {"PaymentToInterest", 942446, 29162},
  {"PaymentToPrincipal", 944479, 29210},
  {"TotalPrincipalPaid", 946548, 29258},
  {"TotalInterestPaid", 948610, 29306},
  {"TotalPayments", 951066, 29364},
  {"ActualPayment", 954639, 29443},
  {"EffectivePayment", 956491, 29480},
  {"PaymentsRemaining", 958278, 29522},
  {"Principal", 961967, 29609},
  {"YearsToPaymentNumber", 967204, 29725},
  {"PaymentNumberToYears", 972441, 29841},
  {"HomeValue", 977667, 29957},
  {"Equity", 979242, 29998},
  {"EquityTargetPayment", 980629, 30035},
  {"CalculationBasis", 991248, 30279},
  {"Current", 1001858, 30523},
  {"Original", 1012469, 30767},
  {"$EquityFindRootStart", 1023092, 31011},
  {"SetErrorChecking", 1033711, 31255},
  {"$ErrorChecking", 1051229, 31684},
  {"$StrongErrorChecking", 1068753, 32113},
  {"Error Checking", 1086271, 32542},
  {"$LoanFunctionsPackageVersion", 1103803, 32971},
  {"AmortizationReport", 1105287, 33002},
  {"$CalculatorBackgroundColor", 1107064, 33043},
  {"EquityCalculator", 1108709, 33078},
  {"HomeValueCalculator", 1109680, 33101},
  {"PaymentCalculator", 1110682, 33124},
  {"PaymentsRemainingCalculator", 1111672, 33147},
  {"PrincipalCalculator", 1112764, 33170},
  {"TotalPaymentsCalculator", 1113772, 33193},
  {"Loan Functions Palette", 1114823, 33216},
  {"Loan Calculators Palette", 1115722, 33237}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 920, 34, 62, "Subtitle",
  CellTags->{"Disclaimer", "LoanFunctions"}],
Cell[2662, 87, 131, 2, 14, "Caption",
  CellTags->{"Disclaimer", "LoanFunctions"}],
Cell[2796, 91, 210, 4, 14, "Caption",
  CellTags->{"Disclaimer", "LoanFunctions"}],
Cell[3009, 97, 207, 4, 14, "Caption",
  CellTags->{"Disclaimer", "LoanFunctions"}],

Cell[CellGroupData[{
Cell[3241, 105, 74, 1, 74, "Section",
  CellTags->{"Disclaimer", "LoanFunctions"}],
Cell[3318, 108, 1507, 27, 347, "DefinitionBox",
  CellTags->{"LoanFunctions", "Disclaimer"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4874, 141, 936, 34, 62, "Subtitle",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[5813, 177, 147, 2, 14, "Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[5963, 181, 226, 4, 14, "Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[6192, 187, 223, 4, 14, "Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[CellGroupData[{
Cell[6440, 195, 108, 1, 74, "Section",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[CellGroupData[{
Cell[6573, 200, 105, 1, 56, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[6681, 203, 924, 25, 84, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7642, 233, 95, 1, 56, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[7740, 236, 689, 16, 64, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8466, 257, 91, 1, 56, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[8560, 260, 2875, 74, 240, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11472, 339, 102, 1, 56, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[11577, 342, 285, 6, 47, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[11865, 350, 175, 6, 29, "MathCaption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[12043, 358, 186, 4, 27, "Input",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[12232, 364, 195, 5, 29, "MathCaption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[CellGroupData[{
Cell[12452, 373, 139, 2, 27, "Input",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[12594, 377, 123, 2, 26, "Output",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],
Cell[12732, 382, 254, 7, 31, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[12989, 391, 5002, 146, 339, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[17994, 539, 204, 4, 14, "Caption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[18201, 545, 686, 14, 73, "MathCaption",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[18890, 561, 2442, 50, 33, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[21369, 616, 107, 1, 56, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[21479, 619, 506, 8, 62, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[21988, 629, 576, 10, 66, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[22567, 641, 1523, 27, 347, "DefinitionBox",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[24093, 670, 192, 4, 30, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[24288, 676, 254, 8, 31, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[24545, 686, 1225, 27, 75, "Input",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25831, 720, 978, 36, 62, "Subtitle",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[26812, 758, 189, 4, 14, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[27004, 764, 268, 6, 14, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[27275, 772, 265, 6, 14, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[27565, 782, 138, 3, 74, "Section",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[27706, 787, 311, 8, 47, "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[28020, 797, 322, 9, 53, "DefinitionBox",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[28345, 808, 244, 8, 14, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[28592, 818, 233, 7, 39, "DefinitionBox",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[28828, 827, 246, 8, 14, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[29077, 837, 250, 7, 39, "DefinitionBox",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[29330, 846, 241, 8, 14, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[29574, 856, 293, 8, 31, "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[29870, 866, 217, 8, 29, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[30090, 876, 228, 6, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[30321, 884, 217, 7, 29, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[30563, 895, 169, 4, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[30735, 901, 156, 4, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],
Cell[30906, 908, 266, 7, 28, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[31197, 919, 320, 9, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[31520, 930, 172, 4, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],
Cell[31707, 937, 201, 6, 28, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[31933, 947, 195, 5, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[32131, 954, 156, 4, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],
Cell[32302, 961, 224, 6, 28, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[32551, 971, 320, 9, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[32874, 982, 194, 4, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],
Cell[33083, 989, 348, 10, 53, "DefinitionBox",
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],
Cell[33434, 1001, 254, 8, 14, "Caption",
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],
Cell[33691, 1011, 233, 7, 39, "DefinitionBox",
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],
Cell[33927, 1020, 256, 8, 14, "Caption",
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],
Cell[34186, 1030, 307, 9, 39, "DefinitionBox",
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],
Cell[34496, 1041, 251, 8, 14, "Caption",
  CellTags->{
  "ResetLoanFunctionsDefaults", "$PaymentsPerYear", 
    "TemporarySetPaymentsPerYear"}],
Cell[34750, 1051, 145, 3, 28, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[34898, 1056, 204, 5, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[35127, 1065, 169, 4, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[35299, 1071, 156, 4, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],
Cell[35470, 1078, 290, 9, 31, "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[35763, 1089, 355, 8, 42, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[36143, 1101, 793, 21, 43, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[36939, 1124, 277, 8, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],
Cell[37231, 1135, 241, 6, 31, "Text",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[37475, 1143, 383, 10, 67, "DefinitionBox",
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[37861, 1155, 255, 8, 14, "Caption",
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[38119, 1165, 233, 7, 39, "DefinitionBox",
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[38355, 1174, 257, 8, 14, "Caption",
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[38615, 1184, 349, 10, 39, "DefinitionBox",
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[38967, 1196, 252, 8, 14, "Caption",
  CellTags->{
  "TemporarySetPaymentsPerYear", "$PaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[39222, 1206, 279, 8, 29, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[39526, 1218, 430, 11, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[39959, 1231, 195, 4, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]],
Cell[40169, 1238, 209, 6, 29, "MathCaption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[CellGroupData[{
Cell[40403, 1248, 170, 4, 27, "Input",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[40576, 1254, 157, 4, 26, "Output",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40794, 1265, 899, 34, 62, "Subtitle",
  CellTags->"HomeCost"],
Cell[41696, 1301, 110, 2, 14, "Caption",
  CellTags->"HomeCost"],
Cell[41809, 1305, 189, 4, 14, "Caption",
  CellTags->"HomeCost"],
Cell[42001, 1311, 186, 4, 14, "Caption",
  CellTags->"HomeCost"],

Cell[CellGroupData[{
Cell[42212, 1319, 51, 1, 74, "Section",
  CellTags->"HomeCost"],
Cell[42266, 1322, 113, 4, 31, "Text",
  CellTags->"HomeCost"],
Cell[42382, 1328, 378, 9, 81, "DefinitionBox",
  CellTags->"HomeCost"],
Cell[42763, 1339, 157, 6, 14, "Caption",
  CellTags->"HomeCost"],
Cell[42923, 1347, 154, 5, 39, "DefinitionBox",
  CellTags->"HomeCost"],
Cell[43080, 1354, 159, 6, 14, "Caption",
  CellTags->"HomeCost"],
Cell[43242, 1362, 261, 8, 39, "DefinitionBox",
  CellTags->"HomeCost"],
Cell[43506, 1372, 154, 6, 14, "Caption",
  CellTags->"HomeCost"],
Cell[43663, 1380, 138, 6, 29, "MathCaption",
  CellTags->"HomeCost"],
Cell[43804, 1388, 149, 4, 27, "Input",
  CellTags->"HomeCost"],
Cell[43956, 1394, 143, 4, 29, "MathCaption",
  CellTags->"HomeCost"],

Cell[CellGroupData[{
Cell[44124, 1402, 152, 4, 27, "Input",
  CellTags->"HomeCost"],
Cell[44279, 1408, 163, 5, 51, "Output",
  CellTags->"HomeCost"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44503, 1420, 901, 34, 62, "Subtitle",
  CellTags->"LoanAmount"],
Cell[45407, 1456, 112, 2, 14, "Caption",
  CellTags->"LoanAmount"],
Cell[45522, 1460, 191, 4, 14, "Caption",
  CellTags->"LoanAmount"],
Cell[45716, 1466, 188, 4, 14, "Caption",
  CellTags->"LoanAmount"],

Cell[CellGroupData[{
Cell[45929, 1474, 55, 1, 74, "Section",
  CellTags->"LoanAmount"],
Cell[45987, 1477, 117, 4, 31, "Text",
  CellTags->"LoanAmount"],
Cell[46107, 1483, 312, 8, 67, "DefinitionBox",
  CellTags->"LoanAmount"],
Cell[46422, 1493, 161, 6, 14, "Caption",
  CellTags->"LoanAmount"],
Cell[46586, 1501, 156, 5, 39, "DefinitionBox",
  CellTags->"LoanAmount"],
Cell[46745, 1508, 163, 6, 14, "Caption",
  CellTags->"LoanAmount"],
Cell[46911, 1516, 263, 8, 39, "DefinitionBox",
  CellTags->"LoanAmount"],
Cell[47177, 1526, 158, 6, 14, "Caption",
  CellTags->"LoanAmount"],
Cell[47338, 1534, 140, 6, 29, "MathCaption",
  CellTags->"LoanAmount"],
Cell[47481, 1542, 151, 4, 27, "Input",
  CellTags->"LoanAmount"],
Cell[47635, 1548, 147, 4, 29, "MathCaption",
  CellTags->"LoanAmount"],

Cell[CellGroupData[{
Cell[47807, 1556, 148, 4, 27, "Input",
  CellTags->"LoanAmount"],
Cell[47958, 1562, 190, 6, 42, "Output",
  CellTags->"LoanAmount"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48209, 1575, 902, 34, 62, "Subtitle",
  CellTags->"DownPayment"],
Cell[49114, 1611, 113, 2, 14, "Caption",
  CellTags->"DownPayment"],
Cell[49230, 1615, 192, 4, 14, "Caption",
  CellTags->"DownPayment"],
Cell[49425, 1621, 189, 4, 14, "Caption",
  CellTags->"DownPayment"],

Cell[CellGroupData[{
Cell[49639, 1629, 57, 1, 74, "Section",
  CellTags->"DownPayment"],
Cell[49699, 1632, 114, 4, 31, "Text",
  CellTags->"DownPayment"],
Cell[49816, 1638, 315, 8, 67, "DefinitionBox",
  CellTags->"DownPayment"],
Cell[50134, 1648, 163, 6, 14, "Caption",
  CellTags->"DownPayment"],
Cell[50300, 1656, 157, 5, 39, "DefinitionBox",
  CellTags->"DownPayment"],
Cell[50460, 1663, 165, 6, 14, "Caption",
  CellTags->"DownPayment"],
Cell[50628, 1671, 264, 8, 39, "DefinitionBox",
  CellTags->"DownPayment"],
Cell[50895, 1681, 160, 6, 14, "Caption",
  CellTags->"DownPayment"],
Cell[51058, 1689, 141, 6, 29, "MathCaption",
  CellTags->"DownPayment"],
Cell[51202, 1697, 152, 4, 27, "Input",
  CellTags->"DownPayment"],
Cell[51357, 1703, 149, 5, 29, "MathCaption",
  CellTags->"DownPayment"],

Cell[CellGroupData[{
Cell[51531, 1712, 150, 4, 27, "Input",
  CellTags->"DownPayment"],
Cell[51684, 1718, 131, 4, 43, "Output",
  CellTags->"DownPayment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51876, 1729, 912, 34, 62, "Subtitle",
  CellTags->"PercentageDownPayment"],
Cell[52791, 1765, 123, 2, 14, "Caption",
  CellTags->"PercentageDownPayment"],
Cell[52917, 1769, 202, 4, 14, "Caption",
  CellTags->"PercentageDownPayment"],
Cell[53122, 1775, 199, 4, 14, "Caption",
  CellTags->"PercentageDownPayment"],

Cell[CellGroupData[{
Cell[53346, 1783, 77, 1, 74, "Section",
  CellTags->"PercentageDownPayment"],
Cell[53426, 1786, 134, 4, 31, "Text",
  CellTags->"PercentageDownPayment"],
Cell[53563, 1792, 327, 8, 67, "DefinitionBox",
  CellTags->"PercentageDownPayment"],
Cell[53893, 1802, 183, 6, 14, "Caption",
  CellTags->"PercentageDownPayment"],
Cell[54079, 1810, 167, 5, 39, "DefinitionBox",
  CellTags->"PercentageDownPayment"],
Cell[54249, 1817, 185, 6, 14, "Caption",
  CellTags->"PercentageDownPayment"],
Cell[54437, 1825, 274, 8, 39, "DefinitionBox",
  CellTags->"PercentageDownPayment"],
Cell[54714, 1835, 180, 6, 14, "Caption",
  CellTags->"PercentageDownPayment"],
Cell[54897, 1843, 151, 6, 29, "MathCaption",
  CellTags->"PercentageDownPayment"],
Cell[55051, 1851, 162, 4, 27, "Input",
  CellTags->"PercentageDownPayment"],
Cell[55216, 1857, 169, 5, 29, "MathCaption",
  CellTags->"PercentageDownPayment"],

Cell[CellGroupData[{
Cell[55410, 1866, 178, 4, 27, "Input",
  CellTags->"PercentageDownPayment"],
Cell[55591, 1872, 209, 6, 43, "Output",
  CellTags->"PercentageDownPayment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[55861, 1885, 898, 34, 62, "Subtitle",
  CellTags->"Payment"],
Cell[56762, 1921, 109, 2, 14, "Caption",
  CellTags->"Payment"],
Cell[56874, 1925, 188, 4, 14, "Caption",
  CellTags->"Payment"],
Cell[57065, 1931, 185, 4, 14, "Caption",
  CellTags->"Payment"],

Cell[CellGroupData[{
Cell[57275, 1939, 49, 1, 74, "Section",
  CellTags->"Payment"],
Cell[57327, 1942, 247, 6, 47, "Text",
  CellTags->"Payment"],
Cell[57577, 1950, 1555, 30, 347, "DefinitionBox",
  CellTags->"Payment"],
Cell[59135, 1982, 155, 6, 14, "Caption",
  CellTags->"Payment"],
Cell[59293, 1990, 153, 5, 39, "DefinitionBox",
  CellTags->"Payment"],
Cell[59449, 1997, 157, 6, 14, "Caption",
  CellTags->"Payment"],
Cell[59609, 2005, 260, 8, 39, "DefinitionBox",
  CellTags->"Payment"],
Cell[59872, 2015, 152, 6, 14, "Caption",
  CellTags->"Payment"],
Cell[60027, 2023, 137, 6, 29, "MathCaption",
  CellTags->"Payment"],
Cell[60167, 2031, 148, 4, 27, "Input",
  CellTags->"Payment"],
Cell[60318, 2037, 122, 4, 28, "MathCaption",
  CellTags->"Payment"],

Cell[CellGroupData[{
Cell[60465, 2045, 165, 4, 27, "Input",
  CellTags->"Payment"],
Cell[60633, 2051, 110, 2, 26, "Output",
  CellTags->"Payment"]
}, Open  ]],
Cell[60758, 2056, 229, 5, 42, "MathCaption",
  CellTags->"Payment"],

Cell[CellGroupData[{
Cell[61012, 2065, 399, 11, 27, "Input",
  CellTags->"Payment"],
Cell[61414, 2078, 624, 18, 26, "Output",
  CellTags->"Payment"]
}, Open  ]],
Cell[62053, 2099, 146, 4, 28, "MathCaption",
  CellTags->"Payment"],

Cell[CellGroupData[{
Cell[62224, 2107, 531, 15, 27, "Input",
  CellTags->"Payment"],
Cell[62758, 2124, 32701, 1186, 186, 12472, 930, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Payment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[95520, 3317, 908, 34, 62, "Subtitle",
  CellTags->"PaymentToInterest"],
Cell[96431, 3353, 119, 2, 14, "Caption",
  CellTags->"PaymentToInterest"],
Cell[96553, 3357, 198, 4, 14, "Caption",
  CellTags->"PaymentToInterest"],
Cell[96754, 3363, 195, 4, 14, "Caption",
  CellTags->"PaymentToInterest"],

Cell[CellGroupData[{
Cell[96974, 3371, 69, 1, 74, "Section",
  CellTags->"PaymentToInterest"],
Cell[97046, 3374, 156, 4, 31, "Text",
  CellTags->"PaymentToInterest"],
Cell[97205, 3380, 1584, 30, 375, "DefinitionBox",
  CellTags->"PaymentToInterest"],
Cell[98792, 3412, 175, 6, 14, "Caption",
  CellTags->"PaymentToInterest"],
Cell[98970, 3420, 163, 5, 39, "DefinitionBox",
  CellTags->"PaymentToInterest"],
Cell[99136, 3427, 177, 6, 14, "Caption",
  CellTags->"PaymentToInterest"],
Cell[99316, 3435, 270, 8, 39, "DefinitionBox",
  CellTags->"PaymentToInterest"],
Cell[99589, 3445, 172, 6, 14, "Caption",
  CellTags->"PaymentToInterest"],
Cell[99764, 3453, 147, 6, 29, "MathCaption",
  CellTags->"PaymentToInterest"],
Cell[99914, 3461, 158, 4, 27, "Input",
  CellTags->"PaymentToInterest"],

Cell[CellGroupData[{
Cell[100097, 3469, 533, 14, 27, "Input",
  CellTags->"PaymentToInterest"],
Cell[100633, 3485, 24752, 733, 186, 6035, 496, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"PaymentToInterest"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125422, 4223, 409, 11, 27, "Input",
  CellTags->"PaymentToInterest"],
Cell[125834, 4236, 634, 18, 26, "Output",
  CellTags->"PaymentToInterest"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126505, 4259, 954, 23, 59, "Input",
  CellTags->"PaymentToInterest"],
Cell[127462, 4284, 26953, 813, 186, 7207, 563, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"PaymentToInterest"]
}, Open  ]],

Cell[CellGroupData[{
Cell[154452, 5102, 187, 5, 27, "Input",
  CellTags->"PaymentToInterest"],
Cell[154642, 5109, 30261, 922, 186, 8124, 643, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"PaymentToInterest"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[184964, 6038, 909, 34, 62, "Subtitle",
  CellTags->"PaymentToPrincipal"],
Cell[185876, 6074, 120, 2, 14, "Caption",
  CellTags->"PaymentToPrincipal"],
Cell[185999, 6078, 199, 4, 14, "Caption",
  CellTags->"PaymentToPrincipal"],
Cell[186201, 6084, 196, 4, 14, "Caption",
  CellTags->"PaymentToPrincipal"],

Cell[CellGroupData[{
Cell[186422, 6092, 71, 1, 74, "Section",
  CellTags->"PaymentToPrincipal"],
Cell[186496, 6095, 159, 4, 31, "Text",
  CellTags->"PaymentToPrincipal"],
Cell[186658, 6101, 1590, 30, 375, "DefinitionBox",
  CellTags->"PaymentToPrincipal"],
Cell[188251, 6133, 177, 6, 14, "Caption",
  CellTags->"PaymentToPrincipal"],
Cell[188431, 6141, 164, 5, 39, "DefinitionBox",
  CellTags->"PaymentToPrincipal"],
Cell[188598, 6148, 179, 6, 14, "Caption",
  CellTags->"PaymentToPrincipal"],
Cell[188780, 6156, 271, 8, 39, "DefinitionBox",
  CellTags->"PaymentToPrincipal"],
Cell[189054, 6166, 174, 6, 14, "Caption",
  CellTags->"PaymentToPrincipal"],
Cell[189231, 6174, 148, 6, 29, "MathCaption",
  CellTags->"PaymentToPrincipal"],
Cell[189382, 6182, 159, 4, 27, "Input",
  CellTags->"PaymentToPrincipal"],

Cell[CellGroupData[{
Cell[189566, 6190, 535, 14, 27, "Input",
  CellTags->"PaymentToPrincipal"],
Cell[190104, 6206, 25416, 764, 186, 6354, 523, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"PaymentToPrincipal"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215557, 6975, 410, 11, 27, "Input",
  CellTags->"PaymentToPrincipal"],
Cell[215970, 6988, 635, 18, 26, "Output",
  CellTags->"PaymentToPrincipal"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216642, 7011, 956, 23, 59, "Input",
  CellTags->"PaymentToPrincipal"],
Cell[217601, 7036, 26008, 789, 186, 6849, 547, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"PaymentToPrincipal"]
}, Open  ]],

Cell[CellGroupData[{
Cell[243646, 7830, 188, 5, 27, "Input",
  CellTags->"PaymentToPrincipal"],
Cell[243837, 7837, 28182, 862, 186, 7552, 601, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"PaymentToPrincipal"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[272080, 8706, 909, 34, 62, "Subtitle",
  CellTags->"TotalPrincipalPaid"],
Cell[272992, 8742, 120, 2, 14, "Caption",
  CellTags->"TotalPrincipalPaid"],
Cell[273115, 8746, 199, 4, 14, "Caption",
  CellTags->"TotalPrincipalPaid"],
Cell[273317, 8752, 196, 4, 14, "Caption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{
Cell[273538, 8760, 71, 1, 74, "Section",
  CellTags->"TotalPrincipalPaid"],
Cell[273612, 8763, 1881, 36, 445, "DefinitionBox",
  CellTags->"TotalPrincipalPaid"],
Cell[275496, 8801, 177, 6, 14, "Caption",
  CellTags->"TotalPrincipalPaid"],
Cell[275676, 8809, 164, 5, 39, "DefinitionBox",
  CellTags->"TotalPrincipalPaid"],
Cell[275843, 8816, 179, 6, 14, "Caption",
  CellTags->"TotalPrincipalPaid"],
Cell[276025, 8824, 238, 7, 39, "DefinitionBox",
  CellTags->"TotalPrincipalPaid"],
Cell[276266, 8833, 174, 6, 14, "Caption",
  CellTags->"TotalPrincipalPaid"],
Cell[276443, 8841, 148, 6, 29, "MathCaption",
  CellTags->"TotalPrincipalPaid"],
Cell[276594, 8849, 159, 4, 27, "Input",
  CellTags->"TotalPrincipalPaid"],
Cell[276756, 8855, 156, 4, 28, "MathCaption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{
Cell[276937, 8863, 262, 7, 27, "Input",
  CellTags->"TotalPrincipalPaid"],
Cell[277202, 8872, 103, 2, 26, "Output",
  CellTags->"TotalPrincipalPaid"]
}, Open  ]],
Cell[277320, 8877, 185, 4, 30, "Text",
  CellTags->"TotalPrincipalPaid"],
Cell[277508, 8883, 102, 1, 28, "MathCaption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{
Cell[277635, 8888, 768, 20, 43, "Input",
  CellTags->"TotalPrincipalPaid"],
Cell[278406, 8910, 2739, 65, 86, "Output",
  CellTags->"TotalPrincipalPaid"]
}, Open  ]],
Cell[281160, 8978, 153, 4, 28, "MathCaption",
  CellTags->"TotalPrincipalPaid"],

Cell[CellGroupData[{
Cell[281338, 8986, 502, 14, 27, "Input",
  CellTags->"TotalPrincipalPaid"],
Cell[281843, 9002, 25649, 717, 186, 5768, 466, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"TotalPrincipalPaid"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[307553, 9726, 908, 34, 62, "Subtitle",
  CellTags->"TotalInterestPaid"],
Cell[308464, 9762, 119, 2, 14, "Caption",
  CellTags->"TotalInterestPaid"],
Cell[308586, 9766, 198, 4, 14, "Caption",
  CellTags->"TotalInterestPaid"],
Cell[308787, 9772, 195, 4, 14, "Caption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{
Cell[309007, 9780, 69, 1, 74, "Section",
  CellTags->"TotalInterestPaid"],
Cell[309079, 9783, 1872, 36, 445, "DefinitionBox",
  CellTags->"TotalInterestPaid"],
Cell[310954, 9821, 175, 6, 14, "Caption",
  CellTags->"TotalInterestPaid"],
Cell[311132, 9829, 163, 5, 39, "DefinitionBox",
  CellTags->"TotalInterestPaid"],
Cell[311298, 9836, 177, 6, 14, "Caption",
  CellTags->"TotalInterestPaid"],
Cell[311478, 9844, 270, 8, 39, "DefinitionBox",
  CellTags->"TotalInterestPaid"],
Cell[311751, 9854, 172, 6, 14, "Caption",
  CellTags->"TotalInterestPaid"],
Cell[311926, 9862, 147, 6, 29, "MathCaption",
  CellTags->"TotalInterestPaid"],
Cell[312076, 9870, 158, 4, 27, "Input",
  CellTags->"TotalInterestPaid"],
Cell[312237, 9876, 174, 4, 28, "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{
Cell[312436, 9884, 594, 15, 43, "Input",
  CellTags->"TotalInterestPaid"],
Cell[313033, 9901, 102, 2, 26, "Output",
  CellTags->"TotalInterestPaid"]
}, Open  ]],
Cell[313150, 9906, 199, 5, 30, "Text",
  CellTags->"TotalInterestPaid"],
Cell[313352, 9913, 101, 1, 28, "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{
Cell[313478, 9918, 409, 11, 27, "Input",
  CellTags->"TotalInterestPaid"],
Cell[313890, 9931, 634, 18, 26, "Output",
  CellTags->"TotalInterestPaid"]
}, Open  ]],
Cell[314539, 9952, 151, 4, 28, "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{
Cell[314715, 9960, 901, 23, 59, "Input",
  CellTags->"TotalInterestPaid"],
Cell[315619, 9985, 29794, 927, 186, 8063, 653, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"TotalInterestPaid"]
}, Open  ]],
Cell[345428, 10915, 100, 1, 30, "Text",
  CellTags->"TotalInterestPaid"],
Cell[345531, 10918, 243, 6, 43, "MathCaption",
  CellTags->"TotalInterestPaid"],

Cell[CellGroupData[{
Cell[345799, 10928, 726, 19, 43, "Input",
  CellTags->"TotalInterestPaid"],
Cell[346528, 10949, 165, 4, 26, "Output",
  CellTags->"TotalInterestPaid"]
}, Open  ]],
Cell[346708, 10956, 234, 8, 37, "Text",
  CellTags->"TotalInterestPaid"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[346991, 10970, 904, 34, 62, "Subtitle",
  CellTags->"TotalPayments"],
Cell[347898, 11006, 115, 2, 14, "Caption",
  CellTags->"TotalPayments"],
Cell[348016, 11010, 194, 4, 14, "Caption",
  CellTags->"TotalPayments"],
Cell[348213, 11016, 191, 4, 14, "Caption",
  CellTags->"TotalPayments"],

Cell[CellGroupData[{
Cell[348429, 11024, 61, 1, 74, "Section",
  CellTags->"TotalPayments"],
Cell[348493, 11027, 1906, 37, 459, "DefinitionBox",
  CellTags->"TotalPayments"],
Cell[350402, 11066, 167, 6, 14, "Caption",
  CellTags->"TotalPayments"],
Cell[350572, 11074, 159, 5, 39, "DefinitionBox",
  CellTags->"TotalPayments"],
Cell[350734, 11081, 169, 6, 14, "Caption",
  CellTags->"TotalPayments"],
Cell[350906, 11089, 266, 8, 39, "DefinitionBox",
  CellTags->"TotalPayments"],
Cell[351175, 11099, 164, 6, 14, "Caption",
  CellTags->"TotalPayments"],
Cell[351342, 11107, 143, 6, 29, "MathCaption",
  CellTags->"TotalPayments"],
Cell[351488, 11115, 154, 4, 27, "Input",
  CellTags->"TotalPayments"],
Cell[351645, 11121, 98, 1, 28, "MathCaption",
  CellTags->"TotalPayments"],

Cell[CellGroupData[{
Cell[351768, 11126, 172, 4, 27, "Input",
  CellTags->"TotalPayments"],
Cell[351943, 11132, 117, 2, 26, "Output",
  CellTags->"TotalPayments"]
}, Open  ]],
Cell[352075, 11137, 127, 4, 28, "MathCaption",
  CellTags->"TotalPayments"],

Cell[CellGroupData[{
Cell[352227, 11145, 271, 7, 27, "Input",
  CellTags->"TotalPayments"],
Cell[352501, 11154, 119, 2, 26, "Output",
  CellTags->"TotalPayments"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[352681, 11163, 923, 34, 62, "Subtitle",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[353607, 11199, 134, 2, 14, "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[353744, 11203, 213, 4, 14, "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[353960, 11209, 210, 4, 14, "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[CellGroupData[{
Cell[354195, 11217, 80, 1, 74, "Section",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[354278, 11220, 234, 6, 31, "Text",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[354515, 11228, 2456, 46, 585, "DefinitionBox",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[356974, 11276, 186, 6, 14, "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[357163, 11284, 178, 5, 39, "DefinitionBox",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[357344, 11291, 188, 6, 14, "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[357535, 11299, 285, 8, 39, "DefinitionBox",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[357823, 11309, 183, 6, 14, "Caption",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[358009, 11317, 162, 6, 29, "MathCaption",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[358174, 11325, 173, 4, 27, "Input",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[358350, 11331, 369, 7, 43, "MathCaption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[CellGroupData[{
Cell[358744, 11342, 557, 15, 27, "Input",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[359304, 11359, 117, 2, 26, "Output",
  CellTags->"TotalPayments"]
}, Open  ]],
Cell[359436, 11364, 217, 5, 29, "MathCaption",
  CellTags->{"ActualPayment", "TotalPayments"}],

Cell[CellGroupData[{
Cell[359678, 11373, 579, 15, 27, "Input",
  CellTags->{"ActualPayment", "TotalPayments"}],
Cell[360260, 11390, 117, 2, 26, "Output",
  CellTags->"TotalPayments"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[360438, 11399, 907, 34, 62, "Subtitle",
  CellTags->"EffectivePayment"],
Cell[361348, 11435, 118, 2, 14, "Caption",
  CellTags->"EffectivePayment"],
Cell[361469, 11439, 197, 4, 14, "Caption",
  CellTags->"EffectivePayment"],
Cell[361669, 11445, 194, 4, 14, "Caption",
  CellTags->"EffectivePayment"],

Cell[CellGroupData[{
Cell[361888, 11453, 67, 1, 74, "Section",
  CellTags->"EffectivePayment"],
Cell[361958, 11456, 224, 6, 31, "Text",
  CellTags->"EffectivePayment"],
Cell[362185, 11464, 2548, 48, 627, "DefinitionBox",
  CellTags->"EffectivePayment"],
Cell[364736, 11514, 173, 6, 14, "Caption",
  CellTags->"EffectivePayment"],
Cell[364912, 11522, 162, 5, 39, "DefinitionBox",
  CellTags->"EffectivePayment"],
Cell[365077, 11529, 175, 6, 14, "Caption",
  CellTags->"EffectivePayment"],
Cell[365255, 11537, 269, 8, 39, "DefinitionBox",
  CellTags->"EffectivePayment"],
Cell[365527, 11547, 170, 6, 14, "Caption",
  CellTags->"EffectivePayment"],
Cell[365700, 11555, 146, 6, 29, "MathCaption",
  CellTags->"EffectivePayment"],
Cell[365849, 11563, 157, 4, 27, "Input",
  CellTags->"EffectivePayment"],
Cell[366009, 11569, 380, 8, 57, "MathCaption",
  CellTags->"EffectivePayment"],

Cell[CellGroupData[{
Cell[366414, 11581, 566, 14, 27, "Input",
  CellTags->"EffectivePayment"],
Cell[366983, 11597, 1494, 33, 103, "Output",
  CellTags->"EffectivePayment"]
}, Open  ]],
Cell[368492, 11633, 290, 6, 42, "MathCaption",
  CellTags->"EffectivePayment"],

Cell[CellGroupData[{
Cell[368807, 11643, 820, 21, 43, "Input",
  CellTags->"EffectivePayment"],
Cell[369630, 11666, 27389, 806, 186, 6623, 544, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"EffectivePayment"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[397080, 12479, 908, 34, 62, "Subtitle",
  CellTags->"PaymentsRemaining"],
Cell[397991, 12515, 119, 2, 14, "Caption",
  CellTags->"PaymentsRemaining"],
Cell[398113, 12519, 198, 4, 14, "Caption",
  CellTags->"PaymentsRemaining"],
Cell[398314, 12525, 195, 4, 14, "Caption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[398534, 12533, 69, 1, 74, "Section",
  CellTags->"PaymentsRemaining"],
Cell[398606, 12536, 800, 14, 151, "DefinitionBox",
  CellTags->"PaymentsRemaining"],
Cell[399409, 12552, 175, 6, 14, "Caption",
  CellTags->"PaymentsRemaining"],
Cell[399587, 12560, 163, 5, 39, "DefinitionBox",
  CellTags->"PaymentsRemaining"],
Cell[399753, 12567, 177, 6, 14, "Caption",
  CellTags->"PaymentsRemaining"],
Cell[399933, 12575, 270, 8, 39, "DefinitionBox",
  CellTags->"PaymentsRemaining"],
Cell[400206, 12585, 172, 6, 14, "Caption",
  CellTags->"PaymentsRemaining"],
Cell[400381, 12593, 147, 6, 29, "MathCaption",
  CellTags->"PaymentsRemaining"],
Cell[400531, 12601, 158, 4, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[400692, 12607, 159, 4, 30, "Text",
  CellTags->"PaymentsRemaining"],
Cell[400854, 12613, 217, 7, 30, "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[401096, 12624, 240, 6, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[401339, 12632, 102, 2, 26, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],
Cell[401456, 12637, 112, 1, 28, "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[401593, 12642, 389, 10, 43, "Input",
  CellTags->"PaymentsRemaining"],
Cell[401985, 12654, 103, 2, 26, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],
Cell[402103, 12659, 120, 4, 30, "Text",
  CellTags->"PaymentsRemaining"],
Cell[402226, 12665, 133, 4, 28, "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[402384, 12673, 235, 6, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[402622, 12681, 103, 2, 26, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],
Cell[402740, 12686, 230, 5, 46, "Text",
  CellTags->"PaymentsRemaining"],
Cell[402973, 12693, 159, 4, 28, "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[403157, 12701, 243, 6, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[403403, 12709, 151, 4, 43, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],
Cell[403569, 12716, 84, 1, 28, "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[403678, 12721, 185, 4, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[403866, 12727, 102, 2, 26, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],
Cell[403983, 12732, 199, 5, 28, "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[404207, 12741, 181, 4, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[404391, 12747, 147, 4, 26, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],
Cell[404553, 12754, 411, 8, 57, "MathCaption",
  CellTags->"PaymentsRemaining"],

Cell[CellGroupData[{
Cell[404989, 12766, 234, 5, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[405226, 12773, 325, 9, 45, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell[CellGroupData[{
Cell[405588, 12787, 172, 4, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[405763, 12793, 223, 5, 26, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],

Cell[CellGroupData[{
Cell[406023, 12803, 172, 4, 27, "Input",
  CellTags->"PaymentsRemaining"],
Cell[406198, 12809, 104, 2, 26, "Output",
  CellTags->"PaymentsRemaining"]
}, Open  ]],
Cell[406317, 12814, 92, 1, 28, "MathCaption",
  CellTags->"PaymentsRemaining"],
Cell[406412, 12817, 210, 6, 27, "Input",
  CellTags->"PaymentsRemaining"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[406671, 12829, 950, 34, 62, "Subtitle",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[407624, 12865, 161, 2, 14, "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[407788, 12869, 240, 4, 14, "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[408031, 12875, 237, 4, 14, "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{
Cell[408293, 12883, 103, 1, 74, "Section",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[408399, 12886, 236, 5, 31, "Text",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[408638, 12893, 1599, 29, 361, "DefinitionBox",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[410240, 12924, 209, 6, 14, "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[410452, 12932, 205, 5, 39, "DefinitionBox",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[410660, 12939, 211, 6, 14, "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[410874, 12947, 312, 8, 39, "DefinitionBox",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[411189, 12957, 206, 6, 14, "Caption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[411398, 12965, 189, 6, 29, "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[411590, 12973, 200, 4, 27, "Input",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[411793, 12979, 197, 4, 28, "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{
Cell[412015, 12987, 242, 5, 27, "Input",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[412260, 12994, 144, 2, 26, "Output",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]],
Cell[412419, 12999, 180, 4, 28, "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{
Cell[412624, 13007, 287, 5, 27, "Input",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[412914, 13014, 144, 2, 26, "Output",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]],
Cell[413073, 13019, 339, 8, 53, "DefinitionBox",
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
Cell[413415, 13029, 220, 6, 14, "Caption",
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
Cell[413638, 13037, 205, 5, 39, "DefinitionBox",
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
Cell[413846, 13044, 222, 6, 14, "Caption",
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
Cell[414071, 13052, 312, 8, 39, "DefinitionBox",
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
Cell[414386, 13062, 217, 6, 14, "Caption",
  CellTags->{"YearsToPaymentNumber", "Principal", "PaymentNumberToYears"}],
Cell[414606, 13070, 349, 8, 67, "DefinitionBox",
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
Cell[414958, 13080, 220, 6, 14, "Caption",
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
Cell[415181, 13088, 205, 5, 39, "DefinitionBox",
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
Cell[415389, 13095, 222, 6, 14, "Caption",
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
Cell[415614, 13103, 312, 8, 39, "DefinitionBox",
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
Cell[415929, 13113, 217, 6, 14, "Caption",
  CellTags->{"PaymentNumberToYears", "Principal", "YearsToPaymentNumber"}],
Cell[416149, 13121, 205, 4, 28, "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{
Cell[416379, 13129, 288, 5, 27, "Input",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[416670, 13136, 144, 2, 26, "Output",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]],
Cell[416829, 13141, 176, 4, 28, "MathCaption",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],

Cell[CellGroupData[{
Cell[417030, 13149, 471, 11, 27, "Input",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}],
Cell[417504, 13162, 24404, 681, 186, 5485, 442, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"Principal", "YearsToPaymentNumber", "PaymentNumberToYears"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[441969, 13850, 900, 34, 62, "Subtitle",
  CellTags->"HomeValue"],
Cell[442872, 13886, 111, 2, 14, "Caption",
  CellTags->"HomeValue"],
Cell[442986, 13890, 190, 4, 14, "Caption",
  CellTags->"HomeValue"],
Cell[443179, 13896, 187, 4, 14, "Caption",
  CellTags->"HomeValue"],

Cell[CellGroupData[{
Cell[443391, 13904, 53, 1, 74, "Section",
  CellTags->"HomeValue"],
Cell[443447, 13907, 215, 5, 46, "Text",
  CellTags->"HomeValue"],
Cell[443665, 13914, 698, 13, 137, "DefinitionBox",
  CellTags->"HomeValue"],
Cell[444366, 13929, 159, 6, 14, "Caption",
  CellTags->"HomeValue"],
Cell[444528, 13937, 155, 5, 39, "DefinitionBox",
  CellTags->"HomeValue"],
Cell[444686, 13944, 161, 6, 14, "Caption",
  CellTags->"HomeValue"],
Cell[444850, 13952, 262, 8, 39, "DefinitionBox",
  CellTags->"HomeValue"],
Cell[445115, 13962, 156, 6, 14, "Caption",
  CellTags->"HomeValue"],
Cell[445274, 13970, 139, 6, 29, "MathCaption",
  CellTags->"HomeValue"],
Cell[445416, 13978, 150, 4, 27, "Input",
  CellTags->"HomeValue"],
Cell[445569, 13984, 167, 4, 28, "MathCaption",
  CellTags->"HomeValue"],

Cell[CellGroupData[{
Cell[445761, 13992, 169, 4, 27, "Input",
  CellTags->"HomeValue"],
Cell[445933, 13998, 95, 2, 26, "Output",
  CellTags->"HomeValue"]
}, Open  ]],
Cell[446043, 14003, 193, 5, 28, "MathCaption",
  CellTags->"HomeValue"],

Cell[CellGroupData[{
Cell[446261, 14012, 298, 8, 27, "Input",
  CellTags->"HomeValue"],
Cell[446562, 14022, 95, 2, 26, "Output",
  CellTags->"HomeValue"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[446718, 14031, 897, 34, 62, "Subtitle",
  CellTags->"Equity"],
Cell[447618, 14067, 108, 2, 14, "Caption",
  CellTags->"Equity"],
Cell[447729, 14071, 187, 4, 14, "Caption",
  CellTags->"Equity"],
Cell[447919, 14077, 184, 4, 14, "Caption",
  CellTags->"Equity"],

Cell[CellGroupData[{
Cell[448128, 14085, 47, 1, 74, "Section",
  CellTags->"Equity"],
Cell[448178, 14088, 1968, 35, 445, "DefinitionBox",
  CellTags->"Equity"],
Cell[450149, 14125, 153, 6, 14, "Caption",
  CellTags->"Equity"],
Cell[450305, 14133, 152, 5, 39, "DefinitionBox",
  CellTags->"Equity"],
Cell[450460, 14140, 155, 6, 14, "Caption",
  CellTags->"Equity"],
Cell[450618, 14148, 259, 8, 39, "DefinitionBox",
  CellTags->"Equity"],
Cell[450880, 14158, 150, 6, 14, "Caption",
  CellTags->"Equity"],
Cell[451033, 14166, 136, 6, 29, "MathCaption",
  CellTags->"Equity"],
Cell[451172, 14174, 147, 4, 27, "Input",
  CellTags->"Equity"],
Cell[451322, 14180, 283, 6, 42, "MathCaption",
  CellTags->"Equity"],

Cell[CellGroupData[{
Cell[451630, 14190, 362, 9, 27, "Input",
  CellTags->"Equity"],
Cell[451995, 14201, 640, 17, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[452672, 14223, 635, 16, 43, "Input",
  CellTags->"Equity"],
Cell[453310, 14241, 24703, 704, 186, 5636, 463, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[478028, 14948, 85, 1, 28, "MathCaption",
  CellTags->"Equity"],

Cell[CellGroupData[{
Cell[478138, 14953, 654, 16, 43, "Input",
  CellTags->"Equity"],
Cell[478795, 14971, 24894, 728, 186, 6064, 490, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[503750, 15706, 987, 36, 62, "Subtitle",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[504740, 15744, 198, 4, 14, "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[504941, 15750, 277, 6, 14, "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[505221, 15758, 274, 6, 14, "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[505520, 15768, 150, 3, 74, "Section",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[505673, 15773, 2319, 41, 487, "DefinitionBox",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[507995, 15816, 256, 8, 14, "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[508254, 15826, 308, 9, 39, "DefinitionBox",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[508565, 15837, 258, 8, 14, "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[508826, 15847, 349, 10, 39, "DefinitionBox",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[509178, 15859, 253, 8, 14, "Caption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[509434, 15869, 226, 8, 29, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[509663, 15879, 237, 6, 27, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[509903, 15887, 644, 12, 79, "Text",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[510550, 15901, 366, 8, 42, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[510941, 15913, 525, 12, 59, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[511469, 15927, 181, 4, 26, "Output",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],
Cell[511665, 15934, 217, 6, 28, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[511907, 15944, 1547, 37, 121, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[513457, 15983, 22189, 710, 186, 6086, 504, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],
Cell[535661, 16696, 254, 7, 31, "Text",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[535918, 16705, 955, 17, 151, "DefinitionBox",
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[536876, 16724, 253, 8, 14, "Caption",
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[537132, 16734, 242, 7, 39, "DefinitionBox",
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[537377, 16743, 255, 8, 14, "Caption",
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[537635, 16753, 316, 9, 39, "DefinitionBox",
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[537954, 16764, 250, 8, 14, "Caption",
  CellTags->{
  "CalculationBasis", "EquityTargetPayment", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[538207, 16774, 295, 8, 30, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[538527, 16786, 601, 14, 59, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[539131, 16802, 181, 4, 26, "Output",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],
Cell[539327, 16809, 279, 8, 30, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[539631, 16821, 1391, 34, 119, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[541025, 16857, 22416, 714, 186, 6103, 506, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],
Cell[563456, 17574, 246, 6, 28, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[563727, 17584, 698, 17, 75, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[564428, 17603, 182, 4, 26, "Output",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],
Cell[564625, 17610, 250, 6, 28, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[564900, 17620, 1598, 38, 121, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[566501, 17660, 22081, 708, 186, 6088, 504, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]],
Cell[588597, 18371, 305, 9, 53, "DefinitionBox",
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],
Cell[588905, 18382, 244, 8, 14, "Caption",
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],
Cell[589152, 18392, 242, 7, 39, "DefinitionBox",
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],
Cell[589397, 18401, 246, 8, 14, "Caption",
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],
Cell[589646, 18411, 316, 9, 39, "DefinitionBox",
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],
Cell[589965, 18422, 241, 8, 14, "Caption",
  CellTags->{
  "Current", "EquityTargetPayment", "CalculationBasis", "Original", 
    "$EquityFindRootStart"}],
Cell[590209, 18432, 306, 9, 53, "DefinitionBox",
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],
Cell[590518, 18443, 245, 8, 14, "Caption",
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],
Cell[590766, 18453, 242, 7, 39, "DefinitionBox",
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],
Cell[591011, 18462, 247, 8, 14, "Caption",
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],
Cell[591261, 18472, 316, 9, 39, "DefinitionBox",
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],
Cell[591580, 18483, 242, 8, 14, "Caption",
  CellTags->{
  "Original", "EquityTargetPayment", "CalculationBasis", "Current", 
    "$EquityFindRootStart"}],
Cell[591825, 18493, 507, 12, 81, "DefinitionBox",
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],
Cell[592335, 18507, 257, 8, 14, "Caption",
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],
Cell[592595, 18517, 242, 7, 39, "DefinitionBox",
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],
Cell[592840, 18526, 259, 8, 14, "Caption",
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],
Cell[593102, 18536, 259, 7, 39, "DefinitionBox",
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],
Cell[593364, 18545, 254, 8, 14, "Caption",
  CellTags->{
  "$EquityFindRootStart", "EquityTargetPayment", "CalculationBasis", 
    "Current", "Original"}],
Cell[593621, 18555, 248, 7, 30, "MathCaption",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],

Cell[CellGroupData[{
Cell[593894, 18566, 183, 4, 27, "Input",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}],
Cell[594080, 18572, 166, 4, 26, "Output",
  CellTags->{
  "EquityTargetPayment", "CalculationBasis", "Current", "Original", 
    "$EquityFindRootStart"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[594307, 18583, 977, 36, 62, "Subtitle",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[595287, 18621, 188, 4, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[595478, 18627, 267, 6, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[595748, 18635, 264, 6, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[596037, 18645, 135, 3, 74, "Section",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[596175, 18650, 348, 11, 48, "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[596526, 18663, 895, 17, 151, "DefinitionBox",
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[597424, 18682, 241, 8, 14, "Caption",
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[597668, 18692, 232, 7, 39, "DefinitionBox",
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[597903, 18701, 243, 8, 14, "Caption",
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[598149, 18711, 284, 8, 39, "DefinitionBox",
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[598436, 18721, 238, 8, 14, "Caption",
  CellTags->{
  "$ErrorChecking", "SetErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[598677, 18731, 778, 15, 137, "DefinitionBox",
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],
Cell[599458, 18748, 247, 8, 14, "Caption",
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],
Cell[599708, 18758, 232, 7, 39, "DefinitionBox",
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],
Cell[599943, 18767, 249, 8, 14, "Caption",
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],
Cell[600195, 18777, 284, 8, 39, "DefinitionBox",
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],
Cell[600482, 18787, 244, 8, 14, "Caption",
  CellTags->{
  "$StrongErrorChecking", "SetErrorChecking", "$ErrorChecking", 
    "Error Checking"}],
Cell[600729, 18797, 216, 8, 29, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[600948, 18807, 227, 6, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[601178, 18815, 323, 11, 31, "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[601504, 18828, 637, 13, 109, "DefinitionBox",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[602144, 18843, 243, 8, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[602390, 18853, 232, 7, 39, "DefinitionBox",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[602625, 18862, 245, 8, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[602873, 18872, 306, 9, 39, "DefinitionBox",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[603182, 18883, 240, 8, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[603425, 18893, 271, 9, 29, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[603721, 18906, 193, 5, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[603917, 18913, 214, 6, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[604146, 18922, 1177, 30, 114, "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[605326, 18954, 234, 7, 31, "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[605563, 18963, 1634, 32, 347, "DefinitionBox",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[607200, 18997, 234, 8, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[607437, 19007, 232, 7, 39, "DefinitionBox",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[607672, 19016, 236, 8, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[607911, 19026, 339, 10, 39, "DefinitionBox",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[608253, 19038, 231, 8, 14, "Caption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[608487, 19048, 324, 9, 43, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[608836, 19061, 308, 9, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[609147, 19072, 869, 25, 63, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[610031, 19100, 350, 9, 43, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[610406, 19113, 526, 14, 59, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[610935, 19129, 907, 25, 61, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[611857, 19157, 286, 9, 29, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[612168, 19170, 232, 6, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[612403, 19178, 213, 6, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[612653, 19189, 308, 9, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[612964, 19200, 384, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[613351, 19211, 384, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[613738, 19222, 869, 25, 63, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[614622, 19250, 306, 7, 43, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[614953, 19261, 341, 10, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[615297, 19273, 384, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[615684, 19284, 384, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[616071, 19295, 209, 5, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[616295, 19303, 425, 14, 44, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[616745, 19321, 233, 6, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[616981, 19329, 214, 6, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[617232, 19340, 342, 10, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[617577, 19352, 385, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[617965, 19363, 334, 10, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[618314, 19376, 172, 3, 28, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[618511, 19383, 309, 9, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[618823, 19394, 385, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[619211, 19405, 300, 9, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[619526, 19417, 144, 3, 28, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[619673, 19422, 204, 5, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[619880, 19429, 200, 6, 28, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[620105, 19439, 194, 5, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[620302, 19446, 215, 6, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[620532, 19455, 409, 10, 48, "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[620944, 19467, 287, 7, 30, "Text",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[621234, 19476, 170, 3, 28, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[621429, 19483, 836, 22, 43, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[622268, 19507, 613, 17, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[622896, 19527, 226, 6, 28, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[623147, 19537, 484, 14, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[623634, 19553, 35920, 1373, 186, 16321, 1124, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[659569, 20929, 510, 12, 68, "Commentary",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[660082, 20943, 303, 8, 29, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[660410, 20955, 585, 15, 43, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[660998, 20972, 61042, 1828, 186, 18963, 1302, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[722055, 22803, 414, 14, 43, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[722494, 22821, 238, 6, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[722735, 22829, 214, 6, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[722986, 22840, 585, 15, 43, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[723574, 22857, 387, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[723964, 22868, 385, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[724352, 22879, 387, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[724742, 22890, 374, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[725119, 22901, 61042, 1828, 186, 18963, 1302, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],
Cell[786176, 24732, 1188, 45, 61, "MathCaption",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],

Cell[CellGroupData[{
Cell[787389, 24781, 237, 6, 27, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[787629, 24789, 213, 6, 26, "Output",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[787879, 24800, 585, 15, 43, "Input",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[788467, 24817, 387, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[788857, 24828, 385, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[789245, 24839, 414, 10, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[789662, 24851, 385, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[790050, 24862, 374, 9, 39, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[790427, 24873, 400, 10, 23, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[790830, 24885, 395, 10, 23, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[791228, 24897, 395, 10, 23, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[791626, 24909, 360, 9, 23, "Message",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}],
Cell[791989, 24920, 19165, 541, 186, 4359, 351, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{
  "SetErrorChecking", "$ErrorChecking", "$StrongErrorChecking", 
    "Error Checking"}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[811215, 25468, 919, 34, 62, "Subtitle",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[812137, 25504, 130, 2, 14, "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[812270, 25508, 209, 4, 14, "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[812482, 25514, 206, 4, 14, "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[CellGroupData[{
Cell[812713, 25522, 91, 1, 74, "Section",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[812807, 25525, 217, 7, 39, "DefinitionBox",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[813027, 25534, 197, 6, 14, "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[813227, 25542, 174, 5, 39, "DefinitionBox",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[813404, 25549, 199, 6, 14, "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[813606, 25557, 248, 7, 39, "DefinitionBox",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[813857, 25566, 194, 6, 14, "Caption",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[814054, 25574, 158, 6, 29, "MathCaption",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[814215, 25582, 169, 4, 27, "Input",
  CellTags->"$LoanFunctionsPackageVersion"],

Cell[CellGroupData[{
Cell[814409, 25590, 122, 2, 27, "Input",
  CellTags->"$LoanFunctionsPackageVersion"],
Cell[814534, 25594, 99, 2, 26, "Output",
  CellTags->"$LoanFunctionsPackageVersion"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[814694, 25603, 909, 34, 62, "Subtitle",
  CellTags->"AmortizationReport"],
Cell[815606, 25639, 120, 2, 14, "Caption",
  CellTags->"AmortizationReport"],
Cell[815729, 25643, 199, 4, 14, "Caption",
  CellTags->"AmortizationReport"],
Cell[815931, 25649, 196, 4, 14, "Caption",
  CellTags->"AmortizationReport"],

Cell[CellGroupData[{
Cell[816152, 25657, 71, 1, 74, "Section",
  CellTags->"AmortizationReport"],
Cell[816226, 25660, 224, 5, 31, "Text",
  CellTags->"AmortizationReport"],
Cell[816453, 25667, 856, 16, 165, "DefinitionBox",
  CellTags->"AmortizationReport"],
Cell[817312, 25685, 177, 6, 14, "Caption",
  CellTags->"AmortizationReport"],
Cell[817492, 25693, 164, 5, 39, "DefinitionBox",
  CellTags->"AmortizationReport"],
Cell[817659, 25700, 179, 6, 14, "Caption",
  CellTags->"AmortizationReport"],
Cell[817841, 25708, 177, 5, 39, "DefinitionBox",
  CellTags->"AmortizationReport"],
Cell[818021, 25715, 174, 6, 14, "Caption",
  CellTags->"AmortizationReport"],
Cell[818198, 25723, 169, 5, 30, "MathCaption",
  CellTags->"AmortizationReport"],

Cell[CellGroupData[{
Cell[818392, 25732, 321, 8, 27, "Input",
  CellTags->"AmortizationReport"],
Cell[818716, 25742, 359, 10, 26, "Output",
  CellTags->"AmortizationReport"]
}, Open  ]],
Cell[819090, 25755, 130, 4, 28, "MathCaption",
  CellTags->"AmortizationReport"]
}, Open  ]],

Cell[CellGroupData[{
Cell[819257, 25764, 117, 3, 74, "Section",
  CellTags->"AmortizationReport"],
Cell[819377, 25769, 105, 1, 30, "Text",
  CellTags->"AmortizationReport"],
Cell[819485, 25772, 496, 16, 83, "Text",
  CellTags->"AmortizationReport"],
Cell[819984, 25790, 40252, 1001, 553, "Text",
  CellTags->"AmortizationReport"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[860285, 26797, 73, 1, 52, "Subtitle",
  CellTags->"$CalculatorBackgroundColor"],
Cell[860361, 26800, 917, 34, 62, "Subtitle",
  CellTags->"$CalculatorBackgroundColor"],
Cell[861281, 26836, 128, 2, 14, "Caption",
  CellTags->"$CalculatorBackgroundColor"],
Cell[861412, 26840, 207, 4, 14, "Caption",
  CellTags->"$CalculatorBackgroundColor"],
Cell[861622, 26846, 204, 4, 14, "Caption",
  CellTags->"$CalculatorBackgroundColor"],

Cell[CellGroupData[{
Cell[861851, 26854, 87, 1, 74, "Section",
  CellTags->"$CalculatorBackgroundColor"],
Cell[861941, 26857, 269, 7, 65, "DefinitionBox",
  CellTags->"$CalculatorBackgroundColor"],
Cell[862213, 26866, 193, 6, 26, "Caption",
  CellTags->"$CalculatorBackgroundColor"],
Cell[862409, 26874, 172, 5, 51, "DefinitionBox",
  CellTags->"$CalculatorBackgroundColor"],
Cell[862584, 26881, 195, 6, 26, "Caption",
  CellTags->"$CalculatorBackgroundColor"],
Cell[862782, 26889, 189, 5, 51, "DefinitionBox",
  CellTags->"$CalculatorBackgroundColor"],
Cell[862974, 26896, 190, 6, 26, "Caption",
  CellTags->"$CalculatorBackgroundColor"],
Cell[863167, 26904, 156, 6, 41, "MathCaption",
  CellTags->"$CalculatorBackgroundColor"],
Cell[863326, 26912, 167, 4, 39, "Input",
  CellTags->"$CalculatorBackgroundColor"],
Cell[863496, 26918, 148, 4, 40, "MathCaption",
  CellTags->"$CalculatorBackgroundColor"],

Cell[CellGroupData[{
Cell[863669, 26926, 118, 2, 39, "Input",
  CellTags->"$CalculatorBackgroundColor"],
Cell[863790, 26930, 132, 3, 26, "Output",
  CellTags->"$CalculatorBackgroundColor"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[863983, 26940, 907, 34, 62, "Subtitle",
  CellTags->"EquityCalculator"],
Cell[864893, 26976, 118, 2, 14, "Caption",
  CellTags->"EquityCalculator"],
Cell[865014, 26980, 197, 4, 14, "Caption",
  CellTags->"EquityCalculator"],
Cell[865214, 26986, 194, 4, 14, "Caption",
  CellTags->"EquityCalculator"],

Cell[CellGroupData[{
Cell[865433, 26994, 67, 1, 74, "Section",
  CellTags->"EquityCalculator"],
Cell[865503, 26997, 250, 7, 53, "DefinitionBox",
  CellTags->"EquityCalculator"],
Cell[865756, 27006, 173, 6, 14, "Caption",
  CellTags->"EquityCalculator"],
Cell[865932, 27014, 162, 5, 39, "DefinitionBox",
  CellTags->"EquityCalculator"],
Cell[866097, 27021, 175, 6, 14, "Caption",
  CellTags->"EquityCalculator"],
Cell[866275, 27029, 236, 7, 39, "DefinitionBox",
  CellTags->"EquityCalculator"],
Cell[866514, 27038, 170, 6, 14, "Caption",
  CellTags->"EquityCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[866733, 27050, 910, 34, 62, "Subtitle",
  CellTags->"HomeValueCalculator"],
Cell[867646, 27086, 121, 2, 14, "Caption",
  CellTags->"HomeValueCalculator"],
Cell[867770, 27090, 200, 4, 14, "Caption",
  CellTags->"HomeValueCalculator"],
Cell[867973, 27096, 197, 4, 14, "Caption",
  CellTags->"HomeValueCalculator"],

Cell[CellGroupData[{
Cell[868195, 27104, 73, 1, 74, "Section",
  CellTags->"HomeValueCalculator"],
Cell[868271, 27107, 265, 8, 53, "DefinitionBox",
  CellTags->"HomeValueCalculator"],
Cell[868539, 27117, 179, 6, 14, "Caption",
  CellTags->"HomeValueCalculator"],
Cell[868721, 27125, 165, 5, 39, "DefinitionBox",
  CellTags->"HomeValueCalculator"],
Cell[868889, 27132, 181, 6, 14, "Caption",
  CellTags->"HomeValueCalculator"],
Cell[869073, 27140, 239, 7, 39, "DefinitionBox",
  CellTags->"HomeValueCalculator"],
Cell[869315, 27149, 176, 6, 14, "Caption",
  CellTags->"HomeValueCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[869540, 27161, 908, 34, 62, "Subtitle",
  CellTags->"PaymentCalculator"],
Cell[870451, 27197, 119, 2, 26, "Caption",
  CellTags->"PaymentCalculator"],
Cell[870573, 27201, 198, 4, 26, "Caption",
  CellTags->"PaymentCalculator"],
Cell[870774, 27207, 195, 4, 26, "Caption",
  CellTags->"PaymentCalculator"],

Cell[CellGroupData[{
Cell[870994, 27215, 69, 1, 86, "Section",
  CellTags->"PaymentCalculator"],
Cell[871066, 27218, 306, 8, 79, "DefinitionBox",
  CellTags->"PaymentCalculator"],
Cell[871375, 27228, 175, 6, 26, "Caption",
  CellTags->"PaymentCalculator"],
Cell[871553, 27236, 163, 5, 51, "DefinitionBox",
  CellTags->"PaymentCalculator"],
Cell[871719, 27243, 177, 6, 26, "Caption",
  CellTags->"PaymentCalculator"],
Cell[871899, 27251, 237, 7, 51, "DefinitionBox",
  CellTags->"PaymentCalculator"],
Cell[872139, 27260, 172, 6, 26, "Caption",
  CellTags->"PaymentCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[872360, 27272, 918, 34, 74, "Subtitle",
  CellTags->"PaymentsRemainingCalculator"],
Cell[873281, 27308, 129, 2, 26, "Caption",
  CellTags->"PaymentsRemainingCalculator"],
Cell[873413, 27312, 208, 4, 26, "Caption",
  CellTags->"PaymentsRemainingCalculator"],
Cell[873624, 27318, 205, 4, 26, "Caption",
  CellTags->"PaymentsRemainingCalculator"],

Cell[CellGroupData[{
Cell[873854, 27326, 89, 1, 86, "Section",
  CellTags->"PaymentsRemainingCalculator"],
Cell[873946, 27329, 297, 8, 65, "DefinitionBox",
  CellTags->"PaymentsRemainingCalculator"],
Cell[874246, 27339, 195, 6, 26, "Caption",
  CellTags->"PaymentsRemainingCalculator"],
Cell[874444, 27347, 173, 5, 51, "DefinitionBox",
  CellTags->"PaymentsRemainingCalculator"],
Cell[874620, 27354, 197, 6, 26, "Caption",
  CellTags->"PaymentsRemainingCalculator"],
Cell[874820, 27362, 247, 7, 51, "DefinitionBox",
  CellTags->"PaymentsRemainingCalculator"],
Cell[875070, 27371, 192, 6, 26, "Caption",
  CellTags->"PaymentsRemainingCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[875311, 27383, 910, 34, 74, "Subtitle",
  CellTags->"PrincipalCalculator"],
Cell[876224, 27419, 121, 2, 26, "Caption",
  CellTags->"PrincipalCalculator"],
Cell[876348, 27423, 200, 4, 26, "Caption",
  CellTags->"PrincipalCalculator"],
Cell[876551, 27429, 197, 4, 26, "Caption",
  CellTags->"PrincipalCalculator"],

Cell[CellGroupData[{
Cell[876773, 27437, 73, 1, 86, "Section",
  CellTags->"PrincipalCalculator"],
Cell[876849, 27440, 259, 7, 65, "DefinitionBox",
  CellTags->"PrincipalCalculator"],
Cell[877111, 27449, 179, 6, 26, "Caption",
  CellTags->"PrincipalCalculator"],
Cell[877293, 27457, 165, 5, 51, "DefinitionBox",
  CellTags->"PrincipalCalculator"],
Cell[877461, 27464, 181, 6, 26, "Caption",
  CellTags->"PrincipalCalculator"],
Cell[877645, 27472, 239, 7, 51, "DefinitionBox",
  CellTags->"PrincipalCalculator"],
Cell[877887, 27481, 176, 6, 26, "Caption",
  CellTags->"PrincipalCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[878112, 27493, 914, 34, 74, "Subtitle",
  CellTags->"TotalPaymentsCalculator"],
Cell[879029, 27529, 125, 2, 26, "Caption",
  CellTags->"TotalPaymentsCalculator"],
Cell[879157, 27533, 204, 4, 26, "Caption",
  CellTags->"TotalPaymentsCalculator"],
Cell[879364, 27539, 201, 4, 26, "Caption",
  CellTags->"TotalPaymentsCalculator"],

Cell[CellGroupData[{
Cell[879590, 27547, 81, 1, 86, "Section",
  CellTags->"TotalPaymentsCalculator"],
Cell[879674, 27550, 324, 8, 79, "DefinitionBox",
  CellTags->"TotalPaymentsCalculator"],
Cell[880001, 27560, 187, 6, 26, "Caption",
  CellTags->"TotalPaymentsCalculator"],
Cell[880191, 27568, 169, 5, 51, "DefinitionBox",
  CellTags->"TotalPaymentsCalculator"],
Cell[880363, 27575, 189, 6, 26, "Caption",
  CellTags->"TotalPaymentsCalculator"],
Cell[880555, 27583, 243, 7, 51, "DefinitionBox",
  CellTags->"TotalPaymentsCalculator"],
Cell[880801, 27592, 184, 6, 26, "Caption",
  CellTags->"TotalPaymentsCalculator"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[881034, 27604, 66, 1, 64, "Subtitle",
  CellTags->"Loan Functions Palette"],
Cell[881103, 27607, 913, 34, 74, "Subtitle",
  CellTags->"Loan Functions Palette"],
Cell[882019, 27643, 124, 2, 26, "Caption",
  CellTags->"Loan Functions Palette"],
Cell[882146, 27647, 203, 4, 26, "Caption",
  CellTags->"Loan Functions Palette"],
Cell[882352, 27653, 200, 4, 26, "Caption",
  CellTags->"Loan Functions Palette"],

Cell[CellGroupData[{
Cell[882577, 27661, 79, 1, 86, "Section",
  CellTags->"Loan Functions Palette"],
Cell[882659, 27664, 624, 15, 66, "Text",
  CellTags->"Loan Functions Palette"],
Cell[883286, 27681, 11488, 302, 496, NotebookDefault,
  CellGroupingRules->"OutputGrouping",
  PageBreakAbove->True,
  PageBreakWithin->False,
  CounterIncrements->"Output",
  CellTags->"Loan Functions Palette"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[894823, 27989, 915, 34, 74, "Subtitle",
  CellTags->"Loan Calculators Palette"],
Cell[895741, 28025, 126, 2, 26, "Caption",
  CellTags->"Loan Calculators Palette"],
Cell[895870, 28029, 205, 4, 26, "Caption",
  CellTags->"Loan Calculators Palette"],
Cell[896078, 28035, 202, 4, 26, "Caption",
  CellTags->"Loan Calculators Palette"],

Cell[CellGroupData[{
Cell[896305, 28043, 83, 1, 86, "Section",
  CellTags->"Loan Calculators Palette"],
Cell[896391, 28046, 636, 15, 66, "Text",
  CellTags->"Loan Calculators Palette"],
Cell[897030, 28063, 3062, 83, 142, NotebookDefault,
  CellGroupingRules->"OutputGrouping",
  PageBreakAbove->True,
  PageBreakWithin->False,
  CounterIncrements->"Output",
  CellTags->"Loan Calculators Palette"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

