(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10841,        301]*)
(*NotebookOutlinePosition[     16070,        428]*)
(*  CellTagsIndexPosition[     15816,        418]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Sc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.700008, 0, 0]],
  StyleBox["ie",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.8, 0.4, 0]],
  StyleBox["nt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0.6, 0]],
  StyleBox["if",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.2, 0.4, 0.2]],
  StyleBox["ic",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Ar",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.4, 0, 0.6]],
  StyleBox["ts",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.500008, 0.2, 0.500008]]
}], "Subtitle",
  PageWidth->PaperWidth,
  CellFrame->{{0, 0}, {0, 2}},
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell["Copyright \[Copyright] 1999 by David Reiss, all rights reserved. ", \
"Caption",
  PageWidth->PaperWidth,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[ButtonBox["http://www.scientificarts.com/",
  ButtonData:>{
    URL[ "http://www.scientificarts.com/"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  PageWidth->PaperWidth,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell[TextData[ButtonBox["dreiss@scientificarts.com",
  ButtonData:>{
    URL[ "mailto:dreiss@scientificarts.com"], None},
  ButtonStyle->"Hyperlink"]], "Caption",
  PageWidth->PaperWidth,
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],

Cell["ReadMe File for the LoanFunctions.m Package", "Section",
  PageWidth->PaperWidth],

Cell["LoanFunctions.m Package", "Subsection"],

Cell["\<\
LoanFunctions.m is a package containing functions that help in \
calculations of certain loan costs: for estimating home purchase costs and \
performing other loan calculations. Its original intent was to provide \
functions that perform cost calculations for the purchase of a single family \
home; however, the functions are somewhat more general than that and can \
therefore be used in a variety of other situations. \
\>", "Text",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "The assumptions used in this package are that the payment periods are \
equal in length and that interest is compounded once per payment period at \
the end of that period. If you are making payments on a loan that, for \
example,  is compounded once per month based on the ",
  StyleBox["number of days in that month",
    FontSlant->"Italic"],
  " then the functions in this package will give results that are slightly \
different than those that correspond to such a circumstance."
}], "Text",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["\<\
WARNING: The author is not liable for any errors or omissions. For \
your decisions you should contact a finance professional for professional \
advice and to obtain the actual information that you use in your decision \
making process. The intent of this package is to provide some simple tools \
for making initial estimates, for creatively exploring options, and as a \
starting point for the creation of functions tailored to an individual's \
specific needs. 

THE AUTHOR, DAVID REISS SHALL NOT BE RESPONSIBLE UNDER ANY CIRCUMSTANCES FOR \
PROVIDING INFORMATION ON OR CORRECTIONS TO ERRORS AND OMISSIONS DISCOVERED AT \
ANY TIME IN LOANFUNCTIONS.M OR ITS ASSOCIATED DOCUMENTATION, WHETHER OR NOT \
HE IS AWARE OF THE ERRORS OR OMISSIONS. THE AUTHOR DOES NOT RECOMMEND THE USE \
OF LOANFUNCTIONS.M OR ITS ASSOCIATED DOCUMENTATION FOR APPLICATIONS IN WHICH \
ERRORS OR OMISSIONS COULD THREATEN LIFE, INJURY OR SIGNIFICANT LOSS.\
\>", \
"DefinitionBox",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["Referralware", "Subsection",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "This package is \"referralware\": if the package is of use to you then you \
are requested to suggest the services of ",
  ButtonBox["Scientific Arts",
    ButtonData:>{
      URL[ "http://www.scientificarts.com"], None},
    ButtonStyle->"Hyperlink"],
  " to friends and colleagues and to pass on potential contacts to ",
  StyleBox["Scientific Arts",
    FontSlant->"Italic"],
  ". In this case ",
  StyleBox["Scientific Arts",
    FontSlant->"Italic"],
  " provides you with a single user license for this software in return for \
the help that you can give in helping our business to succeed."
}], "Text",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["Installing the Package", "Subsection",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "To install the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package place the folder ",
  StyleBox["LoanFunctions", "MR"],
  " within the ",
  StyleBox["AddOns\[RightTriangle]Applications", "SR"],
  " subdirectory of your main ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory. After you have done this, start ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (if it has already been started, quit it first and restart) and then \
choose the ",
  StyleBox["Help\[RightTriangle]Rebuild Help Index", "SR"],
  " menu item.  In the Help Browser you will now have access to the \
documentation for the ",
  StyleBox["LoanFunctions.m", "MR"],
  "  package under the ",
  StyleBox["AddOns", "SR"],
  " category. To be able to use the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package you will need a password."
}], "Text",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell["Password", "Subsection",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],

Cell[TextData[{
  "To use the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package you need a password. When you first try to load the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package you will be prompted for a password. A password can be obtained \
by sending email to ",
  StyleBox["loanpassword@scientificarts.com",
    FontColor->RGBColor[0.6, 0, 0]],
  ". The password will allow you to use the package with a single license of \
Mathematica. Your email address will not be used for any other purpose than \
to send you the password and an associated message. You will not be contacted \
further unless you request it. Your email should contain your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  License ID. You can find out what your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " License ID is by executing ",
  StyleBox["$LicenseID", "MR"],
  " from within a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. (Note that your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " License ID is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the same as your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " password and we do not request your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " password. Your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " License ID stays the same even if you upgrade ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to a new version. Your ",
  StyleBox["LoanFunctions.m", "MR"],
  " password therefore will still be valid should you upgrade to a newer \
version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".)  Once you have obtained your password it should be pasted into the \
dialogue box that prompts you for a password when the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package is first loaded. The password only needs to be entered once and \
will automatically be placed in a file named ",
  StyleBox["LFPassword.m", "MR"],
  " located in the ",
  StyleBox["AddOns\[RightTriangle]Applications\[RightTriangle]LoanFunctions", 
    "SR"],
  " subdirectory of your main ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory (assuming that you have installed the ",
  StyleBox["LoanFunctions.m", "MR"],
  " package as per the instructions in the preceding section). (Alternatively \
you can create a file named ",
  StyleBox["LFPassword.m", "MR"],
  " from within a text editor place the password in it and place it in the ",
  StyleBox["AddOns\[RightTriangle]Applications\[RightTriangle]LoanFunctions", 
    "SR"],
  " subdirectory of your main ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory). Once you have entered the password the ",
  StyleBox["LoanFunctions.m", "MR"],
  "  package will be operational."
}], "Text",
  PageWidth->PaperWidth,
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"EditBar",
WindowSize->{635, 594},
WindowMargins->{{169, Automatic}, {Automatic, 27}},
CellLabelAutoDelete->True,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "$PaymentsPerYear"->{
    Cell[1739, 51, 1003, 37, 76, "Subtitle",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[2745, 90, 214, 5, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[2962, 97, 293, 7, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[3258, 106, 290, 7, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}]},
  "TemporarySetPaymentsPerYear"->{
    Cell[1739, 51, 1003, 37, 76, "Subtitle",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[2745, 90, 214, 5, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[2962, 97, 293, 7, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[3258, 106, 290, 7, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}]},
  "ResetLoanFunctionsDefaults"->{
    Cell[1739, 51, 1003, 37, 76, "Subtitle",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[2745, 90, 214, 5, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[2962, 97, 293, 7, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}],
    Cell[3258, 106, 290, 7, 15, "Caption",
      CellTags->{
      "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
        "ResetLoanFunctionsDefaults"}]},
  "LoanFunctions"->{
    Cell[3689, 120, 531, 9, 78, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[4223, 131, 601, 11, 80, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[4827, 144, 1051, 18, 221, "DefinitionBox",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[5881, 164, 120, 2, 36, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6004, 168, 714, 17, 68, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6721, 187, 130, 2, 36, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6854, 191, 949, 26, 100, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7806, 219, 116, 2, 36, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7925, 223, 2900, 75, 313, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]},
  "LoanFunctions Introduction"->{
    Cell[3689, 120, 531, 9, 78, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[4223, 131, 601, 11, 80, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[4827, 144, 1051, 18, 221, "DefinitionBox",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[5881, 164, 120, 2, 36, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6004, 168, 714, 17, 68, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6721, 187, 130, 2, 36, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[6854, 191, 949, 26, 100, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7806, 219, 116, 2, 36, "Subsection",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
    Cell[7925, 223, 2900, 75, 313, "Text",
      CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"$PaymentsPerYear", 11772, 325},
  {"TemporarySetPaymentsPerYear", 12444, 342},
  {"ResetLoanFunctionsDefaults", 13115, 359},
  {"LoanFunctions", 13773, 376},
  {"LoanFunctions Introduction", 14799, 395}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 1003, 37, 76, "Subtitle",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[2745, 90, 214, 5, 15, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[2962, 97, 293, 7, 15, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[3258, 106, 290, 7, 15, "Caption",
  CellTags->{
  "$PaymentsPerYear", "TemporarySetPaymentsPerYear", 
    "ResetLoanFunctionsDefaults"}],
Cell[3551, 115, 87, 1, 52, "Section"],
Cell[3641, 118, 45, 0, 36, "Subsection"],
Cell[3689, 120, 531, 9, 78, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[4223, 131, 601, 11, 80, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[4827, 144, 1051, 18, 221, "DefinitionBox",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[5881, 164, 120, 2, 36, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[6004, 168, 714, 17, 68, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[6721, 187, 130, 2, 36, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[6854, 191, 949, 26, 100, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[7806, 219, 116, 2, 36, "Subsection",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}],
Cell[7925, 223, 2900, 75, 313, "Text",
  CellTags->{"LoanFunctions", "LoanFunctions Introduction"}]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

